--[[
-- For all Indents and Purposes
-- Copyright (c) 2007 Kristofer Karlsson <kristofer.karlsson@gmail.com>
--
-- Permission is hereby granted, free of charge, to any person obtaining a copy
-- of this software and associated documentation files (the "Software"), to deal
-- in the Software without restriction, including without limitation the rights
-- to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-- copies of the Software, and to permit persons to whom the Software is
-- furnished to do so, subject to the following conditions:
-- 
-- The above copyright notice and this permission notice shall be included in
-- all copies or substantial portions of the Software.
-- 
-- THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-- IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-- FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-- AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-- LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-- OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-- THE SOFTWARE.
--]]

-- For All Indents And Purposes -
-- a indentation + syntax highlighting library
-- All valid lua code should be processed correctly.

-- For both variants:
-- 2) hook the editboxes that you want to have indentation like this:
-- IndentationLib.enable(editbox [, colorTable [, tabWidth] ])
-- if you don't select a color table, it will use the default.
-- Read through this code for further usage help.
-- (The documentation IS the code)

-- Lots of keywords added by Bill Lafreniere 10/13/2013

IndentationLib = {}

local lib = IndentationLib
lib.revision = revision

local stringlen = string.len
local stringformat = string.format
local stringfind = string.find
local stringsub = string.sub
local stringbyte = string.byte
local stringchar = string.char
local stringrep = string.rep
local stringgsub = string.gsub

local workingTable = {}
local workingTable2 = {}
local function tableclear(t)
	for k in next,t do
		t[k] = nil
	end
end

local function stringinsert(s, pos, insertStr)
	return stringsub(s, 1, pos) .. insertStr .. stringsub(s, pos + 1)
end
lib.stringinsert = stringinsert

local function stringdelete(s, pos1, pos2)
	return stringsub(s, 1, pos1 - 1) .. stringsub(s, pos2 + 1)
end
lib.stringdelete = stringdelete

-- token types
local tokens = {}
lib.tokens = tokens

tokens.TOKEN_UNKNOWN = 0
tokens.TOKEN_NUMBER = 1
tokens.TOKEN_LINEBREAK = 2
tokens.TOKEN_WHITESPACE = 3
tokens.TOKEN_IDENTIFIER = 4
tokens.TOKEN_ASSIGNMENT = 5
tokens.TOKEN_EQUALITY = 6
tokens.TOKEN_MINUS = 7
tokens.TOKEN_COMMENT_SHORT = 8
tokens.TOKEN_COMMENT_LONG = 9
tokens.TOKEN_STRING = 10
tokens.TOKEN_LEFTBRACKET = 11
tokens.TOKEN_PERIOD = 12
tokens.TOKEN_DOUBLEPERIOD = 13
tokens.TOKEN_TRIPLEPERIOD = 14
tokens.TOKEN_LTE = 15
tokens.TOKEN_LT = 16
tokens.TOKEN_GTE = 17
tokens.TOKEN_GT = 18
tokens.TOKEN_NOTEQUAL = 19
tokens.TOKEN_COMMA = 20
tokens.TOKEN_SEMICOLON = 21
tokens.TOKEN_COLON = 22
tokens.TOKEN_LEFTPAREN = 23
tokens.TOKEN_RIGHTPAREN = 24
tokens.TOKEN_PLUS = 25
tokens.TOKEN_SLASH = 27
tokens.TOKEN_LEFTWING = 28
tokens.TOKEN_RIGHTWING = 29
tokens.TOKEN_CIRCUMFLEX = 30
tokens.TOKEN_ASTERISK = 31
tokens.TOKEN_RIGHTBRACKET = 32
tokens.TOKEN_KEYWORD = 33
tokens.TOKEN_SPECIAL = 34
tokens.TOKEN_VERTICAL = 35
tokens.TOKEN_TILDE = 36

-- WoW specific tokens
tokens.TOKEN_COLORCODE_START = 37
tokens.TOKEN_COLORCODE_STOP = 38

-- new as of lua 5.1
tokens.TOKEN_HASH = 39
tokens.TOKEN_PERCENT = 40


-- ascii codes
local bytes = {}
lib.bytes = bytes
bytes.BYTE_LINEBREAK_UNIX = stringbyte("\n")
bytes.BYTE_LINEBREAK_MAC = stringbyte("\r")
bytes.BYTE_SINGLE_QUOTE = stringbyte("'")
bytes.BYTE_DOUBLE_QUOTE = stringbyte('"')
bytes.BYTE_0 = stringbyte("0")
bytes.BYTE_9 = stringbyte("9")
bytes.BYTE_PERIOD = stringbyte(".")
bytes.BYTE_SPACE = stringbyte(" ")
bytes.BYTE_TAB = stringbyte("\t")
bytes.BYTE_E = stringbyte("E")
bytes.BYTE_e = stringbyte("e")
bytes.BYTE_MINUS = stringbyte("-")
bytes.BYTE_EQUALS = stringbyte("=")
bytes.BYTE_LEFTBRACKET = stringbyte("[")
bytes.BYTE_RIGHTBRACKET = stringbyte("]")
bytes.BYTE_BACKSLASH = stringbyte("\\")
bytes.BYTE_COMMA = stringbyte(",")
bytes.BYTE_SEMICOLON = stringbyte(";")
bytes.BYTE_COLON = stringbyte(":")
bytes.BYTE_LEFTPAREN = stringbyte("(")
bytes.BYTE_RIGHTPAREN = stringbyte(")")
bytes.BYTE_TILDE = stringbyte("~")
bytes.BYTE_PLUS = stringbyte("+")
bytes.BYTE_SLASH = stringbyte("/")
bytes.BYTE_LEFTWING = stringbyte("{")
bytes.BYTE_RIGHTWING = stringbyte("}")
bytes.BYTE_CIRCUMFLEX = stringbyte("^")
bytes.BYTE_ASTERISK = stringbyte("*")
bytes.BYTE_LESSTHAN = stringbyte("<")
bytes.BYTE_GREATERTHAN = stringbyte(">")
-- WoW specific chars
bytes.BYTE_VERTICAL = stringbyte("|")
bytes.BYTE_r = stringbyte("r")
bytes.BYTE_c = stringbyte("c")

-- new as of lua 5.1
bytes.BYTE_HASH = stringbyte("#")
bytes.BYTE_PERCENT = stringbyte("%")


local linebreakCharacters = {}
lib.linebreakCharacters = linebreakCharacters
linebreakCharacters[bytes.BYTE_LINEBREAK_UNIX] = 1
linebreakCharacters[bytes.BYTE_LINEBREAK_MAC] = 1

local whitespaceCharacters = {}
lib.whitespaceCharacters = whitespaceCharacters
whitespaceCharacters[bytes.BYTE_SPACE] = 1
whitespaceCharacters[bytes.BYTE_TAB] = 1

local specialCharacters = {}
lib.specialCharacters = specialCharacters
specialCharacters[bytes.BYTE_PERIOD] = -1
specialCharacters[bytes.BYTE_LESSTHAN] = -1
specialCharacters[bytes.BYTE_GREATERTHAN] = -1
specialCharacters[bytes.BYTE_LEFTBRACKET] = -1
specialCharacters[bytes.BYTE_EQUALS] = -1
specialCharacters[bytes.BYTE_MINUS] = -1
specialCharacters[bytes.BYTE_SINGLE_QUOTE] = -1
specialCharacters[bytes.BYTE_DOUBLE_QUOTE] = -1
specialCharacters[bytes.BYTE_TILDE] = -1
specialCharacters[bytes.BYTE_RIGHTBRACKET] = tokens.TOKEN_RIGHTBRACKET
specialCharacters[bytes.BYTE_COMMA] = tokens.TOKEN_COMMA
specialCharacters[bytes.BYTE_COLON] = tokens.TOKEN_COLON
specialCharacters[bytes.BYTE_SEMICOLON] = tokens.TOKEN_SEMICOLON
specialCharacters[bytes.BYTE_LEFTPAREN] = tokens.TOKEN_LEFTPAREN
specialCharacters[bytes.BYTE_RIGHTPAREN] = tokens.TOKEN_RIGHTPAREN
specialCharacters[bytes.BYTE_PLUS] = tokens.TOKEN_PLUS
specialCharacters[bytes.BYTE_SLASH] = tokens.TOKEN_SLASH
specialCharacters[bytes.BYTE_LEFTWING] = tokens.TOKEN_LEFTWING
specialCharacters[bytes.BYTE_RIGHTWING] = tokens.TOKEN_RIGHTWING
specialCharacters[bytes.BYTE_CIRCUMFLEX] = tokens.TOKEN_CIRCUMFLEX
specialCharacters[bytes.BYTE_ASTERISK] = tokens.TOKEN_ASTERISK
-- WoW specific
specialCharacters[bytes.BYTE_VERTICAL] = -1
-- new as of lua 5.1
specialCharacters[bytes.BYTE_HASH] = tokens.TOKEN_HASH
specialCharacters[bytes.BYTE_PERCENT] = tokens.TOKEN_PERCENT

local function nextNumberExponentPartInt(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_NUMBER, pos
		end
		
		if byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then	
			pos = pos + 1
		else
			return tokens.TOKEN_NUMBER, pos 
		end
	end
end

local function nextNumberExponentPart(text, pos)
	local byte = stringbyte(text, pos)
	if not byte then
		return tokens.TOKEN_NUMBER, pos
	end
	
	if byte == bytes.BYTE_MINUS then
		-- handle this case: a = 1.2e-- some comment
		-- i decide to let 1.2e be parsed as a a number
		byte = stringbyte(text, pos + 1)
		if byte == bytes.BYTE_MINUS then
			return tokens.TOKEN_NUMBER, pos
		end
		return nextNumberExponentPartInt(text, pos + 1)
	end
	
	return nextNumberExponentPartInt(text, pos)
end

local function nextNumberFractionPart(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_NUMBER, pos
		end
		
		if byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then	
			pos = pos + 1
		elseif byte == bytes.BYTE_E or byte == bytes.BYTE_e then
			return nextNumberExponentPart(text, pos + 1)
		else
			return tokens.TOKEN_NUMBER, pos 
		end
	end
end

local function nextNumberIntPart(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_NUMBER, pos
		end
		
		if byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then	
			pos = pos + 1
		elseif byte == bytes.BYTE_PERIOD then
			return nextNumberFractionPart(text, pos + 1)
		elseif byte == bytes.BYTE_E or byte == bytes.BYTE_e then
			return nextNumberExponentPart(text, pos + 1)
		else
			return tokens.TOKEN_NUMBER, pos
		end
	end
end

local function nextIdentifier(text, pos)
	while true do
		local byte = stringbyte(text, pos)
		
		if not byte or
			linebreakCharacters[byte] or
			whitespaceCharacters[byte] or
			specialCharacters[byte] then
			return tokens.TOKEN_IDENTIFIER, pos
		end
		pos = pos + 1
	end
end

-- returns false or: true, nextPos, equalsCount
local function isBracketStringNext(text, pos)
	local byte = stringbyte(text, pos)
	if byte == bytes.BYTE_LEFTBRACKET then
		local pos2 = pos + 1
		byte = stringbyte(text, pos2)
		while byte == bytes.BYTE_EQUALS do
			pos2 = pos2 + 1
			byte = stringbyte(text, pos2)
		end
		if byte == bytes.BYTE_LEFTBRACKET then
			return true, pos2 + 1, (pos2 - 1) - pos
		else
			return false
		end
	else
		return false
	end
end


-- Already parsed the [==[ part when get here
local function nextBracketString(text, pos, equalsCount)
	local state = 0
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_STRING, pos
		end
		
		if byte == bytes.BYTE_RIGHTBRACKET then
			if state == 0 then
				state = 1
			elseif state == equalsCount + 1 then
				return tokens.TOKEN_STRING, pos + 1
			else
				state = 0
			end
		elseif byte == bytes.BYTE_EQUALS then
			if state > 0 then
				state = state + 1
			end
		else
			state = 0
		end
		pos = pos + 1
	end
end

local function nextComment(text, pos)
	-- When we get here we have already parsed the "--"
	-- Check for long comment
	local isBracketString, nextPos, equalsCount = isBracketStringNext(text, pos)
	if isBracketString then
		local tokenType, nextPos2 = nextBracketString(text, nextPos, equalsCount)
		return tokens.TOKEN_COMMENT_LONG, nextPos2
	end

	local byte = stringbyte(text, pos)

	-- Short comment, find the first linebreak
	while true do
		byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_COMMENT_SHORT, pos
		end
		if linebreakCharacters[byte] then
			return tokens.TOKEN_COMMENT_SHORT, pos
		end
		pos = pos + 1
	end
end

local function nextString(text, pos, character)
	local even = true
	while true do
		local byte = stringbyte(text, pos)
		if not byte then
			return tokens.TOKEN_STRING, pos
		end
		
		if byte == character then
			if even then
				return tokens.TOKEN_STRING, pos + 1
			end
		end
		if byte == bytes.BYTE_BACKSLASH then
			even = not even
		else
			even = true
		end
		
		pos = pos + 1
	end
end

-- INPUT
-- 1: text: text to search in
-- 2: tokenPos:  where to start searching
-- OUTPUT
-- 1: token type
-- 2: position after the last character of the token
function lib.nextToken(text, pos)
	local byte = stringbyte(text, pos)
	if not byte then
		return nil
	end
	
	if linebreakCharacters[byte] then
		return tokens.TOKEN_LINEBREAK, pos + 1
	end
	
	if whitespaceCharacters[byte] then
		while true do
			pos = pos + 1
			byte = stringbyte(text, pos)
			if not byte or not whitespaceCharacters[byte] then
				return tokens.TOKEN_WHITESPACE, pos
			end
		end
	end
	
	local token = specialCharacters[byte]
	if token then
		if token ~= -1 then
			return token, pos + 1
		end
		
		-- WoW specific (for color codes)
		if byte == bytes.BYTE_VERTICAL then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_VERTICAL then
				return tokens.TOKEN_VERTICAL, pos + 2
			end
			if byte == bytes.BYTE_c then
				return tokens.TOKEN_COLORCODE_START, pos + 10
			end
			if byte == bytes.BYTE_r then
				return tokens.TOKEN_COLORCODE_STOP, pos + 2
			end
			return tokens.TOKEN_UNKNOWN, pos + 1
		end
		
		if byte == bytes.BYTE_MINUS then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_MINUS then
				return nextComment(text, pos + 2)
			end
			return tokens.TOKEN_MINUS, pos + 1
		end
		
		if byte == bytes.BYTE_SINGLE_QUOTE then
			return nextString(text, pos + 1, bytes.BYTE_SINGLE_QUOTE)
		end
		
		if byte == bytes.BYTE_DOUBLE_QUOTE then
			return nextString(text, pos + 1, bytes.BYTE_DOUBLE_QUOTE)
		end

		if byte == bytes.BYTE_LEFTBRACKET then
			local isBracketString, nextPos, equalsCount = isBracketStringNext(text, pos)
			if isBracketString then
				return nextBracketString(text, nextPos, equalsCount)
			else
				return tokens.TOKEN_LEFTBRACKET, pos + 1
			end
		end
		
		if byte == bytes.BYTE_EQUALS then
			byte = stringbyte(text, pos + 1)
			if not byte then
				return tokens.TOKEN_ASSIGNMENT, pos + 1
			end
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_EQUALITY, pos + 2
			end
			return tokens.TOKEN_ASSIGNMENT, pos + 1
		end
		
		if byte == bytes.BYTE_PERIOD then
			byte = stringbyte(text, pos + 1)
			if not byte then
				return tokens.TOKEN_PERIOD, pos + 1
			end
			if byte == bytes.BYTE_PERIOD then
				byte = stringbyte(text, pos + 2)
				if byte == bytes.BYTE_PERIOD then
					return tokens.TOKEN_TRIPLEPERIOD, pos + 3
				end
				return tokens.TOKEN_DOUBLEPERIOD, pos + 2
			elseif byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then
				return nextNumberFractionPart(text, pos + 2)
			end
			return tokens.TOKEN_PERIOD, pos + 1
		end
		
		if byte == bytes.BYTE_LESSTHAN then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_LTE, pos + 2
			end
			return tokens.TOKEN_LT, pos + 1
		end
		
		if byte == bytes.BYTE_GREATERTHAN then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_GTE, pos + 2
			end
			return tokens.TOKEN_GT, pos + 1
		end
		
		if byte == bytes.BYTE_TILDE then
			byte = stringbyte(text, pos + 1)
			if byte == bytes.BYTE_EQUALS then
				return tokens.TOKEN_NOTEQUAL, pos + 2
			end
			return tokens.TOKEN_TILDE, pos + 1
		end
		
		return tokens.TOKEN_UNKNOWN, pos + 1
	elseif byte >= bytes.BYTE_0 and byte <= bytes.BYTE_9 then
		return nextNumberIntPart(text, pos + 1)
	else
		return nextIdentifier(text, pos + 1)
	end
end

-- Cool stuff begins here! (indentation and highlighting)

local noIndentEffect = {0, 0}
local indentLeft = {-1, 0}
local indentRight = {0, 1}
local indentBoth = {-1, 1}

local keywords = {
	["and"] = noIndentEffect,
	["break"] = noIndentEffect,
	["false"] = noIndentEffect,
	["for"] = noIndentEffect,
	["if"] = noIndentEffect,
	["in"] = noIndentEffect,
	["local"] = noIndentEffect,
	["nil"] = noIndentEffect,
	["not"] = noIndentEffect,
	["or"] = noIndentEffect,
	["return"] = noIndentEffect,
	["true"] = noIndentEffect,
	["while"] = noIndentEffect,
	["until"] = indentLeft,
	["elseif"] = indentLeft,
	["end"] = indentLeft,
	["do"] = indentRight,
	["then"] = indentRight,
	["repeat"] = indentRight,
	["function"] = indentRight,
	["else"] = indentBoth,
	-- new stuff here
	-- Standard Lua Stuff
	["_ALERT"] = noIndentEffect,
	["_ERRORMESSAGE"] = noIndentEffect,
	["_G"] = noIndentEffect,
	["_INPUT"] = noIndentEffect,
	["_OUTPUT"] = noIndentEffect,
	["_PROMPT"] = noIndentEffect,
	["_STDERR"] = noIndentEffect,
	["_STDIN"] = noIndentEffect,
	["_STDOUT"] = noIndentEffect,
	["_VERSION"] = noIndentEffect,
	["abs"] = noIndentEffect,
	["acos"] = noIndentEffect,
	["asin"] = noIndentEffect,
	["assert"] = noIndentEffect,
	["atan"] = noIndentEffect,
	["atan2"] = noIndentEffect,
	["band"] = noIndentEffect,
	["bit"] = noIndentEffect,
	["bit_band"] = noIndentEffect,
	["bit_bor"] = noIndentEffect,
	["bnot"] = noIndentEffect,
	["bor"] = noIndentEffect,
	["bxor"] = noIndentEffect,
	["byte"] = noIndentEffect,
	["call"] = noIndentEffect,
	["ceil"] = noIndentEffect,
	["char"] = noIndentEffect,
	["clock"] = noIndentEffect,
	["close"] = noIndentEffect,
	["collectgarbage"] = noIndentEffect,
	["concat"] = noIndentEffect,
	["coroutine"] = noIndentEffect,
	["coroutine.create"] = noIndentEffect,
	["coroutine.resume"] = noIndentEffect,
	["coroutine.running"] = noIndentEffect,
	["coroutine.status"] = noIndentEffect,
	["coroutine.wrap"] = noIndentEffect,
	["coroutine.yield"] = noIndentEffect,
	["cos"] = noIndentEffect,
	["cosh"] = noIndentEffect,
	["cpath"] = noIndentEffect,
	["create"] = noIndentEffect,
	["date"] = noIndentEffect,
	["debug"] = noIndentEffect,
	["debug.debug"] = noIndentEffect,
	["debug.getfenv"] = noIndentEffect,
	["debug.gethook"] = noIndentEffect,
	["debug.getinfo"] = noIndentEffect,
	["debug.getlocal"] = noIndentEffect,
	["debug.getmetatable"] = noIndentEffect,
	["debug.getregistry"] = noIndentEffect,
	["debug.getupvalue"] = noIndentEffect,
	["debug.setfenv"] = noIndentEffect,
	["debug.sethook"] = noIndentEffect,
	["debug.setlocal"] = noIndentEffect,
	["debug.setmetatable"] = noIndentEffect,
	["debug.setupvalue"] = noIndentEffect,
	["debug.traceback"] = noIndentEffect,
	["deg"] = noIndentEffect,
	["difftime"] = noIndentEffect,
	["dofile"] = noIndentEffect,
	["dostring"] = noIndentEffect,
	["dump"] = noIndentEffect,
	["error"] = noIndentEffect,
	["execute"] = noIndentEffect,
	["exit"] = noIndentEffect,
	["exp"] = noIndentEffect,
	["file"] = noIndentEffect,
	["file.close"] = noIndentEffect,
	["file.flush"] = noIndentEffect,
	["file.lines"] = noIndentEffect,
	["file.read"] = noIndentEffect,
	["file.seek"] = noIndentEffect,
	["file.setvbuf"] = noIndentEffect,
	["file.write"] = noIndentEffect,
	["find"] = noIndentEffect,
	["floor"] = noIndentEffect,
	["flush"] = noIndentEffect,
	["fmod"] = noIndentEffect,
	["foreach"] = noIndentEffect,
	["foreachi"] = noIndentEffect,
	["format"] = noIndentEffect,
	["frexp"] = noIndentEffect,
	["gcinfo"] = noIndentEffect,
	["getenv"] = noIndentEffect,
	["getfenv"] = noIndentEffect,
	["gethook"] = noIndentEffect,
	["getinfo"] = noIndentEffect,
	["getlocal"] = noIndentEffect,
	["getmetatable"] = noIndentEffect,
	["getn"] = noIndentEffect,
	["getregistry"] = noIndentEffect,
	["getupvalue"] = noIndentEffect,
	["gfind"] = noIndentEffect,
	["globals"] = noIndentEffect,
	["gmatch"] = noIndentEffect,
	["gsub"] = noIndentEffect,
	["huge"] = noIndentEffect,
	["input"] = noIndentEffect,
	["insert"] = noIndentEffect,
	["io"] = noIndentEffect,
	["io.close"] = noIndentEffect,
	["io.flush"] = noIndentEffect,
	["io.input"] = noIndentEffect,
	["io.lines"] = noIndentEffect,
	["io.open"] = noIndentEffect,
	["io.output"] = noIndentEffect,
	["io.popen"] = noIndentEffect,
	["io.read"] = noIndentEffect,
	["io.stderr"] = noIndentEffect,
	["io.stdin"] = noIndentEffect,
	["io.stdout"] = noIndentEffect,
	["io.tmpfile"] = noIndentEffect,
	["io.type"] = noIndentEffect,
	["io.write"] = noIndentEffect,
	["ipairs"] = noIndentEffect,
	["join"] = noIndentEffect,
	["ldexp"] = noIndentEffect,
	["len"] = noIndentEffect,
	["lines"] = noIndentEffect,
	["load"] = noIndentEffect,
	["loaded"] = noIndentEffect,
	["loaders"] = noIndentEffect,
	["loadfile"] = noIndentEffect,
	["loadlib"] = noIndentEffect,
	["loadstring"] = noIndentEffect,
	["log"] = noIndentEffect,
	["log10"] = noIndentEffect,
	["lower"] = noIndentEffect,
	["lshift"] = noIndentEffect,
	["match"] = noIndentEffect,
	["math"] = noIndentEffect,
	["math.abs"] = noIndentEffect,
	["math.acos"] = noIndentEffect,
	["math.asin"] = noIndentEffect,
	["math.atan"] = noIndentEffect,
	["math.atan2"] = noIndentEffect,
	["math.ceil"] = noIndentEffect,
	["math.cos"] = noIndentEffect,
	["math.cosh"] = noIndentEffect,
	["math.deg"] = noIndentEffect,
	["math.exp"] = noIndentEffect,
	["math.floor"] = noIndentEffect,
	["math.fmod"] = noIndentEffect,
	["math.frexp"] = noIndentEffect,
	["math.huge"] = noIndentEffect,
	["math.ldexp"] = noIndentEffect,
	["math.log"] = noIndentEffect,
	["math.log10"] = noIndentEffect,
	["math.max"] = noIndentEffect,
	["math.min"] = noIndentEffect,
	["math.modf"] = noIndentEffect,
	["math.pi"] = noIndentEffect,
	["math.pow"] = noIndentEffect,
	["math.rad"] = noIndentEffect,
	["math.random"] = noIndentEffect,
	["math.randomseed"] = noIndentEffect,
	["math.sin"] = noIndentEffect,
	["math.sinh"] = noIndentEffect,
	["math.sqrt"] = noIndentEffect,
	["math.tan"] = noIndentEffect,
	["math.tanh"] = noIndentEffect,
	["max"] = noIndentEffect,
	["maxn"] = noIndentEffect,
	["min"] = noIndentEffect,
	["mod"] = noIndentEffect,
	["modf"] = noIndentEffect,
	["module"] = noIndentEffect,
	["new"] = noIndentEffect,
	["newtable"] = noIndentEffect,
	["newtype"] = noIndentEffect,
	["next"] = noIndentEffect,
	["open"] = noIndentEffect,
	["os"] = noIndentEffect,
	["os_clock"] = noIndentEffect,
	["os.date"] = noIndentEffect,
	["os.difftime"] = noIndentEffect,
	["os.execute"] = noIndentEffect,
	["os.exit"] = noIndentEffect,
	["os.getenv"] = noIndentEffect,
	["os.remove"] = noIndentEffect,
	["os.rename"] = noIndentEffect,
	["os.setlocale"] = noIndentEffect,
	["os.time"] = noIndentEffect,
	["os.tmpname"] = noIndentEffect,
	["output"] = noIndentEffect,
	["package"] = noIndentEffect,
	["package.cpath"] = noIndentEffect,
	["package.loaded"] = noIndentEffect,
	["package.loaders"] = noIndentEffect,
	["package.loadlib"] = noIndentEffect,
	["package.path"] = noIndentEffect,
	["package.preload"] = noIndentEffect,
	["package.seeall"] = noIndentEffect,
	["pairs"] = noIndentEffect,
	["path"] = noIndentEffect,
	["pcall"] = noIndentEffect,
	["pi"] = noIndentEffect,
	["popen"] = noIndentEffect,
	["pow"] = noIndentEffect,
	["preload"] = noIndentEffect,
	["print"] = noIndentEffect,
	["rad"] = noIndentEffect,
	["random"] = noIndentEffect,
	["randomseed"] = noIndentEffect,
	["rawegal"] = noIndentEffect,
	["rawequal"] = noIndentEffect,
	["rawget"] = noIndentEffect,
	["rawset"] = noIndentEffect,
	["read"] = noIndentEffect,
	["remove"] = noIndentEffect,
	["rename"] = noIndentEffect,
	["rep"] = noIndentEffect,
	["require"] = noIndentEffect,
	["resume"] = noIndentEffect,
	["reverse"] = noIndentEffect,
	["rshift"] = noIndentEffect,
	["rtgsub"] = noIndentEffect,
	["running"] = noIndentEffect,
	["seeall"] = noIndentEffect,
	["seek"] = noIndentEffect,
	["select"] = noIndentEffect,
	["setfenv"] = noIndentEffect,
	["sethook"] = noIndentEffect,
	["setlocal"] = noIndentEffect,
	["setlocale"] = noIndentEffect,
	["setmetatable"] = noIndentEffect,
	["setupvalue"] = noIndentEffect,
	["setvbuf"] = noIndentEffect,
	["sin"] = noIndentEffect,
	["sinh"] = noIndentEffect,
	["sort"] = noIndentEffect,
	["split"] = noIndentEffect,
	["sqrt"] = noIndentEffect,
	["status"] = noIndentEffect,
	["stderr"] = noIndentEffect,
	["stdin"] = noIndentEffect,
	["stdout"] = noIndentEffect,
	["strbyte"] = noIndentEffect,
	["strchar"] = noIndentEffect,
	["strconcat"] = noIndentEffect,
	["strdump"] = noIndentEffect,
	["strfind"] = noIndentEffect,
	["strformat"] = noIndentEffect,
	["strgmatch"] = noIndentEffect,
	["strgsub"] = noIndentEffect,
	["string"] = noIndentEffect,
	["string_byte"] = noIndentEffect,
	["string_char"] = noIndentEffect,
	["string_dump"] = noIndentEffect,
	["string_find"] = noIndentEffect,
	["string_format"] = noIndentEffect,
	["string_gmatch"] = noIndentEffect,
	["string_gsub"] = noIndentEffect,
	["string_len"] = noIndentEffect,
	["string_lower"] = noIndentEffect,
	["string_match"] = noIndentEffect,
	["string_rep"] = noIndentEffect,
	["string_reverse"] = noIndentEffect,
	["string_sub"] = noIndentEffect,
	["string_upper"] = noIndentEffect,
	["strlen"] = noIndentEffect,
	["strlower"] = noIndentEffect,
	["strmatch"] = noIndentEffect,
	["strrep"] = noIndentEffect,
	["strreverse"] = noIndentEffect,
	["strsub"] = noIndentEffect,
	["strupper"] = noIndentEffect,
	["sub"] = noIndentEffect,
	["table"] = noIndentEffect,
	["table.concat"] = noIndentEffect,
	["table.insert"] = noIndentEffect,
	["table.maxn"] = noIndentEffect,
	["table.remove"] = noIndentEffect,
	["table.sort"] = noIndentEffect,
	["tan"] = noIndentEffect,
	["tanh"] = noIndentEffect,
	["time"] = noIndentEffect,
	["tinsert"] = noIndentEffect,
	["tmpfile"] = noIndentEffect,
	["tmpname"] = noIndentEffect,
	["tonumber"] = noIndentEffect,
	["tostring"] = noIndentEffect,
	["tostringall"] = noIndentEffect,
	["traceback"] = noIndentEffect,
	["tremove"] = noIndentEffect,
	["trim"] = noIndentEffect,
	["type"] = noIndentEffect,
	["unpack"] = noIndentEffect,
	["upper"] = noIndentEffect,
	["wrap"] = noIndentEffect,
	["write"] = noIndentEffect,
	["xpcall"] = noIndentEffect,
	["yield"] = noIndentEffect,
	-- WoW Functions
	["AbandonQuest"] = noIndentEffect,
	["AbandonSkill"] = noIndentEffect,
	["AcceptAreaSpiritHeal"] = noIndentEffect,
	["AcceptArenaTeam"] = noIndentEffect,
	["AcceptBattlefieldPort"] = noIndentEffect,
	["AcceptDuel"] = noIndentEffect,
	["AcceptGroup"] = noIndentEffect,
	["AcceptGuild"] = noIndentEffect,
	["AcceptLevelGrant"] = noIndentEffect,
	["AcceptProposal"] = noIndentEffect,
	["AcceptQuest"] = noIndentEffect,
	["AcceptResurrect"] = noIndentEffect,
	["AcceptSkillUps"] = noIndentEffect,
	["AcceptSockets"] = noIndentEffect,
	["AcceptTrade"] = noIndentEffect,
	["AcceptXPLoss"] = noIndentEffect,
	["AchievementAlertFrame_FixAnchors"] = noIndentEffect,
	["AchievementAlertFrame_GetAlertFrame"] = noIndentEffect,
	["AchievementAlertFrame_OnClick"] = noIndentEffect,
	["AchievementAlertFrame_OnHide"] = noIndentEffect,
	["AchievementAlertFrame_OnLoad"] = noIndentEffect,
	["AchievementAlertFrame_ShowAlert"] = noIndentEffect,
	["AchievementFrame_LoadUI"] = noIndentEffect,
	["AchievementMicroButton_OnEvent"] = noIndentEffect,
	["ActionBar_PageDown"] = noIndentEffect,
	["ActionBar_PageUp"] = noIndentEffect,
	["ActionButtonDown"] = noIndentEffect,
	["ActionButtonUp"] = noIndentEffect,
	["ActionButton_CalculateAction"] = noIndentEffect,
	["ActionButton_GetPagedID"] = noIndentEffect,
	["ActionButton_HideGrid"] = noIndentEffect,
	["ActionButton_IsFlashing"] = noIndentEffect,
	["ActionButton_OnEvent"] = noIndentEffect,
	["ActionButton_OnLoad"] = noIndentEffect,
	["ActionButton_OnUpdate"] = noIndentEffect,
	["ActionButton_SetTooltip"] = noIndentEffect,
	["ActionButton_ShowGrid"] = noIndentEffect,
	["ActionButton_StartFlash"] = noIndentEffect,
	["ActionButton_StopFlash"] = noIndentEffect,
	["ActionButton_Update"] = noIndentEffect,
	["ActionButton_UpdateAction"] = noIndentEffect,
	["ActionButton_UpdateCooldown"] = noIndentEffect,
	["ActionButton_UpdateCount"] = noIndentEffect,
	["ActionButton_UpdateFlash"] = noIndentEffect,
	["ActionButton_UpdateHotkeys"] = noIndentEffect,
	["ActionButton_UpdateState"] = noIndentEffect,
	["ActionButton_UpdateUsable"] = noIndentEffect,
	["ActionHasRange"] = noIndentEffect,
	["ActionStatus_DisplayMessage"] = noIndentEffect,
	["ActionStatus_OnEvent"] = noIndentEffect,
	["ActionStatus_OnLoad"] = noIndentEffect,
	["ActionStatus_OnUpdate"] = noIndentEffect,
	["AddChatWindowChannel"] = noIndentEffect,
	["AddChatWindowMessages"] = noIndentEffect,
	["AddFriend"] = noIndentEffect,
	["AddFriendEntryFrame_Collapse"] = noIndentEffect,
	["AddFriendEntryFrame_Expand"] = noIndentEffect,
	["AddFriendFrame_Accept"] = noIndentEffect,
	["AddFriendFrame_OnShow"] = noIndentEffect,
	["AddFriendFrame_ShowEntry"] = noIndentEffect,
	["AddFriendFrame_ShowInfo"] = noIndentEffect,
	["AddFriendNameEditBox_OnTextChanged"] = noIndentEffect,
	["AddIgnore"] = noIndentEffect,
	["AddMute"] = noIndentEffect,
	["AddOrDelIgnore"] = noIndentEffect,
	["AddOrDelMute"] = noIndentEffect,
	["AddOrRemoveFriend"] = noIndentEffect,
	["AddPreviewTalentPoints"] = noIndentEffect,
	["AddQuestWatch"] = noIndentEffect,
	["AddSkillUp"] = noIndentEffect,
	["AddToAutoHide"] = noIndentEffect,
	["AddTrackedAchievement"] = noIndentEffect,
	["AddTradeMoney"] = noIndentEffect,
	["AlertFrame_AnimateIn"] = noIndentEffect,
	["AlertFrame_FixAnchors"] = noIndentEffect,
	["AlertFrame_OnEvent"] = noIndentEffect,
	["AlertFrame_OnLoad"] = noIndentEffect,
	["AlertFrame_ResumeOutAnimation"] = noIndentEffect,
	["AlertFrame_StopOutAnimation"] = noIndentEffect,
	["AltCurrencyFrame_PointsUpdate"] = noIndentEffect,
	["AltCurrencyFrame_Update"] = noIndentEffect,
	["AlternatePowerBar_Initialize"] = noIndentEffect,
	["AlternatePowerBar_OnEvent"] = noIndentEffect,
	["AlternatePowerBar_OnLoad"] = noIndentEffect,
	["AlternatePowerBar_OnUpdate"] = noIndentEffect,
	["AlternatePowerBar_UpdateMaxValues"] = noIndentEffect,
	["AlternatePowerBar_UpdatePowerType"] = noIndentEffect,
	["AlternatePowerBar_UpdateValue"] = noIndentEffect,
	["AnimateTexCoords"] = noIndentEffect,
	["AnimatedShine_OnUpdate"] = noIndentEffect,
	["AnimatedShine_Start"] = noIndentEffect,
	["AnimatedShine_Stop"] = noIndentEffect,
	["AppendToFile"] = noIndentEffect,
	["ApplyBarberShopStyle"] = noIndentEffect,
	["ApplyUnitButtonConfiguration"] = noIndentEffect,
	["ArenaButton_OnClick"] = noIndentEffect,
	["ArenaFrameJoinButton_OnClick"] = noIndentEffect,
	["ArenaFrame_OnEvent"] = noIndentEffect,
	["ArenaFrame_OnLoad"] = noIndentEffect,
	["ArenaFrame_Update"] = noIndentEffect,
	["ArenaRegistrar_OnEvent"] = noIndentEffect,
	["ArenaRegistrar_OnLoad"] = noIndentEffect,
	["ArenaRegistrar_OnShow"] = noIndentEffect,
	["ArenaRegistrar_ShowPurchaseFrame"] = noIndentEffect,
	["ArenaRegistrar_TurnInPetition"] = noIndentEffect,
	["ArenaRegistrar_UpdatePrice"] = noIndentEffect,
	["ArenaTeamDisband"] = noIndentEffect,
	["ArenaTeamInviteByName"] = noIndentEffect,
	["ArenaTeamLeave"] = noIndentEffect,
	["ArenaTeamRoster"] = noIndentEffect,
	["ArenaTeamSetLeaderByName"] = noIndentEffect,
	["ArenaTeamUninviteByName"] = noIndentEffect,
	["ArenaTeam_GetTeamSizeID"] = noIndentEffect,
	["Arena_LoadUI"] = noIndentEffect,
	["AscendStop"] = noIndentEffect,
	["AssistUnit"] = noIndentEffect,
	["AttackTarget"] = noIndentEffect,
	["AuctionFrame_LoadUI"] = noIndentEffect,
	["AudioOptionsFrameCancel_OnClick"] = noIndentEffect,
	["AudioOptionsFrameDefault_OnClick"] = noIndentEffect,
	["AudioOptionsFrameOkay_OnClick"] = noIndentEffect,
	["AudioOptionsFrame_AudioRestart"] = noIndentEffect,
	["AudioOptionsFrame_OnEvent"] = noIndentEffect,
	["AudioOptionsFrame_OnHide"] = noIndentEffect,
	["AudioOptionsFrame_OnLoad"] = noIndentEffect,
	["AudioOptionsFrame_SetAllToDefaults"] = noIndentEffect,
	["AudioOptionsFrame_SetCurrentToDefaults"] = noIndentEffect,
	["AudioOptionsFrame_Toggle"] = noIndentEffect,
	["AudioOptionsPanel_CheckButton_OnClick"] = noIndentEffect,
	["AudioOptionsSoundPanelHardwareDropDown_Initialize"] = noIndentEffect,
	["AudioOptionsSoundPanelHardwareDropDown_OnClick"] = noIndentEffect,
	["AudioOptionsSoundPanelHardwareDropDown_OnLoad"] = noIndentEffect,
	["AudioOptionsSoundPanel_OnLoad"] = noIndentEffect,
	["AudioOptionsVoicePanelBindingOutput_OnUpdate"] = noIndentEffect,
	["AudioOptionsVoicePanelBindingType_Update"] = noIndentEffect,
	["AudioOptionsVoicePanelChatModeDropDown_Initialize"] = noIndentEffect,
	["AudioOptionsVoicePanelChatModeDropDown_OnClick"] = noIndentEffect,
	["AudioOptionsVoicePanelChatModeDropDown_OnLoad"] = noIndentEffect,
	["AudioOptionsVoicePanelEnableMicrophone_UpdateControls"] = noIndentEffect,
	["AudioOptionsVoicePanelEnableVoice_UpdateControls"] = noIndentEffect,
	["AudioOptionsVoicePanelInputDeviceDropDown_Initialize"] = noIndentEffect,
	["AudioOptionsVoicePanelInputDeviceDropDown_OnClick"] = noIndentEffect,
	["AudioOptionsVoicePanelInputDeviceDropDown_OnLoad"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_BindButton"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_CancelBinding"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_OnClick"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_OnEnter"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_OnKeyDown"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_OnKeyUp"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_Refresh"] = noIndentEffect,
	["AudioOptionsVoicePanelKeyBindingButton_SetTooltip"] = noIndentEffect,
	["AudioOptionsVoicePanelOutputDeviceDropDown_Initialize"] = noIndentEffect,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnClick"] = noIndentEffect,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnEvent"] = noIndentEffect,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnLoad"] = noIndentEffect,
	["AudioOptionsVoicePanel_DisableMicrophoneControls"] = noIndentEffect,
	["AudioOptionsVoicePanel_EnableMicrophoneControls"] = noIndentEffect,
	["AudioOptionsVoicePanel_OnEvent"] = noIndentEffect,
	["AudioOptionsVoicePanel_OnHide"] = noIndentEffect,
	["AudioOptionsVoicePanel_OnLoad"] = noIndentEffect,
	["AudioOptionsVoicePanel_OnShow"] = noIndentEffect,
	["AudioOptionsVoicePanel_Refresh"] = noIndentEffect,
	["AudioOptionsVoicePanel_SetInputDevice"] = noIndentEffect,
	["AudioOptionsVoicePanel_SetOutputDevice"] = noIndentEffect,
	["AuraButton_OnUpdate"] = noIndentEffect,
	["AuraButton_Update"] = noIndentEffect,
	["AuraButton_UpdateDuration"] = noIndentEffect,
	["AutoCastShine_AutoCastStart"] = noIndentEffect,
	["AutoCastShine_AutoCastStop"] = noIndentEffect,
	["AutoCastShine_OnLoad"] = noIndentEffect,
	["AutoCastShine_OnUpdate"] = noIndentEffect,
	["AutoCompleteButton_OnClick"] = noIndentEffect,
	["AutoCompleteEditBox_AddHighlightedText"] = noIndentEffect,
	["AutoCompleteEditBox_OnChar"] = noIndentEffect,
	["AutoCompleteEditBox_OnEditFocusLost"] = noIndentEffect,
	["AutoCompleteEditBox_OnEnterPressed"] = noIndentEffect,
	["AutoCompleteEditBox_OnEscapePressed"] = noIndentEffect,
	["AutoCompleteEditBox_OnTabPressed"] = noIndentEffect,
	["AutoCompleteEditBox_OnTextChanged"] = noIndentEffect,
	["AutoComplete_GetNumResults"] = noIndentEffect,
	["AutoComplete_GetSelectedIndex"] = noIndentEffect,
	["AutoComplete_HideIfAttachedTo"] = noIndentEffect,
	["AutoComplete_OnLoad"] = noIndentEffect,
	["AutoComplete_SetSelectedIndex"] = noIndentEffect,
	["AutoComplete_Update"] = noIndentEffect,
	["AutoComplete_UpdateResults"] = noIndentEffect,
	["AutoEquipCursorItem"] = noIndentEffect,
	["AutoFollowStatus_OnEvent"] = noIndentEffect,
	["AutoFollowStatus_OnLoad"] = noIndentEffect,
	["AutoFollowStatus_OnUpdate"] = noIndentEffect,
	["AutoLootMailItem"] = noIndentEffect,
	["AutoStoreGuildBankItem"] = noIndentEffect,
	["BNAcceptFriendInvite"] = noIndentEffect,
	["BNConnected"] = noIndentEffect,
	["BNConversationButton_OnClick"] = noIndentEffect,
	["BNConversationButton_OnEnter"] = noIndentEffect,
	["BNConversationButton_OnEvent"] = noIndentEffect,
	["BNConversationButton_OnLeave"] = noIndentEffect,
	["BNConversationButton_OnLoad"] = noIndentEffect,
	["BNConversationButton_UpdateAttachmentPoint"] = noIndentEffect,
	["BNConversationButton_UpdateEnabledState"] = noIndentEffect,
	["BNConversationButton_UpdateTarget"] = noIndentEffect,
	["BNConversationInviteDialogInviteButton_OnClick"] = noIndentEffect,
	["BNConversationInviteDialog_OnEvent"] = noIndentEffect,
	["BNConversationInviteDialog_OnLoad"] = noIndentEffect,
	["BNConversationInviteListCheckButton_OnClick"] = noIndentEffect,
	["BNConversationInvite_Deselect"] = noIndentEffect,
	["BNConversationInvite_Lock"] = noIndentEffect,
	["BNConversationInvite_LockActions"] = noIndentEffect,
	["BNConversationInvite_NewConversation"] = noIndentEffect,
	["BNConversationInvite_Reset"] = noIndentEffect,
	["BNConversationInvite_Select"] = noIndentEffect,
	["BNConversationInvite_SelectPlayers"] = noIndentEffect,
	["BNConversationInvite_SetMinMaxInvites"] = noIndentEffect,
	["BNConversationInvite_SetMode"] = noIndentEffect,
	["BNConversationInvite_Unlock"] = noIndentEffect,
	["BNConversationInvite_UnlockActions"] = noIndentEffect,
	["BNConversationInvite_Update"] = noIndentEffect,
	["BNConversationInvite_UpdateInviteButtonState"] = noIndentEffect,
	["BNConversation_DisplayConversationTooltip"] = noIndentEffect,
	["BNCreateConversation"] = noIndentEffect,
	["BNDeclineFriendInvite"] = noIndentEffect,
	["BNFeaturesEnabled"] = noIndentEffect,
	["BNFeaturesEnabledAndConnected"] = noIndentEffect,
	["BNGetBlockedInfo"] = noIndentEffect,
	["BNGetBlockedToonInfo"] = noIndentEffect,
	["BNGetConversationInfo"] = noIndentEffect,
	["BNGetConversationMemberInfo"] = noIndentEffect,
	["BNGetCustomMessageTable"] = noIndentEffect,
	["BNGetFOFInfo"] = noIndentEffect,
	["BNGetFriendInfo"] = noIndentEffect,
	["BNGetFriendInfoByID"] = noIndentEffect,
	["BNGetFriendInviteInfo"] = noIndentEffect,
	["BNGetFriendToonInfo"] = noIndentEffect,
	["BNGetInfo"] = noIndentEffect,
	["BNGetMatureLanguageFilter"] = noIndentEffect,
	["BNGetMaxPlayersInConversation"] = noIndentEffect,
	["BNGetNumBlocked"] = noIndentEffect,
	["BNGetNumBlockedToons"] = noIndentEffect,
	["BNGetNumConversationMembers"] = noIndentEffect,
	["BNGetNumFOF"] = noIndentEffect,
	["BNGetNumFriendInvites"] = noIndentEffect,
	["BNGetNumFriendToons"] = noIndentEffect,
	["BNGetNumFriends"] = noIndentEffect,
	["BNGetSelectedBlock"] = noIndentEffect,
	["BNGetSelectedFriend"] = noIndentEffect,
	["BNGetSelectedToonBlock"] = noIndentEffect,
	["BNGetToonInfo"] = noIndentEffect,
	["BNInviteToConversation"] = noIndentEffect,
	["BNIsBlocked"] = noIndentEffect,
	["BNIsFriend"] = noIndentEffect,
	["BNIsSelf"] = noIndentEffect,
	["BNIsToonBlocked"] = noIndentEffect,
	["BNLeaveConversation"] = noIndentEffect,
	["BNListConversation"] = noIndentEffect,
	["BNRemoveFriend"] = noIndentEffect,
	["BNReportFriendInvite"] = noIndentEffect,
	["BNReportPlayer"] = noIndentEffect,
	["BNRequestFOFInfo"] = noIndentEffect,
	["BNSendConversationMessage"] = noIndentEffect,
	["BNSendFriendInvite"] = noIndentEffect,
	["BNSendFriendInviteByID"] = noIndentEffect,
	["BNSendWhisper"] = noIndentEffect,
	["BNSetAFK"] = noIndentEffect,
	["BNSetBlocked"] = noIndentEffect,
	["BNSetCustomMessage"] = noIndentEffect,
	["BNSetDND"] = noIndentEffect,
	["BNSetFocus"] = noIndentEffect,
	["BNSetFriendNote"] = noIndentEffect,
	["BNSetMatureLanguageFilter"] = noIndentEffect,
	["BNSetSelectedBlock"] = noIndentEffect,
	["BNSetSelectedFriend"] = noIndentEffect,
	["BNSetSelectedToonBlock"] = noIndentEffect,
	["BNSetToonBlocked"] = noIndentEffect,
	["BNToastFrame_AddToast"] = noIndentEffect,
	["BNToastFrame_Close"] = noIndentEffect,
	["BNToastFrame_OnClick"] = noIndentEffect,
	["BNToastFrame_OnEvent"] = noIndentEffect,
	["BNToastFrame_OnUpdate"] = noIndentEffect,
	["BNToastFrame_RemoveToast"] = noIndentEffect,
	["BNToastFrame_Show"] = noIndentEffect,
	["BNToastFrame_UpdateAnchor"] = noIndentEffect,
	["BNet_ConfirmReport"] = noIndentEffect,
	["BNet_DisableToasts"] = noIndentEffect,
	["BNet_EnableToasts"] = noIndentEffect,
	["BNet_GetPresenceID"] = noIndentEffect,
	["BNet_InitiateReport"] = noIndentEffect,
	["BNet_OnEvent"] = noIndentEffect,
	["BNet_OnLoad"] = noIndentEffect,
	["BNet_SendReport"] = noIndentEffect,
	["BNet_SetToastDuration"] = noIndentEffect,
	["BNet_UpdateToastEvent"] = noIndentEffect,
	["BackpackButton_OnClick"] = noIndentEffect,
	["BackpackButton_OnModifiedClick"] = noIndentEffect,
	["BackpackButton_UpdateChecked"] = noIndentEffect,
	["BackpackTokenButton_OnClick"] = noIndentEffect,
	["BackpackTokenFrame_IsShown"] = noIndentEffect,
	["BackpackTokenFrame_Update"] = noIndentEffect,
	["BagSlotButton_OnClick"] = noIndentEffect,
	["BagSlotButton_OnDrag"] = noIndentEffect,
	["BagSlotButton_OnEnter"] = noIndentEffect,
	["BagSlotButton_OnModifiedClick"] = noIndentEffect,
	["BagSlotButton_UpdateChecked"] = noIndentEffect,
	["BankButtonIDToInvSlotID"] = noIndentEffect,
	["BankFrameBagButton_OnLoad"] = noIndentEffect,
	["BankFrameBaseButton_OnLoad"] = noIndentEffect,
	["BankFrameItemButtonBag_OnClick"] = noIndentEffect,
	["BankFrameItemButtonBag_Pickup"] = noIndentEffect,
	["BankFrameItemButtonGeneric_OnClick"] = noIndentEffect,
	["BankFrameItemButtonGeneric_OnModifiedClick"] = noIndentEffect,
	["BankFrameItemButton_OnEnter"] = noIndentEffect,
	["BankFrameItemButton_OnLoad"] = noIndentEffect,
	["BankFrameItemButton_Update"] = noIndentEffect,
	["BankFrameItemButton_UpdateLocked"] = noIndentEffect,
	["BankFrame_OnEvent"] = noIndentEffect,
	["BankFrame_OnHide"] = noIndentEffect,
	["BankFrame_OnLoad"] = noIndentEffect,
	["BankFrame_OnShow"] = noIndentEffect,
	["BankFrame_UpdateCooldown"] = noIndentEffect,
	["BarberShopFrame_LoadUI"] = noIndentEffect,
	["BarberShopReset"] = noIndentEffect,
	["BattlefieldButton_OnClick"] = noIndentEffect,
	["BattlefieldFrameJoinButton_OnClick"] = noIndentEffect,
	["BattlefieldFrame_GetSelectedBattlegroundInfo"] = noIndentEffect,
	["BattlefieldFrame_OnEvent"] = noIndentEffect,
	["BattlefieldFrame_OnLoad"] = noIndentEffect,
	["BattlefieldFrame_Update"] = noIndentEffect,
	["BattlefieldFrame_UpdateRandomInfo"] = noIndentEffect,
	["BattlefieldFrame_UpdateStatus"] = noIndentEffect,
	["BattlefieldMgrEntryInviteResponse"] = noIndentEffect,
	["BattlefieldMgrExitRequest"] = noIndentEffect,
	["BattlefieldMgrQueueInviteResponse"] = noIndentEffect,
	["BattlefieldMgrQueueRequest"] = noIndentEffect,
	["BattlefieldMinimap_LoadUI"] = noIndentEffect,
	["BattlefieldTimerFrame_OnUpdate"] = noIndentEffect,
	["BattlegroundShineFadeIn"] = noIndentEffect,
	["BattlegroundShineFadeOut"] = noIndentEffect,
	["BeginTrade"] = noIndentEffect,
	["BetterDate"] = noIndentEffect,
	["BindEnchant"] = noIndentEffect,
	["BlizzardOptionsPanel_Cancel"] = noIndentEffect,
	["BlizzardOptionsPanel_CancelControl"] = noIndentEffect,
	["BlizzardOptionsPanel_CheckButton_Disable"] = noIndentEffect,
	["BlizzardOptionsPanel_CheckButton_Enable"] = noIndentEffect,
	["BlizzardOptionsPanel_CheckButton_OnClick"] = noIndentEffect,
	["BlizzardOptionsPanel_CheckButton_Refresh"] = noIndentEffect,
	["BlizzardOptionsPanel_CheckButton_SetNewValue"] = noIndentEffect,
	["BlizzardOptionsPanel_Default"] = noIndentEffect,
	["BlizzardOptionsPanel_DefaultControl"] = noIndentEffect,
	["BlizzardOptionsPanel_DropDown_Refresh"] = noIndentEffect,
	["BlizzardOptionsPanel_GetCVarDefaultSafe"] = noIndentEffect,
	["BlizzardOptionsPanel_GetCVarMaxSafe"] = noIndentEffect,
	["BlizzardOptionsPanel_GetCVarMinSafe"] = noIndentEffect,
	["BlizzardOptionsPanel_GetCVarSafe"] = noIndentEffect,
	["BlizzardOptionsPanel_Okay"] = noIndentEffect,
	["BlizzardOptionsPanel_OkayControl"] = noIndentEffect,
	["BlizzardOptionsPanel_OnEvent"] = noIndentEffect,
	["BlizzardOptionsPanel_OnLoad"] = noIndentEffect,
	["BlizzardOptionsPanel_Refresh"] = noIndentEffect,
	["BlizzardOptionsPanel_RefreshControl"] = noIndentEffect,
	["BlizzardOptionsPanel_RegisterControl"] = noIndentEffect,
	["BlizzardOptionsPanel_SetCVarSafe"] = noIndentEffect,
	["BlizzardOptionsPanel_SetupControl"] = noIndentEffect,
	["BlizzardOptionsPanel_SetupDependentControl"] = noIndentEffect,
	["BlizzardOptionsPanel_Slider_Disable"] = noIndentEffect,
	["BlizzardOptionsPanel_Slider_Enable"] = noIndentEffect,
	["BlizzardOptionsPanel_Slider_OnValueChanged"] = noIndentEffect,
	["BlizzardOptionsPanel_Slider_Refresh"] = noIndentEffect,
	["BlizzardOptionsPanel_UpdateCombatText"] = noIndentEffect,
	["BlizzardOptionsPanel_UpdateRaidPullouts"] = noIndentEffect,
	["Blizzard_CombatLog_ApplyFilters"] = noIndentEffect,
	["Blizzard_CombatLog_CreateActionMenu"] = noIndentEffect,
	["Blizzard_CombatLog_CreateFilterMenu"] = noIndentEffect,
	["Blizzard_CombatLog_CreateSpellMenu"] = noIndentEffect,
	["Blizzard_CombatLog_CreateTabMenu"] = noIndentEffect,
	["Blizzard_CombatLog_CreateUnitMenu"] = noIndentEffect,
	["Blizzard_CombatLog_DisableEvent"] = noIndentEffect,
	["Blizzard_CombatLog_EnableEvent"] = noIndentEffect,
	["Blizzard_CombatLog_FormattingMenu"] = noIndentEffect,
	["Blizzard_CombatLog_GenerateFullEventList"] = noIndentEffect,
	["Blizzard_CombatLog_GenerateFullFlagList"] = noIndentEffect,
	["Blizzard_CombatLog_HasEvent"] = noIndentEffect,
	["Blizzard_CombatLog_InitializeFilters"] = noIndentEffect,
	["Blizzard_CombatLog_MenuHelper"] = noIndentEffect,
	["Blizzard_CombatLog_MessageTypesMenu"] = noIndentEffect,
	["Blizzard_CombatLog_QuickButtonFrame_OnEvent"] = noIndentEffect,
	["Blizzard_CombatLog_QuickButtonFrame_OnLoad"] = noIndentEffect,
	["Blizzard_CombatLog_QuickButtonRightClick"] = noIndentEffect,
	["Blizzard_CombatLog_QuickButton_OnClick"] = noIndentEffect,
	["Blizzard_CombatLog_Refilter"] = noIndentEffect,
	["Blizzard_CombatLog_RefilterUpdate"] = noIndentEffect,
	["Blizzard_CombatLog_RefreshGlobalLinks"] = noIndentEffect,
	["Blizzard_CombatLog_SpellMenuClick"] = noIndentEffect,
	["Blizzard_CombatLog_UnitMenuClick"] = noIndentEffect,
	["Blizzard_CombatLog_Update_QuickButtons"] = noIndentEffect,
	["BonusActionBar_OnEvent"] = noIndentEffect,
	["BonusActionBar_OnLoad"] = noIndentEffect,
	["BonusActionBar_OnUpdate"] = noIndentEffect,
	["BonusActionButtonDown"] = noIndentEffect,
	["BonusActionButtonUp"] = noIndentEffect,
	["BossTargetFrameDropDown_Initialize"] = noIndentEffect,
	["BossTargetFrame_OnLoad"] = noIndentEffect,
	["BuffButton_OnClick"] = noIndentEffect,
	["BuffButton_OnLoad"] = noIndentEffect,
	["BuffFrame_OnEvent"] = noIndentEffect,
	["BuffFrame_OnLoad"] = noIndentEffect,
	["BuffFrame_OnUpdate"] = noIndentEffect,
	["BuffFrame_Update"] = noIndentEffect,
	["BuffFrame_UpdateAllBuffAnchors"] = noIndentEffect,
	["BuffFrame_UpdatePositions"] = noIndentEffect,
	["BuildColoredListString"] = noIndentEffect,
	["BuildListString"] = noIndentEffect,
	["BuildMultilineTooltip"] = noIndentEffect,
	["BuildNewLineListString"] = noIndentEffect,
	["ButtonInventorySlot"] = noIndentEffect,
	["ButtonPulse_OnUpdate"] = noIndentEffect,
	["ButtonPulse_StopPulse"] = noIndentEffect,
	["BuyGuildBankTab"] = noIndentEffect,
	["BuyGuildCharter"] = noIndentEffect,
	["BuyMerchantItem"] = noIndentEffect,
	["BuyPetition"] = noIndentEffect,
	["BuySkillTier"] = noIndentEffect,
	["BuyStableSlot"] = noIndentEffect,
	["BuyTrainerService"] = noIndentEffect,
	["BuybackItem"] = noIndentEffect,
	["COMBAT_TEXT_SCROLL_FUNCTION"] = noIndentEffect,
	["CalculateAuctionDeposit"] = noIndentEffect,
	["CalendarAddEvent"] = noIndentEffect,
	["CalendarCanAddEvent"] = noIndentEffect,
	["CalendarCanSendInvite"] = noIndentEffect,
	["CalendarCloseEvent"] = noIndentEffect,
	["CalendarContextDeselectEvent"] = noIndentEffect,
	["CalendarContextEventCanComplain"] = noIndentEffect,
	["CalendarContextEventCanEdit"] = noIndentEffect,
	["CalendarContextEventClipboard"] = noIndentEffect,
	["CalendarContextEventComplain"] = noIndentEffect,
	["CalendarContextEventCopy"] = noIndentEffect,
	["CalendarContextEventGetCalendarType"] = noIndentEffect,
	["CalendarContextEventPaste"] = noIndentEffect,
	["CalendarContextEventRemove"] = noIndentEffect,
	["CalendarContextEventSignUp"] = noIndentEffect,
	["CalendarContextGetEventIndex"] = noIndentEffect,
	["CalendarContextInviteAvailable"] = noIndentEffect,
	["CalendarContextInviteDecline"] = noIndentEffect,
	["CalendarContextInviteIsPending"] = noIndentEffect,
	["CalendarContextInviteModeratorStatus"] = noIndentEffect,
	["CalendarContextInviteRemove"] = noIndentEffect,
	["CalendarContextInviteStatus"] = noIndentEffect,
	["CalendarContextInviteTentative"] = noIndentEffect,
	["CalendarContextInviteType"] = noIndentEffect,
	["CalendarContextSelectEvent"] = noIndentEffect,
	["CalendarDefaultGuildFilter"] = noIndentEffect,
	["CalendarEventAvailable"] = noIndentEffect,
	["CalendarEventCanEdit"] = noIndentEffect,
	["CalendarEventCanModerate"] = noIndentEffect,
	["CalendarEventClearAutoApprove"] = noIndentEffect,
	["CalendarEventClearLocked"] = noIndentEffect,
	["CalendarEventClearModerator"] = noIndentEffect,
	["CalendarEventDecline"] = noIndentEffect,
	["CalendarEventGetCalendarType"] = noIndentEffect,
	["CalendarEventGetInvite"] = noIndentEffect,
	["CalendarEventGetInviteResponseTime"] = noIndentEffect,
	["CalendarEventGetInviteSortCriterion"] = noIndentEffect,
	["CalendarEventGetNumInvites"] = noIndentEffect,
	["CalendarEventGetRepeatOptions"] = noIndentEffect,
	["CalendarEventGetSelectedInvite"] = noIndentEffect,
	["CalendarEventGetStatusOptions"] = noIndentEffect,
	["CalendarEventGetTextures"] = noIndentEffect,
	["CalendarEventGetTypes"] = noIndentEffect,
	["CalendarEventHasPendingInvite"] = noIndentEffect,
	["CalendarEventHaveSettingsChanged"] = noIndentEffect,
	["CalendarEventInvite"] = noIndentEffect,
	["CalendarEventIsModerator"] = noIndentEffect,
	["CalendarEventRemoveInvite"] = noIndentEffect,
	["CalendarEventSelectInvite"] = noIndentEffect,
	["CalendarEventSetAutoApprove"] = noIndentEffect,
	["CalendarEventSetDate"] = noIndentEffect,
	["CalendarEventSetDescription"] = noIndentEffect,
	["CalendarEventSetLocked"] = noIndentEffect,
	["CalendarEventSetLockoutDate"] = noIndentEffect,
	["CalendarEventSetLockoutTime"] = noIndentEffect,
	["CalendarEventSetModerator"] = noIndentEffect,
	["CalendarEventSetRepeatOption"] = noIndentEffect,
	["CalendarEventSetSize"] = noIndentEffect,
	["CalendarEventSetStatus"] = noIndentEffect,
	["CalendarEventSetTextureID"] = noIndentEffect,
	["CalendarEventSetTime"] = noIndentEffect,
	["CalendarEventSetTitle"] = noIndentEffect,
	["CalendarEventSetType"] = noIndentEffect,
	["CalendarEventSignUp"] = noIndentEffect,
	["CalendarEventSortInvites"] = noIndentEffect,
	["CalendarEventTentative"] = noIndentEffect,
	["CalendarGetAbsMonth"] = noIndentEffect,
	["CalendarGetDate"] = noIndentEffect,
	["CalendarGetDayEvent"] = noIndentEffect,
	["CalendarGetDayEventSequenceInfo"] = noIndentEffect,
	["CalendarGetEventIndex"] = noIndentEffect,
	["CalendarGetEventInfo"] = noIndentEffect,
	["CalendarGetFirstPendingInvite"] = noIndentEffect,
	["CalendarGetHolidayInfo"] = noIndentEffect,
	["CalendarGetMaxCreateDate"] = noIndentEffect,
	["CalendarGetMaxDate"] = noIndentEffect,
	["CalendarGetMinDate"] = noIndentEffect,
	["CalendarGetMinHistoryDate"] = noIndentEffect,
	["CalendarGetMonth"] = noIndentEffect,
	["CalendarGetMonthNames"] = noIndentEffect,
	["CalendarGetNumDayEvents"] = noIndentEffect,
	["CalendarGetNumPendingInvites"] = noIndentEffect,
	["CalendarGetRaidInfo"] = noIndentEffect,
	["CalendarGetWeekdayNames"] = noIndentEffect,
	["CalendarIsActionPending"] = noIndentEffect,
	["CalendarMassInviteArenaTeam"] = noIndentEffect,
	["CalendarMassInviteGuild"] = noIndentEffect,
	["CalendarNewEvent"] = noIndentEffect,
	["CalendarNewGuildAnnouncement"] = noIndentEffect,
	["CalendarNewGuildEvent"] = noIndentEffect,
	["CalendarOpenEvent"] = noIndentEffect,
	["CalendarRemoveEvent"] = noIndentEffect,
	["CalendarSetAbsMonth"] = noIndentEffect,
	["CalendarSetMonth"] = noIndentEffect,
	["CalendarUpdateEvent"] = noIndentEffect,
	["Calendar_LoadUI"] = noIndentEffect,
	["CallCompanion"] = noIndentEffect,
	["CallRestrictedClosure"] = noIndentEffect,
	["CameraOrSelectOrMoveStart"] = noIndentEffect,
	["CameraOrSelectOrMoveStop"] = noIndentEffect,
	["CameraZoomIn"] = noIndentEffect,
	["CameraZoomOut"] = noIndentEffect,
	["CanAlterSkin"] = noIndentEffect,
	["CanCancelAuction"] = noIndentEffect,
	["CanChangePlayerDifficulty"] = noIndentEffect,
	["CanComplainChat"] = noIndentEffect,
	["CanComplainInboxItem"] = noIndentEffect,
	["CanCooperateWithToon"] = noIndentEffect,
	["CanCreateFilters"] = noIndentEffect,
	["CanEditGuildEvent"] = noIndentEffect,
	["CanEditGuildInfo"] = noIndentEffect,
	["CanEditGuildTabInfo"] = noIndentEffect,
	["CanEditMOTD"] = noIndentEffect,
	["CanEditOfficerNote"] = noIndentEffect,
	["CanEditPublicNote"] = noIndentEffect,
	["CanEjectPassengerFromSeat"] = noIndentEffect,
	["CanExitVehicle"] = noIndentEffect,
	["CanGrantLevel"] = noIndentEffect,
	["CanGroupInvite"] = noIndentEffect,
	["CanGuildBankRepair"] = noIndentEffect,
	["CanGuildDemote"] = noIndentEffect,
	["CanGuildInvite"] = noIndentEffect,
	["CanGuildPromote"] = noIndentEffect,
	["CanGuildRemove"] = noIndentEffect,
	["CanHearthAndResurrectFromArea"] = noIndentEffect,
	["CanInspect"] = noIndentEffect,
	["CanJoinBattlefieldAsGroup"] = noIndentEffect,
	["CanMapChangeDifficulty"] = noIndentEffect,
	["CanMerchantRepair"] = noIndentEffect,
	["CanOpenPanels"] = noIndentEffect,
	["CanPartyLFGBackfill"] = noIndentEffect,
	["CanQueueForWintergrasp"] = noIndentEffect,
	["CanResetTutorials"] = noIndentEffect,
	["CanSendAuctionQuery"] = noIndentEffect,
	["CanShowAchievementUI"] = noIndentEffect,
	["CanShowCenterUIPanel"] = noIndentEffect,
	["CanShowResetInstances"] = noIndentEffect,
	["CanShowRightUIPanel"] = noIndentEffect,
	["CanShowUIPanels"] = noIndentEffect,
	["CanSignPetition"] = noIndentEffect,
	["CanSummonFriend"] = noIndentEffect,
	["CanSwitchVehicleSeat"] = noIndentEffect,
	["CanSwitchVehicleSeats"] = noIndentEffect,
	["CanUseEquipmentSets"] = noIndentEffect,
	["CanViewOfficerNote"] = noIndentEffect,
	["CanWithdrawGuildBankMoney"] = noIndentEffect,
	["CancelAreaSpiritHeal"] = noIndentEffect,
	["CancelAuction"] = noIndentEffect,
	["CancelBarberShop"] = noIndentEffect,
	["CancelDuel"] = noIndentEffect,
	["CancelItemTempEnchantment"] = noIndentEffect,
	["CancelLogout"] = noIndentEffect,
	["CancelPendingEquip"] = noIndentEffect,
	["CancelSell"] = noIndentEffect,
	["CancelShapeshiftForm"] = noIndentEffect,
	["CancelSkillUps"] = noIndentEffect,
	["CancelSummon"] = noIndentEffect,
	["CancelTrade"] = noIndentEffect,
	["CancelTradeAccept"] = noIndentEffect,
	["CancelUnitBuff"] = noIndentEffect,
	["CannotBeResurrected"] = noIndentEffect,
	["CaptureBar_Create"] = noIndentEffect,
	["CaptureBar_Update"] = noIndentEffect,
	["CastPetAction"] = noIndentEffect,
	["CastShapeshiftForm"] = noIndentEffect,
	["CastSpell"] = noIndentEffect,
	["CastSpellByID"] = noIndentEffect,
	["CastSpellByName"] = noIndentEffect,
	["CastingBarFrame_FinishSpell"] = noIndentEffect,
	["CastingBarFrame_OnEvent"] = noIndentEffect,
	["CastingBarFrame_OnLoad"] = noIndentEffect,
	["CastingBarFrame_OnShow"] = noIndentEffect,
	["CastingBarFrame_OnUpdate"] = noIndentEffect,
	["CastingBarFrame_UpdateIsShown"] = noIndentEffect,
	["ChangeActionBarPage"] = noIndentEffect,
	["ChangeChatColor"] = noIndentEffect,
	["ChangeMultiCastActionPage"] = noIndentEffect,
	["ChangePlayerDifficulty"] = noIndentEffect,
	["ChannelBan"] = noIndentEffect,
	["ChannelFrameDaughterFrame_Cancel"] = noIndentEffect,
	["ChannelFrameDaughterFrame_Okay"] = noIndentEffect,
	["ChannelFrameDaughterFrame_OnHide"] = noIndentEffect,
	["ChannelFrame_Desaturate"] = noIndentEffect,
	["ChannelFrame_Join_OnClick"] = noIndentEffect,
	["ChannelFrame_New_OnClick"] = noIndentEffect,
	["ChannelFrame_OnEvent"] = noIndentEffect,
	["ChannelFrame_OnLoad"] = noIndentEffect,
	["ChannelFrame_OnUpdate"] = noIndentEffect,
	["ChannelFrame_Update"] = noIndentEffect,
	["ChannelFrame_UpdateJoin"] = noIndentEffect,
	["ChannelInvite"] = noIndentEffect,
	["ChannelKick"] = noIndentEffect,
	["ChannelListButton_OnDragStart"] = noIndentEffect,
	["ChannelListButton_OnDragStop"] = noIndentEffect,
	["ChannelListDropDown_HideDropDown"] = noIndentEffect,
	["ChannelListDropDown_Initialize"] = noIndentEffect,
	["ChannelListDropDown_Invite"] = noIndentEffect,
	["ChannelListDropDown_SetPassword"] = noIndentEffect,
	["ChannelList_CountUpdate"] = noIndentEffect,
	["ChannelList_OnClick"] = noIndentEffect,
	["ChannelList_SetScroll"] = noIndentEffect,
	["ChannelList_ShowDropdown"] = noIndentEffect,
	["ChannelList_Update"] = noIndentEffect,
	["ChannelList_UpdateHighlight"] = noIndentEffect,
	["ChannelList_UpdateVoice"] = noIndentEffect,
	["ChannelModerator"] = noIndentEffect,
	["ChannelMute"] = noIndentEffect,
	["ChannelPulloutRosterButton_OnEvent"] = noIndentEffect,
	["ChannelPulloutRoster_DrawButton"] = noIndentEffect,
	["ChannelPulloutRoster_GetActiveSession"] = noIndentEffect,
	["ChannelPulloutRoster_GetSessionIDByName"] = noIndentEffect,
	["ChannelPulloutRoster_GetSessionInfo"] = noIndentEffect,
	["ChannelPulloutRoster_OnEvent"] = noIndentEffect,
	["ChannelPulloutRoster_OnLoad"] = noIndentEffect,
	["ChannelPulloutRoster_Populate"] = noIndentEffect,
	["ChannelPulloutRoster_Scroll"] = noIndentEffect,
	["ChannelPulloutRoster_ScrollToBottom"] = noIndentEffect,
	["ChannelPulloutRoster_ScrollToTop"] = noIndentEffect,
	["ChannelPulloutRoster_Sort"] = noIndentEffect,
	["ChannelPulloutRoster_Update"] = noIndentEffect,
	["ChannelPulloutRoster_UpdateScrollControls"] = noIndentEffect,
	["ChannelPulloutTabDropDown_Initialize"] = noIndentEffect,
	["ChannelPulloutTab_OnClick"] = noIndentEffect,
	["ChannelPulloutTab_ReanchorLeft"] = noIndentEffect,
	["ChannelPulloutTab_UpdateText"] = noIndentEffect,
	["ChannelPullout_OnEvent"] = noIndentEffect,
	["ChannelPullout_OnLoad"] = noIndentEffect,
	["ChannelPullout_OnUpdate"] = noIndentEffect,
	["ChannelPullout_SaveOpacity"] = noIndentEffect,
	["ChannelPullout_SetOpacity"] = noIndentEffect,
	["ChannelPullout_ShowOpacity"] = noIndentEffect,
	["ChannelPullout_ToggleDisplay"] = noIndentEffect,
	["ChannelRosterDropDown_Initialize"] = noIndentEffect,
	["ChannelRosterFrame_ShowDropdown"] = noIndentEffect,
	["ChannelRoster_OnClick"] = noIndentEffect,
	["ChannelRoster_SetScroll"] = noIndentEffect,
	["ChannelRoster_Update"] = noIndentEffect,
	["ChannelRoster_UpdateVoice"] = noIndentEffect,
	["ChannelSilenceAll"] = noIndentEffect,
	["ChannelSilenceVoice"] = noIndentEffect,
	["ChannelToggleAnnouncements"] = noIndentEffect,
	["ChannelUnSilenceAll"] = noIndentEffect,
	["ChannelUnSilenceVoice"] = noIndentEffect,
	["ChannelUnban"] = noIndentEffect,
	["ChannelUnmoderator"] = noIndentEffect,
	["ChannelUnmute"] = noIndentEffect,
	["ChannelVoiceOff"] = noIndentEffect,
	["ChannelVoiceOn"] = noIndentEffect,
	["CharacterAttackFrame_OnEnter"] = noIndentEffect,
	["CharacterDamageFrame_OnEnter"] = noIndentEffect,
	["CharacterFrameTab_OnClick"] = noIndentEffect,
	["CharacterFrame_OnEvent"] = noIndentEffect,
	["CharacterFrame_OnHide"] = noIndentEffect,
	["CharacterFrame_OnLoad"] = noIndentEffect,
	["CharacterFrame_OnShow"] = noIndentEffect,
	["CharacterFrame_ShowSubFrame"] = noIndentEffect,
	["CharacterFrame_TabBoundsCheck"] = noIndentEffect,
	["CharacterMicroButton_OnEvent"] = noIndentEffect,
	["CharacterMicroButton_OnLoad"] = noIndentEffect,
	["CharacterMicroButton_SetNormal"] = noIndentEffect,
	["CharacterMicroButton_SetPushed"] = noIndentEffect,
	["CharacterModelFrame_OnMouseUp"] = noIndentEffect,
	["CharacterRangedDamageFrame_OnEnter"] = noIndentEffect,
	["CharacterSpellBonusDamage_OnEnter"] = noIndentEffect,
	["CharacterSpellCritChance_OnEnter"] = noIndentEffect,
	["ChatChannelDropDown_Initialize"] = noIndentEffect,
	["ChatChannelDropDown_InviteToConversation"] = noIndentEffect,
	["ChatChannelDropDown_LeaveConversation"] = noIndentEffect,
	["ChatChannelDropDown_PopInChat"] = noIndentEffect,
	["ChatChannelDropDown_PopOutChat"] = noIndentEffect,
	["ChatChannelDropDown_Show"] = noIndentEffect,
	["ChatChannelPasswordHandler"] = noIndentEffect,
	["ChatConfigCancel_OnClick"] = noIndentEffect,
	["ChatConfigCategory_OnClick"] = noIndentEffect,
	["ChatConfigCombat_OnLoad"] = noIndentEffect,
	["ChatConfigFilter_OnClick"] = noIndentEffect,
	["ChatConfigFrame_OnEvent"] = noIndentEffect,
	["ChatConfigFrame_OnLoad"] = noIndentEffect,
	["ChatConfigFrame_PlayCheckboxSound"] = noIndentEffect,
	["ChatConfig_CreateCheckboxes"] = noIndentEffect,
	["ChatConfig_CreateColorSwatches"] = noIndentEffect,
	["ChatConfig_CreateTieredCheckboxes"] = noIndentEffect,
	["ChatConfig_HideCombatTabs"] = noIndentEffect,
	["ChatConfig_MoveFilterDown"] = noIndentEffect,
	["ChatConfig_MoveFilterUp"] = noIndentEffect,
	["ChatConfig_ShowCombatTabs"] = noIndentEffect,
	["ChatConfig_UpdateChatSettings"] = noIndentEffect,
	["ChatConfig_UpdateCheckboxes"] = noIndentEffect,
	["ChatConfig_UpdateCombatSettings"] = noIndentEffect,
	["ChatConfig_UpdateCombatTabs"] = noIndentEffect,
	["ChatConfig_UpdateFilterList"] = noIndentEffect,
	["ChatConfig_UpdateSwatches"] = noIndentEffect,
	["ChatConfig_UpdateTieredCheckboxFrame"] = noIndentEffect,
	["ChatConfig_UpdateTieredCheckboxes"] = noIndentEffect,
	["ChatEdit_ActivateChat"] = noIndentEffect,
	["ChatEdit_AddHistory"] = noIndentEffect,
	["ChatEdit_ChooseBoxForSend"] = noIndentEffect,
	["ChatEdit_CustomTabPressed"] = noIndentEffect,
	["ChatEdit_DeactivateChat"] = noIndentEffect,
	["ChatEdit_ExtractBNConversation"] = noIndentEffect,
	["ChatEdit_ExtractChannel"] = noIndentEffect,
	["ChatEdit_ExtractTellTarget"] = noIndentEffect,
	["ChatEdit_FocusActiveWindow"] = noIndentEffect,
	["ChatEdit_GetActiveWindow"] = noIndentEffect,
	["ChatEdit_GetLastActiveWindow"] = noIndentEffect,
	["ChatEdit_GetLastTellTarget"] = noIndentEffect,
	["ChatEdit_GetLastToldTarget"] = noIndentEffect,
	["ChatEdit_GetNextTellTarget"] = noIndentEffect,
	["ChatEdit_HandleChatType"] = noIndentEffect,
	["ChatEdit_InsertLink"] = noIndentEffect,
	["ChatEdit_LanguageShow"] = noIndentEffect,
	["ChatEdit_OnEditFocusGained"] = noIndentEffect,
	["ChatEdit_OnEditFocusLost"] = noIndentEffect,
	["ChatEdit_OnEnterPressed"] = noIndentEffect,
	["ChatEdit_OnEscapePressed"] = noIndentEffect,
	["ChatEdit_OnEvent"] = noIndentEffect,
	["ChatEdit_OnHide"] = noIndentEffect,
	["ChatEdit_OnInputLanguageChanged"] = noIndentEffect,
	["ChatEdit_OnLoad"] = noIndentEffect,
	["ChatEdit_OnShow"] = noIndentEffect,
	["ChatEdit_OnSpacePressed"] = noIndentEffect,
	["ChatEdit_OnTabPressed"] = noIndentEffect,
	["ChatEdit_OnTextChanged"] = noIndentEffect,
	["ChatEdit_OnTextSet"] = noIndentEffect,
	["ChatEdit_OnUpdate"] = noIndentEffect,
	["ChatEdit_ParseText"] = noIndentEffect,
	["ChatEdit_ResetChatType"] = noIndentEffect,
	["ChatEdit_ResetChatTypeToSticky"] = noIndentEffect,
	["ChatEdit_SecureTabPressed"] = noIndentEffect,
	["ChatEdit_SendText"] = noIndentEffect,
	["ChatEdit_SetLastActiveWindow"] = noIndentEffect,
	["ChatEdit_SetLastTellTarget"] = noIndentEffect,
	["ChatEdit_SetLastToldTarget"] = noIndentEffect,
	["ChatEdit_UpdateHeader"] = noIndentEffect,
	["ChatFrameMenu_UpdateAnchorPoint"] = noIndentEffect,
	["ChatFrame_ActivateCombatMessages"] = noIndentEffect,
	["ChatFrame_AddBNConversationTarget"] = noIndentEffect,
	["ChatFrame_AddChannel"] = noIndentEffect,
	["ChatFrame_AddMessageEventFilter"] = noIndentEffect,
	["ChatFrame_AddMessageGroup"] = noIndentEffect,
	["ChatFrame_AddPrivateMessageTarget"] = noIndentEffect,
	["ChatFrame_ChatPageDown"] = noIndentEffect,
	["ChatFrame_ChatPageUp"] = noIndentEffect,
	["ChatFrame_ConfigEventHandler"] = noIndentEffect,
	["ChatFrame_DisplayChatHelp"] = noIndentEffect,
	["ChatFrame_DisplayGameTime"] = noIndentEffect,
	["ChatFrame_DisplayGuildHelp"] = noIndentEffect,
	["ChatFrame_DisplayHelpText"] = noIndentEffect,
	["ChatFrame_DisplayMacroHelpText"] = noIndentEffect,
	["ChatFrame_DisplayStartupText"] = noIndentEffect,
	["ChatFrame_DisplayTimePlayed"] = noIndentEffect,
	["ChatFrame_DisplayUsageError"] = noIndentEffect,
	["ChatFrame_ExcludeBNConversationTarget"] = noIndentEffect,
	["ChatFrame_ExcludePrivateMessageTarget"] = noIndentEffect,
	["ChatFrame_GetMessageEventFilters"] = noIndentEffect,
	["ChatFrame_MessageEventHandler"] = noIndentEffect,
	["ChatFrame_OnEvent"] = noIndentEffect,
	["ChatFrame_OnHyperlinkShow"] = noIndentEffect,
	["ChatFrame_OnLoad"] = noIndentEffect,
	["ChatFrame_OnMouseWheel"] = noIndentEffect,
	["ChatFrame_OnUpdate"] = noIndentEffect,
	["ChatFrame_OpenChat"] = noIndentEffect,
	["ChatFrame_OpenMenu"] = noIndentEffect,
	["ChatFrame_ReceiveAllBNConversations"] = noIndentEffect,
	["ChatFrame_ReceiveAllPrivateMessages"] = noIndentEffect,
	["ChatFrame_RegisterForChannels"] = noIndentEffect,
	["ChatFrame_RegisterForMessages"] = noIndentEffect,
	["ChatFrame_RemoveAllChannels"] = noIndentEffect,
	["ChatFrame_RemoveAllMessageGroups"] = noIndentEffect,
	["ChatFrame_RemoveBNConversationTarget"] = noIndentEffect,
	["ChatFrame_RemoveChannel"] = noIndentEffect,
	["ChatFrame_RemoveExcludeBNConversationTarget"] = noIndentEffect,
	["ChatFrame_RemoveExcludePrivateMessageTarget"] = noIndentEffect,
	["ChatFrame_RemoveMessageEventFilter"] = noIndentEffect,
	["ChatFrame_RemoveMessageGroup"] = noIndentEffect,
	["ChatFrame_RemovePrivateMessageTarget"] = noIndentEffect,
	["ChatFrame_ReplyTell"] = noIndentEffect,
	["ChatFrame_ReplyTell2"] = noIndentEffect,
	["ChatFrame_ScrollDown"] = noIndentEffect,
	["ChatFrame_ScrollToBottom"] = noIndentEffect,
	["ChatFrame_ScrollUp"] = noIndentEffect,
	["ChatFrame_SendTell"] = noIndentEffect,
	["ChatFrame_SystemEventHandler"] = noIndentEffect,
	["ChatFrame_TimeBreakDown"] = noIndentEffect,
	["ChatHistory_GetAccessID"] = noIndentEffect,
	["ChatHistory_GetChatType"] = noIndentEffect,
	["ChatHistory_GetToken"] = noIndentEffect,
	["ChatMenu_Battleground"] = noIndentEffect,
	["ChatMenu_Emote"] = noIndentEffect,
	["ChatMenu_Guild"] = noIndentEffect,
	["ChatMenu_OnLoad"] = noIndentEffect,
	["ChatMenu_OnShow"] = noIndentEffect,
	["ChatMenu_Party"] = noIndentEffect,
	["ChatMenu_Raid"] = noIndentEffect,
	["ChatMenu_Reply"] = noIndentEffect,
	["ChatMenu_Say"] = noIndentEffect,
	["ChatMenu_SetChatType"] = noIndentEffect,
	["ChatMenu_VoiceMacro"] = noIndentEffect,
	["ChatMenu_Whisper"] = noIndentEffect,
	["ChatMenu_Yell"] = noIndentEffect,
	["ChatUnitColor_OpenColorPicker"] = noIndentEffect,
	["Chat_GetChannelShortcutName"] = noIndentEffect,
	["Chat_GetChatCategory"] = noIndentEffect,
	["Chat_GetColoredChatName"] = noIndentEffect,
	["CheckBinderDist"] = noIndentEffect,
	["CheckInbox"] = noIndentEffect,
	["CheckInteractDistance"] = noIndentEffect,
	["CheckSpiritHealerDist"] = noIndentEffect,
	["CheckTalentMasterDist"] = noIndentEffect,
	["CinematicFrame_OnEvent"] = noIndentEffect,
	["CinematicFrame_OnLoad"] = noIndentEffect,
	["ClassTrainerFrame_LoadUI"] = noIndentEffect,
	["ClearAchievementComparisonUnit"] = noIndentEffect,
	["ClearAllLFGDungeons"] = noIndentEffect,
	["ClearChannelWatch"] = noIndentEffect,
	["ClearCursor"] = noIndentEffect,
	["ClearFocus"] = noIndentEffect,
	["ClearInspectPlayer"] = noIndentEffect,
	["ClearLFGDungeon"] = noIndentEffect,
	["ClearOverrideBindings"] = noIndentEffect,
	["ClearPartyAssignment"] = noIndentEffect,
	["ClearPendingGuildBankPermissions"] = noIndentEffect,
	["ClearRaidMarker"] = noIndentEffect,
	["ClearSendMail"] = noIndentEffect,
	["ClearTarget"] = noIndentEffect,
	["ClearTutorials"] = noIndentEffect,
	["ClickAuctionSellItemButton"] = noIndentEffect,
	["ClickLandmark"] = noIndentEffect,
	["ClickPetitionButton"] = noIndentEffect,
	["ClickSendMailItemButton"] = noIndentEffect,
	["ClickSocketButton"] = noIndentEffect,
	["ClickStablePet"] = noIndentEffect,
	["ClickTargetTradeButton"] = noIndentEffect,
	["ClickTradeButton"] = noIndentEffect,
	["CloseAllBags"] = noIndentEffect,
	["CloseAllWindows"] = noIndentEffect,
	["CloseAllWindows_WithExceptions"] = noIndentEffect,
	["CloseArenaTeamRoster"] = noIndentEffect,
	["CloseAuctionHouse"] = noIndentEffect,
	["CloseBackpack"] = noIndentEffect,
	["CloseBag"] = noIndentEffect,
	["CloseBankBagFrames"] = noIndentEffect,
	["CloseBankFrame"] = noIndentEffect,
	["CloseBattlefield"] = noIndentEffect,
	["CloseChildWindows"] = noIndentEffect,
	["CloseDropDownMenus"] = noIndentEffect,
	["CloseGossip"] = noIndentEffect,
	["CloseGuildBankFrame"] = noIndentEffect,
	["CloseGuildRegistrar"] = noIndentEffect,
	["CloseGuildRoster"] = noIndentEffect,
	["CloseItemText"] = noIndentEffect,
	["CloseLoot"] = noIndentEffect,
	["CloseMail"] = noIndentEffect,
	["CloseMenus"] = noIndentEffect,
	["CloseMerchant"] = noIndentEffect,
	["ClosePetStables"] = noIndentEffect,
	["ClosePetition"] = noIndentEffect,
	["ClosePetitionVendor"] = noIndentEffect,
	["CloseQuest"] = noIndentEffect,
	["CloseSocketInfo"] = noIndentEffect,
	["CloseSpecialWindows"] = noIndentEffect,
	["CloseTabardCreation"] = noIndentEffect,
	["CloseTaxiMap"] = noIndentEffect,
	["CloseTrade"] = noIndentEffect,
	["CloseTradeSkill"] = noIndentEffect,
	["CloseTrainer"] = noIndentEffect,
	["CloseWindows"] = noIndentEffect,
	["CoinPickupFrameCancel_Click"] = noIndentEffect,
	["CoinPickupFrameLeft_Click"] = noIndentEffect,
	["CoinPickupFrameOkay_Click"] = noIndentEffect,
	["CoinPickupFrameRight_Click"] = noIndentEffect,
	["CoinPickupFrame_OnChar"] = noIndentEffect,
	["CoinPickupFrame_OnHide"] = noIndentEffect,
	["CoinPickupFrame_OnKeyDown"] = noIndentEffect,
	["CoinPickupFrame_OnKeyUp"] = noIndentEffect,
	["CollapseAllFactionHeaders"] = noIndentEffect,
	["CollapseChannelHeader"] = noIndentEffect,
	["CollapseFactionHeader"] = noIndentEffect,
	["CollapseQuestHeader"] = noIndentEffect,
	["CollapseSkillHeader"] = noIndentEffect,
	["CollapseTradeSkillSubClass"] = noIndentEffect,
	["CollapseTrainerSkillLine"] = noIndentEffect,
	["ColorClassesCheckBox_OnClick"] = noIndentEffect,
	["ColorPaperDollStat"] = noIndentEffect,
	["ColorPicker_GetPreviousValues"] = noIndentEffect,
	["CombatConfig_Colorize_Update"] = noIndentEffect,
	["CombatConfig_CreateCombatFilter"] = noIndentEffect,
	["CombatConfig_DeleteCurrentCombatFilter"] = noIndentEffect,
	["CombatConfig_Formatting_Update"] = noIndentEffect,
	["CombatConfig_SetCombatFiltersToDefault"] = noIndentEffect,
	["CombatConfig_SetFilterName"] = noIndentEffect,
	["CombatConfig_Settings_Update"] = noIndentEffect,
	["CombatFeedback_Initialize"] = noIndentEffect,
	["CombatFeedback_OnCombatEvent"] = noIndentEffect,
	["CombatFeedback_OnUpdate"] = noIndentEffect,
	["CombatFeedback_StartFullscreenStatus"] = noIndentEffect,
	["CombatFeedback_StopFullscreenStatus"] = noIndentEffect,
	["CombatLogAddFilter"] = noIndentEffect,
	["CombatLogAdvanceEntry"] = noIndentEffect,
	["CombatLogClearEntries"] = noIndentEffect,
	["CombatLogGetCurrentEntry"] = noIndentEffect,
	["CombatLogGetNumEntries"] = noIndentEffect,
	["CombatLogGetRetentionTime"] = noIndentEffect,
	["CombatLogResetFilter"] = noIndentEffect,
	["CombatLogSetCurrentEntry"] = noIndentEffect,
	["CombatLogSetRetentionTime"] = noIndentEffect,
	["CombatLog_AddEvent"] = noIndentEffect,
	["CombatLog_Color_ColorArrayByEventType"] = noIndentEffect,
	["CombatLog_Color_ColorArrayBySchool"] = noIndentEffect,
	["CombatLog_Color_ColorArrayByUnitType"] = noIndentEffect,
	["CombatLog_Color_ColorStringByEventType"] = noIndentEffect,
	["CombatLog_Color_ColorStringBySchool"] = noIndentEffect,
	["CombatLog_Color_ColorStringByUnitType"] = noIndentEffect,
	["CombatLog_Color_FloatToText"] = noIndentEffect,
	["CombatLog_Color_HighlightColorArray"] = noIndentEffect,
	["CombatLog_LoadUI"] = noIndentEffect,
	["CombatLog_Object_IsA"] = noIndentEffect,
	["CombatLog_OnEvent"] = noIndentEffect,
	["CombatLog_String_DamageResultString"] = noIndentEffect,
	["CombatLog_String_GetIcon"] = noIndentEffect,
	["CombatLog_String_GetToken"] = noIndentEffect,
	["CombatLog_String_PowerType"] = noIndentEffect,
	["CombatLog_String_SchoolString"] = noIndentEffect,
	["CombatTextSetActiveUnit"] = noIndentEffect,
	["CombatText_AddMessage"] = noIndentEffect,
	["CombatText_ClearAnimationList"] = noIndentEffect,
	["CombatText_FountainScroll"] = noIndentEffect,
	["CombatText_GetAvailableString"] = noIndentEffect,
	["CombatText_GetOldestString"] = noIndentEffect,
	["CombatText_OnEvent"] = noIndentEffect,
	["CombatText_OnLoad"] = noIndentEffect,
	["CombatText_OnUpdate"] = noIndentEffect,
	["CombatText_RemoveMessage"] = noIndentEffect,
	["CombatText_StandardScroll"] = noIndentEffect,
	["CombatText_UpdateDisplayedMessages"] = noIndentEffect,
	["ComboFrame_OnEvent"] = noIndentEffect,
	["ComboFrame_Update"] = noIndentEffect,
	["ComboPointShineFadeIn"] = noIndentEffect,
	["ComboPointShineFadeOut"] = noIndentEffect,
	["CommentatorAddPlayer"] = noIndentEffect,
	["CommentatorEnterInstance"] = noIndentEffect,
	["CommentatorExitInstance"] = noIndentEffect,
	["CommentatorFollowPlayer"] = noIndentEffect,
	["CommentatorGetCamera"] = noIndentEffect,
	["CommentatorGetCurrentMapID"] = noIndentEffect,
	["CommentatorGetInstanceInfo"] = noIndentEffect,
	["CommentatorGetMapInfo"] = noIndentEffect,
	["CommentatorGetMode"] = noIndentEffect,
	["CommentatorGetNumMaps"] = noIndentEffect,
	["CommentatorGetNumPlayers"] = noIndentEffect,
	["CommentatorGetPlayerInfo"] = noIndentEffect,
	["CommentatorGetSkirmishMode"] = noIndentEffect,
	["CommentatorGetSkirmishQueueCount"] = noIndentEffect,
	["CommentatorGetSkirmishQueuePlayerInfo"] = noIndentEffect,
	["CommentatorLookatPlayer"] = noIndentEffect,
	["CommentatorRemovePlayer"] = noIndentEffect,
	["CommentatorRequestSkirmishMode"] = noIndentEffect,
	["CommentatorRequestSkirmishQueueData"] = noIndentEffect,
	["CommentatorSetBattlemaster"] = noIndentEffect,
	["CommentatorSetCamera"] = noIndentEffect,
	["CommentatorSetCameraCollision"] = noIndentEffect,
	["CommentatorSetMapAndInstanceIndex"] = noIndentEffect,
	["CommentatorSetMode"] = noIndentEffect,
	["CommentatorSetMoveSpeed"] = noIndentEffect,
	["CommentatorSetPlayerIndex"] = noIndentEffect,
	["CommentatorSetSkirmishMatchmakingMode"] = noIndentEffect,
	["CommentatorSetTargetHeightOffset"] = noIndentEffect,
	["CommentatorStartInstance"] = noIndentEffect,
	["CommentatorStartSkirmishMatch"] = noIndentEffect,
	["CommentatorToggleMode"] = noIndentEffect,
	["CommentatorUpdateMapInfo"] = noIndentEffect,
	["CommentatorUpdatePlayerInfo"] = noIndentEffect,
	["CommentatorZoomIn"] = noIndentEffect,
	["CommentatorZoomOut"] = noIndentEffect,
	["CompanionButton_OnClick"] = noIndentEffect,
	["CompanionButton_OnDrag"] = noIndentEffect,
	["CompanionButton_OnEnter"] = noIndentEffect,
	["CompanionButton_OnLoad"] = noIndentEffect,
	["CompanionButton_OnModifiedClick"] = noIndentEffect,
	["CompanionSummonButton_OnClick"] = noIndentEffect,
	["ComplainChat"] = noIndentEffect,
	["ComplainInboxItem"] = noIndentEffect,
	["CompleteLFGRoleCheck"] = noIndentEffect,
	["CompleteQuest"] = noIndentEffect,
	["ComputePetBonus"] = noIndentEffect,
	["ConfirmAcceptQuest"] = noIndentEffect,
	["ConfirmBindOnUse"] = noIndentEffect,
	["ConfirmBinder"] = noIndentEffect,
	["ConfirmLootRoll"] = noIndentEffect,
	["ConfirmLootSlot"] = noIndentEffect,
	["ConfirmReadyCheck"] = noIndentEffect,
	["ConfirmSummon"] = noIndentEffect,
	["ConfirmTalentWipe"] = noIndentEffect,
	["ConsoleAddMessage"] = noIndentEffect,
	["ConsoleExec"] = noIndentEffect,
	["ConsolePrint"] = noIndentEffect,
	["ConsolidatedBuffs_OnEnter"] = noIndentEffect,
	["ConsolidatedBuffs_OnHide"] = noIndentEffect,
	["ConsolidatedBuffs_OnShow"] = noIndentEffect,
	["ConsolidatedBuffs_OnUpdate"] = noIndentEffect,
	["ConsolidatedBuffs_UpdateAllAnchors"] = noIndentEffect,
	["ContainerFrameItemButton_OnClick"] = noIndentEffect,
	["ContainerFrameItemButton_OnDrag"] = noIndentEffect,
	["ContainerFrameItemButton_OnEnter"] = noIndentEffect,
	["ContainerFrameItemButton_OnLoad"] = noIndentEffect,
	["ContainerFrameItemButton_OnModifiedClick"] = noIndentEffect,
	["ContainerFrame_GenerateFrame"] = noIndentEffect,
	["ContainerFrame_GetExtendedPriceString"] = noIndentEffect,
	["ContainerFrame_GetOpenFrame"] = noIndentEffect,
	["ContainerFrame_OnEvent"] = noIndentEffect,
	["ContainerFrame_OnHide"] = noIndentEffect,
	["ContainerFrame_OnLoad"] = noIndentEffect,
	["ContainerFrame_OnShow"] = noIndentEffect,
	["ContainerFrame_Update"] = noIndentEffect,
	["ContainerFrame_UpdateCooldown"] = noIndentEffect,
	["ContainerFrame_UpdateCooldowns"] = noIndentEffect,
	["ContainerFrame_UpdateLocked"] = noIndentEffect,
	["ContainerFrame_UpdateLockedItem"] = noIndentEffect,
	["ContainerIDToInventoryID"] = noIndentEffect,
	["ContainerRefundItemPurchase"] = noIndentEffect,
	["ConvertToParty"] = noIndentEffect,
	["ConvertToRaid"] = noIndentEffect,
	["CooldownFrame_SetTimer"] = noIndentEffect,
	["CopyTable"] = noIndentEffect,
	["CreateChatChannelList"] = noIndentEffect,
	["CreateFont"] = noIndentEffect,
	["CreateFrame"] = noIndentEffect,
	["CreateMacro"] = noIndentEffect,
	["CreateMiniWorldMapArrowFrame"] = noIndentEffect,
	["CreateWorldMapArrowFrame"] = noIndentEffect,
	["CursorCanGoInSlot"] = noIndentEffect,
	["CursorHasItem"] = noIndentEffect,
	["CursorHasMacro"] = noIndentEffect,
	["CursorHasMoney"] = noIndentEffect,
	["CursorHasSpell"] = noIndentEffect,
	["CursorOnUpdate"] = noIndentEffect,
	["CursorUpdate"] = noIndentEffect,
	["DamageColor_OpenColorPicker"] = noIndentEffect,
	["DeathKnniggetThrobFunction"] = noIndentEffect,
	["DebuffButton_UpdateAnchors"] = noIndentEffect,
	["DeclineArenaTeam"] = noIndentEffect,
	["DeclineGroup"] = noIndentEffect,
	["DeclineGuild"] = noIndentEffect,
	["DeclineInvite"] = noIndentEffect,
	["DeclineLevelGrant"] = noIndentEffect,
	["DeclineName"] = noIndentEffect,
	["DeclineQuest"] = noIndentEffect,
	["DeclineResurrect"] = noIndentEffect,
	["DelIgnore"] = noIndentEffect,
	["DelMute"] = noIndentEffect,
	["DeleteCursorItem"] = noIndentEffect,
	["DeleteEquipmentSet"] = noIndentEffect,
	["DeleteFile"] = noIndentEffect,
	["DeleteGMTicket"] = noIndentEffect,
	["DeleteInboxItem"] = noIndentEffect,
	["DeleteMacro"] = noIndentEffect,
	["DemoteAssistant"] = noIndentEffect,
	["DepositGuildBankMoney"] = noIndentEffect,
	["DescendStop"] = noIndentEffect,
	["DestroyTotem"] = noIndentEffect,
	["DetectWowMouse"] = noIndentEffect,
	["DisableAddOn"] = noIndentEffect,
	["DisableAllAddOns"] = noIndentEffect,
	["DisablePagingButton"] = noIndentEffect,
	["DisableSpellAutocast"] = noIndentEffect,
	["Disable_BagButtons"] = noIndentEffect,
	["DismissCompanion"] = noIndentEffect,
	["Dismount"] = noIndentEffect,
	["DisplayChannelOwner"] = noIndentEffect,
	["DisplayChannelVoiceOff"] = noIndentEffect,
	["DisplayChannelVoiceOn"] = noIndentEffect,
	["DoEmote"] = noIndentEffect,
	["DoReadyCheck"] = noIndentEffect,
	["DoTradeSkill"] = noIndentEffect,
	["DownloadSettings"] = noIndentEffect,
	["DrawOneHopLines"] = noIndentEffect,
	["DrawRouteLine"] = noIndentEffect,
	["DressUpItemLink"] = noIndentEffect,
	["DressUpTexturePath"] = noIndentEffect,
	["DropCursorMoney"] = noIndentEffect,
	["DropItemOnUnit"] = noIndentEffect,
	["DungeonCompletionAlertFrameReward_OnEnter"] = noIndentEffect,
	["DungeonCompletionAlertFrameReward_OnLeave"] = noIndentEffect,
	["DungeonCompletionAlertFrameReward_SetReward"] = noIndentEffect,
	["DungeonCompletionAlertFrame_FixAnchors"] = noIndentEffect,
	["DungeonCompletionAlertFrame_OnLoad"] = noIndentEffect,
	["DungeonCompletionAlertFrame_ShowAlert"] = noIndentEffect,
	["DungeonUsesTerrainMap"] = noIndentEffect,
	["DurabilityFrame_SetAlerts"] = noIndentEffect,
	["DynamicScrollFrame_CreateButtons"] = noIndentEffect,
	["DynamicScrollFrame_OnVerticalScroll"] = noIndentEffect,
	["DynamicScrollFrame_UnlockAllHighlights"] = noIndentEffect,
	["DynamicScrollFrame_Update"] = noIndentEffect,
	["EasyMenu"] = noIndentEffect,
	["EasyMenu_Initialize"] = noIndentEffect,
	["EditBox_ClearFocus"] = noIndentEffect,
	["EditBox_ClearHighlight"] = noIndentEffect,
	["EditBox_HandleTabbing"] = noIndentEffect,
	["EditBox_HighlightText"] = noIndentEffect,
	["EditBox_SetFocus"] = noIndentEffect,
	["EditMacro"] = noIndentEffect,
	["EjectPassengerFromSeat"] = noIndentEffect,
	["EmoteMenu_Click"] = noIndentEffect,
	["EmoteMenu_OnLoad"] = noIndentEffect,
	["EnableAddOn"] = noIndentEffect,
	["EnableAllAddOns"] = noIndentEffect,
	["EnablePagingButton"] = noIndentEffect,
	["EnableSpellAutocast"] = noIndentEffect,
	["Enable_BagButtons"] = noIndentEffect,
	["EndBoundTradeable"] = noIndentEffect,
	["EndRefund"] = noIndentEffect,
	["EnumerateFrames"] = noIndentEffect,
	["EnumerateServerChannels"] = noIndentEffect,
	["EquipCursorItem"] = noIndentEffect,
	["EquipItemByName"] = noIndentEffect,
	["EquipPendingItem"] = noIndentEffect,
	["EquipmentManagerClearIgnoredSlotsForSave"] = noIndentEffect,
	["EquipmentManagerIgnoreSlotForSave"] = noIndentEffect,
	["EquipmentManagerIsSlotIgnoredForSave"] = noIndentEffect,
	["EquipmentManagerUnignoreSlotForSave"] = noIndentEffect,
	["EquipmentManager_EquipContainerItem"] = noIndentEffect,
	["EquipmentManager_EquipInventoryItem"] = noIndentEffect,
	["EquipmentManager_EquipItemByLocation"] = noIndentEffect,
	["EquipmentManager_EquipSet"] = noIndentEffect,
	["EquipmentManager_GetItemInfoByLocation"] = noIndentEffect,
	["EquipmentManager_OnEvent"] = noIndentEffect,
	["EquipmentManager_PutItemInInventory"] = noIndentEffect,
	["EquipmentManager_RunAction"] = noIndentEffect,
	["EquipmentManager_UnequipItemInSlot"] = noIndentEffect,
	["EquipmentManager_UnpackLocation"] = noIndentEffect,
	["EquipmentManager_UpdateFreeBagSpace"] = noIndentEffect,
	["EquipmentSetContainsLockedItems"] = noIndentEffect,
	["ExhaustionTick_OnEvent"] = noIndentEffect,
	["ExhaustionTick_OnLoad"] = noIndentEffect,
	["ExhaustionTick_OnUpdate"] = noIndentEffect,
	["ExhaustionToolTipText"] = noIndentEffect,
	["ExpandAllFactionHeaders"] = noIndentEffect,
	["ExpandChannelHeader"] = noIndentEffect,
	["ExpandCurrencyList"] = noIndentEffect,
	["ExpandFactionHeader"] = noIndentEffect,
	["ExpandQuestHeader"] = noIndentEffect,
	["ExpandSkillHeader"] = noIndentEffect,
	["ExpandTradeSkillSubClass"] = noIndentEffect,
	["ExpandTrainerSkillLine"] = noIndentEffect,
	["EyeTemplate_OnUpdate"] = noIndentEffect,
	["EyeTemplate_StartAnimating"] = noIndentEffect,
	["EyeTemplate_StopAnimating"] = noIndentEffect,
	["FCFChannelDropDown_OnClick"] = noIndentEffect,
	["FCFClickAnywhereButton_OnEvent"] = noIndentEffect,
	["FCFClickAnywhereButton_OnLoad"] = noIndentEffect,
	["FCFClickAnywhereButton_UpdateState"] = noIndentEffect,
	["FCFDockOverflowButton_OnClick"] = noIndentEffect,
	["FCFDockOverflowButton_OnEvent"] = noIndentEffect,
	["FCFDockOverflowButton_UpdatePulseState"] = noIndentEffect,
	["FCFDockOverflowListButton_OnClick"] = noIndentEffect,
	["FCFDockOverflowListButton_SetValue"] = noIndentEffect,
	["FCFDockOverflowList_Update"] = noIndentEffect,
	["FCFDockOverflow_CloseLists"] = noIndentEffect,
	["FCFDockScrollFrame_GetLeftmostTab"] = noIndentEffect,
	["FCFDockScrollFrame_GetScrollDistanceNeeded"] = noIndentEffect,
	["FCFDockScrollFrame_JumpToTab"] = noIndentEffect,
	["FCFDockScrollFrame_OnUpdate"] = noIndentEffect,
	["FCFDock_AddChatFrame"] = noIndentEffect,
	["FCFDock_CalculateTabSize"] = noIndentEffect,
	["FCFDock_ForceReanchoring"] = noIndentEffect,
	["FCFDock_GetChatFrames"] = noIndentEffect,
	["FCFDock_GetInsertIndex"] = noIndentEffect,
	["FCFDock_GetSelectedWindow"] = noIndentEffect,
	["FCFDock_HasDockedChatFrame"] = noIndentEffect,
	["FCFDock_HideInsertHighlight"] = noIndentEffect,
	["FCFDock_OnEvent"] = noIndentEffect,
	["FCFDock_OnLoad"] = noIndentEffect,
	["FCFDock_OnPrimarySizeChanged"] = noIndentEffect,
	["FCFDock_OnUpdate"] = noIndentEffect,
	["FCFDock_PlaceInsertHighlight"] = noIndentEffect,
	["FCFDock_RemoveChatFrame"] = noIndentEffect,
	["FCFDock_ScrollToSelectedTab"] = noIndentEffect,
	["FCFDock_SelectWindow"] = noIndentEffect,
	["FCFDock_SetDirty"] = noIndentEffect,
	["FCFDock_SetPrimary"] = noIndentEffect,
	["FCFDock_UpdateTabs"] = noIndentEffect,
	["FCFDropDown_LoadChannels"] = noIndentEffect,
	["FCFDropDown_LoadChatTypes"] = noIndentEffect,
	["FCFManager_GetNumDedicatedFrames"] = noIndentEffect,
	["FCFManager_RegisterDedicatedFrame"] = noIndentEffect,
	["FCFManager_ShouldSuppressMessage"] = noIndentEffect,
	["FCFManager_UnregisterDedicatedFrame"] = noIndentEffect,
	["FCFMessageTypeDropDown_OnClick"] = noIndentEffect,
	["FCFMin_UpdateColors"] = noIndentEffect,
	["FCFOptionsDropDown_Initialize"] = noIndentEffect,
	["FCFOptionsDropDown_OnLoad"] = noIndentEffect,
	["FCFTab_OnDragStop"] = noIndentEffect,
	["FCFTab_OnUpdate"] = noIndentEffect,
	["FCFTab_UpdateAlpha"] = noIndentEffect,
	["FCFTab_UpdateColors"] = noIndentEffect,
	["FCF_CancelFontColorSettings"] = noIndentEffect,
	["FCF_CancelWindowColorSettings"] = noIndentEffect,
	["FCF_Close"] = noIndentEffect,
	["FCF_CopyChatSettings"] = noIndentEffect,
	["FCF_CreateMinimizedFrame"] = noIndentEffect,
	["FCF_DockFrame"] = noIndentEffect,
	["FCF_DockUpdate"] = noIndentEffect,
	["FCF_FadeInChatFrame"] = noIndentEffect,
	["FCF_FadeOutChatFrame"] = noIndentEffect,
	["FCF_FlagMinimizedPositionReset"] = noIndentEffect,
	["FCF_FlashTab"] = noIndentEffect,
	["FCF_GetButtonSide"] = noIndentEffect,
	["FCF_GetChatWindowInfo"] = noIndentEffect,
	["FCF_GetCurrentChatFrame"] = noIndentEffect,
	["FCF_GetCurrentChatFrameID"] = noIndentEffect,
	["FCF_GetNumActiveChatFrames"] = noIndentEffect,
	["FCF_HideOnFadeFinished"] = noIndentEffect,
	["FCF_IsValidChatFrame"] = noIndentEffect,
	["FCF_LeaveConversation"] = noIndentEffect,
	["FCF_LoadChatSubTypes"] = noIndentEffect,
	["FCF_MaximizeFrame"] = noIndentEffect,
	["FCF_MinimizeFrame"] = noIndentEffect,
	["FCF_NewChatWindow"] = noIndentEffect,
	["FCF_OnUpdate"] = noIndentEffect,
	["FCF_OpenNewWindow"] = noIndentEffect,
	["FCF_OpenTemporaryWindow"] = noIndentEffect,
	["FCF_PopInWindow"] = noIndentEffect,
	["FCF_RenameChatWindow_Popup"] = noIndentEffect,
	["FCF_ResetAllWindows"] = noIndentEffect,
	["FCF_ResetChatWindows"] = noIndentEffect,
	["FCF_RestoreChatsToFrame"] = noIndentEffect,
	["FCF_RestorePositionAndDimensions"] = noIndentEffect,
	["FCF_SaveDock"] = noIndentEffect,
	["FCF_SavePositionAndDimensions"] = noIndentEffect,
	["FCF_SelectDockFrame"] = noIndentEffect,
	["FCF_SetButtonSide"] = noIndentEffect,
	["FCF_SetChatTypeColor"] = noIndentEffect,
	["FCF_SetChatWindowBackGroundColor"] = noIndentEffect,
	["FCF_SetChatWindowFontSize"] = noIndentEffect,
	["FCF_SetChatWindowOpacity"] = noIndentEffect,
	["FCF_SetExpandedUninteractable"] = noIndentEffect,
	["FCF_SetLocked"] = noIndentEffect,
	["FCF_SetTabPosition"] = noIndentEffect,
	["FCF_SetTemporaryWindowType"] = noIndentEffect,
	["FCF_SetUninteractable"] = noIndentEffect,
	["FCF_SetWindowAlpha"] = noIndentEffect,
	["FCF_SetWindowColor"] = noIndentEffect,
	["FCF_SetWindowName"] = noIndentEffect,
	["FCF_Set_NormalChat"] = noIndentEffect,
	["FCF_StartAlertFlash"] = noIndentEffect,
	["FCF_StopAlertFlash"] = noIndentEffect,
	["FCF_StopDragging"] = noIndentEffect,
	["FCF_StripChatMsg"] = noIndentEffect,
	["FCF_TabCompare"] = noIndentEffect,
	["FCF_Tab_OnClick"] = noIndentEffect,
	["FCF_ToggleLock"] = noIndentEffect,
	["FCF_ToggleUninteractable"] = noIndentEffect,
	["FCF_UnDockFrame"] = noIndentEffect,
	["FCF_UpdateButtonSide"] = noIndentEffect,
	["FCF_UpdateDockPosition"] = noIndentEffect,
	["FactionToggleAtWar"] = noIndentEffect,
	["FadingFrame_OnLoad"] = noIndentEffect,
	["FadingFrame_OnUpdate"] = noIndentEffect,
	["FadingFrame_SetFadeInTime"] = noIndentEffect,
	["FadingFrame_SetFadeOutTime"] = noIndentEffect,
	["FadingFrame_SetHoldTime"] = noIndentEffect,
	["FadingFrame_Show"] = noIndentEffect,
	["FauxScrollFrame_GetOffset"] = noIndentEffect,
	["FauxScrollFrame_OnVerticalScroll"] = noIndentEffect,
	["FauxScrollFrame_SetOffset"] = noIndentEffect,
	["FauxScrollFrame_Update"] = noIndentEffect,
	["FillLocalizedClassList"] = noIndentEffect,
	["FindSpellBookSlotByID"] = noIndentEffect,
	["FlagTutorial"] = noIndentEffect,
	["FlipCameraYaw"] = noIndentEffect,
	["FloatingChatFrameManager_OnEvent"] = noIndentEffect,
	["FloatingChatFrameManager_OnLoad"] = noIndentEffect,
	["FloatingChatFrame_OnEvent"] = noIndentEffect,
	["FloatingChatFrame_OnLoad"] = noIndentEffect,
	["FloatingChatFrame_OnMouseScroll"] = noIndentEffect,
	["FloatingChatFrame_Update"] = noIndentEffect,
	["FocusFrameDropDown_Initialize"] = noIndentEffect,
	["FocusFrame_IsLocked"] = noIndentEffect,
	["FocusFrame_OnDragStart"] = noIndentEffect,
	["FocusFrame_OnDragStop"] = noIndentEffect,
	["FocusFrame_SetLock"] = noIndentEffect,
	["FocusFrame_SetSmallSize"] = noIndentEffect,
	["FocusUnit"] = noIndentEffect,
	["FollowUnit"] = noIndentEffect,
	["ForceGossip"] = noIndentEffect,
	["ForceLogout"] = noIndentEffect,
	["ForceQuit"] = noIndentEffect,
	["FormatPaperDollTooltipStat"] = noIndentEffect,
	["FrameXML_Debug"] = noIndentEffect,
	["FriendsFrameAddFriendButton_OnClick"] = noIndentEffect,
	["FriendsFrameBNDropDown_Initialize"] = noIndentEffect,
	["FriendsFrameBNOfflineDropDown_Initialize"] = noIndentEffect,
	["FriendsFrameBroadcastInput_OnClearPressed"] = noIndentEffect,
	["FriendsFrameBroadcastInput_OnEnterPressed"] = noIndentEffect,
	["FriendsFrameBroadcastInput_OnEscapePressed"] = noIndentEffect,
	["FriendsFrameBroadcastInput_UpdateDisplay"] = noIndentEffect,
	["FriendsFrameDropDown_Initialize"] = noIndentEffect,
	["FriendsFrameFriendButton_OnClick"] = noIndentEffect,
	["FriendsFrameGuildStatusButton_OnClick"] = noIndentEffect,
	["FriendsFrameIgnoreButton_OnClick"] = noIndentEffect,
	["FriendsFrameMuteButton_OnClick"] = noIndentEffect,
	["FriendsFrameOfflineDropDown_Initialize"] = noIndentEffect,
	["FriendsFramePendingScrollFrame_AdjustScroll"] = noIndentEffect,
	["FriendsFrameSendMessageButton_OnClick"] = noIndentEffect,
	["FriendsFrameStatusDropDown_Initialize"] = noIndentEffect,
	["FriendsFrameStatusDropDown_OnLoad"] = noIndentEffect,
	["FriendsFrameStatusDropDown_OnShow"] = noIndentEffect,
	["FriendsFrameStatusDropDown_ShowTooltip"] = noIndentEffect,
	["FriendsFrameStatusDropDown_Update"] = noIndentEffect,
	["FriendsFrameTooltip_SetLine"] = noIndentEffect,
	["FriendsFrameTooltip_Show"] = noIndentEffect,
	["FriendsFrameUnsquelchButton_OnClick"] = noIndentEffect,
	["FriendsFrameWhoButton_OnClick"] = noIndentEffect,
	["FriendsFrame_CheckBattlenetStatus"] = noIndentEffect,
	["FriendsFrame_ClickSummonButton"] = noIndentEffect,
	["FriendsFrame_GetLastOnline"] = noIndentEffect,
	["FriendsFrame_GetTopButton"] = noIndentEffect,
	["FriendsFrame_GroupInvite"] = noIndentEffect,
	["FriendsFrame_OnEvent"] = noIndentEffect,
	["FriendsFrame_OnHide"] = noIndentEffect,
	["FriendsFrame_OnLoad"] = noIndentEffect,
	["FriendsFrame_OnShow"] = noIndentEffect,
	["FriendsFrame_RemoveFriend"] = noIndentEffect,
	["FriendsFrame_SelectFriend"] = noIndentEffect,
	["FriendsFrame_SelectSquelched"] = noIndentEffect,
	["FriendsFrame_SendMessage"] = noIndentEffect,
	["FriendsFrame_SetButton"] = noIndentEffect,
	["FriendsFrame_SetOnlineStatus"] = noIndentEffect,
	["FriendsFrame_ShowBNDropdown"] = noIndentEffect,
	["FriendsFrame_ShowDropdown"] = noIndentEffect,
	["FriendsFrame_ShowSubFrame"] = noIndentEffect,
	["FriendsFrame_SummonButton_OnEvent"] = noIndentEffect,
	["FriendsFrame_SummonButton_OnShow"] = noIndentEffect,
	["FriendsFrame_SummonButton_Update"] = noIndentEffect,
	["FriendsFrame_UnBlock"] = noIndentEffect,
	["FriendsFrame_UnIgnore"] = noIndentEffect,
	["FriendsFrame_UnMute"] = noIndentEffect,
	["FriendsFrame_Update"] = noIndentEffect,
	["FriendsFriendsButton_OnClick"] = noIndentEffect,
	["FriendsFriendsFrameDropDown_Initialize"] = noIndentEffect,
	["FriendsFriendsFrameDropDown_OnClick"] = noIndentEffect,
	["FriendsFriendsFrame_Close"] = noIndentEffect,
	["FriendsFriendsFrame_OnEvent"] = noIndentEffect,
	["FriendsFriendsFrame_Reset"] = noIndentEffect,
	["FriendsFriendsFrame_SendRequest"] = noIndentEffect,
	["FriendsFriendsFrame_Show"] = noIndentEffect,
	["FriendsFriendsList_Update"] = noIndentEffect,
	["FriendsList_Update"] = noIndentEffect,
	["GMChatFrame_LoadUI"] = noIndentEffect,
	["GMReportLag"] = noIndentEffect,
	["GMRequestPlayerInfo"] = noIndentEffect,
	["GMResponseNeedMoreHelp"] = noIndentEffect,
	["GMResponseResolve"] = noIndentEffect,
	["GMSurveyAnswer"] = noIndentEffect,
	["GMSurveyAnswerSubmit"] = noIndentEffect,
	["GMSurveyCommentSubmit"] = noIndentEffect,
	["GMSurveyFrame_LoadUI"] = noIndentEffect,
	["GMSurveyNumAnswers"] = noIndentEffect,
	["GMSurveyQuestion"] = noIndentEffect,
	["GMSurveySubmit"] = noIndentEffect,
	["GameMovieFinished"] = noIndentEffect,
	["GameTimeFrame_OnClick"] = noIndentEffect,
	["GameTimeFrame_OnEnter"] = noIndentEffect,
	["GameTimeFrame_OnEvent"] = noIndentEffect,
	["GameTimeFrame_OnLoad"] = noIndentEffect,
	["GameTimeFrame_OnUpdate"] = noIndentEffect,
	["GameTimeFrame_SetDate"] = noIndentEffect,
	["GameTime_ComputeMilitaryTime"] = noIndentEffect,
	["GameTime_ComputeMinutes"] = noIndentEffect,
	["GameTime_ComputeStandardTime"] = noIndentEffect,
	["GameTime_GetFormattedTime"] = noIndentEffect,
	["GameTime_GetGameTime"] = noIndentEffect,
	["GameTime_GetLocalTime"] = noIndentEffect,
	["GameTime_GetTime"] = noIndentEffect,
	["GameTime_UpdateTooltip"] = noIndentEffect,
	["GameTooltip_AddNewbieTip"] = noIndentEffect,
	["GameTooltip_ClearMoney"] = noIndentEffect,
	["GameTooltip_ClearStatusBars"] = noIndentEffect,
	["GameTooltip_Hide"] = noIndentEffect,
	["GameTooltip_HideResetCursor"] = noIndentEffect,
	["GameTooltip_OnHide"] = noIndentEffect,
	["GameTooltip_OnLoad"] = noIndentEffect,
	["GameTooltip_OnTooltipAddMoney"] = noIndentEffect,
	["GameTooltip_OnUpdate"] = noIndentEffect,
	["GameTooltip_SetDefaultAnchor"] = noIndentEffect,
	["GameTooltip_ShowCompareItem"] = noIndentEffect,
	["GameTooltip_ShowStatusBar"] = noIndentEffect,
	["GameTooltip_UnitColor"] = noIndentEffect,
	["GearManagerDialogDeleteSet_OnClick"] = noIndentEffect,
	["GearManagerDialogEquipSet_OnClick"] = noIndentEffect,
	["GearManagerDialogPopupCancel_OnClick"] = noIndentEffect,
	["GearManagerDialogPopupOkay_OnClick"] = noIndentEffect,
	["GearManagerDialogPopupOkay_Update"] = noIndentEffect,
	["GearManagerDialogPopup_OnHide"] = noIndentEffect,
	["GearManagerDialogPopup_OnLoad"] = noIndentEffect,
	["GearManagerDialogPopup_OnShow"] = noIndentEffect,
	["GearManagerDialogPopup_Update"] = noIndentEffect,
	["GearManagerDialogSaveSet_OnClick"] = noIndentEffect,
	["GearManagerDialog_OnEvent"] = noIndentEffect,
	["GearManagerDialog_OnHide"] = noIndentEffect,
	["GearManagerDialog_OnLoad"] = noIndentEffect,
	["GearManagerDialog_OnShow"] = noIndentEffect,
	["GearManagerDialog_Update"] = noIndentEffect,
	["GearSetButton_OnClick"] = noIndentEffect,
	["GearSetButton_OnEnter"] = noIndentEffect,
	["GearSetPopupButton_OnClick"] = noIndentEffect,
	["GetAbandonQuestItems"] = noIndentEffect,
	["GetAbandonQuestName"] = noIndentEffect,
	["GetAccountExpansionLevel"] = noIndentEffect,
	["GetAchievementCategory"] = noIndentEffect,
	["GetAchievementComparisonInfo"] = noIndentEffect,
	["GetAchievementCriteriaInfo"] = noIndentEffect,
	["GetAchievementInfo"] = noIndentEffect,
	["GetAchievementInfoFromCriteria"] = noIndentEffect,
	["GetAchievementLink"] = noIndentEffect,
	["GetAchievementNumCriteria"] = noIndentEffect,
	["GetAchievementNumRewards"] = noIndentEffect,
	["GetAchievementReward"] = noIndentEffect,
	["GetActionAutocast"] = noIndentEffect,
	["GetActionBarPage"] = noIndentEffect,
	["GetActionBarToggles"] = noIndentEffect,
	["GetActionCooldown"] = noIndentEffect,
	["GetActionCount"] = noIndentEffect,
	["GetActionInfo"] = noIndentEffect,
	["GetActionText"] = noIndentEffect,
	["GetActionTexture"] = noIndentEffect,
	["GetActiveLevel"] = noIndentEffect,
	["GetActiveTalentGroup"] = noIndentEffect,
	["GetActiveTitle"] = noIndentEffect,
	["GetActiveVoiceChannel"] = noIndentEffect,
	["GetAddOnCPUUsage"] = noIndentEffect,
	["GetAddOnDependencies"] = noIndentEffect,
	["GetAddOnInfo"] = noIndentEffect,
	["GetAddOnMemoryUsage"] = noIndentEffect,
	["GetAddOnMetadata"] = noIndentEffect,
	["GetAdjustedSkillPoints"] = noIndentEffect,
	["GetAllowLowLevelRaid"] = noIndentEffect,
	["GetAreaSpiritHealerTime"] = noIndentEffect,
	["GetArenaCurrency"] = noIndentEffect,
	["GetArenaTeam"] = noIndentEffect,
	["GetArenaTeamGdfInfo"] = noIndentEffect,
	["GetArenaTeamRosterInfo"] = noIndentEffect,
	["GetArenaTeamRosterSelection"] = noIndentEffect,
	["GetArenaTeamRosterShowOffline"] = noIndentEffect,
	["GetArmorPenetration"] = noIndentEffect,
	["GetAttackPowerForStat"] = noIndentEffect,
	["GetAuctionHouseDepositRate"] = noIndentEffect,
	["GetAuctionInvTypes"] = noIndentEffect,
	["GetAuctionItemClasses"] = noIndentEffect,
	["GetAuctionItemInfo"] = noIndentEffect,
	["GetAuctionItemLink"] = noIndentEffect,
	["GetAuctionItemSubClasses"] = noIndentEffect,
	["GetAuctionItemTimeLeft"] = noIndentEffect,
	["GetAuctionSellItemInfo"] = noIndentEffect,
	["GetAuctionSort"] = noIndentEffect,
	["GetAutoCompletePresenceID"] = noIndentEffect,
	["GetAutoCompleteResults"] = noIndentEffect,
	["GetAvailableLevel"] = noIndentEffect,
	["GetAvailableQuestInfo"] = noIndentEffect,
	["GetAvailableRoles"] = noIndentEffect,
	["GetAvailableTitle"] = noIndentEffect,
	["GetBackgroundTexCoordsForRole"] = noIndentEffect,
	["GetBackpackCurrencyInfo"] = noIndentEffect,
	["GetBackpackFrame"] = noIndentEffect,
	["GetBagName"] = noIndentEffect,
	["GetBankSlotCost"] = noIndentEffect,
	["GetBarberShopStyleInfo"] = noIndentEffect,
	["GetBarberShopTotalCost"] = noIndentEffect,
	["GetBaseMip"] = noIndentEffect,
	["GetBattlefieldArenaFaction"] = noIndentEffect,
	["GetBattlefieldEstimatedWaitTime"] = noIndentEffect,
	["GetBattlefieldFlagPosition"] = noIndentEffect,
	["GetBattlefieldInfo"] = noIndentEffect,
	["GetBattlefieldInstanceExpiration"] = noIndentEffect,
	["GetBattlefieldInstanceInfo"] = noIndentEffect,
	["GetBattlefieldInstanceRunTime"] = noIndentEffect,
	["GetBattlefieldMapIconScale"] = noIndentEffect,
	["GetBattlefieldPortExpiration"] = noIndentEffect,
	["GetBattlefieldPosition"] = noIndentEffect,
	["GetBattlefieldScore"] = noIndentEffect,
	["GetBattlefieldStatData"] = noIndentEffect,
	["GetBattlefieldStatInfo"] = noIndentEffect,
	["GetBattlefieldStatus"] = noIndentEffect,
	["GetBattlefieldTeamInfo"] = noIndentEffect,
	["GetBattlefieldTimeWaited"] = noIndentEffect,
	["GetBattlefieldVehicleInfo"] = noIndentEffect,
	["GetBattlefieldWinner"] = noIndentEffect,
	["GetBattlegroundInfo"] = noIndentEffect,
	["GetBidderAuctionItems"] = noIndentEffect,
	["GetBillingTimeRested"] = noIndentEffect,
	["GetBindLocation"] = noIndentEffect,
	["GetBinding"] = noIndentEffect,
	["GetBindingAction"] = noIndentEffect,
	["GetBindingByKey"] = noIndentEffect,
	["GetBindingFromClick"] = noIndentEffect,
	["GetBindingKey"] = noIndentEffect,
	["GetBindingText"] = noIndentEffect,
	["GetBlockChance"] = noIndentEffect,
	["GetBonusBarOffset"] = noIndentEffect,
	["GetBuildInfo"] = noIndentEffect,
	["GetBuybackItemInfo"] = noIndentEffect,
	["GetBuybackItemLink"] = noIndentEffect,
	["GetCVar"] = noIndentEffect,
	["GetCVarAbsoluteMax"] = noIndentEffect,
	["GetCVarAbsoluteMin"] = noIndentEffect,
	["GetCVarBool"] = noIndentEffect,
	["GetCVarDefault"] = noIndentEffect,
	["GetCVarInfo"] = noIndentEffect,
	["GetCVarMax"] = noIndentEffect,
	["GetCVarMin"] = noIndentEffect,
	["GetCategoryInfo"] = noIndentEffect,
	["GetCategoryList"] = noIndentEffect,
	["GetCategoryNumAchievements"] = noIndentEffect,
	["GetChannelDisplayInfo"] = noIndentEffect,
	["GetChannelList"] = noIndentEffect,
	["GetChannelName"] = noIndentEffect,
	["GetChannelRosterInfo"] = noIndentEffect,
	["GetChatTypeIndex"] = noIndentEffect,
	["GetChatUnitColor"] = noIndentEffect,
	["GetChatWindowChannels"] = noIndentEffect,
	["GetChatWindowInfo"] = noIndentEffect,
	["GetChatWindowMessages"] = noIndentEffect,
	["GetChatWindowSavedDimensions"] = noIndentEffect,
	["GetChatWindowSavedPosition"] = noIndentEffect,
	["GetClickFrame"] = noIndentEffect,
	["GetCoinIcon"] = noIndentEffect,
	["GetCoinText"] = noIndentEffect,
	["GetCoinTextureString"] = noIndentEffect,
	["GetColoredName"] = noIndentEffect,
	["GetCombatRating"] = noIndentEffect,
	["GetCombatRatingBonus"] = noIndentEffect,
	["GetComboPoints"] = noIndentEffect,
	["GetCompanionCooldown"] = noIndentEffect,
	["GetCompanionInfo"] = noIndentEffect,
	["GetComparisonAchievementPoints"] = noIndentEffect,
	["GetComparisonCategoryNumAchievements"] = noIndentEffect,
	["GetComparisonStatistic"] = noIndentEffect,
	["GetContainerFreeSlots"] = noIndentEffect,
	["GetContainerItemCooldown"] = noIndentEffect,
	["GetContainerItemDurability"] = noIndentEffect,
	["GetContainerItemGems"] = noIndentEffect,
	["GetContainerItemID"] = noIndentEffect,
	["GetContainerItemInfo"] = noIndentEffect,
	["GetContainerItemLink"] = noIndentEffect,
	["GetContainerItemPurchaseInfo"] = noIndentEffect,
	["GetContainerItemPurchaseItem"] = noIndentEffect,
	["GetContainerItemQuestInfo"] = noIndentEffect,
	["GetContainerNumFreeSlots"] = noIndentEffect,
	["GetContainerNumSlots"] = noIndentEffect,
	["GetCorpseMapPosition"] = noIndentEffect,
	["GetCorpseRecoveryDelay"] = noIndentEffect,
	["GetCritChance"] = noIndentEffect,
	["GetCritChanceFromAgility"] = noIndentEffect,
	["GetCurrencyListInfo"] = noIndentEffect,
	["GetCurrencyListSize"] = noIndentEffect,
	["GetCurrentArenaSeason"] = noIndentEffect,
	["GetCurrentBindingSet"] = noIndentEffect,
	["GetCurrentGuildBankTab"] = noIndentEffect,
	["GetCurrentKeyBoardFocus"] = noIndentEffect,
	["GetCurrentMapAreaID"] = noIndentEffect,
	["GetCurrentMapContinent"] = noIndentEffect,
	["GetCurrentMapDungeonLevel"] = noIndentEffect,
	["GetCurrentMapZone"] = noIndentEffect,
	["GetCurrentMultisampleFormat"] = noIndentEffect,
	["GetCurrentResolution"] = noIndentEffect,
	["GetCurrentTitle"] = noIndentEffect,
	["GetCursorInfo"] = noIndentEffect,
	["GetCursorMoney"] = noIndentEffect,
	["GetCursorPosition"] = noIndentEffect,
	["GetDailyQuestsCompleted"] = noIndentEffect,
	["GetDamageBonusStat"] = noIndentEffect,
	["GetDeathReleasePosition"] = noIndentEffect,
	["GetDebugStats"] = noIndentEffect,
	["GetDebugZoneMap"] = noIndentEffect,
	["GetDefaultLanguage"] = noIndentEffect,
	["GetDenominationsFromCopper"] = noIndentEffect,
	["GetDodgeBlockParryChanceFromDefense"] = noIndentEffect,
	["GetDodgeChance"] = noIndentEffect,
	["GetDungeonDifficulty"] = noIndentEffect,
	["GetDungeonNameWithDifficulty"] = noIndentEffect,
	["GetEquipmentSetIconInfo"] = noIndentEffect,
	["GetEquipmentSetInfo"] = noIndentEffect,
	["GetEquipmentSetInfoByName"] = noIndentEffect,
	["GetEquipmentSetItemIDs"] = noIndentEffect,
	["GetEquipmentSetLocations"] = noIndentEffect,
	["GetEventCPUUsage"] = noIndentEffect,
	["GetExistingLocales"] = noIndentEffect,
	["GetExistingSocketInfo"] = noIndentEffect,
	["GetExistingSocketLink"] = noIndentEffect,
	["GetExpansionLevel"] = noIndentEffect,
	["GetExpertise"] = noIndentEffect,
	["GetExpertisePercent"] = noIndentEffect,
	["GetExtendedItemInfo"] = noIndentEffect,
	["GetFacialHairCustomization"] = noIndentEffect,
	["GetFactionInfo"] = noIndentEffect,
	["GetFactionInfoByID"] = noIndentEffect,
	["GetFarclip"] = noIndentEffect,
	["GetFirstTradeSkill"] = noIndentEffect,
	["GetFixedLink"] = noIndentEffect,
	["GetFrameCPUUsage"] = noIndentEffect,
	["GetFrameHandle"] = noIndentEffect,
	["GetFrameHandleFrame"] = noIndentEffect,
	["GetFramerate"] = noIndentEffect,
	["GetFramesRegisteredForEvent"] = noIndentEffect,
	["GetFriendInfo"] = noIndentEffect,
	["GetFullRaidList"] = noIndentEffect,
	["GetFunctionCPUUsage"] = noIndentEffect,
	["GetGMStatus"] = noIndentEffect,
	["GetGMTicket"] = noIndentEffect,
	["GetGMTicketCategories"] = noIndentEffect,
	["GetGameTime"] = noIndentEffect,
	["GetGamma"] = noIndentEffect,
	["GetGlyphLink"] = noIndentEffect,
	["GetGlyphSocketInfo"] = noIndentEffect,
	["GetGossipActiveQuests"] = noIndentEffect,
	["GetGossipAvailableQuests"] = noIndentEffect,
	["GetGossipOptions"] = noIndentEffect,
	["GetGossipText"] = noIndentEffect,
	["GetGreetingText"] = noIndentEffect,
	["GetGroupPreviewTalentPointsSpent"] = noIndentEffect,
	["GetGuildBankItemInfo"] = noIndentEffect,
	["GetGuildBankItemLink"] = noIndentEffect,
	["GetGuildBankMoney"] = noIndentEffect,
	["GetGuildBankMoneyTransaction"] = noIndentEffect,
	["GetGuildBankTabCost"] = noIndentEffect,
	["GetGuildBankTabInfo"] = noIndentEffect,
	["GetGuildBankTabPermissions"] = noIndentEffect,
	["GetGuildBankText"] = noIndentEffect,
	["GetGuildBankTransaction"] = noIndentEffect,
	["GetGuildBankWithdrawLimit"] = noIndentEffect,
	["GetGuildBankWithdrawMoney"] = noIndentEffect,
	["GetGuildCharterCost"] = noIndentEffect,
	["GetGuildEventInfo"] = noIndentEffect,
	["GetGuildInfo"] = noIndentEffect,
	["GetGuildInfoText"] = noIndentEffect,
	["GetGuildRosterInfo"] = noIndentEffect,
	["GetGuildRosterLastOnline"] = noIndentEffect,
	["GetGuildRosterMOTD"] = noIndentEffect,
	["GetGuildRosterSelection"] = noIndentEffect,
	["GetGuildRosterShowOffline"] = noIndentEffect,
	["GetGuildTabardFileNames"] = noIndentEffect,
	["GetHairCustomization"] = noIndentEffect,
	["GetHolidayBGHonorCurrencyBonuses"] = noIndentEffect,
	["GetHonorCurrency"] = noIndentEffect,
	["GetIgnoreName"] = noIndentEffect,
	["GetInboxHeaderInfo"] = noIndentEffect,
	["GetInboxInvoiceInfo"] = noIndentEffect,
	["GetInboxItem"] = noIndentEffect,
	["GetInboxItemLink"] = noIndentEffect,
	["GetInboxNumItems"] = noIndentEffect,
	["GetInboxText"] = noIndentEffect,
	["GetInspectArenaTeamData"] = noIndentEffect,
	["GetInspectHonorData"] = noIndentEffect,
	["GetInstanceBootTimeRemaining"] = noIndentEffect,
	["GetInstanceDifficulty"] = noIndentEffect,
	["GetInstanceInfo"] = noIndentEffect,
	["GetInstanceLockTimeRemaining"] = noIndentEffect,
	["GetInstanceLockTimeRemainingEncounter"] = noIndentEffect,
	["GetInventoryAlertStatus"] = noIndentEffect,
	["GetInventoryItemBroken"] = noIndentEffect,
	["GetInventoryItemCooldown"] = noIndentEffect,
	["GetInventoryItemCount"] = noIndentEffect,
	["GetInventoryItemDurability"] = noIndentEffect,
	["GetInventoryItemGems"] = noIndentEffect,
	["GetInventoryItemID"] = noIndentEffect,
	["GetInventoryItemLink"] = noIndentEffect,
	["GetInventoryItemQuality"] = noIndentEffect,
	["GetInventoryItemTexture"] = noIndentEffect,
	["GetInventoryItemsForSlot"] = noIndentEffect,
	["GetInventorySlotInfo"] = noIndentEffect,
	["GetItemCooldown"] = noIndentEffect,
	["GetItemCount"] = noIndentEffect,
	["GetItemFamily"] = noIndentEffect,
	["GetItemGem"] = noIndentEffect,
	["GetItemIcon"] = noIndentEffect,
	["GetItemInfo"] = noIndentEffect,
	["GetItemQualityColor"] = noIndentEffect,
	["GetItemSpell"] = noIndentEffect,
	["GetItemStatDelta"] = noIndentEffect,
	["GetItemStats"] = noIndentEffect,
	["GetItemUniqueness"] = noIndentEffect,
	["GetKeyRingSize"] = noIndentEffect,
	["GetKnownSlotFromHighestRankSlot"] = noIndentEffect,
	["GetLFDChoiceCollapseState"] = noIndentEffect,
	["GetLFDChoiceEnabledState"] = noIndentEffect,
	["GetLFDChoiceInfo"] = noIndentEffect,
	["GetLFDChoiceLockedState"] = noIndentEffect,
	["GetLFDChoiceOrder"] = noIndentEffect,
	["GetLFDLockInfo"] = noIndentEffect,
	["GetLFDLockPlayerCount"] = noIndentEffect,
	["GetLFGBootProposal"] = noIndentEffect,
	["GetLFGCompletionReward"] = noIndentEffect,
	["GetLFGCompletionRewardItem"] = noIndentEffect,
	["GetLFGDeserterExpiration"] = noIndentEffect,
	["GetLFGDungeonInfo"] = noIndentEffect,
	["GetLFGDungeonRewardInfo"] = noIndentEffect,
	["GetLFGDungeonRewardLink"] = noIndentEffect,
	["GetLFGDungeonRewards"] = noIndentEffect,
	["GetLFGInfoLocal"] = noIndentEffect,
	["GetLFGInfoServer"] = noIndentEffect,
	["GetLFGMode"] = noIndentEffect,
	["GetLFGProposal"] = noIndentEffect,
	["GetLFGProposalEncounter"] = noIndentEffect,
	["GetLFGProposalMember"] = noIndentEffect,
	["GetLFGQueueStats"] = noIndentEffect,
	["GetLFGQueuedList"] = noIndentEffect,
	["GetLFGRandomCooldownExpiration"] = noIndentEffect,
	["GetLFGRandomDungeonInfo"] = noIndentEffect,
	["GetLFGRoleUpdate"] = noIndentEffect,
	["GetLFGRoleUpdateMember"] = noIndentEffect,
	["GetLFGRoleUpdateSlot"] = noIndentEffect,
	["GetLFGRoles"] = noIndentEffect,
	["GetLFGTypes"] = noIndentEffect,
	["GetLFRChoiceOrder"] = noIndentEffect,
	["GetLanguageByIndex"] = noIndentEffect,
	["GetLastQueueStatusIndex"] = noIndentEffect,
	["GetLatestCompletedAchievements"] = noIndentEffect,
	["GetLatestCompletedComparisonAchievements"] = noIndentEffect,
	["GetLatestThreeSenders"] = noIndentEffect,
	["GetLatestUpdatedComparisonStats"] = noIndentEffect,
	["GetLatestUpdatedStats"] = noIndentEffect,
	["GetLocale"] = noIndentEffect,
	["GetLootMethod"] = noIndentEffect,
	["GetLootRollItemInfo"] = noIndentEffect,
	["GetLootRollItemLink"] = noIndentEffect,
	["GetLootRollTimeLeft"] = noIndentEffect,
	["GetLootSlotInfo"] = noIndentEffect,
	["GetLootSlotLink"] = noIndentEffect,
	["GetLootThreshold"] = noIndentEffect,
	["GetMacroBody"] = noIndentEffect,
	["GetMacroIconInfo"] = noIndentEffect,
	["GetMacroIndexByName"] = noIndentEffect,
	["GetMacroInfo"] = noIndentEffect,
	["GetMacroItem"] = noIndentEffect,
	["GetMacroItemIconInfo"] = noIndentEffect,
	["GetMacroSpell"] = noIndentEffect,
	["GetManaRegen"] = noIndentEffect,
	["GetManagedEnvironment"] = noIndentEffect,
	["GetMapContinents"] = noIndentEffect,
	["GetMapDebugObjectInfo"] = noIndentEffect,
	["GetMapInfo"] = noIndentEffect,
	["GetMapLandmarkInfo"] = noIndentEffect,
	["GetMapOverlayInfo"] = noIndentEffect,
	["GetMapZones"] = noIndentEffect,
	["GetMasterLootCandidate"] = noIndentEffect,
	["GetMaterialTextColors"] = noIndentEffect,
	["GetMaxArenaCurrency"] = noIndentEffect,
	["GetMaxCombatRatingBonus"] = noIndentEffect,
	["GetMaxDailyQuests"] = noIndentEffect,
	["GetMaxUIPanelsWidth"] = noIndentEffect,
	["GetMerchantItemCostInfo"] = noIndentEffect,
	["GetMerchantItemCostItem"] = noIndentEffect,
	["GetMerchantItemInfo"] = noIndentEffect,
	["GetMerchantItemLink"] = noIndentEffect,
	["GetMerchantItemMaxStack"] = noIndentEffect,
	["GetMerchantNumItems"] = noIndentEffect,
	["GetMessageTypeColor"] = noIndentEffect,
	["GetMessageTypeState"] = noIndentEffect,
	["GetMinigameState"] = noIndentEffect,
	["GetMinigameType"] = noIndentEffect,
	["GetMinimapZoneText"] = noIndentEffect,
	["GetMirrorTimerInfo"] = noIndentEffect,
	["GetMirrorTimerProgress"] = noIndentEffect,
	["GetModifiedClick"] = noIndentEffect,
	["GetModifiedClickAction"] = noIndentEffect,
	["GetMoney"] = noIndentEffect,
	["GetMoneyString"] = noIndentEffect,
	["GetMouseButtonClicked"] = noIndentEffect,
	["GetMouseButtonName"] = noIndentEffect,
	["GetMouseFocus"] = noIndentEffect,
	["GetMovieResolution"] = noIndentEffect,
	["GetMultiCastBarOffset"] = noIndentEffect,
	["GetMultiCastTotemSpells"] = noIndentEffect,
	["GetMultisampleFormats"] = noIndentEffect,
	["GetMuteName"] = noIndentEffect,
	["GetMuteStatus"] = noIndentEffect,
	["GetNetStats"] = noIndentEffect,
	["GetNewSocketInfo"] = noIndentEffect,
	["GetNewSocketLink"] = noIndentEffect,
	["GetNextAchievement"] = noIndentEffect,
	["GetNextCompleatedTutorial"] = noIndentEffect,
	["GetNextStableSlotCost"] = noIndentEffect,
	["GetNumActiveQuests"] = noIndentEffect,
	["GetNumAddOns"] = noIndentEffect,
	["GetNumArenaOpponents"] = noIndentEffect,
	["GetNumArenaTeamMembers"] = noIndentEffect,
	["GetNumAuctionItems"] = noIndentEffect,
	["GetNumAvailableQuests"] = noIndentEffect,
	["GetNumBankSlots"] = noIndentEffect,
	["GetNumBattlefieldFlagPositions"] = noIndentEffect,
	["GetNumBattlefieldPositions"] = noIndentEffect,
	["GetNumBattlefieldScores"] = noIndentEffect,
	["GetNumBattlefieldStats"] = noIndentEffect,
	["GetNumBattlefieldVehicles"] = noIndentEffect,
	["GetNumBattlefields"] = noIndentEffect,
	["GetNumBattlegroundTypes"] = noIndentEffect,
	["GetNumBindings"] = noIndentEffect,
	["GetNumBuybackItems"] = noIndentEffect,
	["GetNumChannelMembers"] = noIndentEffect,
	["GetNumCompanions"] = noIndentEffect,
	["GetNumComparisonCompletedAchievements"] = noIndentEffect,
	["GetNumCompletedAchievements"] = noIndentEffect,
	["GetNumDeclensionSets"] = noIndentEffect,
	["GetNumDisplayChannels"] = noIndentEffect,
	["GetNumDungeonMapLevels"] = noIndentEffect,
	["GetNumEquipmentSets"] = noIndentEffect,
	["GetNumFactions"] = noIndentEffect,
	["GetNumFrames"] = noIndentEffect,
	["GetNumFriends"] = noIndentEffect,
	["GetNumGlyphSockets"] = noIndentEffect,
	["GetNumGossipActiveQuests"] = noIndentEffect,
	["GetNumGossipAvailableQuests"] = noIndentEffect,
	["GetNumGossipOptions"] = noIndentEffect,
	["GetNumGuildBankMoneyTransactions"] = noIndentEffect,
	["GetNumGuildBankTabs"] = noIndentEffect,
	["GetNumGuildBankTransactions"] = noIndentEffect,
	["GetNumGuildEvents"] = noIndentEffect,
	["GetNumGuildMembers"] = noIndentEffect,
	["GetNumIgnores"] = noIndentEffect,
	["GetNumLanguages"] = noIndentEffect,
	["GetNumLootItems"] = noIndentEffect,
	["GetNumMacroIcons"] = noIndentEffect,
	["GetNumMacroItemIcons"] = noIndentEffect,
	["GetNumMacros"] = noIndentEffect,
	["GetNumMapDebugObjects"] = noIndentEffect,
	["GetNumMapLandmarks"] = noIndentEffect,
	["GetNumMapOverlays"] = noIndentEffect,
	["GetNumModifiedClickActions"] = noIndentEffect,
	["GetNumMutes"] = noIndentEffect,
	["GetNumPackages"] = noIndentEffect,
	["GetNumPartyMembers"] = noIndentEffect,
	["GetNumPetitionItems"] = noIndentEffect,
	["GetNumPetitionNames"] = noIndentEffect,
	["GetNumQuestChoices"] = noIndentEffect,
	["GetNumQuestItemDrops"] = noIndentEffect,
	["GetNumQuestItems"] = noIndentEffect,
	["GetNumQuestLeaderBoards"] = noIndentEffect,
	["GetNumQuestLogChoices"] = noIndentEffect,
	["GetNumQuestLogEntries"] = noIndentEffect,
	["GetNumQuestLogRewardFactions"] = noIndentEffect,
	["GetNumQuestLogRewards"] = noIndentEffect,
	["GetNumQuestRewards"] = noIndentEffect,
	["GetNumQuestWatches"] = noIndentEffect,
	["GetNumRaidMembers"] = noIndentEffect,
	["GetNumRandomDungeons"] = noIndentEffect,
	["GetNumRoutes"] = noIndentEffect,
	["GetNumSavedInstances"] = noIndentEffect,
	["GetNumShapeshiftForms"] = noIndentEffect,
	["GetNumSkillLines"] = noIndentEffect,
	["GetNumSockets"] = noIndentEffect,
	["GetNumSpellTabs"] = noIndentEffect,
	["GetNumStablePets"] = noIndentEffect,
	["GetNumStableSlots"] = noIndentEffect,
	["GetNumStationeries"] = noIndentEffect,
	["GetNumTalentGroups"] = noIndentEffect,
	["GetNumTalentTabs"] = noIndentEffect,
	["GetNumTalents"] = noIndentEffect,
	["GetNumTitles"] = noIndentEffect,
	["GetNumTrackedAchievements"] = noIndentEffect,
	["GetNumTrackingTypes"] = noIndentEffect,
	["GetNumTradeSkills"] = noIndentEffect,
	["GetNumTrainerServices"] = noIndentEffect,
	["GetNumVoiceSessionMembersBySessionID"] = noIndentEffect,
	["GetNumVoiceSessions"] = noIndentEffect,
	["GetNumWatchedTokens"] = noIndentEffect,
	["GetNumWhoResults"] = noIndentEffect,
	["GetNumWorldStateUI"] = noIndentEffect,
	["GetObjectiveText"] = noIndentEffect,
	["GetOptOutOfLoot"] = noIndentEffect,
	["GetOwnerAuctionItems"] = noIndentEffect,
	["GetPVPDesired"] = noIndentEffect,
	["GetPVPLifetimeStats"] = noIndentEffect,
	["GetPVPRankInfo"] = noIndentEffect,
	["GetPVPRankProgress"] = noIndentEffect,
	["GetPVPSessionStats"] = noIndentEffect,
	["GetPVPTimer"] = noIndentEffect,
	["GetPVPYesterdayStats"] = noIndentEffect,
	["GetPackageInfo"] = noIndentEffect,
	["GetParryChance"] = noIndentEffect,
	["GetPartyAssignment"] = noIndentEffect,
	["GetPartyLFGBackfillInfo"] = noIndentEffect,
	["GetPartyLeaderIndex"] = noIndentEffect,
	["GetPartyMember"] = noIndentEffect,
	["GetPetActionCooldown"] = noIndentEffect,
	["GetPetActionInfo"] = noIndentEffect,
	["GetPetActionSlotUsable"] = noIndentEffect,
	["GetPetActionsUsable"] = noIndentEffect,
	["GetPetExperience"] = noIndentEffect,
	["GetPetFoodTypes"] = noIndentEffect,
	["GetPetHappiness"] = noIndentEffect,
	["GetPetIcon"] = noIndentEffect,
	["GetPetSpellBonusDamage"] = noIndentEffect,
	["GetPetTalentTree"] = noIndentEffect,
	["GetPetTimeRemaining"] = noIndentEffect,
	["GetPetitionInfo"] = noIndentEffect,
	["GetPetitionItemInfo"] = noIndentEffect,
	["GetPetitionNameInfo"] = noIndentEffect,
	["GetPlayerFacing"] = noIndentEffect,
	["GetPlayerInfoByGUID"] = noIndentEffect,
	["GetPlayerMapPosition"] = noIndentEffect,
	["GetPlayerTradeMoney"] = noIndentEffect,
	["GetPossessInfo"] = noIndentEffect,
	["GetPowerRegen"] = noIndentEffect,
	["GetPrevCompleatedTutorial"] = noIndentEffect,
	["GetPreviewTalentPointsSpent"] = noIndentEffect,
	["GetPreviousAchievement"] = noIndentEffect,
	["GetPreviousArenaSeason"] = noIndentEffect,
	["GetProgressText"] = noIndentEffect,
	["GetQuestBackgroundMaterial"] = noIndentEffect,
	["GetQuestDifficultyColor"] = noIndentEffect,
	["GetQuestGreenRange"] = noIndentEffect,
	["GetQuestIndexForTimer"] = noIndentEffect,
	["GetQuestIndexForWatch"] = noIndentEffect,
	["GetQuestItemInfo"] = noIndentEffect,
	["GetQuestItemLink"] = noIndentEffect,
	["GetQuestLink"] = noIndentEffect,
	["GetQuestLogChoiceInfo"] = noIndentEffect,
	["GetQuestLogCompletionText"] = noIndentEffect,
	["GetQuestLogGroupNum"] = noIndentEffect,
	["GetQuestLogItemDrop"] = noIndentEffect,
	["GetQuestLogItemLink"] = noIndentEffect,
	["GetQuestLogLeaderBoard"] = noIndentEffect,
	["GetQuestLogPushable"] = noIndentEffect,
	["GetQuestLogQuestText"] = noIndentEffect,
	["GetQuestLogRequiredMoney"] = noIndentEffect,
	["GetQuestLogRewardArenaPoints"] = noIndentEffect,
	["GetQuestLogRewardFactionInfo"] = noIndentEffect,
	["GetQuestLogRewardHonor"] = noIndentEffect,
	["GetQuestLogRewardInfo"] = noIndentEffect,
	["GetQuestLogRewardMoney"] = noIndentEffect,
	["GetQuestLogRewardSpell"] = noIndentEffect,
	["GetQuestLogRewardTalents"] = noIndentEffect,
	["GetQuestLogRewardTitle"] = noIndentEffect,
	["GetQuestLogRewardXP"] = noIndentEffect,
	["GetQuestLogSelection"] = noIndentEffect,
	["GetQuestLogSpecialItemCooldown"] = noIndentEffect,
	["GetQuestLogSpecialItemInfo"] = noIndentEffect,
	["GetQuestLogSpellLink"] = noIndentEffect,
	["GetQuestLogTimeLeft"] = noIndentEffect,
	["GetQuestLogTitle"] = noIndentEffect,
	["GetQuestMoneyToGet"] = noIndentEffect,
	["GetQuestPOILeaderBoard"] = noIndentEffect,
	["GetQuestResetTime"] = noIndentEffect,
	["GetQuestReward"] = noIndentEffect,
	["GetQuestSortIndex"] = noIndentEffect,
	["GetQuestSpellLink"] = noIndentEffect,
	["GetQuestText"] = noIndentEffect,
	["GetQuestTimers"] = noIndentEffect,
	["GetQuestWatchIndex"] = noIndentEffect,
	["GetQuestWorldMapAreaID"] = noIndentEffect,
	["GetQuestsCompleted"] = noIndentEffect,
	["GetRaidDifficulty"] = noIndentEffect,
	["GetRaidRosterInfo"] = noIndentEffect,
	["GetRaidRosterSelection"] = noIndentEffect,
	["GetRaidTargetIndex"] = noIndentEffect,
	["GetRandomArgument"] = noIndentEffect,
	["GetRandomBGHonorCurrencyBonuses"] = noIndentEffect,
	["GetRandomDungeonBestChoice"] = noIndentEffect,
	["GetRangedCritChance"] = noIndentEffect,
	["GetReadonlyRestrictedTable"] = noIndentEffect,
	["GetReadyCheckStatus"] = noIndentEffect,
	["GetReadyCheckTimeLeft"] = noIndentEffect,
	["GetRealNumPartyMembers"] = noIndentEffect,
	["GetRealNumRaidMembers"] = noIndentEffect,
	["GetRealZoneText"] = noIndentEffect,
	["GetRealmName"] = noIndentEffect,
	["GetRefreshRates"] = noIndentEffect,
	["GetReleaseTimeRemaining"] = noIndentEffect,
	["GetRepairAllCost"] = noIndentEffect,
	["GetResSicknessDuration"] = noIndentEffect,
	["GetRestState"] = noIndentEffect,
	["GetRewardArenaPoints"] = noIndentEffect,
	["GetRewardHonor"] = noIndentEffect,
	["GetRewardMoney"] = noIndentEffect,
	["GetRewardSpell"] = noIndentEffect,
	["GetRewardTalents"] = noIndentEffect,
	["GetRewardText"] = noIndentEffect,
	["GetRewardTitle"] = noIndentEffect,
	["GetRewardXP"] = noIndentEffect,
	["GetRuneCooldown"] = noIndentEffect,
	["GetRuneCount"] = noIndentEffect,
	["GetRuneType"] = noIndentEffect,
	["GetRunningMacro"] = noIndentEffect,
	["GetRunningMacroButton"] = noIndentEffect,
	["GetSavedInstanceInfo"] = noIndentEffect,
	["GetScreenHeight"] = noIndentEffect,
	["GetScreenHeightScale"] = noIndentEffect,
	["GetScreenResolutions"] = noIndentEffect,
	["GetScreenWidth"] = noIndentEffect,
	["GetScreenWidthScale"] = noIndentEffect,
	["GetScriptCPUUsage"] = noIndentEffect,
	["GetSelectedAuctionItem"] = noIndentEffect,
	["GetSelectedBattlefield"] = noIndentEffect,
	["GetSelectedDisplayChannel"] = noIndentEffect,
	["GetSelectedFaction"] = noIndentEffect,
	["GetSelectedFriend"] = noIndentEffect,
	["GetSelectedIgnore"] = noIndentEffect,
	["GetSelectedMute"] = noIndentEffect,
	["GetSelectedSkill"] = noIndentEffect,
	["GetSelectedStablePet"] = noIndentEffect,
	["GetSelectedStationeryTexture"] = noIndentEffect,
	["GetSendMailCOD"] = noIndentEffect,
	["GetSendMailItem"] = noIndentEffect,
	["GetSendMailItemLink"] = noIndentEffect,
	["GetSendMailMoney"] = noIndentEffect,
	["GetSendMailPrice"] = noIndentEffect,
	["GetShapeshiftForm"] = noIndentEffect,
	["GetShapeshiftFormCooldown"] = noIndentEffect,
	["GetShapeshiftFormInfo"] = noIndentEffect,
	["GetShieldBlock"] = noIndentEffect,
	["GetSkillLineInfo"] = noIndentEffect,
	["GetSocketItemBoundTradeable"] = noIndentEffect,
	["GetSocketItemInfo"] = noIndentEffect,
	["GetSocketItemRefundable"] = noIndentEffect,
	["GetSocketTypes"] = noIndentEffect,
	["GetSpellAutocast"] = noIndentEffect,
	["GetSpellBonusDamage"] = noIndentEffect,
	["GetSpellBonusHealing"] = noIndentEffect,
	["GetSpellCooldown"] = noIndentEffect,
	["GetSpellCount"] = noIndentEffect,
	["GetSpellCritChance"] = noIndentEffect,
	["GetSpellCritChanceFromIntellect"] = noIndentEffect,
	["GetSpellInfo"] = noIndentEffect,
	["GetSpellLink"] = noIndentEffect,
	["GetSpellName"] = noIndentEffect,
	["GetSpellNameColor"] = noIndentEffect,
	["GetSpellPenetration"] = noIndentEffect,
	["GetSpellTabInfo"] = noIndentEffect,
	["GetSpellTexture"] = noIndentEffect,
	["GetStablePetFoodTypes"] = noIndentEffect,
	["GetStablePetInfo"] = noIndentEffect,
	["GetStationeryInfo"] = noIndentEffect,
	["GetStatistic"] = noIndentEffect,
	["GetStatisticsCategoryList"] = noIndentEffect,
	["GetSubZoneText"] = noIndentEffect,
	["GetSuggestedGroupNum"] = noIndentEffect,
	["GetSummonConfirmAreaName"] = noIndentEffect,
	["GetSummonConfirmSummoner"] = noIndentEffect,
	["GetSummonConfirmTimeLeft"] = noIndentEffect,
	["GetSummonFriendCooldown"] = noIndentEffect,
	["GetTabardCreationCost"] = noIndentEffect,
	["GetTabardInfo"] = noIndentEffect,
	["GetTableColor"] = noIndentEffect,
	["GetTalentInfo"] = noIndentEffect,
	["GetTalentLink"] = noIndentEffect,
	["GetTalentPrereqs"] = noIndentEffect,
	["GetTalentTabInfo"] = noIndentEffect,
	["GetTargetTradeMoney"] = noIndentEffect,
	["GetTaxiBenchmarkMode"] = noIndentEffect,
	["GetTerrainMip"] = noIndentEffect,
	["GetTexCoordsByGrid"] = noIndentEffect,
	["GetTexCoordsForRole"] = noIndentEffect,
	["GetTexLodBias"] = noIndentEffect,
	["GetText"] = noIndentEffect,
	["GetThreatStatusColor"] = noIndentEffect,
	["GetTime"] = noIndentEffect,
	["GetTimeToWellRested"] = noIndentEffect,
	["GetTimerTextColor"] = noIndentEffect,
	["GetTitleName"] = noIndentEffect,
	["GetTitleText"] = noIndentEffect,
	["GetTotalAchievementPoints"] = noIndentEffect,
	["GetTotemInfo"] = noIndentEffect,
	["GetTotemTimeLeft"] = noIndentEffect,
	["GetTrackedAchievements"] = noIndentEffect,
	["GetTrackingInfo"] = noIndentEffect,
	["GetTrackingTexture"] = noIndentEffect,
	["GetTradePlayerItemInfo"] = noIndentEffect,
	["GetTradePlayerItemLink"] = noIndentEffect,
	["GetTradeSkillCooldown"] = noIndentEffect,
	["GetTradeSkillDescription"] = noIndentEffect,
	["GetTradeSkillIcon"] = noIndentEffect,
	["GetTradeSkillInfo"] = noIndentEffect,
	["GetTradeSkillInvSlotFilter"] = noIndentEffect,
	["GetTradeSkillInvSlots"] = noIndentEffect,
	["GetTradeSkillItemLevelFilter"] = noIndentEffect,
	["GetTradeSkillItemLink"] = noIndentEffect,
	["GetTradeSkillItemNameFilter"] = noIndentEffect,
	["GetTradeSkillLine"] = noIndentEffect,
	["GetTradeSkillListLink"] = noIndentEffect,
	["GetTradeSkillNumMade"] = noIndentEffect,
	["GetTradeSkillNumReagents"] = noIndentEffect,
	["GetTradeSkillReagentInfo"] = noIndentEffect,
	["GetTradeSkillReagentItemLink"] = noIndentEffect,
	["GetTradeSkillRecipeLink"] = noIndentEffect,
	["GetTradeSkillSelectionIndex"] = noIndentEffect,
	["GetTradeSkillSubClassFilter"] = noIndentEffect,
	["GetTradeSkillSubClasses"] = noIndentEffect,
	["GetTradeSkillTools"] = noIndentEffect,
	["GetTradeTargetItemInfo"] = noIndentEffect,
	["GetTradeTargetItemLink"] = noIndentEffect,
	["GetTradeskillRepeatCount"] = noIndentEffect,
	["GetTrainerGreetingText"] = noIndentEffect,
	["GetTrainerSelectionIndex"] = noIndentEffect,
	["GetTrainerServiceAbilityReq"] = noIndentEffect,
	["GetTrainerServiceCost"] = noIndentEffect,
	["GetTrainerServiceDescription"] = noIndentEffect,
	["GetTrainerServiceIcon"] = noIndentEffect,
	["GetTrainerServiceInfo"] = noIndentEffect,
	["GetTrainerServiceItemLink"] = noIndentEffect,
	["GetTrainerServiceLevelReq"] = noIndentEffect,
	["GetTrainerServiceNumAbilityReq"] = noIndentEffect,
	["GetTrainerServiceSkillLine"] = noIndentEffect,
	["GetTrainerServiceSkillReq"] = noIndentEffect,
	["GetTrainerServiceStepIncrease"] = noIndentEffect,
	["GetTrainerServiceStepReq"] = noIndentEffect,
	["GetTrainerServiceTypeFilter"] = noIndentEffect,
	["GetTrainerSkillLineFilter"] = noIndentEffect,
	["GetTrainerSkillLines"] = noIndentEffect,
	["GetUIPanel"] = noIndentEffect,
	["GetUIPanelWidth"] = noIndentEffect,
	["GetUnitHealthModifier"] = noIndentEffect,
	["GetUnitHealthRegenRateFromSpirit"] = noIndentEffect,
	["GetUnitManaRegenRateFromSpirit"] = noIndentEffect,
	["GetUnitMaxHealthModifier"] = noIndentEffect,
	["GetUnitName"] = noIndentEffect,
	["GetUnitPitch"] = noIndentEffect,
	["GetUnitPowerModifier"] = noIndentEffect,
	["GetUnitSpeed"] = noIndentEffect,
	["GetUnspentTalentPoints"] = noIndentEffect,
	["GetVehicleUIIndicator"] = noIndentEffect,
	["GetVehicleUIIndicatorSeat"] = noIndentEffect,
	["GetVideoCaps"] = noIndentEffect,
	["GetVoiceCurrentSessionID"] = noIndentEffect,
	["GetVoiceSessionInfo"] = noIndentEffect,
	["GetVoiceSessionMemberInfoBySessionID"] = noIndentEffect,
	["GetVoiceStatus"] = noIndentEffect,
	["GetWatchedFactionInfo"] = noIndentEffect,
	["GetWaterDetail"] = noIndentEffect,
	["GetWeaponEnchantInfo"] = noIndentEffect,
	["GetWhoInfo"] = noIndentEffect,
	["GetWintergraspWaitTime"] = noIndentEffect,
	["GetWorldPVPQueueStatus"] = noIndentEffect,
	["GetWorldStateUIInfo"] = noIndentEffect,
	["GetXPExhaustion"] = noIndentEffect,
	["GetZonePVPInfo"] = noIndentEffect,
	["GetZoneText"] = noIndentEffect,
	["GiveMasterLoot"] = noIndentEffect,
	["GlyphFrame_LoadUI"] = noIndentEffect,
	["GlyphMatchesSocket"] = noIndentEffect,
	["GossipFrameActiveQuestsUpdate"] = noIndentEffect,
	["GossipFrameAvailableQuestsUpdate"] = noIndentEffect,
	["GossipFrameOptionsUpdate"] = noIndentEffect,
	["GossipFrameUpdate"] = noIndentEffect,
	["GossipFrame_OnEvent"] = noIndentEffect,
	["GossipFrame_OnLoad"] = noIndentEffect,
	["GossipResize"] = noIndentEffect,
	["GossipTitleButton_OnClick"] = noIndentEffect,
	["GrantLevel"] = noIndentEffect,
	["GroupLootDropDown_GiveLoot"] = noIndentEffect,
	["GroupLootDropDown_Initialize"] = noIndentEffect,
	["GroupLootDropDown_OnLoad"] = noIndentEffect,
	["GroupLootFrame_DisableLootButton"] = noIndentEffect,
	["GroupLootFrame_EnableLootButton"] = noIndentEffect,
	["GroupLootFrame_OnEvent"] = noIndentEffect,
	["GroupLootFrame_OnHide"] = noIndentEffect,
	["GroupLootFrame_OnShow"] = noIndentEffect,
	["GroupLootFrame_OnUpdate"] = noIndentEffect,
	["GroupLootFrame_OpenNewFrame"] = noIndentEffect,
	["GuildBankFrame_LoadUI"] = noIndentEffect,
	["GuildBankTabPermissionsTab_OnClick"] = noIndentEffect,
	["GuildControlAddRank"] = noIndentEffect,
	["GuildControlCheckboxUpdate"] = noIndentEffect,
	["GuildControlDelRank"] = noIndentEffect,
	["GuildControlGetNumRanks"] = noIndentEffect,
	["GuildControlGetRankFlags"] = noIndentEffect,
	["GuildControlGetRankName"] = noIndentEffect,
	["GuildControlPopupAcceptButton_OnClick"] = noIndentEffect,
	["GuildControlPopupFrameAddRankButton_OnUpdate"] = noIndentEffect,
	["GuildControlPopupFrameDropDownButton_OnClick"] = noIndentEffect,
	["GuildControlPopupFrameDropDown_Initialize"] = noIndentEffect,
	["GuildControlPopupFrameDropDown_OnLoad"] = noIndentEffect,
	["GuildControlPopupFrameRemoveRankButton_OnClick"] = noIndentEffect,
	["GuildControlPopupFrameRemoveRankButton_OnUpdate"] = noIndentEffect,
	["GuildControlPopupFrame_Initialize"] = noIndentEffect,
	["GuildControlPopupFrame_OnEvent"] = noIndentEffect,
	["GuildControlPopupFrame_OnHide"] = noIndentEffect,
	["GuildControlPopupFrame_OnLoad"] = noIndentEffect,
	["GuildControlPopupFrame_OnShow"] = noIndentEffect,
	["GuildControlPopup_UpdateDepositCheckBox"] = noIndentEffect,
	["GuildControlPopupframe_Update"] = noIndentEffect,
	["GuildControlSaveRank"] = noIndentEffect,
	["GuildControlSetRank"] = noIndentEffect,
	["GuildControlSetRankFlag"] = noIndentEffect,
	["GuildDemote"] = noIndentEffect,
	["GuildDisband"] = noIndentEffect,
	["GuildEventLog_Update"] = noIndentEffect,
	["GuildFrameControlButton_OnUpdate"] = noIndentEffect,
	["GuildFrameGuildListToggleButton_OnClick"] = noIndentEffect,
	["GuildFramePopup_HideAll"] = noIndentEffect,
	["GuildFramePopup_Show"] = noIndentEffect,
	["GuildFrame_GetLastOnline"] = noIndentEffect,
	["GuildInfo"] = noIndentEffect,
	["GuildInvite"] = noIndentEffect,
	["GuildLeave"] = noIndentEffect,
	["GuildPromote"] = noIndentEffect,
	["GuildRegistrar_OnShow"] = noIndentEffect,
	["GuildRegistrar_ShowPurchaseFrame"] = noIndentEffect,
	["GuildRoster"] = noIndentEffect,
	["GuildRosterSetOfficerNote"] = noIndentEffect,
	["GuildRosterSetPublicNote"] = noIndentEffect,
	["GuildSetLeader"] = noIndentEffect,
	["GuildSetMOTD"] = noIndentEffect,
	["GuildStatus_Update"] = noIndentEffect,
	["GuildUninvite"] = noIndentEffect,
	["HandleModifiedItemClick"] = noIndentEffect,
	["HasAction"] = noIndentEffect,
	["HasCompletedAnyAchievement"] = noIndentEffect,
	["HasDebugZoneMap"] = noIndentEffect,
	["HasFilledPetition"] = noIndentEffect,
	["HasFullControl"] = noIndentEffect,
	["HasInspectHonorData"] = noIndentEffect,
	["HasKey"] = noIndentEffect,
	["HasLFGRestrictions"] = noIndentEffect,
	["HasMessageType"] = noIndentEffect,
	["HasMessageTypeGroup"] = noIndentEffect,
	["HasMultiCastActionBar"] = noIndentEffect,
	["HasMultiCastActionPage"] = noIndentEffect,
	["HasNewMail"] = noIndentEffect,
	["HasPetSpells"] = noIndentEffect,
	["HasPetUI"] = noIndentEffect,
	["HasSoulstone"] = noIndentEffect,
	["HasWandEquipped"] = noIndentEffect,
	["HealthBar_OnValueChanged"] = noIndentEffect,
	["HearthAndResurrectFromArea"] = noIndentEffect,
	["HelpFrameGMTalk_OnShow"] = noIndentEffect,
	["HelpFrameOpenTicketCancel_OnClick"] = noIndentEffect,
	["HelpFrameOpenTicketSubmit_OnClick"] = noIndentEffect,
	["HelpFrameReportIssue_OnShow"] = noIndentEffect,
	["HelpFrameStuck_OnShow"] = noIndentEffect,
	["HelpFrameViewResponseButton_OnLoad"] = noIndentEffect,
	["HelpFrameViewResponseIssueResolved_OnClick"] = noIndentEffect,
	["HelpFrameViewResponseMoreHelp_OnClick"] = noIndentEffect,
	["HelpFrame_HaveGMResponse"] = noIndentEffect,
	["HelpFrame_HaveGMTicket"] = noIndentEffect,
	["HelpFrame_IsGMTicketQueueActive"] = noIndentEffect,
	["HelpFrame_OnEvent"] = noIndentEffect,
	["HelpFrame_OnHide"] = noIndentEffect,
	["HelpFrame_OnLoad"] = noIndentEffect,
	["HelpFrame_OnShow"] = noIndentEffect,
	["HelpFrame_PopAllFrames"] = noIndentEffect,
	["HelpFrame_PopFrame"] = noIndentEffect,
	["HelpFrame_ShowFrame"] = noIndentEffect,
	["HelpReportLag"] = noIndentEffect,
	["HideBonusActionBar"] = noIndentEffect,
	["HideDropDownMenu"] = noIndentEffect,
	["HideMultiCastActionBar"] = noIndentEffect,
	["HideParentPanel"] = noIndentEffect,
	["HidePartyFrame"] = noIndentEffect,
	["HidePetActionBar"] = noIndentEffect,
	["HideRepairCursor"] = noIndentEffect,
	["HideTextStatusBarText"] = noIndentEffect,
	["HideUIPanel"] = noIndentEffect,
	["HideWatchedReputationBarText"] = noIndentEffect,
	["HonorFrame_OnEvent"] = noIndentEffect,
	["HonorFrame_OnLoad"] = noIndentEffect,
	["HonorFrame_Update"] = noIndentEffect,
	["HybridScrollFrameScrollButton_OnClick"] = noIndentEffect,
	["HybridScrollFrameScrollButton_OnUpdate"] = noIndentEffect,
	["HybridScrollFrameScrollChild_OnLoad"] = noIndentEffect,
	["HybridScrollFrame_CollapseButton"] = noIndentEffect,
	["HybridScrollFrame_CreateButtons"] = noIndentEffect,
	["HybridScrollFrame_ExpandButton"] = noIndentEffect,
	["HybridScrollFrame_GetOffset"] = noIndentEffect,
	["HybridScrollFrame_OnLoad"] = noIndentEffect,
	["HybridScrollFrame_OnMouseWheel"] = noIndentEffect,
	["HybridScrollFrame_OnValueChanged"] = noIndentEffect,
	["HybridScrollFrame_SetOffset"] = noIndentEffect,
	["HybridScrollFrame_Update"] = noIndentEffect,
	["HybridScrollFrame_UpdateButtonStates"] = noIndentEffect,
	["IgnoreList_SetHeader"] = noIndentEffect,
	["IgnoreList_Update"] = noIndentEffect,
	["InCinematic"] = noIndentEffect,
	["InCombatLockdown"] = noIndentEffect,
	["InGuildCheck"] = noIndentEffect,
	["InRepairMode"] = noIndentEffect,
	["InboxFrameItem_OnEnter"] = noIndentEffect,
	["InboxFrame_OnClick"] = noIndentEffect,
	["InboxFrame_OnModifiedClick"] = noIndentEffect,
	["InboxFrame_Update"] = noIndentEffect,
	["InboxGetMoreMail"] = noIndentEffect,
	["InboxItemCanDelete"] = noIndentEffect,
	["InboxNextPage"] = noIndentEffect,
	["InboxPrevPage"] = noIndentEffect,
	["InitWorldMapPing"] = noIndentEffect,
	["InitiateRolePoll"] = noIndentEffect,
	["InitiateTrade"] = noIndentEffect,
	["InspectAchievements"] = noIndentEffect,
	["InspectFrame_LoadUI"] = noIndentEffect,
	["InspectUnit"] = noIndentEffect,
	["InstanceLock_OnEnter"] = noIndentEffect,
	["InteractUnit"] = noIndentEffect,
	["InterfaceAddOnsList_Update"] = noIndentEffect,
	["InterfaceCategoryList_Update"] = noIndentEffect,
	["InterfaceOptionsActionBarsPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsActionBarsPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsBattlenetPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsBuffsPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsBuffsPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsCameraPanelStyleDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsCameraPanelStyleDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsCameraPanelStyleDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCameraPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCameraPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCombatPanelTOTDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsCombatPanelTOTDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsCombatPanelTOTDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCombatTextPanelFCTDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsCombatTextPanelFCTDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsCombatTextPanelFCTDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCombatTextPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsCombatTextPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_Update"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_Initialize"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_OnClick"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_OnEvent"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelPreviewTalentChanges_SetFunc"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelShowAggroPercentage_SetFunc"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelShowClock_SetFunc"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_Initialize"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_OnClick"] = noIndentEffect,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_OnEvent"] = noIndentEffect,
	["InterfaceOptionsDisplayPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsDisplayPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsFrameCancel_OnClick"] = noIndentEffect,
	["InterfaceOptionsFrameDefaults_OnClick"] = noIndentEffect,
	["InterfaceOptionsFrameOkay_OnClick"] = noIndentEffect,
	["InterfaceOptionsFrame_InitializeUVars"] = noIndentEffect,
	["InterfaceOptionsFrame_LoadUVars"] = noIndentEffect,
	["InterfaceOptionsFrame_OnEvent"] = noIndentEffect,
	["InterfaceOptionsFrame_OnHide"] = noIndentEffect,
	["InterfaceOptionsFrame_OnLoad"] = noIndentEffect,
	["InterfaceOptionsFrame_OnShow"] = noIndentEffect,
	["InterfaceOptionsFrame_OpenToCategory"] = noIndentEffect,
	["InterfaceOptionsFrame_SetAllToDefaults"] = noIndentEffect,
	["InterfaceOptionsFrame_SetCurrentToDefaults"] = noIndentEffect,
	["InterfaceOptionsFrame_Show"] = noIndentEffect,
	["InterfaceOptionsFrame_TabOnClick"] = noIndentEffect,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_InitializeHelper"] = noIndentEffect,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsLanguagesPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsListButton_OnClick"] = noIndentEffect,
	["InterfaceOptionsListButton_ToggleSubCategories"] = noIndentEffect,
	["InterfaceOptionsList_DisplayPanel"] = noIndentEffect,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_Initialize"] = noIndentEffect,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_OnClick"] = noIndentEffect,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_OnEvent"] = noIndentEffect,
	["InterfaceOptionsObjectivesPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsObjectivesPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsOptionsFrame_RefreshAddOns"] = noIndentEffect,
	["InterfaceOptionsOptionsFrame_RefreshCategories"] = noIndentEffect,
	["InterfaceOptionsPanel_CheckButton_OnClick"] = noIndentEffect,
	["InterfaceOptionsPanel_CheckButton_Update"] = noIndentEffect,
	["InterfaceOptionsPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptionsSocialPanelChatMouseScroll_SetScrolling"] = noIndentEffect,
	["InterfaceOptionsSocialPanelChatStyle_Initialize"] = noIndentEffect,
	["InterfaceOptionsSocialPanelChatStyle_OnClick"] = noIndentEffect,
	["InterfaceOptionsSocialPanelChatStyle_OnEvent"] = noIndentEffect,
	["InterfaceOptionsSocialPanelChatStyle_SetChatStyle"] = noIndentEffect,
	["InterfaceOptionsSocialPanelConversationMode_Initialize"] = noIndentEffect,
	["InterfaceOptionsSocialPanelConversationMode_OnClick"] = noIndentEffect,
	["InterfaceOptionsSocialPanelConversationMode_OnEvent"] = noIndentEffect,
	["InterfaceOptionsSocialPanelProfanityFilter_SyncWithBattlenet"] = noIndentEffect,
	["InterfaceOptionsSocialPanelProfanityFilter_UpdateDisplay"] = noIndentEffect,
	["InterfaceOptionsSocialPanelTimestamps_AddTimestampFormat"] = noIndentEffect,
	["InterfaceOptionsSocialPanelTimestamps_Initialize"] = noIndentEffect,
	["InterfaceOptionsSocialPanelTimestamps_OnClick"] = noIndentEffect,
	["InterfaceOptionsSocialPanelTimestamps_OnEvent"] = noIndentEffect,
	["InterfaceOptionsSocialPanel_OnEvent"] = noIndentEffect,
	["InterfaceOptionsSocialPanel_OnLoad"] = noIndentEffect,
	["InterfaceOptions_AddCategory"] = noIndentEffect,
	["InterfaceOptions_UpdateMultiActionBars"] = noIndentEffect,
	["InviteUnit"] = noIndentEffect,
	["IsActionInRange"] = noIndentEffect,
	["IsActiveBattlefieldArena"] = noIndentEffect,
	["IsActiveQuestTrivial"] = noIndentEffect,
	["IsAddOnLoadOnDemand"] = noIndentEffect,
	["IsAddOnLoaded"] = noIndentEffect,
	["IsAlreadyInQueue"] = noIndentEffect,
	["IsAltKeyDown"] = noIndentEffect,
	["IsArenaTeamCaptain"] = noIndentEffect,
	["IsAtStableMaster"] = noIndentEffect,
	["IsAttackAction"] = noIndentEffect,
	["IsAttackSpell"] = noIndentEffect,
	["IsAuctionSortReversed"] = noIndentEffect,
	["IsAutoRepeatAction"] = noIndentEffect,
	["IsAutoRepeatSpell"] = noIndentEffect,
	["IsAvailableQuestTrivial"] = noIndentEffect,
	["IsBNLogin"] = noIndentEffect,
	["IsBagOpen"] = noIndentEffect,
	["IsBattlefieldArena"] = noIndentEffect,
	["IsClassColoringMessageType"] = noIndentEffect,
	["IsCombatLog"] = noIndentEffect,
	["IsConsumableAction"] = noIndentEffect,
	["IsConsumableItem"] = noIndentEffect,
	["IsConsumableSpell"] = noIndentEffect,
	["IsControlKeyDown"] = noIndentEffect,
	["IsCurrentAction"] = noIndentEffect,
	["IsCurrentItem"] = noIndentEffect,
	["IsCurrentQuestFailed"] = noIndentEffect,
	["IsCurrentSpell"] = noIndentEffect,
	["IsDebugBuild"] = noIndentEffect,
	["IsDesaturateSupported"] = noIndentEffect,
	["IsDisplayChannelModerator"] = noIndentEffect,
	["IsDisplayChannelOwner"] = noIndentEffect,
	["IsDressableItem"] = noIndentEffect,
	["IsEquippableItem"] = noIndentEffect,
	["IsEquippedAction"] = noIndentEffect,
	["IsEquippedItem"] = noIndentEffect,
	["IsEquippedItemType"] = noIndentEffect,
	["IsFactionInactive"] = noIndentEffect,
	["IsFalling"] = noIndentEffect,
	["IsFishingLoot"] = noIndentEffect,
	["IsFlyableArea"] = noIndentEffect,
	["IsFlying"] = noIndentEffect,
	["IsFrameHandle"] = noIndentEffect,
	["IsGuildLeader"] = noIndentEffect,
	["IsHarmfulItem"] = noIndentEffect,
	["IsHarmfulSpell"] = noIndentEffect,
	["IsHelpfulItem"] = noIndentEffect,
	["IsHelpfulSpell"] = noIndentEffect,
	["IsIgnored"] = noIndentEffect,
	["IsIgnoredOrMuted"] = noIndentEffect,
	["IsInArenaTeam"] = noIndentEffect,
	["IsInGuild"] = noIndentEffect,
	["IsInInstance"] = noIndentEffect,
	["IsInLFGDungeon"] = noIndentEffect,
	["IsIndoors"] = noIndentEffect,
	["IsInventoryItemLocked"] = noIndentEffect,
	["IsItemInRange"] = noIndentEffect,
	["IsLFGDungeonJoinable"] = noIndentEffect,
	["IsLeftAltKeyDown"] = noIndentEffect,
	["IsLeftControlKeyDown"] = noIndentEffect,
	["IsLeftShiftKeyDown"] = noIndentEffect,
	["IsLinuxClient"] = noIndentEffect,
	["IsListedInLFR"] = noIndentEffect,
	["IsListeningForMessageType"] = noIndentEffect,
	["IsLoggedIn"] = noIndentEffect,
	["IsMacClient"] = noIndentEffect,
	["IsMessageDoneBy"] = noIndentEffect,
	["IsMessageDoneTo"] = noIndentEffect,
	["IsModifiedClick"] = noIndentEffect,
	["IsModifierKeyDown"] = noIndentEffect,
	["IsMounted"] = noIndentEffect,
	["IsMouseButtonDown"] = noIndentEffect,
	["IsMouselooking"] = noIndentEffect,
	["IsMuted"] = noIndentEffect,
	["IsOptionFrameOpen"] = noIndentEffect,
	["IsOutOfBounds"] = noIndentEffect,
	["IsOutdoors"] = noIndentEffect,
	["IsPVPTimerRunning"] = noIndentEffect,
	["IsPartyLFG"] = noIndentEffect,
	["IsPartyLeader"] = noIndentEffect,
	["IsPassiveSpell"] = noIndentEffect,
	["IsPetAttackAction"] = noIndentEffect,
	["IsPetAttackActive"] = noIndentEffect,
	["IsPlayerResolutionAvailable"] = noIndentEffect,
	["IsPossessBarVisible"] = noIndentEffect,
	["IsQuestCompletable"] = noIndentEffect,
	["IsQuestFlaggedComplete"] = noIndentEffect,
	["IsQuestLogSpecialItemInRange"] = noIndentEffect,
	["IsQuestWatched"] = noIndentEffect,
	["IsRaidLeader"] = noIndentEffect,
	["IsRaidOfficer"] = noIndentEffect,
	["IsRealPartyLeader"] = noIndentEffect,
	["IsRealRaidLeader"] = noIndentEffect,
	["IsReferAFriendLinked"] = noIndentEffect,
	["IsResting"] = noIndentEffect,
	["IsRightAltKeyDown"] = noIndentEffect,
	["IsRightControlKeyDown"] = noIndentEffect,
	["IsRightShiftKeyDown"] = noIndentEffect,
	["IsSecureCmd"] = noIndentEffect,
	["IsSelectedSpell"] = noIndentEffect,
	["IsShiftKeyDown"] = noIndentEffect,
	["IsSilenced"] = noIndentEffect,
	["IsSpellInRange"] = noIndentEffect,
	["IsSpellKnown"] = noIndentEffect,
	["IsStackableAction"] = noIndentEffect,
	["IsStealthed"] = noIndentEffect,
	["IsStereoVideoAvailable"] = noIndentEffect,
	["IsSubZonePVPPOI"] = noIndentEffect,
	["IsSwimming"] = noIndentEffect,
	["IsThreatWarningEnabled"] = noIndentEffect,
	["IsTitleKnown"] = noIndentEffect,
	["IsTrackedAchievement"] = noIndentEffect,
	["IsTradeSkillLinked"] = noIndentEffect,
	["IsTradeskillTrainer"] = noIndentEffect,
	["IsTrainerServiceSkillStep"] = noIndentEffect,
	["IsTutorialFlagged"] = noIndentEffect,
	["IsUnitOnQuest"] = noIndentEffect,
	["IsUsableAction"] = noIndentEffect,
	["IsUsableItem"] = noIndentEffect,
	["IsUsableSpell"] = noIndentEffect,
	["IsUsingVehicleControls"] = noIndentEffect,
	["IsVehicleAimAngleAdjustable"] = noIndentEffect,
	["IsVehicleAimPowerAdjustable"] = noIndentEffect,
	["IsVoiceChatAllowed"] = noIndentEffect,
	["IsVoiceChatAllowedByServer"] = noIndentEffect,
	["IsVoiceChatEnabled"] = noIndentEffect,
	["IsWindowsClient"] = noIndentEffect,
	["IsXPUserDisabled"] = noIndentEffect,
	["IsZoomOutAvailable"] = noIndentEffect,
	["ItemAnim_OnAnimFinished"] = noIndentEffect,
	["ItemAnim_OnEvent"] = noIndentEffect,
	["ItemAnim_OnLoad"] = noIndentEffect,
	["ItemHasRange"] = noIndentEffect,
	["ItemSocketingFrame_LoadUI"] = noIndentEffect,
	["ItemTextFrame_OnEvent"] = noIndentEffect,
	["ItemTextFrame_OnLoad"] = noIndentEffect,
	["ItemTextFrame_OnUpdate"] = noIndentEffect,
	["ItemTextGetCreator"] = noIndentEffect,
	["ItemTextGetItem"] = noIndentEffect,
	["ItemTextGetMaterial"] = noIndentEffect,
	["ItemTextGetPage"] = noIndentEffect,
	["ItemTextGetText"] = noIndentEffect,
	["ItemTextHasNextPage"] = noIndentEffect,
	["ItemTextNextPage"] = noIndentEffect,
	["ItemTextPrevPage"] = noIndentEffect,
	["JoinBattlefield"] = noIndentEffect,
	["JoinChannelByName"] = noIndentEffect,
	["JoinLFG"] = noIndentEffect,
	["JoinPermanentChannel"] = noIndentEffect,
	["JoinTemporaryChannel"] = noIndentEffect,
	["JumpOrAscendStart"] = noIndentEffect,
	["KBArticle_BeginLoading"] = noIndentEffect,
	["KBArticle_GetData"] = noIndentEffect,
	["KBArticle_IsLoaded"] = noIndentEffect,
	["KBQuery_BeginLoading"] = noIndentEffect,
	["KBQuery_GetArticleHeaderCount"] = noIndentEffect,
	["KBQuery_GetArticleHeaderData"] = noIndentEffect,
	["KBQuery_GetTotalArticleCount"] = noIndentEffect,
	["KBQuery_IsLoaded"] = noIndentEffect,
	["KBSetup_BeginLoading"] = noIndentEffect,
	["KBSetup_GetArticleHeaderCount"] = noIndentEffect,
	["KBSetup_GetArticleHeaderData"] = noIndentEffect,
	["KBSetup_GetCategoryCount"] = noIndentEffect,
	["KBSetup_GetCategoryData"] = noIndentEffect,
	["KBSetup_GetLanguageCount"] = noIndentEffect,
	["KBSetup_GetLanguageData"] = noIndentEffect,
	["KBSetup_GetSubCategoryCount"] = noIndentEffect,
	["KBSetup_GetSubCategoryData"] = noIndentEffect,
	["KBSetup_GetTotalArticleCount"] = noIndentEffect,
	["KBSetup_IsLoaded"] = noIndentEffect,
	["KBSystem_GetMOTD"] = noIndentEffect,
	["KBSystem_GetServerNotice"] = noIndentEffect,
	["KBSystem_GetServerStatus"] = noIndentEffect,
	["KeyBindingFrame_LoadUI"] = noIndentEffect,
	["KeyRingButtonIDToInvSlotID"] = noIndentEffect,
	["KnowledgeBaseArticleListFrame_HideArticleList"] = noIndentEffect,
	["KnowledgeBaseArticleListFrame_NextPage"] = noIndentEffect,
	["KnowledgeBaseArticleListFrame_PopulateArticleList"] = noIndentEffect,
	["KnowledgeBaseArticleListFrame_PreviousPage"] = noIndentEffect,
	["KnowledgeBaseArticleListItem_OnClick"] = noIndentEffect,
	["KnowledgeBaseArticleListItem_OnEnter"] = noIndentEffect,
	["KnowledgeBaseArticleListItem_OnLeave"] = noIndentEffect,
	["KnowledgeBaseArticleListItem_OnUpdate"] = noIndentEffect,
	["KnowledgeBaseArticleListItem_Update"] = noIndentEffect,
	["KnowledgeBaseErrorFrame_SetErrorMessage"] = noIndentEffect,
	["KnowledgeBaseFrameCategoryButton_OnClick"] = noIndentEffect,
	["KnowledgeBaseFrameCategoryDropDown_AddInfo"] = noIndentEffect,
	["KnowledgeBaseFrameCategoryDropDown_Initialize"] = noIndentEffect,
	["KnowledgeBaseFrameCategoryDropDown_OnLoad"] = noIndentEffect,
	["KnowledgeBaseFrameSubCategoryButton_OnClick"] = noIndentEffect,
	["KnowledgeBaseFrameSubCategoryDropDown_AddInfo"] = noIndentEffect,
	["KnowledgeBaseFrameSubCategoryDropDown_Initialize"] = noIndentEffect,
	["KnowledgeBaseFrameSubCategoryDropDown_OnLoad"] = noIndentEffect,
	["KnowledgeBaseFrame_DisableButtons"] = noIndentEffect,
	["KnowledgeBaseFrame_EnableButtons"] = noIndentEffect,
	["KnowledgeBaseFrame_LoadTopIssues"] = noIndentEffect,
	["KnowledgeBaseFrame_OnEvent"] = noIndentEffect,
	["KnowledgeBaseFrame_OnLoad"] = noIndentEffect,
	["KnowledgeBaseFrame_OnShow"] = noIndentEffect,
	["KnowledgeBaseFrame_Search"] = noIndentEffect,
	["KnowledgeBaseFrame_ShowArticleFrame"] = noIndentEffect,
	["KnowledgeBaseFrame_ShowErrorFrame"] = noIndentEffect,
	["KnowledgeBaseFrame_ShowSearchFrame"] = noIndentEffect,
	["KnowledgeBaseFrame_UpdateMotd"] = noIndentEffect,
	["KnowledgeBaseFrame_UpdateServerMessage"] = noIndentEffect,
	["KnowledgeBaseMotdTextFrame_OnEnter"] = noIndentEffect,
	["KnowledgeBaseMotdTextFrame_OnLeave"] = noIndentEffect,
	["KnowledgeBaseMotdTextFrame_OnUpdate"] = noIndentEffect,
	["KnowledgeBaseServerMessageTextFrame_OnEnter"] = noIndentEffect,
	["KnowledgeBaseServerMessageTextFrame_OnLeave"] = noIndentEffect,
	["KnowledgeBaseServerMessageTextFrame_OnUpdate"] = noIndentEffect,
	["KnowledgeBaseUpdateTopPanelPositions"] = noIndentEffect,
	["LFDConstructDeclinedMessage"] = noIndentEffect,
	["LFDDungeonReadyDialogInstanceInfo_OnEnter"] = noIndentEffect,
	["LFDDungeonReadyDialogReward_OnEnter"] = noIndentEffect,
	["LFDDungeonReadyDialogReward_SetMisc"] = noIndentEffect,
	["LFDDungeonReadyDialogReward_SetReward"] = noIndentEffect,
	["LFDDungeonReadyDialog_UpdateInstanceInfo"] = noIndentEffect,
	["LFDDungeonReadyDialog_UpdateRewards"] = noIndentEffect,
	["LFDDungeonReadyPopup_OnFail"] = noIndentEffect,
	["LFDDungeonReadyPopup_OnUpdate"] = noIndentEffect,
	["LFDDungeonReadyPopup_Update"] = noIndentEffect,
	["LFDDungeonReadyStatus_ResetReadyStates"] = noIndentEffect,
	["LFDDungeonReadyStatus_UpdateIcon"] = noIndentEffect,
	["LFDFrameRoleCheckButton_OnClick"] = noIndentEffect,
	["LFDFrameRoleCheckButton_OnEnter"] = noIndentEffect,
	["LFDFrame_OnEvent"] = noIndentEffect,
	["LFDFrame_OnHide"] = noIndentEffect,
	["LFDFrame_OnLoad"] = noIndentEffect,
	["LFDFrame_OnShow"] = noIndentEffect,
	["LFDFrame_UpdateBackfill"] = noIndentEffect,
	["LFDGetNumDungeons"] = noIndentEffect,
	["LFDList_DefaultFilterFunction"] = noIndentEffect,
	["LFDList_SetDungeonEnabled"] = noIndentEffect,
	["LFDList_SetHeaderCollapsed"] = noIndentEffect,
	["LFDList_SetHeaderEnabled"] = noIndentEffect,
	["LFDQueueFrameDungeonChoiceEnableButton_OnClick"] = noIndentEffect,
	["LFDQueueFrameDungeonListButton_OnEnter"] = noIndentEffect,
	["LFDQueueFrameExpandOrCollapseButton_OnClick"] = noIndentEffect,
	["LFDQueueFrameFindGroupButton_Update"] = noIndentEffect,
	["LFDQueueFrameRandomCooldownFrame_OnEvent"] = noIndentEffect,
	["LFDQueueFrameRandomCooldownFrame_OnLoad"] = noIndentEffect,
	["LFDQueueFrameRandomCooldownFrame_OnUpdate"] = noIndentEffect,
	["LFDQueueFrameRandomCooldownFrame_Update"] = noIndentEffect,
	["LFDQueueFrameRandom_UpdateFrame"] = noIndentEffect,
	["LFDQueueFrameSpecificListButton_SetDungeon"] = noIndentEffect,
	["LFDQueueFrameSpecificList_Update"] = noIndentEffect,
	["LFDQueueFrameTypeDropDownButton_OnClick"] = noIndentEffect,
	["LFDQueueFrameTypeDropDown_Initialize"] = noIndentEffect,
	["LFDQueueFrameTypeDropDown_SetUp"] = noIndentEffect,
	["LFDQueueFrame_Join"] = noIndentEffect,
	["LFDQueueFrame_QueueForInstanceIfEnabled"] = noIndentEffect,
	["LFDQueueFrame_SetRoles"] = noIndentEffect,
	["LFDQueueFrame_SetType"] = noIndentEffect,
	["LFDQueueFrame_SetTypeRandomDungeon"] = noIndentEffect,
	["LFDQueueFrame_SetTypeSpecificDungeon"] = noIndentEffect,
	["LFDQueueFrame_Update"] = noIndentEffect,
	["LFDQueueFrame_UpdatePortrait"] = noIndentEffect,
	["LFDRoleCheckPopupAccept_OnClick"] = noIndentEffect,
	["LFDRoleCheckPopupDecline_OnClick"] = noIndentEffect,
	["LFDRoleCheckPopupDescription_OnEnter"] = noIndentEffect,
	["LFDRoleCheckPopup_Update"] = noIndentEffect,
	["LFDSearchStatusPlayer_SetFound"] = noIndentEffect,
	["LFDSearchStatus_OnEvent"] = noIndentEffect,
	["LFDSearchStatus_OnUpdate"] = noIndentEffect,
	["LFDSearchStatus_Update"] = noIndentEffect,
	["LFDSearchStatus_UpdateRoles"] = noIndentEffect,
	["LFD_CURRENT_FILTER"] = noIndentEffect,
	["LFD_IsEmpowered"] = noIndentEffect,
	["LFGDebug"] = noIndentEffect,
	["LFGDungeonList_Setup"] = noIndentEffect,
	["LFGEventFrame_OnEvent"] = noIndentEffect,
	["LFGEventFrame_OnLoad"] = noIndentEffect,
	["LFGGetDungeonInfoByID"] = noIndentEffect,
	["LFGIsIDHeader"] = noIndentEffect,
	["LFGListFilterChoices"] = noIndentEffect,
	["LFGListRemoveCollapsedChildren"] = noIndentEffect,
	["LFGListRemoveHeadersWithoutChildren"] = noIndentEffect,
	["LFGListUpdateHeaderEnabledAndLockedStates"] = noIndentEffect,
	["LFGQueueFrame_UpdateLFGDungeonList"] = noIndentEffect,
	["LFGSpecificChoiceEnableButton_SetIsRadio"] = noIndentEffect,
	["LFGTeleport"] = noIndentEffect,
	["LFG_DisableRoleButton"] = noIndentEffect,
	["LFG_EnableRoleButton"] = noIndentEffect,
	["LFG_PermanentlyDisableRoleButton"] = noIndentEffect,
	["LFG_UpdateAvailableRoles"] = noIndentEffect,
	["LFG_UpdateFindGroupButtons"] = noIndentEffect,
	["LFG_UpdateFramesIfShown"] = noIndentEffect,
	["LFG_UpdateLockedOutPanels"] = noIndentEffect,
	["LFG_UpdateQueuedList"] = noIndentEffect,
	["LFG_UpdateRoleCheckboxes"] = noIndentEffect,
	["LFG_UpdateRolesChangeable"] = noIndentEffect,
	["LFRBrowseButton_OnClick"] = noIndentEffect,
	["LFRBrowseButton_OnEnter"] = noIndentEffect,
	["LFRBrowseFrameListButton_SetData"] = noIndentEffect,
	["LFRBrowseFrameList_Update"] = noIndentEffect,
	["LFRBrowseFrameRaidDropDownButton_OnClick"] = noIndentEffect,
	["LFRBrowseFrameRaidDropDown_Initialize"] = noIndentEffect,
	["LFRBrowseFrameRaidDropDown_SetUp"] = noIndentEffect,
	["LFRBrowseFrameRefreshButton_OnUpdate"] = noIndentEffect,
	["LFRBrowseFrame_OnLoad"] = noIndentEffect,
	["LFRBrowseFrame_OnUpdateAlways"] = noIndentEffect,
	["LFRBrowse_UpdateButtonStates"] = noIndentEffect,
	["LFRFrameRoleCheckButton_OnClick"] = noIndentEffect,
	["LFRFrame_OnEvent"] = noIndentEffect,
	["LFRFrame_OnLoad"] = noIndentEffect,
	["LFRFrame_SetActiveTab"] = noIndentEffect,
	["LFRGetNumDungeons"] = noIndentEffect,
	["LFRList_DefaultFilterFunction"] = noIndentEffect,
	["LFRList_SetHeaderCollapsed"] = noIndentEffect,
	["LFRList_SetHeaderEnabled"] = noIndentEffect,
	["LFRList_SetRaidEnabled"] = noIndentEffect,
	["LFRQueueFrameDungeonChoiceEnableButton_OnClick"] = noIndentEffect,
	["LFRQueueFrameExpandOrCollapseButton_OnClick"] = noIndentEffect,
	["LFRQueueFrameFindGroupButton_Update"] = noIndentEffect,
	["LFRQueueFrameSpecificListButton_SetDungeon"] = noIndentEffect,
	["LFRQueueFrameSpecificList_Update"] = noIndentEffect,
	["LFRQueueFrame_Join"] = noIndentEffect,
	["LFRQueueFrame_QueueForInstanceIfEnabled"] = noIndentEffect,
	["LFRQueueFrame_SetRoles"] = noIndentEffect,
	["LFRQueueFrame_Update"] = noIndentEffect,
	["LFR_CURRENT_FILTER"] = noIndentEffect,
	["LFR_CanQueueForLockedInstances"] = noIndentEffect,
	["LFR_CanQueueForMultiple"] = noIndentEffect,
	["LFR_IsEmpowered"] = noIndentEffect,
	["LanguageMenu_Click"] = noIndentEffect,
	["LanguageMenu_LoadLanguages"] = noIndentEffect,
	["LanguageMenu_OnEvent"] = noIndentEffect,
	["LanguageMenu_OnLoad"] = noIndentEffect,
	["LearnPreviewTalents"] = noIndentEffect,
	["LearnTalent"] = noIndentEffect,
	["LeaveBattlefield"] = noIndentEffect,
	["LeaveChannelByName"] = noIndentEffect,
	["LeaveLFG"] = noIndentEffect,
	["LeaveParty"] = noIndentEffect,
	["ListChannelByName"] = noIndentEffect,
	["ListChannels"] = noIndentEffect,
	["LoadAddOn"] = noIndentEffect,
	["LoadBindings"] = noIndentEffect,
	["LoadMicroButtonTextures"] = noIndentEffect,
	["Localize"] = noIndentEffect,
	["LocalizeFrames"] = noIndentEffect,
	["LocalizePost"] = noIndentEffect,
	["LockMultiCastActionBar"] = noIndentEffect,
	["LockPetActionBar"] = noIndentEffect,
	["LoggingChat"] = noIndentEffect,
	["LoggingCombat"] = noIndentEffect,
	["Logout"] = noIndentEffect,
	["LoopbackVUMeter_OnLoad"] = noIndentEffect,
	["LoopbackVUMeter_OnUpdate"] = noIndentEffect,
	["LootButton_OnClick"] = noIndentEffect,
	["LootFrame_OnEvent"] = noIndentEffect,
	["LootFrame_OnHide"] = noIndentEffect,
	["LootFrame_OnLoad"] = noIndentEffect,
	["LootFrame_OnShow"] = noIndentEffect,
	["LootFrame_PageDown"] = noIndentEffect,
	["LootFrame_PageUp"] = noIndentEffect,
	["LootFrame_Show"] = noIndentEffect,
	["LootFrame_Update"] = noIndentEffect,
	["LootFrame_UpdateButton"] = noIndentEffect,
	["LootItem_OnEnter"] = noIndentEffect,
	["LootSlot"] = noIndentEffect,
	["LootSlotIsCoin"] = noIndentEffect,
	["LootSlotIsItem"] = noIndentEffect,
	["LowHealthFrame_OnUpdate"] = noIndentEffect,
	["LowHealthFrame_StartFlashing"] = noIndentEffect,
	["LowHealthFrame_StopFlashing"] = noIndentEffect,
	["LowerFrameLevel"] = noIndentEffect,
	["MacOptionsCancelFrame_OnShow"] = noIndentEffect,
	["MacOptionsCompressFrame_OnShow"] = noIndentEffect,
	["MacOptionsFrameCodecDropDown_Initialize"] = noIndentEffect,
	["MacOptionsFrameCodecDropDown_OnClick"] = noIndentEffect,
	["MacOptionsFrameCodecDropDown_OnLoad"] = noIndentEffect,
	["MacOptionsFrameFramerateDropDown_Initialize"] = noIndentEffect,
	["MacOptionsFrameFramerateDropDown_OnClick"] = noIndentEffect,
	["MacOptionsFrameFramerateDropDown_OnLoad"] = noIndentEffect,
	["MacOptionsFrameResolutionButton_OnClick"] = noIndentEffect,
	["MacOptionsFrameResolutionDropDown_Initialize"] = noIndentEffect,
	["MacOptionsFrameResolutionDropDown_OnLoad"] = noIndentEffect,
	["MacOptionsFrame_Cancel"] = noIndentEffect,
	["MacOptionsFrame_DisableCheckBox"] = noIndentEffect,
	["MacOptionsFrame_DisableSlider"] = noIndentEffect,
	["MacOptionsFrame_DisableText"] = noIndentEffect,
	["MacOptionsFrame_EnableCheckBox"] = noIndentEffect,
	["MacOptionsFrame_Load"] = noIndentEffect,
	["MacOptionsFrame_OnEvent"] = noIndentEffect,
	["MacOptionsFrame_OnLoad"] = noIndentEffect,
	["MacOptionsFrame_Save"] = noIndentEffect,
	["MacOptionsFrame_SetDefaults"] = noIndentEffect,
	["MacOptionsFrame_UpdateTime"] = noIndentEffect,
	["MacroFrame_LoadUI"] = noIndentEffect,
	["MacroFrame_SaveMacro"] = noIndentEffect,
	["MailFrameTab_OnClick"] = noIndentEffect,
	["MailFrame_OnEvent"] = noIndentEffect,
	["MailFrame_OnLoad"] = noIndentEffect,
	["MainMenuBarBackpackButton_OnEvent"] = noIndentEffect,
	["MainMenuBarBackpackButton_UpdateFreeSlots"] = noIndentEffect,
	["MainMenuBarPerformanceBarFrame_OnEnter"] = noIndentEffect,
	["MainMenuBarVehicleLeaveButton_OnEvent"] = noIndentEffect,
	["MainMenuBarVehicleLeaveButton_OnLoad"] = noIndentEffect,
	["MainMenuBarVehicleLeaveButton_Update"] = noIndentEffect,
	["MainMenuBar_AnimFinished"] = noIndentEffect,
	["MainMenuBar_OnEvent"] = noIndentEffect,
	["MainMenuBar_OnLoad"] = noIndentEffect,
	["MainMenuBar_ToPlayerArt"] = noIndentEffect,
	["MainMenuBar_ToVehicleArt"] = noIndentEffect,
	["MainMenuBar_UnlockAB"] = noIndentEffect,
	["MainMenuBar_UpdateArt"] = noIndentEffect,
	["MainMenuBar_UpdateKeyRing"] = noIndentEffect,
	["MainMenuExpBar_Update"] = noIndentEffect,
	["MainMenuMicroButton_SetNormal"] = noIndentEffect,
	["MainMenuMicroButton_SetPushed"] = noIndentEffect,
	["MakeMinigameMove"] = noIndentEffect,
	["ManageBackpackTokenFrame"] = noIndentEffect,
	["MerchantFrame_ConfirmExtendedItemCost"] = noIndentEffect,
	["MerchantFrame_ConfirmHighCostItem"] = noIndentEffect,
	["MerchantFrame_OnEvent"] = noIndentEffect,
	["MerchantFrame_OnHide"] = noIndentEffect,
	["MerchantFrame_OnLoad"] = noIndentEffect,
	["MerchantFrame_OnShow"] = noIndentEffect,
	["MerchantFrame_ResetRefundItem"] = noIndentEffect,
	["MerchantFrame_SetRefundItem"] = noIndentEffect,
	["MerchantFrame_Update"] = noIndentEffect,
	["MerchantFrame_UpdateAltCurrency"] = noIndentEffect,
	["MerchantFrame_UpdateBuybackInfo"] = noIndentEffect,
	["MerchantFrame_UpdateCanRepairAll"] = noIndentEffect,
	["MerchantFrame_UpdateGuildBankRepair"] = noIndentEffect,
	["MerchantFrame_UpdateMerchantInfo"] = noIndentEffect,
	["MerchantFrame_UpdateRepairButtons"] = noIndentEffect,
	["MerchantItemButton_OnClick"] = noIndentEffect,
	["MerchantItemButton_OnEnter"] = noIndentEffect,
	["MerchantItemButton_OnLoad"] = noIndentEffect,
	["MerchantItemButton_OnModifiedClick"] = noIndentEffect,
	["MerchantItemBuybackButton_OnLoad"] = noIndentEffect,
	["MerchantNextPageButton_OnClick"] = noIndentEffect,
	["MerchantPrevPageButton_OnClick"] = noIndentEffect,
	["MessageFrameScrollButton_OnLoad"] = noIndentEffect,
	["MessageFrameScrollButton_OnUpdate"] = noIndentEffect,
	["MessageTypeColor_OpenColorPicker"] = noIndentEffect,
	["MicroButtonTooltipText"] = noIndentEffect,
	["MiniMapBattlefieldDropDown_Initialize"] = noIndentEffect,
	["MiniMapBattlefieldDropDown_OnLoad"] = noIndentEffect,
	["MiniMapBattlefieldFrame_OnUpdate"] = noIndentEffect,
	["MiniMapBattlefieldFrame_isArena"] = noIndentEffect,
	["MiniMapInstanceDifficulty_OnEvent"] = noIndentEffect,
	["MiniMapLFGFrameDropDown_Update"] = noIndentEffect,
	["MiniMapLFGFrame_OnClick"] = noIndentEffect,
	["MiniMapLFGFrame_OnEnter"] = noIndentEffect,
	["MiniMapLFGFrame_OnLeave"] = noIndentEffect,
	["MiniMapLFGFrame_TeleportIn"] = noIndentEffect,
	["MiniMapLFGFrame_TeleportOut"] = noIndentEffect,
	["MiniMapLFG_UpdateIsShown"] = noIndentEffect,
	["MiniMapTrackingDropDown_Initialize"] = noIndentEffect,
	["MiniMapTrackingDropDown_OnLoad"] = noIndentEffect,
	["MiniMapTrackingShineFadeIn"] = noIndentEffect,
	["MiniMapTrackingShineFadeOut"] = noIndentEffect,
	["MiniMapTracking_SetTracking"] = noIndentEffect,
	["MiniMapTracking_Update"] = noIndentEffect,
	["MiniMapVoiceChatDropDown_Initialize"] = noIndentEffect,
	["MiniMapVoiceChatDropDown_OnLoad"] = noIndentEffect,
	["MiniMapVoiceChat_Update"] = noIndentEffect,
	["MinimapButton_OnMouseDown"] = noIndentEffect,
	["MinimapButton_OnMouseUp"] = noIndentEffect,
	["MinimapMailFrameUpdate"] = noIndentEffect,
	["MinimapPing_FadeOut"] = noIndentEffect,
	["MinimapPing_OnEvent"] = noIndentEffect,
	["MinimapPing_OnLoad"] = noIndentEffect,
	["MinimapPing_OnUpdate"] = noIndentEffect,
	["Minimap_OnClick"] = noIndentEffect,
	["Minimap_SetPing"] = noIndentEffect,
	["Minimap_SetTooltip"] = noIndentEffect,
	["Minimap_Update"] = noIndentEffect,
	["Minimap_UpdateRotationSetting"] = noIndentEffect,
	["Minimap_ZoomIn"] = noIndentEffect,
	["Minimap_ZoomInClick"] = noIndentEffect,
	["Minimap_ZoomOut"] = noIndentEffect,
	["Minimap_ZoomOutClick"] = noIndentEffect,
	["MirrorTimerFrame_OnEvent"] = noIndentEffect,
	["MirrorTimerFrame_OnLoad"] = noIndentEffect,
	["MirrorTimerFrame_OnUpdate"] = noIndentEffect,
	["MirrorTimer_Show"] = noIndentEffect,
	["Model_OnLoad"] = noIndentEffect,
	["Model_OnUpdate"] = noIndentEffect,
	["Model_RotateLeft"] = noIndentEffect,
	["Model_RotateRight"] = noIndentEffect,
	["MoneyFrame_OnEvent"] = noIndentEffect,
	["MoneyFrame_OnLoad"] = noIndentEffect,
	["MoneyFrame_SetType"] = noIndentEffect,
	["MoneyFrame_Update"] = noIndentEffect,
	["MoneyFrame_UpdateMoney"] = noIndentEffect,
	["MoneyInputFrame_ClearFocus"] = noIndentEffect,
	["MoneyInputFrame_GetCopper"] = noIndentEffect,
	["MoneyInputFrame_OnShow"] = noIndentEffect,
	["MoneyInputFrame_OnTextChanged"] = noIndentEffect,
	["MoneyInputFrame_ResetMoney"] = noIndentEffect,
	["MoneyInputFrame_SetCopper"] = noIndentEffect,
	["MoneyInputFrame_SetMode"] = noIndentEffect,
	["MoneyInputFrame_SetNextFocus"] = noIndentEffect,
	["MoneyInputFrame_SetOnValueChangedFunc"] = noIndentEffect,
	["MoneyInputFrame_SetPreviousFocus"] = noIndentEffect,
	["MoneyInputFrame_SetTextColor"] = noIndentEffect,
	["MouseIsOver"] = noIndentEffect,
	["MouselookStart"] = noIndentEffect,
	["MouselookStop"] = noIndentEffect,
	["MoveAndSteerStart"] = noIndentEffect,
	["MoveAndSteerStop"] = noIndentEffect,
	["MoveBackwardStart"] = noIndentEffect,
	["MoveBackwardStop"] = noIndentEffect,
	["MoveForwardStart"] = noIndentEffect,
	["MoveForwardStop"] = noIndentEffect,
	["MoveViewDownStart"] = noIndentEffect,
	["MoveViewDownStop"] = noIndentEffect,
	["MoveViewInStart"] = noIndentEffect,
	["MoveViewInStop"] = noIndentEffect,
	["MoveViewLeftStart"] = noIndentEffect,
	["MoveViewLeftStop"] = noIndentEffect,
	["MoveViewOutStart"] = noIndentEffect,
	["MoveViewOutStop"] = noIndentEffect,
	["MoveViewRightStart"] = noIndentEffect,
	["MoveViewRightStop"] = noIndentEffect,
	["MoveViewUpStart"] = noIndentEffect,
	["MoveViewUpStop"] = noIndentEffect,
	["MovieFrame_OnEvent"] = noIndentEffect,
	["MovieFrame_OnHide"] = noIndentEffect,
	["MovieFrame_OnKeyUp"] = noIndentEffect,
	["MovieFrame_OnLoad"] = noIndentEffect,
	["MovieFrame_OnMovieFinished"] = noIndentEffect,
	["MovieFrame_OnMovieHideSubtitle"] = noIndentEffect,
	["MovieFrame_OnMovieShowSubtitle"] = noIndentEffect,
	["MovieFrame_OnShow"] = noIndentEffect,
	["MovieFrame_OnUpdate"] = noIndentEffect,
	["MovieFrame_PlayMovie"] = noIndentEffect,
	["MovieRecordingProgress_OnUpdate"] = noIndentEffect,
	["MultiActionBarFrame_OnLoad"] = noIndentEffect,
	["MultiActionBar_HideAllGrids"] = noIndentEffect,
	["MultiActionBar_ShowAllGrids"] = noIndentEffect,
	["MultiActionBar_Update"] = noIndentEffect,
	["MultiActionBar_UpdateGrid"] = noIndentEffect,
	["MultiActionBar_UpdateGridVisibility"] = noIndentEffect,
	["MultiActionButtonDown"] = noIndentEffect,
	["MultiActionButtonUp"] = noIndentEffect,
	["MultiBar1_IsVisible"] = noIndentEffect,
	["MultiBar2_IsVisible"] = noIndentEffect,
	["MultiBar3_IsVisible"] = noIndentEffect,
	["MultiBar4_IsVisible"] = noIndentEffect,
	["MultiCastActionBarFrame_OnEvent"] = noIndentEffect,
	["MultiCastActionBarFrame_OnLoad"] = noIndentEffect,
	["MultiCastActionBarFrame_OnUpdate"] = noIndentEffect,
	["MultiCastActionBarFrame_Update"] = noIndentEffect,
	["MultiCastActionButtonDown"] = noIndentEffect,
	["MultiCastActionButtonUp"] = noIndentEffect,
	["MultiCastActionButton_OnEnter"] = noIndentEffect,
	["MultiCastActionButton_OnEvent"] = noIndentEffect,
	["MultiCastActionButton_OnLeave"] = noIndentEffect,
	["MultiCastActionButton_OnLoad"] = noIndentEffect,
	["MultiCastActionButton_OnPostClick"] = noIndentEffect,
	["MultiCastActionButton_OnShow"] = noIndentEffect,
	["MultiCastActionButton_Update"] = noIndentEffect,
	["MultiCastFlyoutButton_OnClick"] = noIndentEffect,
	["MultiCastFlyoutButton_OnEnter"] = noIndentEffect,
	["MultiCastFlyoutButton_OnLeave"] = noIndentEffect,
	["MultiCastFlyoutButton_OnLoad"] = noIndentEffect,
	["MultiCastFlyoutButton_SetTooltip"] = noIndentEffect,
	["MultiCastFlyoutFrameCloseButton_OnClick"] = noIndentEffect,
	["MultiCastFlyoutFrameOpenButton_Hide"] = noIndentEffect,
	["MultiCastFlyoutFrameOpenButton_OnClick"] = noIndentEffect,
	["MultiCastFlyoutFrameOpenButton_OnLeave"] = noIndentEffect,
	["MultiCastFlyoutFrameOpenButton_Show"] = noIndentEffect,
	["MultiCastFlyoutFrame_Hide"] = noIndentEffect,
	["MultiCastFlyoutFrame_LoadPageSpells"] = noIndentEffect,
	["MultiCastFlyoutFrame_LoadSlotSpells"] = noIndentEffect,
	["MultiCastFlyoutFrame_OnEnter"] = noIndentEffect,
	["MultiCastFlyoutFrame_OnHide"] = noIndentEffect,
	["MultiCastFlyoutFrame_OnLeave"] = noIndentEffect,
	["MultiCastFlyoutFrame_OnShow"] = noIndentEffect,
	["MultiCastFlyoutFrame_OnUpdate"] = noIndentEffect,
	["MultiCastFlyoutFrame_ToggleFlyout"] = noIndentEffect,
	["MultiCastRecallSpellButtonUp"] = noIndentEffect,
	["MultiCastRecallSpellButton_OnClick"] = noIndentEffect,
	["MultiCastRecallSpellButton_OnLoad"] = noIndentEffect,
	["MultiCastRecallSpellButton_Update"] = noIndentEffect,
	["MultiCastSlotButton_OnEnter"] = noIndentEffect,
	["MultiCastSlotButton_OnEvent"] = noIndentEffect,
	["MultiCastSlotButton_OnLeave"] = noIndentEffect,
	["MultiCastSlotButton_Update"] = noIndentEffect,
	["MultiCastSpellButton_OnEnter"] = noIndentEffect,
	["MultiCastSpellButton_OnEvent"] = noIndentEffect,
	["MultiCastSpellButton_OnLeave"] = noIndentEffect,
	["MultiCastSpellButton_OnLoad"] = noIndentEffect,
	["MultiCastSpellButton_SetTooltip"] = noIndentEffect,
	["MultiCastSpellButton_UpdateCooldown"] = noIndentEffect,
	["MultiCastSpellButton_UpdateState"] = noIndentEffect,
	["MultiCastSummonSpellButtonUp"] = noIndentEffect,
	["MultiCastSummonSpellButton_OnClick"] = noIndentEffect,
	["MultiCastSummonSpellButton_OnEnter"] = noIndentEffect,
	["MultiCastSummonSpellButton_OnEvent"] = noIndentEffect,
	["MultiCastSummonSpellButton_OnLeave"] = noIndentEffect,
	["MultiCastSummonSpellButton_OnLoad"] = noIndentEffect,
	["MultiCastSummonSpellButton_Update"] = noIndentEffect,
	["MultibarGrid_IsVisible"] = noIndentEffect,
	["Multibar_EmptyFunc"] = noIndentEffect,
	["NewGMTicket"] = noIndentEffect,
	["NextView"] = noIndentEffect,
	["NoPlayTime"] = noIndentEffect,
	["NotWhileDeadError"] = noIndentEffect,
	["NotifyInspect"] = noIndentEffect,
	["NumTaxiNodes"] = noIndentEffect,
	["OfferPetition"] = noIndentEffect,
	["OffhandHasWeapon"] = noIndentEffect,
	["OnMenuLoad"] = noIndentEffect,
	["OpenAllBags"] = noIndentEffect,
	["OpenBackpack"] = noIndentEffect,
	["OpenBag"] = noIndentEffect,
	["OpenCalendar"] = noIndentEffect,
	["OpenCoinPickupFrame"] = noIndentEffect,
	["OpenColorPicker"] = noIndentEffect,
	["OpenGlyphFrame"] = noIndentEffect,
	["OpenMailAttachment_OnClick"] = noIndentEffect,
	["OpenMailAttachment_OnEnter"] = noIndentEffect,
	["OpenMailFrame_OnHide"] = noIndentEffect,
	["OpenMailFrame_UpdateButtonPositions"] = noIndentEffect,
	["OpenMail_Delete"] = noIndentEffect,
	["OpenMail_GetItemCounts"] = noIndentEffect,
	["OpenMail_Reply"] = noIndentEffect,
	["OpenMail_ReportSpam"] = noIndentEffect,
	["OpenMail_Update"] = noIndentEffect,
	["OpenStackSplitFrame"] = noIndentEffect,
	["OpenTrainer"] = noIndentEffect,
	["OpeningCinematic"] = noIndentEffect,
	["OptionsCategoryFrame_Update"] = noIndentEffect,
	["OptionsFrameCancel_OnClick"] = noIndentEffect,
	["OptionsFrameDefault_OnClick"] = noIndentEffect,
	["OptionsFrameOkay_OnClick"] = noIndentEffect,
	["OptionsFrame_AddCategory"] = noIndentEffect,
	["OptionsFrame_OnHide"] = noIndentEffect,
	["OptionsFrame_OnLoad"] = noIndentEffect,
	["OptionsFrame_OnShow"] = noIndentEffect,
	["OptionsFrame_OpenToCategory"] = noIndentEffect,
	["OptionsFrame_RefreshCategories"] = noIndentEffect,
	["OptionsFrame_SetAllToDefaults"] = noIndentEffect,
	["OptionsFrame_SetCurrentToDefaults"] = noIndentEffect,
	["OptionsListButtonToggle_OnClick"] = noIndentEffect,
	["OptionsListButton_OnClick"] = noIndentEffect,
	["OptionsListButton_OnLoad"] = noIndentEffect,
	["OptionsListButton_ToggleSubCategories"] = noIndentEffect,
	["OptionsListScroll_Update"] = noIndentEffect,
	["OptionsList_ClearSelection"] = noIndentEffect,
	["OptionsList_DisplayButton"] = noIndentEffect,
	["OptionsList_DisplayPanel"] = noIndentEffect,
	["OptionsList_DisplayScrollBar"] = noIndentEffect,
	["OptionsList_HideButton"] = noIndentEffect,
	["OptionsList_HideScrollBar"] = noIndentEffect,
	["OptionsList_OnLoad"] = noIndentEffect,
	["OptionsList_SelectButton"] = noIndentEffect,
	["PVPBannerCustomization_Left"] = noIndentEffect,
	["PVPBannerCustomization_Right"] = noIndentEffect,
	["PVPBannerFrame_OnShow"] = noIndentEffect,
	["PVPBannerFrame_OpenColorPicker"] = noIndentEffect,
	["PVPBannerFrame_SaveBanner"] = noIndentEffect,
	["PVPBannerFrame_SetBannerColor"] = noIndentEffect,
	["PVPBannerFrame_SetBorderColor"] = noIndentEffect,
	["PVPBannerFrame_SetEmblemColor"] = noIndentEffect,
	["PVPBattlegroundButton_OnClick"] = noIndentEffect,
	["PVPBattlegroundFrameJoinButton_OnClick"] = noIndentEffect,
	["PVPBattlegroundFrame_OnEvent"] = noIndentEffect,
	["PVPBattlegroundFrame_OnHide"] = noIndentEffect,
	["PVPBattlegroundFrame_OnLoad"] = noIndentEffect,
	["PVPBattlegroundFrame_OnShow"] = noIndentEffect,
	["PVPBattlegroundFrame_UpdateGroupAvailable"] = noIndentEffect,
	["PVPBattlegroundFrame_UpdateVisible"] = noIndentEffect,
	["PVPBattleground_GetSelectedBattlegroundInfo"] = noIndentEffect,
	["PVPBattleground_ResetInfo"] = noIndentEffect,
	["PVPBattleground_UpdateBattlegrounds"] = noIndentEffect,
	["PVPBattleground_UpdateInfo"] = noIndentEffect,
	["PVPBattleground_UpdateJoinButton"] = noIndentEffect,
	["PVPBattleground_UpdateQueueStatus"] = noIndentEffect,
	["PVPBattleground_UpdateRandomInfo"] = noIndentEffect,
	["PVPDropDown_Initialize"] = noIndentEffect,
	["PVPFrameToggleButton_OnClick"] = noIndentEffect,
	["PVPFrame_IsJustBG"] = noIndentEffect,
	["PVPFrame_OnEvent"] = noIndentEffect,
	["PVPFrame_OnHide"] = noIndentEffect,
	["PVPFrame_OnLoad"] = noIndentEffect,
	["PVPFrame_OnShow"] = noIndentEffect,
	["PVPFrame_SetFaction"] = noIndentEffect,
	["PVPFrame_SetJustBG"] = noIndentEffect,
	["PVPFrame_SetToInSeason"] = noIndentEffect,
	["PVPFrame_SetToOffSeason"] = noIndentEffect,
	["PVPFrame_ShowDropdown"] = noIndentEffect,
	["PVPFrame_Update"] = noIndentEffect,
	["PVPHonor_Update"] = noIndentEffect,
	["PVPMicroButton_SetNormal"] = noIndentEffect,
	["PVPMicroButton_SetPushed"] = noIndentEffect,
	["PVPQueue_UpdateRandomInfo"] = noIndentEffect,
	["PVPStandard_OnLoad"] = noIndentEffect,
	["PVPTeamDetailsButton_OnClick"] = noIndentEffect,
	["PVPTeamDetailsToggleButton_OnClick"] = noIndentEffect,
	["PVPTeamDetails_OnHide"] = noIndentEffect,
	["PVPTeamDetails_OnShow"] = noIndentEffect,
	["PVPTeamDetails_Update"] = noIndentEffect,
	["PVPTeam_OnClick"] = noIndentEffect,
	["PVPTeam_OnEnter"] = noIndentEffect,
	["PVPTeam_OnLeave"] = noIndentEffect,
	["PVPTeam_OnMouseDown"] = noIndentEffect,
	["PVPTeam_OnMouseUp"] = noIndentEffect,
	["PVPTeam_Update"] = noIndentEffect,
	["PanelTemplates_DeselectTab"] = noIndentEffect,
	["PanelTemplates_DisableTab"] = noIndentEffect,
	["PanelTemplates_EnableTab"] = noIndentEffect,
	["PanelTemplates_GetSelectedTab"] = noIndentEffect,
	["PanelTemplates_GetTabWidth"] = noIndentEffect,
	["PanelTemplates_SelectTab"] = noIndentEffect,
	["PanelTemplates_SetDisabledTabState"] = noIndentEffect,
	["PanelTemplates_SetNumTabs"] = noIndentEffect,
	["PanelTemplates_SetTab"] = noIndentEffect,
	["PanelTemplates_TabResize"] = noIndentEffect,
	["PanelTemplates_Tab_OnClick"] = noIndentEffect,
	["PanelTemplates_UpdateTabs"] = noIndentEffect,
	["PaperDollFormatStat"] = noIndentEffect,
	["PaperDollFrameItemFlyoutButton_OnClick"] = noIndentEffect,
	["PaperDollFrameItemFlyoutButton_OnEnter"] = noIndentEffect,
	["PaperDollFrameItemFlyout_CreateButton"] = noIndentEffect,
	["PaperDollFrameItemFlyout_DisplayButton"] = noIndentEffect,
	["PaperDollFrameItemFlyout_DisplaySpecialButton"] = noIndentEffect,
	["PaperDollFrameItemFlyout_Hide"] = noIndentEffect,
	["PaperDollFrameItemFlyout_OnEvent"] = noIndentEffect,
	["PaperDollFrameItemFlyout_OnHide"] = noIndentEffect,
	["PaperDollFrameItemFlyout_OnShow"] = noIndentEffect,
	["PaperDollFrameItemFlyout_OnUpdate"] = noIndentEffect,
	["PaperDollFrameItemFlyout_Show"] = noIndentEffect,
	["PaperDollFrameItemPopoutButton_HideAll"] = noIndentEffect,
	["PaperDollFrameItemPopoutButton_OnClick"] = noIndentEffect,
	["PaperDollFrameItemPopoutButton_OnLoad"] = noIndentEffect,
	["PaperDollFrameItemPopoutButton_SetReversed"] = noIndentEffect,
	["PaperDollFrameItemPopoutButton_ShowAll"] = noIndentEffect,
	["PaperDollFrame_ClearIgnoredSlots"] = noIndentEffect,
	["PaperDollFrame_GetArmorReduction"] = noIndentEffect,
	["PaperDollFrame_IgnoreSlotsForSet"] = noIndentEffect,
	["PaperDollFrame_OnEvent"] = noIndentEffect,
	["PaperDollFrame_OnHide"] = noIndentEffect,
	["PaperDollFrame_OnLoad"] = noIndentEffect,
	["PaperDollFrame_OnShow"] = noIndentEffect,
	["PaperDollFrame_SetArmor"] = noIndentEffect,
	["PaperDollFrame_SetAttackBothHands"] = noIndentEffect,
	["PaperDollFrame_SetAttackPower"] = noIndentEffect,
	["PaperDollFrame_SetAttackSpeed"] = noIndentEffect,
	["PaperDollFrame_SetBlock"] = noIndentEffect,
	["PaperDollFrame_SetDamage"] = noIndentEffect,
	["PaperDollFrame_SetDefense"] = noIndentEffect,
	["PaperDollFrame_SetDodge"] = noIndentEffect,
	["PaperDollFrame_SetExpertise"] = noIndentEffect,
	["PaperDollFrame_SetGuild"] = noIndentEffect,
	["PaperDollFrame_SetLabelAndText"] = noIndentEffect,
	["PaperDollFrame_SetLevel"] = noIndentEffect,
	["PaperDollFrame_SetManaRegen"] = noIndentEffect,
	["PaperDollFrame_SetMeleeCritChance"] = noIndentEffect,
	["PaperDollFrame_SetParry"] = noIndentEffect,
	["PaperDollFrame_SetRangedAttack"] = noIndentEffect,
	["PaperDollFrame_SetRangedAttackPower"] = noIndentEffect,
	["PaperDollFrame_SetRangedAttackSpeed"] = noIndentEffect,
	["PaperDollFrame_SetRangedCritChance"] = noIndentEffect,
	["PaperDollFrame_SetRangedDamage"] = noIndentEffect,
	["PaperDollFrame_SetRating"] = noIndentEffect,
	["PaperDollFrame_SetResilience"] = noIndentEffect,
	["PaperDollFrame_SetResistances"] = noIndentEffect,
	["PaperDollFrame_SetSpellBonusDamage"] = noIndentEffect,
	["PaperDollFrame_SetSpellBonusHealing"] = noIndentEffect,
	["PaperDollFrame_SetSpellCritChance"] = noIndentEffect,
	["PaperDollFrame_SetSpellHaste"] = noIndentEffect,
	["PaperDollFrame_SetSpellPenetration"] = noIndentEffect,
	["PaperDollFrame_SetStat"] = noIndentEffect,
	["PaperDollFrame_UpdateStats"] = noIndentEffect,
	["PaperDollItemSlotButton_OnClick"] = noIndentEffect,
	["PaperDollItemSlotButton_OnEnter"] = noIndentEffect,
	["PaperDollItemSlotButton_OnEvent"] = noIndentEffect,
	["PaperDollItemSlotButton_OnHide"] = noIndentEffect,
	["PaperDollItemSlotButton_OnLeave"] = noIndentEffect,
	["PaperDollItemSlotButton_OnLoad"] = noIndentEffect,
	["PaperDollItemSlotButton_OnModifiedClick"] = noIndentEffect,
	["PaperDollItemSlotButton_OnShow"] = noIndentEffect,
	["PaperDollItemSlotButton_Update"] = noIndentEffect,
	["PaperDollItemSlotButton_UpdateFlyout"] = noIndentEffect,
	["PaperDollItemSlotButton_UpdateLock"] = noIndentEffect,
	["PaperDollStatTooltip"] = noIndentEffect,
	["PaperDoll_IsEquippedSlot"] = noIndentEffect,
	["PartialPlayTime"] = noIndentEffect,
	["PartyFrameDropDown_Initialize"] = noIndentEffect,
	["PartyFrameDropDown_OnLoad"] = noIndentEffect,
	["PartyLFGStartBackfill"] = noIndentEffect,
	["PartyMemberBackground_SaveOpacity"] = noIndentEffect,
	["PartyMemberBackground_SetOpacity"] = noIndentEffect,
	["PartyMemberBackground_ToggleOpacity"] = noIndentEffect,
	["PartyMemberBuffTooltip_Update"] = noIndentEffect,
	["PartyMemberFrame_OnEvent"] = noIndentEffect,
	["PartyMemberFrame_OnLoad"] = noIndentEffect,
	["PartyMemberFrame_OnUpdate"] = noIndentEffect,
	["PartyMemberFrame_RefreshPetDebuffs"] = noIndentEffect,
	["PartyMemberFrame_ToPlayerArt"] = noIndentEffect,
	["PartyMemberFrame_ToVehicleArt"] = noIndentEffect,
	["PartyMemberFrame_UpdateArt"] = noIndentEffect,
	["PartyMemberFrame_UpdateAssignedRoles"] = noIndentEffect,
	["PartyMemberFrame_UpdateLeader"] = noIndentEffect,
	["PartyMemberFrame_UpdateMember"] = noIndentEffect,
	["PartyMemberFrame_UpdateMemberHealth"] = noIndentEffect,
	["PartyMemberFrame_UpdateOnlineStatus"] = noIndentEffect,
	["PartyMemberFrame_UpdatePet"] = noIndentEffect,
	["PartyMemberFrame_UpdatePvPStatus"] = noIndentEffect,
	["PartyMemberFrame_UpdateReadyCheck"] = noIndentEffect,
	["PartyMemberFrame_UpdateStatusBarText"] = noIndentEffect,
	["PartyMemberFrame_UpdateVoiceStatus"] = noIndentEffect,
	["PartyMemberHealthCheck"] = noIndentEffect,
	["PendingListFrameDropDown_Initialize"] = noIndentEffect,
	["PendingListFrameDropDown_OnLoad"] = noIndentEffect,
	["PendingListFrame_BlockCommunication"] = noIndentEffect,
	["PendingListFrame_OnHide"] = noIndentEffect,
	["PendingListFrame_OnShow"] = noIndentEffect,
	["PendingListFrame_ReportPlayer"] = noIndentEffect,
	["PendingListFrame_ReportSpam"] = noIndentEffect,
	["PendingList_Scroll"] = noIndentEffect,
	["PendingList_Update"] = noIndentEffect,
	["PendingList_UpdateTab"] = noIndentEffect,
	["PetAbandon"] = noIndentEffect,
	["PetActionBarFrame_IsAboveShapeshift"] = noIndentEffect,
	["PetActionBarFrame_OnUpdate"] = noIndentEffect,
	["PetActionBar_HideGrid"] = noIndentEffect,
	["PetActionBar_OnEvent"] = noIndentEffect,
	["PetActionBar_OnLoad"] = noIndentEffect,
	["PetActionBar_ShowGrid"] = noIndentEffect,
	["PetActionBar_Update"] = noIndentEffect,
	["PetActionBar_UpdateCooldowns"] = noIndentEffect,
	["PetActionBar_UpdatePositionValues"] = noIndentEffect,
	["PetActionButtonDown"] = noIndentEffect,
	["PetActionButtonUp"] = noIndentEffect,
	["PetActionButton_IsFlashing"] = noIndentEffect,
	["PetActionButton_OnClick"] = noIndentEffect,
	["PetActionButton_OnDragStart"] = noIndentEffect,
	["PetActionButton_OnEnter"] = noIndentEffect,
	["PetActionButton_OnEvent"] = noIndentEffect,
	["PetActionButton_OnLeave"] = noIndentEffect,
	["PetActionButton_OnLoad"] = noIndentEffect,
	["PetActionButton_OnModifiedClick"] = noIndentEffect,
	["PetActionButton_OnReceiveDrag"] = noIndentEffect,
	["PetActionButton_OnUpdate"] = noIndentEffect,
	["PetActionButton_SetHotkeys"] = noIndentEffect,
	["PetActionButton_StartFlash"] = noIndentEffect,
	["PetActionButton_StopFlash"] = noIndentEffect,
	["PetAggressiveMode"] = noIndentEffect,
	["PetAttack"] = noIndentEffect,
	["PetCanBeAbandoned"] = noIndentEffect,
	["PetCanBeDismissed"] = noIndentEffect,
	["PetCanBeRenamed"] = noIndentEffect,
	["PetCastingBarFrame_OnEvent"] = noIndentEffect,
	["PetCastingBarFrame_OnLoad"] = noIndentEffect,
	["PetDefensiveMode"] = noIndentEffect,
	["PetDismiss"] = noIndentEffect,
	["PetExpBar_Update"] = noIndentEffect,
	["PetFollow"] = noIndentEffect,
	["PetFrameDropDown_Initialize"] = noIndentEffect,
	["PetFrameDropDown_OnLoad"] = noIndentEffect,
	["PetFrame_OnEvent"] = noIndentEffect,
	["PetFrame_OnLoad"] = noIndentEffect,
	["PetFrame_OnUpdate"] = noIndentEffect,
	["PetFrame_SetHappiness"] = noIndentEffect,
	["PetFrame_Update"] = noIndentEffect,
	["PetHasActionBar"] = noIndentEffect,
	["PetPaperDollFrame_FindCompanionIndex"] = noIndentEffect,
	["PetPaperDollFrame_OnEvent"] = noIndentEffect,
	["PetPaperDollFrame_OnHide"] = noIndentEffect,
	["PetPaperDollFrame_OnLoad"] = noIndentEffect,
	["PetPaperDollFrame_OnShow"] = noIndentEffect,
	["PetPaperDollFrame_SetCompanionPage"] = noIndentEffect,
	["PetPaperDollFrame_SetResistances"] = noIndentEffect,
	["PetPaperDollFrame_SetSpellBonusDamage"] = noIndentEffect,
	["PetPaperDollFrame_SetStats"] = noIndentEffect,
	["PetPaperDollFrame_SetTab"] = noIndentEffect,
	["PetPaperDollFrame_Update"] = noIndentEffect,
	["PetPaperDollFrame_UpdateCompanionCooldowns"] = noIndentEffect,
	["PetPaperDollFrame_UpdateCompanionPreview"] = noIndentEffect,
	["PetPaperDollFrame_UpdateCompanions"] = noIndentEffect,
	["PetPaperDollFrame_UpdateIsAvailable"] = noIndentEffect,
	["PetPaperDollFrame_UpdateTabs"] = noIndentEffect,
	["PetPassiveMode"] = noIndentEffect,
	["PetRename"] = noIndentEffect,
	["PetStable_NoPetsAllowed"] = noIndentEffect,
	["PetStable_OnEvent"] = noIndentEffect,
	["PetStable_OnLoad"] = noIndentEffect,
	["PetStable_Update"] = noIndentEffect,
	["PetStopAttack"] = noIndentEffect,
	["PetWait"] = noIndentEffect,
	["PetitionFrame_Update"] = noIndentEffect,
	["PickupAction"] = noIndentEffect,
	["PickupBagFromSlot"] = noIndentEffect,
	["PickupCompanion"] = noIndentEffect,
	["PickupContainerItem"] = noIndentEffect,
	["PickupEquipmentSet"] = noIndentEffect,
	["PickupEquipmentSetByName"] = noIndentEffect,
	["PickupGuildBankItem"] = noIndentEffect,
	["PickupGuildBankMoney"] = noIndentEffect,
	["PickupInventoryItem"] = noIndentEffect,
	["PickupItem"] = noIndentEffect,
	["PickupMacro"] = noIndentEffect,
	["PickupMerchantItem"] = noIndentEffect,
	["PickupPetAction"] = noIndentEffect,
	["PickupPlayerMoney"] = noIndentEffect,
	["PickupSpell"] = noIndentEffect,
	["PickupStablePet"] = noIndentEffect,
	["PickupTradeMoney"] = noIndentEffect,
	["PitchDownStart"] = noIndentEffect,
	["PitchDownStop"] = noIndentEffect,
	["PitchUpStart"] = noIndentEffect,
	["PitchUpStop"] = noIndentEffect,
	["PlaceAction"] = noIndentEffect,
	["PlaceAuctionBid"] = noIndentEffect,
	["PlaceGlyphInSocket"] = noIndentEffect,
	["PlayDance"] = noIndentEffect,
	["PlayMusic"] = noIndentEffect,
	["PlaySound"] = noIndentEffect,
	["PlaySoundFile"] = noIndentEffect,
	["PlayerCanTeleport"] = noIndentEffect,
	["PlayerFrameDropDown_Initialize"] = noIndentEffect,
	["PlayerFrameDropDown_OnLoad"] = noIndentEffect,
	["PlayerFrame_AnimFinished"] = noIndentEffect,
	["PlayerFrame_AnimateOut"] = noIndentEffect,
	["PlayerFrame_OnEvent"] = noIndentEffect,
	["PlayerFrame_OnLoad"] = noIndentEffect,
	["PlayerFrame_OnReceiveDrag"] = noIndentEffect,
	["PlayerFrame_OnUpdate"] = noIndentEffect,
	["PlayerFrame_SequenceFinished"] = noIndentEffect,
	["PlayerFrame_SetRunicPower"] = noIndentEffect,
	["PlayerFrame_SetupDeathKnniggetLayout"] = noIndentEffect,
	["PlayerFrame_ToPlayerArt"] = noIndentEffect,
	["PlayerFrame_ToVehicleArt"] = noIndentEffect,
	["PlayerFrame_Update"] = noIndentEffect,
	["PlayerFrame_UpdateArt"] = noIndentEffect,
	["PlayerFrame_UpdateGroupIndicator"] = noIndentEffect,
	["PlayerFrame_UpdateLayout"] = noIndentEffect,
	["PlayerFrame_UpdatePartyLeader"] = noIndentEffect,
	["PlayerFrame_UpdatePlaytime"] = noIndentEffect,
	["PlayerFrame_UpdatePvPStatus"] = noIndentEffect,
	["PlayerFrame_UpdateReadyCheck"] = noIndentEffect,
	["PlayerFrame_UpdateRolesAssigned"] = noIndentEffect,
	["PlayerFrame_UpdateStatus"] = noIndentEffect,
	["PlayerFrame_UpdateVoiceStatus"] = noIndentEffect,
	["PlayerIsPVPInactive"] = noIndentEffect,
	["PlayerStatFrameLeftDropDown_Initialize"] = noIndentEffect,
	["PlayerStatFrameLeftDropDown_OnClick"] = noIndentEffect,
	["PlayerStatFrameLeftDropDown_OnLoad"] = noIndentEffect,
	["PlayerStatFrameLeftDropDown_OnShow"] = noIndentEffect,
	["PlayerStatFrameRightDropDown_Initialize"] = noIndentEffect,
	["PlayerStatFrameRightDropDown_OnClick"] = noIndentEffect,
	["PlayerStatFrameRightDropDown_OnLoad"] = noIndentEffect,
	["PlayerStatFrameRightDropDown_OnShow"] = noIndentEffect,
	["PlayerTitleButton_OnClick"] = noIndentEffect,
	["PlayerTitleFrame_UpdateTitles"] = noIndentEffect,
	["PlayerTitlePickerFrame_Toggle"] = noIndentEffect,
	["PlayerTitlePickerScrollFrame_OnLoad"] = noIndentEffect,
	["PlayerTitlePickerScrollFrame_Update"] = noIndentEffect,
	["PositionMiniWorldMapArrowFrame"] = noIndentEffect,
	["PositionWorldMapArrowFrame"] = noIndentEffect,
	["PossessBar_OnEvent"] = noIndentEffect,
	["PossessBar_OnLoad"] = noIndentEffect,
	["PossessBar_Update"] = noIndentEffect,
	["PossessBar_UpdateState"] = noIndentEffect,
	["PossessButton_OnClick"] = noIndentEffect,
	["PossessButton_OnEnter"] = noIndentEffect,
	["PrevView"] = noIndentEffect,
	["ProcessMapClick"] = noIndentEffect,
	["ProcessQuestLogRewardFactions"] = noIndentEffect,
	["PromoteToAssistant"] = noIndentEffect,
	["PromoteToLeader"] = noIndentEffect,
	["PurchaseSlot"] = noIndentEffect,
	["PutItemInBackpack"] = noIndentEffect,
	["PutItemInBag"] = noIndentEffect,
	["PutKeyInKeyRing"] = noIndentEffect,
	["QueryAuctionItems"] = noIndentEffect,
	["QueryCastSequence"] = noIndentEffect,
	["QueryGuildBankLog"] = noIndentEffect,
	["QueryGuildBankTab"] = noIndentEffect,
	["QueryGuildBankText"] = noIndentEffect,
	["QueryGuildEventLog"] = noIndentEffect,
	["QueryQuestsCompleted"] = noIndentEffect,
	["QuestChooseRewardError"] = noIndentEffect,
	["QuestDetailAcceptButton_OnClick"] = noIndentEffect,
	["QuestDetailDeclineButton_OnClick"] = noIndentEffect,
	["QuestFlagsPVP"] = noIndentEffect,
	["QuestFrameDetailPanel_OnShow"] = noIndentEffect,
	["QuestFrameGreetingPanel_OnShow"] = noIndentEffect,
	["QuestFrameProgressItems_Update"] = noIndentEffect,
	["QuestFrameProgressPanel_OnShow"] = noIndentEffect,
	["QuestFrameRewardPanel_OnShow"] = noIndentEffect,
	["QuestFrame_GetMaterial"] = noIndentEffect,
	["QuestFrame_OnEvent"] = noIndentEffect,
	["QuestFrame_OnHide"] = noIndentEffect,
	["QuestFrame_OnLoad"] = noIndentEffect,
	["QuestFrame_OnShow"] = noIndentEffect,
	["QuestFrame_SetMaterial"] = noIndentEffect,
	["QuestFrame_SetPortrait"] = noIndentEffect,
	["QuestFrame_SetTextColor"] = noIndentEffect,
	["QuestFrame_SetTitleTextColor"] = noIndentEffect,
	["QuestGetAutoAccept"] = noIndentEffect,
	["QuestGoodbyeButton_OnClick"] = noIndentEffect,
	["QuestInfoFadingFrame_OnUpdate"] = noIndentEffect,
	["QuestInfoItem_OnClick"] = noIndentEffect,
	["QuestInfoTimerFrame_OnUpdate"] = noIndentEffect,
	["QuestInfo_Display"] = noIndentEffect,
	["QuestInfo_DoReputations"] = noIndentEffect,
	["QuestInfo_ShowAnchor"] = noIndentEffect,
	["QuestInfo_ShowDescriptionHeader"] = noIndentEffect,
	["QuestInfo_ShowDescriptionText"] = noIndentEffect,
	["QuestInfo_ShowFadingFrame"] = noIndentEffect,
	["QuestInfo_ShowGroupSize"] = noIndentEffect,
	["QuestInfo_ShowObjectives"] = noIndentEffect,
	["QuestInfo_ShowObjectivesHeader"] = noIndentEffect,
	["QuestInfo_ShowObjectivesText"] = noIndentEffect,
	["QuestInfo_ShowRequiredMoney"] = noIndentEffect,
	["QuestInfo_ShowRewardText"] = noIndentEffect,
	["QuestInfo_ShowRewards"] = noIndentEffect,
	["QuestInfo_ShowSpacer"] = noIndentEffect,
	["QuestInfo_ShowTimer"] = noIndentEffect,
	["QuestInfo_ShowTitle"] = noIndentEffect,
	["QuestInfo_ToggleRewardElement"] = noIndentEffect,
	["QuestIsDaily"] = noIndentEffect,
	["QuestIsWeekly"] = noIndentEffect,
	["QuestLogControlPanel_UpdatePosition"] = noIndentEffect,
	["QuestLogControlPanel_UpdateState"] = noIndentEffect,
	["QuestLogDetailFrame_AttachToQuestLog"] = noIndentEffect,
	["QuestLogDetailFrame_DetachFromQuestLog"] = noIndentEffect,
	["QuestLogDetailFrame_OnHide"] = noIndentEffect,
	["QuestLogDetailFrame_OnLoad"] = noIndentEffect,
	["QuestLogDetailFrame_OnShow"] = noIndentEffect,
	["QuestLogFrameTrackButton_OnClick"] = noIndentEffect,
	["QuestLogPushQuest"] = noIndentEffect,
	["QuestLogScrollFrame_OnLoad"] = noIndentEffect,
	["QuestLogShowMapPOI_UpdatePosition"] = noIndentEffect,
	["QuestLogTitleButton_OnClick"] = noIndentEffect,
	["QuestLogTitleButton_OnEnter"] = noIndentEffect,
	["QuestLogTitleButton_OnEvent"] = noIndentEffect,
	["QuestLogTitleButton_OnLeave"] = noIndentEffect,
	["QuestLogTitleButton_OnLoad"] = noIndentEffect,
	["QuestLogTitleButton_Resize"] = noIndentEffect,
	["QuestLog_GetFirstSelectableQuest"] = noIndentEffect,
	["QuestLog_OnEvent"] = noIndentEffect,
	["QuestLog_OnHide"] = noIndentEffect,
	["QuestLog_OnLoad"] = noIndentEffect,
	["QuestLog_OnShow"] = noIndentEffect,
	["QuestLog_OnUpdate"] = noIndentEffect,
	["QuestLog_OpenToQuest"] = noIndentEffect,
	["QuestLog_SetFirstValidSelection"] = noIndentEffect,
	["QuestLog_SetNearestValidSelection"] = noIndentEffect,
	["QuestLog_SetSelection"] = noIndentEffect,
	["QuestLog_UnsetSelection"] = noIndentEffect,
	["QuestLog_Update"] = noIndentEffect,
	["QuestLog_UpdateMap"] = noIndentEffect,
	["QuestLog_UpdateMapButton"] = noIndentEffect,
	["QuestLog_UpdatePartyInfoTooltip"] = noIndentEffect,
	["QuestLog_UpdateQuestCount"] = noIndentEffect,
	["QuestLog_UpdateQuestDetails"] = noIndentEffect,
	["QuestMapUpdateAllQuests"] = noIndentEffect,
	["QuestPOIButton_OnMouseDown"] = noIndentEffect,
	["QuestPOIButton_OnMouseUp"] = noIndentEffect,
	["QuestPOIGetIconInfo"] = noIndentEffect,
	["QuestPOIGetQuestIDByIndex"] = noIndentEffect,
	["QuestPOIGetQuestIDByVisibleIndex"] = noIndentEffect,
	["QuestPOIUpdateIcons"] = noIndentEffect,
	["QuestPOIUpdateTexture"] = noIndentEffect,
	["QuestPOI_DeselectButton"] = noIndentEffect,
	["QuestPOI_DeselectButtonByParent"] = noIndentEffect,
	["QuestPOI_DisplayButton"] = noIndentEffect,
	["QuestPOI_HideAllButtons"] = noIndentEffect,
	["QuestPOI_HideButtons"] = noIndentEffect,
	["QuestPOI_SelectButton"] = noIndentEffect,
	["QuestPOI_SelectButtonByIndex"] = noIndentEffect,
	["QuestPOI_SelectButtonByQuestId"] = noIndentEffect,
	["QuestPOI_SetTextColor"] = noIndentEffect,
	["QuestProgressCompleteButton_OnClick"] = noIndentEffect,
	["QuestRewardCancelButton_OnClick"] = noIndentEffect,
	["QuestRewardCompleteButton_OnClick"] = noIndentEffect,
	["QuestRewardItem_OnClick"] = noIndentEffect,
	["QuestTitleButton_OnClick"] = noIndentEffect,
	["Quit"] = noIndentEffect,
	["RaidBossEmoteFrame_OnEvent"] = noIndentEffect,
	["RaidBossEmoteFrame_OnLoad"] = noIndentEffect,
	["RaidFrame_LoadUI"] = noIndentEffect,
	["RaidFrame_OnEvent"] = noIndentEffect,
	["RaidFrame_OnLoad"] = noIndentEffect,
	["RaidFrame_Update"] = noIndentEffect,
	["RaidInfoExtendButton_OnClick"] = noIndentEffect,
	["RaidInfoFrame_Update"] = noIndentEffect,
	["RaidInfoFrame_UpdateSelectedIndex"] = noIndentEffect,
	["RaidInfoInstance_OnClick"] = noIndentEffect,
	["RaidInfoInstance_OnEnter"] = noIndentEffect,
	["RaidInfoInstance_OnMouseDown"] = noIndentEffect,
	["RaidInfoInstance_OnMouseUp"] = noIndentEffect,
	["RaidInfoScrollFrame_OnLoad"] = noIndentEffect,
	["RaidNotice_AddMessage"] = noIndentEffect,
	["RaidNotice_FadeInit"] = noIndentEffect,
	["RaidNotice_OnUpdate"] = noIndentEffect,
	["RaidNotice_SetSlot"] = noIndentEffect,
	["RaidNotice_UpdateSlot"] = noIndentEffect,
	["RaidOptionsFrame_UpdatePartyFrames"] = noIndentEffect,
	["RaidWarningFrame_OnEvent"] = noIndentEffect,
	["RaidWarningFrame_OnLoad"] = noIndentEffect,
	["RaiseFrameLevel"] = noIndentEffect,
	["RaiseFrameLevelByTwo"] = noIndentEffect,
	["RandomRoll"] = noIndentEffect,
	["ReadFile"] = noIndentEffect,
	["ReadyCheckFrame_OnEvent"] = noIndentEffect,
	["ReadyCheckFrame_OnHide"] = noIndentEffect,
	["ReadyCheckFrame_OnLoad"] = noIndentEffect,
	["ReadyCheck_Confirm"] = noIndentEffect,
	["ReadyCheck_Finish"] = noIndentEffect,
	["ReadyCheck_OnUpdate"] = noIndentEffect,
	["ReadyCheck_Start"] = noIndentEffect,
	["RealPartyIsFull"] = noIndentEffect,
	["RecalculateGearManagerDialogPopup"] = noIndentEffect,
	["RecentTimeDate"] = noIndentEffect,
	["RecordLoopbackSoundButton_OnUpdate"] = noIndentEffect,
	["RefreshAuras"] = noIndentEffect,
	["RefreshBuffs"] = noIndentEffect,
	["RefreshDebuffs"] = noIndentEffect,
	["RefreshEquipmentSetIconInfo"] = noIndentEffect,
	["RefreshLFGList"] = noIndentEffect,
	["RefreshMoneyFrame"] = noIndentEffect,
	["RegisterAutoHide"] = noIndentEffect,
	["RegisterCVar"] = noIndentEffect,
	["RegisterForSave"] = noIndentEffect,
	["RegisterForSavePerCharacter"] = noIndentEffect,
	["RegisterStateDriver"] = noIndentEffect,
	["RegisterStaticConstants"] = noIndentEffect,
	["RegisterUnitWatch"] = noIndentEffect,
	["RejectProposal"] = noIndentEffect,
	["ReloadUI"] = noIndentEffect,
	["RemoveChatWindowChannel"] = noIndentEffect,
	["RemoveChatWindowMessages"] = noIndentEffect,
	["RemoveFriend"] = noIndentEffect,
	["RemoveGlyphFromSocket"] = noIndentEffect,
	["RemoveQuestWatch"] = noIndentEffect,
	["RemoveSkillUp"] = noIndentEffect,
	["RemoveTrackedAchievement"] = noIndentEffect,
	["RenameEquipmentSet"] = noIndentEffect,
	["RenamePetition"] = noIndentEffect,
	["RepairAllItems"] = noIndentEffect,
	["ReplaceEnchant"] = noIndentEffect,
	["ReplaceTradeEnchant"] = noIndentEffect,
	["RepopMe"] = noIndentEffect,
	["ReportBug"] = noIndentEffect,
	["ReportPlayerIsPVPAFK"] = noIndentEffect,
	["ReportSuggestion"] = noIndentEffect,
	["ReputationBar_DrawHorizontalLine"] = noIndentEffect,
	["ReputationBar_DrawVerticalLine"] = noIndentEffect,
	["ReputationBar_OnClick"] = noIndentEffect,
	["ReputationFrame_OnEvent"] = noIndentEffect,
	["ReputationFrame_OnLoad"] = noIndentEffect,
	["ReputationFrame_OnShow"] = noIndentEffect,
	["ReputationFrame_SetRowType"] = noIndentEffect,
	["ReputationFrame_Update"] = noIndentEffect,
	["ReputationWatchBar_Update"] = noIndentEffect,
	["RequestBattlefieldPositions"] = noIndentEffect,
	["RequestBattlefieldScoreData"] = noIndentEffect,
	["RequestBattlegroundInstanceInfo"] = noIndentEffect,
	["RequestInspectHonorData"] = noIndentEffect,
	["RequestLFDPartyLockInfo"] = noIndentEffect,
	["RequestLFDPlayerLockInfo"] = noIndentEffect,
	["RequestRaidInfo"] = noIndentEffect,
	["RequestTimePlayed"] = noIndentEffect,
	["ResetCPUUsage"] = noIndentEffect,
	["ResetChatColors"] = noIndentEffect,
	["ResetChatWindows"] = noIndentEffect,
	["ResetCursor"] = noIndentEffect,
	["ResetDisabledAddOns"] = noIndentEffect,
	["ResetGroupPreviewTalentPoints"] = noIndentEffect,
	["ResetInstances"] = noIndentEffect,
	["ResetPerformanceValues"] = noIndentEffect,
	["ResetPreviewTalentPoints"] = noIndentEffect,
	["ResetTutorials"] = noIndentEffect,
	["ResetView"] = noIndentEffect,
	["RespondInstanceLock"] = noIndentEffect,
	["RespondMailLockSendItem"] = noIndentEffect,
	["RestartGx"] = noIndentEffect,
	["RestoreVideoEffectsDefaults"] = noIndentEffect,
	["RestoreVideoResolutionDefaults"] = noIndentEffect,
	["RestoreVideoStereoDefaults"] = noIndentEffect,
	["ResurrectGetOfferer"] = noIndentEffect,
	["ResurrectHasSickness"] = noIndentEffect,
	["ResurrectHasTimer"] = noIndentEffect,
	["RetrieveCorpse"] = noIndentEffect,
	["ReturnInboxItem"] = noIndentEffect,
	["RollOnLoot"] = noIndentEffect,
	["RunBinding"] = noIndentEffect,
	["RunMacro"] = noIndentEffect,
	["RunMacroText"] = noIndentEffect,
	["RunScript"] = noIndentEffect,
	["RuneButton_OnEnter"] = noIndentEffect,
	["RuneButton_OnLeave"] = noIndentEffect,
	["RuneButton_OnLoad"] = noIndentEffect,
	["RuneButton_OnUpdate"] = noIndentEffect,
	["RuneButton_ShineFadeIn"] = noIndentEffect,
	["RuneButton_ShineFadeOut"] = noIndentEffect,
	["RuneButton_Update"] = noIndentEffect,
	["RuneFrame_AddRune"] = noIndentEffect,
	["RuneFrame_FixRunes"] = noIndentEffect,
	["RuneFrame_OnEvent"] = noIndentEffect,
	["RuneFrame_OnLoad"] = noIndentEffect,
	["SaveBindings"] = noIndentEffect,
	["SaveEquipmentSet"] = noIndentEffect,
	["SavePendingGuildBankTabPermissions"] = noIndentEffect,
	["SaveView"] = noIndentEffect,
	["ScorePlayerDropDown_Cancel"] = noIndentEffect,
	["ScorePlayerDropDown_Initialize"] = noIndentEffect,
	["ScorePlayerDropDown_OnClick"] = noIndentEffect,
	["ScorePlayer_OnMouseUp"] = noIndentEffect,
	["Screenshot"] = noIndentEffect,
	["ScrollFrameTemplate_OnMouseWheel"] = noIndentEffect,
	["ScrollFrame_OnLoad"] = noIndentEffect,
	["ScrollFrame_OnScrollRangeChanged"] = noIndentEffect,
	["ScrollingEdit_OnCursorChanged"] = noIndentEffect,
	["ScrollingEdit_OnTextChanged"] = noIndentEffect,
	["ScrollingEdit_OnUpdate"] = noIndentEffect,
	["SearchButton_OnUpdate"] = noIndentEffect,
	["SearchLFGGetEncounterResults"] = noIndentEffect,
	["SearchLFGGetJoinedID"] = noIndentEffect,
	["SearchLFGGetNumResults"] = noIndentEffect,
	["SearchLFGGetPartyResults"] = noIndentEffect,
	["SearchLFGGetResults"] = noIndentEffect,
	["SearchLFGJoin"] = noIndentEffect,
	["SearchLFGLeave"] = noIndentEffect,
	["SearchLFGSort"] = noIndentEffect,
	["SeatIndicator_Pulse"] = noIndentEffect,
	["SecondsToTime"] = noIndentEffect,
	["SecondsToTimeAbbrev"] = noIndentEffect,
	["SecureActionButton_OnClick"] = noIndentEffect,
	["SecureButton_GetAttribute"] = noIndentEffect,
	["SecureButton_GetButtonSuffix"] = noIndentEffect,
	["SecureButton_GetEffectiveButton"] = noIndentEffect,
	["SecureButton_GetModifiedAttribute"] = noIndentEffect,
	["SecureButton_GetModifiedUnit"] = noIndentEffect,
	["SecureButton_GetModifierPrefix"] = noIndentEffect,
	["SecureButton_GetUnit"] = noIndentEffect,
	["SecureButton_ParseModifierString"] = noIndentEffect,
	["SecureCmdItemParse"] = noIndentEffect,
	["SecureCmdOptionParse"] = noIndentEffect,
	["SecureCmdUseItem"] = noIndentEffect,
	["SecureGroupHeader_OnAttributeChanged"] = noIndentEffect,
	["SecureGroupHeader_OnEvent"] = noIndentEffect,
	["SecureGroupHeader_OnLoad"] = noIndentEffect,
	["SecureGroupHeader_Update"] = noIndentEffect,
	["SecureGroupPetHeader_OnAttributeChanged"] = noIndentEffect,
	["SecureGroupPetHeader_OnEvent"] = noIndentEffect,
	["SecureGroupPetHeader_OnLoad"] = noIndentEffect,
	["SecureGroupPetHeader_Update"] = noIndentEffect,
	["SecureHandlerExecute"] = noIndentEffect,
	["SecureHandlerSetFrameRef"] = noIndentEffect,
	["SecureHandlerUnwrapScript"] = noIndentEffect,
	["SecureHandlerWrapScript"] = noIndentEffect,
	["SecureHandler_AttributeOnAttributeChanged"] = noIndentEffect,
	["SecureHandler_OnClick"] = noIndentEffect,
	["SecureHandler_OnDragEvent"] = noIndentEffect,
	["SecureHandler_OnLoad"] = noIndentEffect,
	["SecureHandler_OnMouseUpDown"] = noIndentEffect,
	["SecureHandler_OnMouseWheel"] = noIndentEffect,
	["SecureHandler_OnSimpleEvent"] = noIndentEffect,
	["SecureHandler_StateOnAttributeChanged"] = noIndentEffect,
	["SecureUnitButton_OnClick"] = noIndentEffect,
	["SecureUnitButton_OnLoad"] = noIndentEffect,
	["SelectActiveQuest"] = noIndentEffect,
	["SelectAvailableQuest"] = noIndentEffect,
	["SelectGossipActiveQuest"] = noIndentEffect,
	["SelectGossipAvailableQuest"] = noIndentEffect,
	["SelectGossipOption"] = noIndentEffect,
	["SelectPackage"] = noIndentEffect,
	["SelectQuestLogEntry"] = noIndentEffect,
	["SelectStationery"] = noIndentEffect,
	["SelectTradeSkill"] = noIndentEffect,
	["SelectTrainerService"] = noIndentEffect,
	["SendAddonMessage"] = noIndentEffect,
	["SendChatMessage"] = noIndentEffect,
	["SendMail"] = noIndentEffect,
	["SendMailAttachmentButton_OnClick"] = noIndentEffect,
	["SendMailAttachmentButton_OnDropAny"] = noIndentEffect,
	["SendMailAttachment_OnEnter"] = noIndentEffect,
	["SendMailFrame_CanSend"] = noIndentEffect,
	["SendMailFrame_Reset"] = noIndentEffect,
	["SendMailFrame_SendMail"] = noIndentEffect,
	["SendMailFrame_Update"] = noIndentEffect,
	["SendMailMailButton_OnClick"] = noIndentEffect,
	["SendMailMoneyButton_OnClick"] = noIndentEffect,
	["SendMailRadioButton_OnClick"] = noIndentEffect,
	["SendSystemMessage"] = noIndentEffect,
	["SendWho"] = noIndentEffect,
	["SetAbandonQuest"] = noIndentEffect,
	["SetAchievementComparisonUnit"] = noIndentEffect,
	["SetActionBarToggles"] = noIndentEffect,
	["SetActiveTalentGroup"] = noIndentEffect,
	["SetActiveVoiceChannel"] = noIndentEffect,
	["SetActiveVoiceChannelBySessionID"] = noIndentEffect,
	["SetAllowLowLevelRaid"] = noIndentEffect,
	["SetArenaTeamRosterSelection"] = noIndentEffect,
	["SetArenaTeamRosterShowOffline"] = noIndentEffect,
	["SetAuctionsTabShowing"] = noIndentEffect,
	["SetBagPortraitTexture"] = noIndentEffect,
	["SetBaseMip"] = noIndentEffect,
	["SetBattlefieldScoreFaction"] = noIndentEffect,
	["SetBinding"] = noIndentEffect,
	["SetBindingClick"] = noIndentEffect,
	["SetBindingItem"] = noIndentEffect,
	["SetBindingMacro"] = noIndentEffect,
	["SetBindingSpell"] = noIndentEffect,
	["SetButtonPulse"] = noIndentEffect,
	["SetCVar"] = noIndentEffect,
	["SetChannelOwner"] = noIndentEffect,
	["SetChannelPassword"] = noIndentEffect,
	["SetChannelWatch"] = noIndentEffect,
	["SetChatColorNameByClass"] = noIndentEffect,
	["SetChatMouseOverDelay"] = noIndentEffect,
	["SetChatUnitColor"] = noIndentEffect,
	["SetChatWindowAlpha"] = noIndentEffect,
	["SetChatWindowColor"] = noIndentEffect,
	["SetChatWindowDocked"] = noIndentEffect,
	["SetChatWindowLocked"] = noIndentEffect,
	["SetChatWindowName"] = noIndentEffect,
	["SetChatWindowSavedDimensions"] = noIndentEffect,
	["SetChatWindowSavedPosition"] = noIndentEffect,
	["SetChatWindowShown"] = noIndentEffect,
	["SetChatWindowSize"] = noIndentEffect,
	["SetChatWindowUninteractable"] = noIndentEffect,
	["SetConsoleKey"] = noIndentEffect,
	["SetCurrencyBackpack"] = noIndentEffect,
	["SetCurrencyUnused"] = noIndentEffect,
	["SetCurrentGuildBankTab"] = noIndentEffect,
	["SetCurrentTitle"] = noIndentEffect,
	["SetCursor"] = noIndentEffect,
	["SetDesaturation"] = noIndentEffect,
	["SetDressUpBackground"] = noIndentEffect,
	["SetDungeonDifficulty"] = noIndentEffect,
	["SetDungeonMapLevel"] = noIndentEffect,
	["SetEuropeanNumbers"] = noIndentEffect,
	["SetFactionActive"] = noIndentEffect,
	["SetFactionInactive"] = noIndentEffect,
	["SetFarclip"] = noIndentEffect,
	["SetFriendNotes"] = noIndentEffect,
	["SetGamma"] = noIndentEffect,
	["SetGuildBankTabInfo"] = noIndentEffect,
	["SetGuildBankTabPermissions"] = noIndentEffect,
	["SetGuildBankTabWithdraw"] = noIndentEffect,
	["SetGuildBankText"] = noIndentEffect,
	["SetGuildBankWithdrawLimit"] = noIndentEffect,
	["SetGuildInfoText"] = noIndentEffect,
	["SetGuildRosterSelection"] = noIndentEffect,
	["SetGuildRosterShowOffline"] = noIndentEffect,
	["SetInventoryPortraitTexture"] = noIndentEffect,
	["SetItemButtonCount"] = noIndentEffect,
	["SetItemButtonDesaturated"] = noIndentEffect,
	["SetItemButtonNameFrameVertexColor"] = noIndentEffect,
	["SetItemButtonNormalTextureVertexColor"] = noIndentEffect,
	["SetItemButtonSlotVertexColor"] = noIndentEffect,
	["SetItemButtonStock"] = noIndentEffect,
	["SetItemButtonTexture"] = noIndentEffect,
	["SetItemButtonTextureVertexColor"] = noIndentEffect,
	["SetItemRef"] = noIndentEffect,
	["SetLFGBootVote"] = noIndentEffect,
	["SetLFGComment"] = noIndentEffect,
	["SetLFGDungeon"] = noIndentEffect,
	["SetLFGDungeonEnabled"] = noIndentEffect,
	["SetLFGHeaderCollapsed"] = noIndentEffect,
	["SetLFGRoles"] = noIndentEffect,
	["SetLayoutMode"] = noIndentEffect,
	["SetLootMethod"] = noIndentEffect,
	["SetLootPortrait"] = noIndentEffect,
	["SetLootThreshold"] = noIndentEffect,
	["SetMacroItem"] = noIndentEffect,
	["SetMacroSpell"] = noIndentEffect,
	["SetMapByID"] = noIndentEffect,
	["SetMapToCurrentZone"] = noIndentEffect,
	["SetMapZoom"] = noIndentEffect,
	["SetModifiedClick"] = noIndentEffect,
	["SetMoneyFrameColor"] = noIndentEffect,
	["SetMouselookOverrideBinding"] = noIndentEffect,
	["SetMultiCastSpell"] = noIndentEffect,
	["SetMultisampleFormat"] = noIndentEffect,
	["SetNextBarberShopStyle"] = noIndentEffect,
	["SetOptOutOfLoot"] = noIndentEffect,
	["SetOverrideBinding"] = noIndentEffect,
	["SetOverrideBindingClick"] = noIndentEffect,
	["SetOverrideBindingItem"] = noIndentEffect,
	["SetOverrideBindingMacro"] = noIndentEffect,
	["SetOverrideBindingSpell"] = noIndentEffect,
	["SetPOIIconOverlapDistance"] = noIndentEffect,
	["SetPOIIconOverlapPushDistance"] = noIndentEffect,
	["SetPVP"] = noIndentEffect,
	["SetPartyAssignment"] = noIndentEffect,
	["SetPendingGuildBankTabPermissions"] = noIndentEffect,
	["SetPendingGuildBankTabWithdraw"] = noIndentEffect,
	["SetPetStablePaperdoll"] = noIndentEffect,
	["SetPortraitTexture"] = noIndentEffect,
	["SetPortraitToTexture"] = noIndentEffect,
	["SetRaidDifficulty"] = noIndentEffect,
	["SetRaidRosterSelection"] = noIndentEffect,
	["SetRaidSubgroup"] = noIndentEffect,
	["SetRaidTarget"] = noIndentEffect,
	["SetRaidTargetIcon"] = noIndentEffect,
	["SetRaidTargetIconTexture"] = noIndentEffect,
	["SetSavedInstanceExtend"] = noIndentEffect,
	["SetScreenResolution"] = noIndentEffect,
	["SetSelectedAuctionItem"] = noIndentEffect,
	["SetSelectedBattlefield"] = noIndentEffect,
	["SetSelectedDisplayChannel"] = noIndentEffect,
	["SetSelectedFaction"] = noIndentEffect,
	["SetSelectedFriend"] = noIndentEffect,
	["SetSelectedIgnore"] = noIndentEffect,
	["SetSelectedMute"] = noIndentEffect,
	["SetSelectedSkill"] = noIndentEffect,
	["SetSelfMuteState"] = noIndentEffect,
	["SetSendMailCOD"] = noIndentEffect,
	["SetSendMailMoney"] = noIndentEffect,
	["SetSendMailShowing"] = noIndentEffect,
	["SetSpellNameColor"] = noIndentEffect,
	["SetTableColor"] = noIndentEffect,
	["SetTalentButtonLocation"] = noIndentEffect,
	["SetTargetSpellbarAspect"] = noIndentEffect,
	["SetTaxiBenchmarkMode"] = noIndentEffect,
	["SetTaxiMap"] = noIndentEffect,
	["SetTerrainMip"] = noIndentEffect,
	["SetTexLodBias"] = noIndentEffect,
	["SetTextStatusBarText"] = noIndentEffect,
	["SetTextStatusBarTextPrefix"] = noIndentEffect,
	["SetTextStatusBarTextZeroText"] = noIndentEffect,
	["SetTitleByName"] = noIndentEffect,
	["SetTooltipMoney"] = noIndentEffect,
	["SetTracking"] = noIndentEffect,
	["SetTradeMoney"] = noIndentEffect,
	["SetTradeSkillInvSlotFilter"] = noIndentEffect,
	["SetTradeSkillItemLevelFilter"] = noIndentEffect,
	["SetTradeSkillItemNameFilter"] = noIndentEffect,
	["SetTradeSkillSubClassFilter"] = noIndentEffect,
	["SetTrainerServiceTypeFilter"] = noIndentEffect,
	["SetTrainerSkillLineFilter"] = noIndentEffect,
	["SetUIVisibility"] = noIndentEffect,
	["SetUpAnimation"] = noIndentEffect,
	["SetView"] = noIndentEffect,
	["SetWatchedFactionIndex"] = noIndentEffect,
	["SetWaterDetail"] = noIndentEffect,
	["SetWhoToUI"] = noIndentEffect,
	["SetZoneText"] = noIndentEffect,
	["SetupFullscreenScale"] = noIndentEffect,
	["SetupUnitButtonConfiguration"] = noIndentEffect,
	["ShapeshiftBar_ChangeForm"] = noIndentEffect,
	["ShapeshiftBar_OnEvent"] = noIndentEffect,
	["ShapeshiftBar_OnLoad"] = noIndentEffect,
	["ShapeshiftBar_Update"] = noIndentEffect,
	["ShapeshiftBar_UpdateState"] = noIndentEffect,
	["ShiftQuestWatches"] = noIndentEffect,
	["ShowBonusActionBar"] = noIndentEffect,
	["ShowBuybackSellCursor"] = noIndentEffect,
	["ShowCloak"] = noIndentEffect,
	["ShowContainerSellCursor"] = noIndentEffect,
	["ShowFriends"] = noIndentEffect,
	["ShowHelm"] = noIndentEffect,
	["ShowInspectCursor"] = noIndentEffect,
	["ShowInventorySellCursor"] = noIndentEffect,
	["ShowMacroFrame"] = noIndentEffect,
	["ShowMerchantSellCursor"] = noIndentEffect,
	["ShowMiniWorldMapArrowFrame"] = noIndentEffect,
	["ShowMultiCastActionBar"] = noIndentEffect,
	["ShowNumericThreat"] = noIndentEffect,
	["ShowPartyFrame"] = noIndentEffect,
	["ShowPetActionBar"] = noIndentEffect,
	["ShowQuickButton"] = noIndentEffect,
	["ShowReadyCheck"] = noIndentEffect,
	["ShowRepairCursor"] = noIndentEffect,
	["ShowResurrectRequest"] = noIndentEffect,
	["ShowTextStatusBarText"] = noIndentEffect,
	["ShowUIPanel"] = noIndentEffect,
	["ShowWatchedReputationBarText"] = noIndentEffect,
	["ShowWhoPanel"] = noIndentEffect,
	["ShowWorldMapArrowFrame"] = noIndentEffect,
	["ShowingCloak"] = noIndentEffect,
	["ShowingHelm"] = noIndentEffect,
	["SignPetition"] = noIndentEffect,
	["SilenceMember"] = noIndentEffect,
	["SitStandOrDescendStart"] = noIndentEffect,
	["SkillBar_OnClick"] = noIndentEffect,
	["SkillDetailFrame_SetStatusBar"] = noIndentEffect,
	["SkillFrame_OnEvent"] = noIndentEffect,
	["SkillFrame_OnLoad"] = noIndentEffect,
	["SkillFrame_OnShow"] = noIndentEffect,
	["SkillFrame_SetStatusBar"] = noIndentEffect,
	["SkillFrame_UpdateSkills"] = noIndentEffect,
	["SmallMoneyFrame_OnLoad"] = noIndentEffect,
	["SocketContainerItem"] = noIndentEffect,
	["SocketInventoryItem"] = noIndentEffect,
	["SortArenaTeamRoster"] = noIndentEffect,
	["SortAuctionApplySort"] = noIndentEffect,
	["SortAuctionClearSort"] = noIndentEffect,
	["SortAuctionItems"] = noIndentEffect,
	["SortAuctionSetSort"] = noIndentEffect,
	["SortBGList"] = noIndentEffect,
	["SortBattlefieldScoreData"] = noIndentEffect,
	["SortGuildRoster"] = noIndentEffect,
	["SortQuestWatches"] = noIndentEffect,
	["SortWho"] = noIndentEffect,
	["Sound_ChatSystem_GetInputDriverNameByIndex"] = noIndentEffect,
	["Sound_ChatSystem_GetNumInputDrivers"] = noIndentEffect,
	["Sound_ChatSystem_GetNumOutputDrivers"] = noIndentEffect,
	["Sound_ChatSystem_GetOutputDriverNameByIndex"] = noIndentEffect,
	["Sound_GameSystem_GetInputDriverNameByIndex"] = noIndentEffect,
	["Sound_GameSystem_GetNumInputDrivers"] = noIndentEffect,
	["Sound_GameSystem_GetNumOutputDrivers"] = noIndentEffect,
	["Sound_GameSystem_GetOutputDriverNameByIndex"] = noIndentEffect,
	["Sound_GameSystem_RestartSoundSystem"] = noIndentEffect,
	["Sound_MasterVolumeDown"] = noIndentEffect,
	["Sound_MasterVolumeUp"] = noIndentEffect,
	["Sound_ToggleMusic"] = noIndentEffect,
	["Sound_ToggleSound"] = noIndentEffect,
	["SpellBookFrameTabButton_OnClick"] = noIndentEffect,
	["SpellBookFrame_HideSpells"] = noIndentEffect,
	["SpellBookFrame_OnEvent"] = noIndentEffect,
	["SpellBookFrame_OnHide"] = noIndentEffect,
	["SpellBookFrame_OnLoad"] = noIndentEffect,
	["SpellBookFrame_OnShow"] = noIndentEffect,
	["SpellBookFrame_PlayCloseSound"] = noIndentEffect,
	["SpellBookFrame_PlayOpenSound"] = noIndentEffect,
	["SpellBookFrame_SetTabType"] = noIndentEffect,
	["SpellBookFrame_ShowSpells"] = noIndentEffect,
	["SpellBookFrame_Update"] = noIndentEffect,
	["SpellBookFrame_UpdatePages"] = noIndentEffect,
	["SpellBookNextPageButton_OnClick"] = noIndentEffect,
	["SpellBookPrevPageButton_OnClick"] = noIndentEffect,
	["SpellBookSkillLineTab_OnClick"] = noIndentEffect,
	["SpellBook_GetAutoCastShine"] = noIndentEffect,
	["SpellBook_GetCurrentPage"] = noIndentEffect,
	["SpellBook_GetSpellID"] = noIndentEffect,
	["SpellBook_GetTabInfo"] = noIndentEffect,
	["SpellBook_ReleaseAutoCastShine"] = noIndentEffect,
	["SpellBook_UpdatePageArrows"] = noIndentEffect,
	["SpellButton_OnClick"] = noIndentEffect,
	["SpellButton_OnDrag"] = noIndentEffect,
	["SpellButton_OnEnter"] = noIndentEffect,
	["SpellButton_OnEvent"] = noIndentEffect,
	["SpellButton_OnHide"] = noIndentEffect,
	["SpellButton_OnLoad"] = noIndentEffect,
	["SpellButton_OnModifiedClick"] = noIndentEffect,
	["SpellButton_OnShow"] = noIndentEffect,
	["SpellButton_UpdateButton"] = noIndentEffect,
	["SpellButton_UpdateSelection"] = noIndentEffect,
	["SpellCanTargetGlyph"] = noIndentEffect,
	["SpellCanTargetItem"] = noIndentEffect,
	["SpellCanTargetUnit"] = noIndentEffect,
	["SpellColor_OpenColorPicker"] = noIndentEffect,
	["SpellHasRange"] = noIndentEffect,
	["SpellIsTargeting"] = noIndentEffect,
	["SpellStopCasting"] = noIndentEffect,
	["SpellStopTargeting"] = noIndentEffect,
	["SpellTargetItem"] = noIndentEffect,
	["SpellTargetUnit"] = noIndentEffect,
	["SplitContainerItem"] = noIndentEffect,
	["SplitGuildBankItem"] = noIndentEffect,
	["StablePet"] = noIndentEffect,
	["StackSplitFrameCancel_Click"] = noIndentEffect,
	["StackSplitFrameLeft_Click"] = noIndentEffect,
	["StackSplitFrameOkay_Click"] = noIndentEffect,
	["StackSplitFrameRight_Click"] = noIndentEffect,
	["StackSplitFrame_OnChar"] = noIndentEffect,
	["StackSplitFrame_OnHide"] = noIndentEffect,
	["StackSplitFrame_OnKeyDown"] = noIndentEffect,
	["StackSplitFrame_OnKeyUp"] = noIndentEffect,
	["StartAttack"] = noIndentEffect,
	["StartAuction"] = noIndentEffect,
	["StartDuel"] = noIndentEffect,
	["StaticPopupSpecial_Hide"] = noIndentEffect,
	["StaticPopupSpecial_Show"] = noIndentEffect,
	["StaticPopup_CollapseTable"] = noIndentEffect,
	["StaticPopup_EditBoxOnEnterPressed"] = noIndentEffect,
	["StaticPopup_EditBoxOnEscapePressed"] = noIndentEffect,
	["StaticPopup_EditBoxOnTextChanged"] = noIndentEffect,
	["StaticPopup_EscapePressed"] = noIndentEffect,
	["StaticPopup_FindVisible"] = noIndentEffect,
	["StaticPopup_Hide"] = noIndentEffect,
	["StaticPopup_HideExclusive"] = noIndentEffect,
	["StaticPopup_IsLastDisplayedFrame"] = noIndentEffect,
	["StaticPopup_OnClick"] = noIndentEffect,
	["StaticPopup_OnEvent"] = noIndentEffect,
	["StaticPopup_OnHide"] = noIndentEffect,
	["StaticPopup_OnKeyDown"] = noIndentEffect,
	["StaticPopup_OnShow"] = noIndentEffect,
	["StaticPopup_OnUpdate"] = noIndentEffect,
	["StaticPopup_Resize"] = noIndentEffect,
	["StaticPopup_SetUpPosition"] = noIndentEffect,
	["StaticPopup_Show"] = noIndentEffect,
	["StaticPopup_Visible"] = noIndentEffect,
	["StationeryPopupButton_OnClick"] = noIndentEffect,
	["StationeryPopupFrame_Update"] = noIndentEffect,
	["StatsFrame_OnLoad"] = noIndentEffect,
	["StatsFrame_OnUpdate"] = noIndentEffect,
	["StopAttack"] = noIndentEffect,
	["StopCinematic"] = noIndentEffect,
	["StopMacro"] = noIndentEffect,
	["StopMusic"] = noIndentEffect,
	["StopTradeSkillRepeat"] = noIndentEffect,
	["StopwatchCloseButton_OnClick"] = noIndentEffect,
	["StopwatchFrame_OnDragStart"] = noIndentEffect,
	["StopwatchFrame_OnDragStop"] = noIndentEffect,
	["StopwatchFrame_OnEvent"] = noIndentEffect,
	["StopwatchFrame_OnHide"] = noIndentEffect,
	["StopwatchFrame_OnLoad"] = noIndentEffect,
	["StopwatchFrame_OnMouseDown"] = noIndentEffect,
	["StopwatchFrame_OnMouseUp"] = noIndentEffect,
	["StopwatchFrame_OnShow"] = noIndentEffect,
	["StopwatchFrame_OnUpdate"] = noIndentEffect,
	["StopwatchPlayPauseButton_OnClick"] = noIndentEffect,
	["StopwatchResetButton_OnClick"] = noIndentEffect,
	["StopwatchTicker_OnUpdate"] = noIndentEffect,
	["StopwatchTicker_Update"] = noIndentEffect,
	["Stopwatch_Clear"] = noIndentEffect,
	["Stopwatch_FinishCountdown"] = noIndentEffect,
	["Stopwatch_IsPlaying"] = noIndentEffect,
	["Stopwatch_Pause"] = noIndentEffect,
	["Stopwatch_Play"] = noIndentEffect,
	["Stopwatch_StartCountdown"] = noIndentEffect,
	["Stopwatch_Toggle"] = noIndentEffect,
	["StrafeLeftStart"] = noIndentEffect,
	["StrafeLeftStop"] = noIndentEffect,
	["StrafeRightStart"] = noIndentEffect,
	["StrafeRightStop"] = noIndentEffect,
	["Stuck"] = noIndentEffect,
	["SubZoneText_OnLoad"] = noIndentEffect,
	["SummonFriend"] = noIndentEffect,
	["SummonRandomCritter"] = noIndentEffect,
	["SwapRaidSubgroup"] = noIndentEffect,
	["SynchronizeBNetStatus"] = noIndentEffect,
	["TEXT"] = noIndentEffect,
	["TabardCharacterModelFrame_OnLoad"] = noIndentEffect,
	["TabardCharacterModelFrame_OnUpdate"] = noIndentEffect,
	["TabardCharacterModelRotateLeftButton_OnClick"] = noIndentEffect,
	["TabardCharacterModelRotateRightButton_OnClick"] = noIndentEffect,
	["TabardCustomization_Left"] = noIndentEffect,
	["TabardCustomization_Right"] = noIndentEffect,
	["TabardFrame_OnEvent"] = noIndentEffect,
	["TabardFrame_OnLoad"] = noIndentEffect,
	["TabardFrame_UpdateButtons"] = noIndentEffect,
	["TabardFrame_UpdateTextures"] = noIndentEffect,
	["TakeInboxItem"] = noIndentEffect,
	["TakeInboxMoney"] = noIndentEffect,
	["TakeInboxTextItem"] = noIndentEffect,
	["TakeScreenshot"] = noIndentEffect,
	["TakeTaxiNode"] = noIndentEffect,
	["TalentFrame_DrawLines"] = noIndentEffect,
	["TalentFrame_GetArrowTexture"] = noIndentEffect,
	["TalentFrame_GetArrowTextureCount"] = noIndentEffect,
	["TalentFrame_GetBranchTexture"] = noIndentEffect,
	["TalentFrame_GetBranchTextureCount"] = noIndentEffect,
	["TalentFrame_Load"] = noIndentEffect,
	["TalentFrame_LoadUI"] = noIndentEffect,
	["TalentFrame_ResetArrowTextureCount"] = noIndentEffect,
	["TalentFrame_ResetBranchTextureCount"] = noIndentEffect,
	["TalentFrame_ResetBranches"] = noIndentEffect,
	["TalentFrame_SetArrowTexture"] = noIndentEffect,
	["TalentFrame_SetBranchTexture"] = noIndentEffect,
	["TalentFrame_SetPrereqs"] = noIndentEffect,
	["TalentFrame_Update"] = noIndentEffect,
	["TalentFrame_UpdateSpecInfoCache"] = noIndentEffect,
	["TalentFrame_UpdateTalentPoints"] = noIndentEffect,
	["TalentMicroButton_OnEvent"] = noIndentEffect,
	["TargetDirectionEnemy"] = noIndentEffect,
	["TargetDirectionFinished"] = noIndentEffect,
	["TargetDirectionFriend"] = noIndentEffect,
	["TargetFrameDropDown_Initialize"] = noIndentEffect,
	["TargetFrame_CheckClassification"] = noIndentEffect,
	["TargetFrame_CheckDead"] = noIndentEffect,
	["TargetFrame_CheckFaction"] = noIndentEffect,
	["TargetFrame_CheckLevel"] = noIndentEffect,
	["TargetFrame_CreateSpellbar"] = noIndentEffect,
	["TargetFrame_CreateTargetofTarget"] = noIndentEffect,
	["TargetFrame_HealthUpdate"] = noIndentEffect,
	["TargetFrame_OnEvent"] = noIndentEffect,
	["TargetFrame_OnHide"] = noIndentEffect,
	["TargetFrame_OnLoad"] = noIndentEffect,
	["TargetFrame_OnUpdate"] = noIndentEffect,
	["TargetFrame_Update"] = noIndentEffect,
	["TargetFrame_UpdateAuraPositions"] = noIndentEffect,
	["TargetFrame_UpdateAuras"] = noIndentEffect,
	["TargetFrame_UpdateBuffAnchor"] = noIndentEffect,
	["TargetFrame_UpdateDebuffAnchor"] = noIndentEffect,
	["TargetFrame_UpdateRaidTargetIcon"] = noIndentEffect,
	["TargetHealthCheck"] = noIndentEffect,
	["TargetLastEnemy"] = noIndentEffect,
	["TargetLastFriend"] = noIndentEffect,
	["TargetLastTarget"] = noIndentEffect,
	["TargetNearest"] = noIndentEffect,
	["TargetNearestEnemy"] = noIndentEffect,
	["TargetNearestEnemyPlayer"] = noIndentEffect,
	["TargetNearestFriend"] = noIndentEffect,
	["TargetNearestFriendPlayer"] = noIndentEffect,
	["TargetNearestPartyMember"] = noIndentEffect,
	["TargetNearestRaidMember"] = noIndentEffect,
	["TargetTotem"] = noIndentEffect,
	["TargetUnit"] = noIndentEffect,
	["Target_Spellbar_AdjustPosition"] = noIndentEffect,
	["Target_Spellbar_OnEvent"] = noIndentEffect,
	["TargetofTargetHealthCheck"] = noIndentEffect,
	["TargetofTarget_CheckDead"] = noIndentEffect,
	["TargetofTarget_OnHide"] = noIndentEffect,
	["TargetofTarget_Update"] = noIndentEffect,
	["TaxiFrame_OnEvent"] = noIndentEffect,
	["TaxiFrame_OnLoad"] = noIndentEffect,
	["TaxiGetDestX"] = noIndentEffect,
	["TaxiGetDestY"] = noIndentEffect,
	["TaxiGetSrcX"] = noIndentEffect,
	["TaxiGetSrcY"] = noIndentEffect,
	["TaxiNodeCost"] = noIndentEffect,
	["TaxiNodeGetType"] = noIndentEffect,
	["TaxiNodeName"] = noIndentEffect,
	["TaxiNodeOnButtonEnter"] = noIndentEffect,
	["TaxiNodePosition"] = noIndentEffect,
	["TaxiNodeSetCurrent"] = noIndentEffect,
	["TeleportToDebugObject"] = noIndentEffect,
	["TempEnchantButton_OnClick"] = noIndentEffect,
	["TempEnchantButton_OnEnter"] = noIndentEffect,
	["TempEnchantButton_OnLoad"] = noIndentEffect,
	["TempEnchantButton_OnUpdate"] = noIndentEffect,
	["TemporaryEnchantFrame_Hide"] = noIndentEffect,
	["TemporaryEnchantFrame_OnUpdate"] = noIndentEffect,
	["TextEmoteSort"] = noIndentEffect,
	["TextStatusBar_CapDisplayOfNumericValue"] = noIndentEffect,
	["TextStatusBar_Initialize"] = noIndentEffect,
	["TextStatusBar_OnEvent"] = noIndentEffect,
	["TextStatusBar_OnValueChanged"] = noIndentEffect,
	["TextStatusBar_UpdateTextString"] = noIndentEffect,
	["TicketStatusFrameButton_OnClick"] = noIndentEffect,
	["TicketStatusFrameButton_OnLoad"] = noIndentEffect,
	["TicketStatusFrame_OnEvent"] = noIndentEffect,
	["TicketStatusFrame_OnHide"] = noIndentEffect,
	["TicketStatusFrame_OnLoad"] = noIndentEffect,
	["TicketStatusFrame_OnShow"] = noIndentEffect,
	["TicketStatusFrame_OnUpdate"] = noIndentEffect,
	["TimeManagerAlarmAMPMDropDown_Initialize"] = noIndentEffect,
	["TimeManagerAlarmAMPMDropDown_OnClick"] = noIndentEffect,
	["TimeManagerAlarmAMPMDropDown_OnHide"] = noIndentEffect,
	["TimeManagerAlarmAMPMDropDown_OnShow"] = noIndentEffect,
	["TimeManagerAlarmEnabledButton_OnClick"] = noIndentEffect,
	["TimeManagerAlarmEnabledButton_Update"] = noIndentEffect,
	["TimeManagerAlarmHourDropDown_Initialize"] = noIndentEffect,
	["TimeManagerAlarmHourDropDown_OnClick"] = noIndentEffect,
	["TimeManagerAlarmMessageEditBox_OnEditFocusLost"] = noIndentEffect,
	["TimeManagerAlarmMessageEditBox_OnEnterPressed"] = noIndentEffect,
	["TimeManagerAlarmMessageEditBox_OnEscapePressed"] = noIndentEffect,
	["TimeManagerAlarmMinuteDropDown_Initialize"] = noIndentEffect,
	["TimeManagerAlarmMinuteDropDown_OnClick"] = noIndentEffect,
	["TimeManagerClockButton_Hide"] = noIndentEffect,
	["TimeManagerClockButton_OnClick"] = noIndentEffect,
	["TimeManagerClockButton_OnEnter"] = noIndentEffect,
	["TimeManagerClockButton_OnLeave"] = noIndentEffect,
	["TimeManagerClockButton_OnLoad"] = noIndentEffect,
	["TimeManagerClockButton_OnUpdate"] = noIndentEffect,
	["TimeManagerClockButton_OnUpdateWithTooltip"] = noIndentEffect,
	["TimeManagerClockButton_Show"] = noIndentEffect,
	["TimeManagerClockButton_Update"] = noIndentEffect,
	["TimeManagerClockButton_UpdateTooltip"] = noIndentEffect,
	["TimeManagerCloseButton_OnClick"] = noIndentEffect,
	["TimeManagerFrame_OnHide"] = noIndentEffect,
	["TimeManagerFrame_OnLoad"] = noIndentEffect,
	["TimeManagerFrame_OnShow"] = noIndentEffect,
	["TimeManagerFrame_OnUpdate"] = noIndentEffect,
	["TimeManagerLocalTimeCheck_OnClick"] = noIndentEffect,
	["TimeManagerMilitaryTimeCheck_OnClick"] = noIndentEffect,
	["TimeManagerStopwatchCheck_OnClick"] = noIndentEffect,
	["TimeManager_CheckAlarm"] = noIndentEffect,
	["TimeManager_FireAlarm"] = noIndentEffect,
	["TimeManager_FireAlarmWarning"] = noIndentEffect,
	["TimeManager_IsAlarmFiring"] = noIndentEffect,
	["TimeManager_LoadUI"] = noIndentEffect,
	["TimeManager_ShouldCheckAlarm"] = noIndentEffect,
	["TimeManager_StartCheckingAlarm"] = noIndentEffect,
	["TimeManager_Toggle"] = noIndentEffect,
	["TimeManager_ToggleLocalTime"] = noIndentEffect,
	["TimeManager_ToggleTimeFormat"] = noIndentEffect,
	["TimeManager_TurnOffAlarm"] = noIndentEffect,
	["TimeManager_Update"] = noIndentEffect,
	["TimeManager_UpdateAlarmTime"] = noIndentEffect,
	["TimeManager_UpdateTimeTicker"] = noIndentEffect,
	["ToggleAchievementFrame"] = noIndentEffect,
	["ToggleAutoRun"] = noIndentEffect,
	["ToggleBackpack"] = noIndentEffect,
	["ToggleBag"] = noIndentEffect,
	["ToggleBattlefieldMinimap"] = noIndentEffect,
	["ToggleCalendar"] = noIndentEffect,
	["ToggleCharacter"] = noIndentEffect,
	["ToggleChatChannel"] = noIndentEffect,
	["ToggleChatColorNamesByClassGroup"] = noIndentEffect,
	["ToggleChatMessageGroup"] = noIndentEffect,
	["ToggleCollision"] = noIndentEffect,
	["ToggleCollisionDisplay"] = noIndentEffect,
	["ToggleDropDownMenu"] = noIndentEffect,
	["ToggleFrame"] = noIndentEffect,
	["ToggleFramerate"] = noIndentEffect,
	["ToggleFriendsFrame"] = noIndentEffect,
	["ToggleFriendsPanel"] = noIndentEffect,
	["ToggleGameMenu"] = noIndentEffect,
	["ToggleGlyphFrame"] = noIndentEffect,
	["ToggleGuildEventLog"] = noIndentEffect,
	["ToggleGuildInfoFrame"] = noIndentEffect,
	["ToggleHelpFrame"] = noIndentEffect,
	["ToggleIgnorePanel"] = noIndentEffect,
	["ToggleKeyRing"] = noIndentEffect,
	["ToggleLFDParentFrame"] = noIndentEffect,
	["ToggleLFRParentFrame"] = noIndentEffect,
	["ToggleMapFramerate"] = noIndentEffect,
	["ToggleMessageDest"] = noIndentEffect,
	["ToggleMessageSource"] = noIndentEffect,
	["ToggleMessageType"] = noIndentEffect,
	["ToggleMessageTypeGroup"] = noIndentEffect,
	["ToggleMiniMapRotation"] = noIndentEffect,
	["ToggleMinimap"] = noIndentEffect,
	["TogglePVP"] = noIndentEffect,
	["TogglePVPFrame"] = noIndentEffect,
	["TogglePerformanceDisplay"] = noIndentEffect,
	["TogglePerformancePause"] = noIndentEffect,
	["TogglePerformanceValues"] = noIndentEffect,
	["TogglePetAutocast"] = noIndentEffect,
	["TogglePlayerBounds"] = noIndentEffect,
	["TogglePortals"] = noIndentEffect,
	["ToggleRun"] = noIndentEffect,
	["ToggleSheath"] = noIndentEffect,
	["ToggleSpellAutocast"] = noIndentEffect,
	["ToggleSpellBook"] = noIndentEffect,
	["ToggleStats"] = noIndentEffect,
	["ToggleTalentFrame"] = noIndentEffect,
	["ToggleTimeManager"] = noIndentEffect,
	["ToggleTris"] = noIndentEffect,
	["ToggleWorldStateScoreFrame"] = noIndentEffect,
	["TokenButtonLinkButton_OnClick"] = noIndentEffect,
	["TokenButton_OnClick"] = noIndentEffect,
	["TokenButton_OnLoad"] = noIndentEffect,
	["TokenFramePopup_CloseIfHidden"] = noIndentEffect,
	["TokenFrame_LoadUI"] = noIndentEffect,
	["TokenFrame_OnLoad"] = noIndentEffect,
	["TokenFrame_OnShow"] = noIndentEffect,
	["TokenFrame_Update"] = noIndentEffect,
	["TokenFrame_UpdatePopup"] = noIndentEffect,
	["TotemButton_OnClick"] = noIndentEffect,
	["TotemButton_OnLoad"] = noIndentEffect,
	["TotemButton_OnUpdate"] = noIndentEffect,
	["TotemButton_Update"] = noIndentEffect,
	["TotemFrame_OnEvent"] = noIndentEffect,
	["TotemFrame_OnLoad"] = noIndentEffect,
	["TotemFrame_Update"] = noIndentEffect,
	["TradeFrameCancelButton_OnClick"] = noIndentEffect,
	["TradeFrameTradeButton_Disable"] = noIndentEffect,
	["TradeFrameTradeButton_Enable"] = noIndentEffect,
	["TradeFrameTradeButton_SetToEnabledState"] = noIndentEffect,
	["TradeFrame_GetAvailableSlot"] = noIndentEffect,
	["TradeFrame_OnEvent"] = noIndentEffect,
	["TradeFrame_OnHide"] = noIndentEffect,
	["TradeFrame_OnLoad"] = noIndentEffect,
	["TradeFrame_OnMouseUp"] = noIndentEffect,
	["TradeFrame_OnShow"] = noIndentEffect,
	["TradeFrame_SetAcceptState"] = noIndentEffect,
	["TradeFrame_Update"] = noIndentEffect,
	["TradeFrame_UpdateMoney"] = noIndentEffect,
	["TradeFrame_UpdatePlayerItem"] = noIndentEffect,
	["TradeFrame_UpdateTargetItem"] = noIndentEffect,
	["TradeSkillFrame_LoadUI"] = noIndentEffect,
	["TradeSkillOnlyShowMakeable"] = noIndentEffect,
	["TradeSkillOnlyShowSkillUps"] = noIndentEffect,
	["TriggerTutorial"] = noIndentEffect,
	["TurnInArenaPetition"] = noIndentEffect,
	["TurnInGuildCharter"] = noIndentEffect,
	["TurnInPetition"] = noIndentEffect,
	["TurnLeftStart"] = noIndentEffect,
	["TurnLeftStop"] = noIndentEffect,
	["TurnOrActionStart"] = noIndentEffect,
	["TurnOrActionStop"] = noIndentEffect,
	["TurnRightStart"] = noIndentEffect,
	["TurnRightStop"] = noIndentEffect,
	["TutorialFrameNextButton_OnClick"] = noIndentEffect,
	["TutorialFramePrevButton_OnClick"] = noIndentEffect,
	["TutorialFrame_AlertButton_OnClick"] = noIndentEffect,
	["TutorialFrame_CheckBadge"] = noIndentEffect,
	["TutorialFrame_CheckNextPrevButtons"] = noIndentEffect,
	["TutorialFrame_ClearQueue"] = noIndentEffect,
	["TutorialFrame_ClearTextures"] = noIndentEffect,
	["TutorialFrame_Hide"] = noIndentEffect,
	["TutorialFrame_NewTutorial"] = noIndentEffect,
	["TutorialFrame_OnHide"] = noIndentEffect,
	["TutorialFrame_OnLoad"] = noIndentEffect,
	["TutorialFrame_OnShow"] = noIndentEffect,
	["TutorialFrame_Update"] = noIndentEffect,
	["UIDoFramesIntersect"] = noIndentEffect,
	["UIDropDownMenuButton_GetChecked"] = noIndentEffect,
	["UIDropDownMenuButton_GetName"] = noIndentEffect,
	["UIDropDownMenuButton_OnClick"] = noIndentEffect,
	["UIDropDownMenuButton_OpenColorPicker"] = noIndentEffect,
	["UIDropDownMenuDelegate_OnAttributeChanged"] = noIndentEffect,
	["UIDropDownMenu_AddButton"] = noIndentEffect,
	["UIDropDownMenu_ClearAll"] = noIndentEffect,
	["UIDropDownMenu_CreateFrames"] = noIndentEffect,
	["UIDropDownMenu_CreateInfo"] = noIndentEffect,
	["UIDropDownMenu_DisableButton"] = noIndentEffect,
	["UIDropDownMenu_DisableDropDown"] = noIndentEffect,
	["UIDropDownMenu_EnableButton"] = noIndentEffect,
	["UIDropDownMenu_EnableDropDown"] = noIndentEffect,
	["UIDropDownMenu_GetCurrentDropDown"] = noIndentEffect,
	["UIDropDownMenu_GetSelectedID"] = noIndentEffect,
	["UIDropDownMenu_GetSelectedName"] = noIndentEffect,
	["UIDropDownMenu_GetSelectedValue"] = noIndentEffect,
	["UIDropDownMenu_GetText"] = noIndentEffect,
	["UIDropDownMenu_GetValue"] = noIndentEffect,
	["UIDropDownMenu_Initialize"] = noIndentEffect,
	["UIDropDownMenu_InitializeHelper"] = noIndentEffect,
	["UIDropDownMenu_IsEnabled"] = noIndentEffect,
	["UIDropDownMenu_JustifyText"] = noIndentEffect,
	["UIDropDownMenu_OnHide"] = noIndentEffect,
	["UIDropDownMenu_OnUpdate"] = noIndentEffect,
	["UIDropDownMenu_Refresh"] = noIndentEffect,
	["UIDropDownMenu_SetAnchor"] = noIndentEffect,
	["UIDropDownMenu_SetButtonText"] = noIndentEffect,
	["UIDropDownMenu_SetButtonWidth"] = noIndentEffect,
	["UIDropDownMenu_SetSelectedID"] = noIndentEffect,
	["UIDropDownMenu_SetSelectedName"] = noIndentEffect,
	["UIDropDownMenu_SetSelectedValue"] = noIndentEffect,
	["UIDropDownMenu_SetText"] = noIndentEffect,
	["UIDropDownMenu_SetWidth"] = noIndentEffect,
	["UIDropDownMenu_StartCounting"] = noIndentEffect,
	["UIDropDownMenu_StopCounting"] = noIndentEffect,
	["UIErrorsFrame_OnEvent"] = noIndentEffect,
	["UIErrorsFrame_OnLoad"] = noIndentEffect,
	["UIFrameFade"] = noIndentEffect,
	["UIFrameFadeIn"] = noIndentEffect,
	["UIFrameFadeOut"] = noIndentEffect,
	["UIFrameFadeRemoveFrame"] = noIndentEffect,
	["UIFrameFade_OnUpdate"] = noIndentEffect,
	["UIFrameFlash"] = noIndentEffect,
	["UIFrameFlashRemoveFrame"] = noIndentEffect,
	["UIFrameFlashStop"] = noIndentEffect,
	["UIFrameFlash_OnUpdate"] = noIndentEffect,
	["UIFrameIsFading"] = noIndentEffect,
	["UIFrameIsFlashing"] = noIndentEffect,
	["UIMenuButton_OnClick"] = noIndentEffect,
	["UIMenuButton_OnEnter"] = noIndentEffect,
	["UIMenuButton_OnLeave"] = noIndentEffect,
	["UIMenuButton_OnLoad"] = noIndentEffect,
	["UIMenu_AddButton"] = noIndentEffect,
	["UIMenu_AutoSize"] = noIndentEffect,
	["UIMenu_FinishInitializing"] = noIndentEffect,
	["UIMenu_GetNumButtons"] = noIndentEffect,
	["UIMenu_Initialize"] = noIndentEffect,
	["UIMenu_OnShow"] = noIndentEffect,
	["UIMenu_OnUpdate"] = noIndentEffect,
	["UIMenu_StartCounting"] = noIndentEffect,
	["UIMenu_StopCounting"] = noIndentEffect,
	["UIParentLoadAddOn"] = noIndentEffect,
	["UIParent_ManageFramePosition"] = noIndentEffect,
	["UIParent_ManageFramePositions"] = noIndentEffect,
	["UIParent_OnEvent"] = noIndentEffect,
	["UIParent_OnLoad"] = noIndentEffect,
	["UnSilenceMember"] = noIndentEffect,
	["UninviteUnit"] = noIndentEffect,
	["UnitAffectingCombat"] = noIndentEffect,
	["UnitArmor"] = noIndentEffect,
	["UnitAttackBothHands"] = noIndentEffect,
	["UnitAttackPower"] = noIndentEffect,
	["UnitAttackSpeed"] = noIndentEffect,
	["UnitAura"] = noIndentEffect,
	["UnitBuff"] = noIndentEffect,
	["UnitCanAssist"] = noIndentEffect,
	["UnitCanAttack"] = noIndentEffect,
	["UnitCanCooperate"] = noIndentEffect,
	["UnitCastingInfo"] = noIndentEffect,
	["UnitChannelInfo"] = noIndentEffect,
	["UnitCharacterPoints"] = noIndentEffect,
	["UnitClass"] = noIndentEffect,
	["UnitClassBase"] = noIndentEffect,
	["UnitClassification"] = noIndentEffect,
	["UnitControllingVehicle"] = noIndentEffect,
	["UnitCreatureFamily"] = noIndentEffect,
	["UnitCreatureType"] = noIndentEffect,
	["UnitDamage"] = noIndentEffect,
	["UnitDebuff"] = noIndentEffect,
	["UnitDefense"] = noIndentEffect,
	["UnitDetailedThreatSituation"] = noIndentEffect,
	["UnitExists"] = noIndentEffect,
	["UnitFactionGroup"] = noIndentEffect,
	["UnitFrameHealthBar_Initialize"] = noIndentEffect,
	["UnitFrameHealthBar_OnEvent"] = noIndentEffect,
	["UnitFrameHealthBar_OnUpdate"] = noIndentEffect,
	["UnitFrameHealthBar_OnValueChanged"] = noIndentEffect,
	["UnitFrameHealthBar_Update"] = noIndentEffect,
	["UnitFrameManaBar_Initialize"] = noIndentEffect,
	["UnitFrameManaBar_OnEvent"] = noIndentEffect,
	["UnitFrameManaBar_OnUpdate"] = noIndentEffect,
	["UnitFrameManaBar_RegisterDefaultEvents"] = noIndentEffect,
	["UnitFrameManaBar_UnregisterDefaultEvents"] = noIndentEffect,
	["UnitFrameManaBar_Update"] = noIndentEffect,
	["UnitFrameManaBar_UpdateType"] = noIndentEffect,
	["UnitFramePortrait_Update"] = noIndentEffect,
	["UnitFrameThreatIndicator_Initialize"] = noIndentEffect,
	["UnitFrameThreatIndicator_OnEvent"] = noIndentEffect,
	["UnitFrame_Initialize"] = noIndentEffect,
	["UnitFrame_OnEnter"] = noIndentEffect,
	["UnitFrame_OnEvent"] = noIndentEffect,
	["UnitFrame_OnLeave"] = noIndentEffect,
	["UnitFrame_SetUnit"] = noIndentEffect,
	["UnitFrame_Update"] = noIndentEffect,
	["UnitFrame_UpdateThreatIndicator"] = noIndentEffect,
	["UnitFrame_UpdateTooltip"] = noIndentEffect,
	["UnitGUID"] = noIndentEffect,
	["UnitGroupRolesAssigned"] = noIndentEffect,
	["UnitHasLFGDeserter"] = noIndentEffect,
	["UnitHasLFGRandomCooldown"] = noIndentEffect,
	["UnitHasMana"] = noIndentEffect,
	["UnitHasRelicSlot"] = noIndentEffect,
	["UnitHasVehicleUI"] = noIndentEffect,
	["UnitHealth"] = noIndentEffect,
	["UnitHealthMax"] = noIndentEffect,
	["UnitInBattleground"] = noIndentEffect,
	["UnitInParty"] = noIndentEffect,
	["UnitInRaid"] = noIndentEffect,
	["UnitInRange"] = noIndentEffect,
	["UnitInVehicle"] = noIndentEffect,
	["UnitInVehicleControlSeat"] = noIndentEffect,
	["UnitIsAFK"] = noIndentEffect,
	["UnitIsCharmed"] = noIndentEffect,
	["UnitIsConnected"] = noIndentEffect,
	["UnitIsControlling"] = noIndentEffect,
	["UnitIsCorpse"] = noIndentEffect,
	["UnitIsDND"] = noIndentEffect,
	["UnitIsDead"] = noIndentEffect,
	["UnitIsDeadOrGhost"] = noIndentEffect,
	["UnitIsEnemy"] = noIndentEffect,
	["UnitIsFeignDeath"] = noIndentEffect,
	["UnitIsFriend"] = noIndentEffect,
	["UnitIsGhost"] = noIndentEffect,
	["UnitIsInMyGuild"] = noIndentEffect,
	["UnitIsPVP"] = noIndentEffect,
	["UnitIsPVPFreeForAll"] = noIndentEffect,
	["UnitIsPVPSanctuary"] = noIndentEffect,
	["UnitIsPartyLeader"] = noIndentEffect,
	["UnitIsPlayer"] = noIndentEffect,
	["UnitIsPossessed"] = noIndentEffect,
	["UnitIsRaidOfficer"] = noIndentEffect,
	["UnitIsSameServer"] = noIndentEffect,
	["UnitIsSilenced"] = noIndentEffect,
	["UnitIsTalking"] = noIndentEffect,
	["UnitIsTapped"] = noIndentEffect,
	["UnitIsTappedByAllThreatList"] = noIndentEffect,
	["UnitIsTappedByPlayer"] = noIndentEffect,
	["UnitIsTrivial"] = noIndentEffect,
	["UnitIsUnit"] = noIndentEffect,
	["UnitIsVisible"] = noIndentEffect,
	["UnitLevel"] = noIndentEffect,
	["UnitMana"] = noIndentEffect,
	["UnitManaMax"] = noIndentEffect,
	["UnitName"] = noIndentEffect,
	["UnitOnTaxi"] = noIndentEffect,
	["UnitPVPName"] = noIndentEffect,
	["UnitPVPRank"] = noIndentEffect,
	["UnitPlayerControlled"] = noIndentEffect,
	["UnitPlayerOrPetInParty"] = noIndentEffect,
	["UnitPlayerOrPetInRaid"] = noIndentEffect,
	["UnitPopup_HideButtons"] = noIndentEffect,
	["UnitPopup_OnClick"] = noIndentEffect,
	["UnitPopup_OnUpdate"] = noIndentEffect,
	["UnitPopup_ShowMenu"] = noIndentEffect,
	["UnitPower"] = noIndentEffect,
	["UnitPowerMax"] = noIndentEffect,
	["UnitPowerType"] = noIndentEffect,
	["UnitRace"] = noIndentEffect,
	["UnitRangedAttack"] = noIndentEffect,
	["UnitRangedAttackPower"] = noIndentEffect,
	["UnitRangedDamage"] = noIndentEffect,
	["UnitReaction"] = noIndentEffect,
	["UnitResistance"] = noIndentEffect,
	["UnitSelectionColor"] = noIndentEffect,
	["UnitSex"] = noIndentEffect,
	["UnitStat"] = noIndentEffect,
	["UnitSwitchToVehicleSeat"] = noIndentEffect,
	["UnitTargetsVehicleInRaidUI"] = noIndentEffect,
	["UnitThreatSituation"] = noIndentEffect,
	["UnitUsingVehicle"] = noIndentEffect,
	["UnitVehicleSeatCount"] = noIndentEffect,
	["UnitVehicleSeatInfo"] = noIndentEffect,
	["UnitVehicleSkin"] = noIndentEffect,
	["UnitWatchRegistered"] = noIndentEffect,
	["UnitXP"] = noIndentEffect,
	["UnitXPMax"] = noIndentEffect,
	["UnlockMultiCastActionBar"] = noIndentEffect,
	["UnlockPetActionBar"] = noIndentEffect,
	["UnregisterAutoHide"] = noIndentEffect,
	["UnregisterStateDriver"] = noIndentEffect,
	["UnregisterUnitWatch"] = noIndentEffect,
	["UnstablePet"] = noIndentEffect,
	["UpdateAddOnCPUUsage"] = noIndentEffect,
	["UpdateAddOnMemoryUsage"] = noIndentEffect,
	["UpdateBagButtonHighlight"] = noIndentEffect,
	["UpdateBagSlotStatus"] = noIndentEffect,
	["UpdateCoinPickupFrame"] = noIndentEffect,
	["UpdateGMTicket"] = noIndentEffect,
	["UpdateInventoryAlertStatus"] = noIndentEffect,
	["UpdateMapHighlight"] = noIndentEffect,
	["UpdateMenuBarTop"] = noIndentEffect,
	["UpdateMicroButtons"] = noIndentEffect,
	["UpdatePaperdollStats"] = noIndentEffect,
	["UpdatePartyMemberBackground"] = noIndentEffect,
	["UpdateSpells"] = noIndentEffect,
	["UpdateStackSplitFrame"] = noIndentEffect,
	["UpdateSubCategoryEnabledState"] = noIndentEffect,
	["UpdateUIPanelPositions"] = noIndentEffect,
	["UpdateWorldMapArrowFrames"] = noIndentEffect,
	["UploadSettings"] = noIndentEffect,
	["UseAction"] = noIndentEffect,
	["UseContainerItem"] = noIndentEffect,
	["UseEquipmentSet"] = noIndentEffect,
	["UseInventoryItem"] = noIndentEffect,
	["UseItemByName"] = noIndentEffect,
	["UseQuestLogSpecialItem"] = noIndentEffect,
	["UseSoulstone"] = noIndentEffect,
	["UsesGUID"] = noIndentEffect,
	["ValidateFramePosition"] = noIndentEffect,
	["VehicleActionButton_OnClick"] = noIndentEffect,
	["VehicleAimDecrement"] = noIndentEffect,
	["VehicleAimDownStart"] = noIndentEffect,
	["VehicleAimDownStop"] = noIndentEffect,
	["VehicleAimGetAngle"] = noIndentEffect,
	["VehicleAimGetNormAngle"] = noIndentEffect,
	["VehicleAimGetNormPower"] = noIndentEffect,
	["VehicleAimIncrement"] = noIndentEffect,
	["VehicleAimRequestAngle"] = noIndentEffect,
	["VehicleAimRequestNormAngle"] = noIndentEffect,
	["VehicleAimSetNormPower"] = noIndentEffect,
	["VehicleAimUpStart"] = noIndentEffect,
	["VehicleAimUpStop"] = noIndentEffect,
	["VehicleCameraZoomIn"] = noIndentEffect,
	["VehicleCameraZoomOut"] = noIndentEffect,
	["VehicleExit"] = noIndentEffect,
	["VehicleMenuBarPitch_OnClick"] = noIndentEffect,
	["VehicleMenuBarPitch_OnEvent"] = noIndentEffect,
	["VehicleMenuBarPitch_OnLoad"] = noIndentEffect,
	["VehicleMenuBarPitch_SetValue"] = noIndentEffect,
	["VehicleMenuBarStatusBars_ShowTooltip"] = noIndentEffect,
	["VehicleMenuBar_MoveMicroButtons"] = noIndentEffect,
	["VehicleMenuBar_OnEvent"] = noIndentEffect,
	["VehicleMenuBar_OnLoad"] = noIndentEffect,
	["VehicleMenuBar_ReleaseSkins"] = noIndentEffect,
	["VehicleMenuBar_SetSkin"] = noIndentEffect,
	["VehicleMenuBar_UpdateActionBars"] = noIndentEffect,
	["VehicleNextSeat"] = noIndentEffect,
	["VehiclePrevSeat"] = noIndentEffect,
	["VehicleSeatIndicatorButton_OnClick"] = noIndentEffect,
	["VehicleSeatIndicatorButton_OnEnter"] = noIndentEffect,
	["VehicleSeatIndicatorButton_OnLeave"] = noIndentEffect,
	["VehicleSeatIndicatorDropDown_Initialize"] = noIndentEffect,
	["VehicleSeatIndicatorDropDown_OnClick"] = noIndentEffect,
	["VehicleSeatIndicator_OnEvent"] = noIndentEffect,
	["VehicleSeatIndicator_OnLoad"] = noIndentEffect,
	["VehicleSeatIndicator_SetUpVehicle"] = noIndentEffect,
	["VehicleSeatIndicator_UnloadTextures"] = noIndentEffect,
	["VehicleSeatIndicator_Update"] = noIndentEffect,
	["VideoOptionsEffectsPanelSlider_OnValueChanged"] = noIndentEffect,
	["VideoOptionsEffectsPanel_Default"] = noIndentEffect,
	["VideoOptionsEffectsPanel_FixupQualityLevels"] = noIndentEffect,
	["VideoOptionsEffectsPanel_GetVideoQuality"] = noIndentEffect,
	["VideoOptionsEffectsPanel_OnEvent"] = noIndentEffect,
	["VideoOptionsEffectsPanel_OnLoad"] = noIndentEffect,
	["VideoOptionsEffectsPanel_Refresh"] = noIndentEffect,
	["VideoOptionsEffectsPanel_SetCustomQuality"] = noIndentEffect,
	["VideoOptionsEffectsPanel_SetPresetQuality"] = noIndentEffect,
	["VideoOptionsEffectsPanel_SetVideoQuality"] = noIndentEffect,
	["VideoOptionsEffectsPanel_SetVideoQualityLabels"] = noIndentEffect,
	["VideoOptionsEffectsPanel_UpdateVideoQuality"] = noIndentEffect,
	["VideoOptionsFrameCancel_OnClick"] = noIndentEffect,
	["VideoOptionsFrameDefault_OnClick"] = noIndentEffect,
	["VideoOptionsFrameOkay_OnClick"] = noIndentEffect,
	["VideoOptionsFrame_OnHide"] = noIndentEffect,
	["VideoOptionsFrame_OnLoad"] = noIndentEffect,
	["VideoOptionsFrame_SetAllToDefaults"] = noIndentEffect,
	["VideoOptionsFrame_SetCurrentToDefaults"] = noIndentEffect,
	["VideoOptionsFrame_Toggle"] = noIndentEffect,
	["VideoOptionsPanel_Cancel"] = noIndentEffect,
	["VideoOptionsPanel_Default"] = noIndentEffect,
	["VideoOptionsPanel_Okay"] = noIndentEffect,
	["VideoOptionsPanel_OnLoad"] = noIndentEffect,
	["VideoOptionsResolutionPanelMultiSampleDropDown_Initialize"] = noIndentEffect,
	["VideoOptionsResolutionPanelMultiSampleDropDown_OnClick"] = noIndentEffect,
	["VideoOptionsResolutionPanelMultiSampleDropDown_OnLoad"] = noIndentEffect,
	["VideoOptionsResolutionPanelRefreshDropDown_Initialize"] = noIndentEffect,
	["VideoOptionsResolutionPanelRefreshDropDown_OnClick"] = noIndentEffect,
	["VideoOptionsResolutionPanelRefreshDropDown_OnLoad"] = noIndentEffect,
	["VideoOptionsResolutionPanelResolutionDropDown_Initialize"] = noIndentEffect,
	["VideoOptionsResolutionPanelResolutionDropDown_LoadResolutions"] = noIndentEffect,
	["VideoOptionsResolutionPanelResolutionDropDown_OnClick"] = noIndentEffect,
	["VideoOptionsResolutionPanelResolutionDropDown_OnLoad"] = noIndentEffect,
	["VideoOptionsResolutionPanel_Default"] = noIndentEffect,
	["VideoOptionsResolutionPanel_GetMultisampleFormats"] = noIndentEffect,
	["VideoOptionsResolutionPanel_GetRefreshRates"] = noIndentEffect,
	["VideoOptionsResolutionPanel_OnEvent"] = noIndentEffect,
	["VideoOptionsResolutionPanel_OnLoad"] = noIndentEffect,
	["VideoOptionsResolutionPanel_Refresh"] = noIndentEffect,
	["VideoOptionsResolutionPanel_RefreshGammaControls"] = noIndentEffect,
	["VideoOptionsResolutionPanel_SetGamma"] = noIndentEffect,
	["VideoOptionsResolutionPanel_SetWindowed"] = noIndentEffect,
	["VideoOptionsStereoPanel_Default"] = noIndentEffect,
	["VideoOptionsStereoPanel_OnEvent"] = noIndentEffect,
	["VideoOptionsStereoPanel_OnLoad"] = noIndentEffect,
	["VoiceChatShineFadeIn"] = noIndentEffect,
	["VoiceChatShineFadeOut"] = noIndentEffect,
	["VoiceChatTalkers_CanHide"] = noIndentEffect,
	["VoiceChatTalkers_CreateButtons"] = noIndentEffect,
	["VoiceChatTalkers_FadeOut"] = noIndentEffect,
	["VoiceChatTalkers_OnEvent"] = noIndentEffect,
	["VoiceChatTalkers_OnLoad"] = noIndentEffect,
	["VoiceChatTalkers_OnUpdate"] = noIndentEffect,
	["VoiceChatTalkers_ResizeFrame"] = noIndentEffect,
	["VoiceChatTalkers_Update"] = noIndentEffect,
	["VoiceChat_ActivatePrimaryCaptureCallback"] = noIndentEffect,
	["VoiceChat_Animate"] = noIndentEffect,
	["VoiceChat_GetCurrentMicrophoneSignalLevel"] = noIndentEffect,
	["VoiceChat_IsPlayingLoopbackSound"] = noIndentEffect,
	["VoiceChat_IsRecordingLoopbackSound"] = noIndentEffect,
	["VoiceChat_OnUpdate"] = noIndentEffect,
	["VoiceChat_PlayLoopbackSound"] = noIndentEffect,
	["VoiceChat_RecordLoopbackSound"] = noIndentEffect,
	["VoiceChat_StartCapture"] = noIndentEffect,
	["VoiceChat_StopCapture"] = noIndentEffect,
	["VoiceChat_StopPlayingLoopbackSound"] = noIndentEffect,
	["VoiceChat_StopRecordingLoopbackSound"] = noIndentEffect,
	["VoiceChat_Toggle"] = noIndentEffect,
	["VoiceEnumerateCaptureDevices"] = noIndentEffect,
	["VoiceEnumerateOutputDevices"] = noIndentEffect,
	["VoiceGetCurrentCaptureDevice"] = noIndentEffect,
	["VoiceGetCurrentOutputDevice"] = noIndentEffect,
	["VoiceIsDisabledByClient"] = noIndentEffect,
	["VoiceMacroMenu_Click"] = noIndentEffect,
	["VoiceMacroMenu_OnLoad"] = noIndentEffect,
	["VoicePushToTalkStart"] = noIndentEffect,
	["VoicePushToTalkStop"] = noIndentEffect,
	["VoiceSelectCaptureDevice"] = noIndentEffect,
	["VoiceSelectOutputDevice"] = noIndentEffect,
	["WatchFrameDropDown_Initialize"] = noIndentEffect,
	["WatchFrameDropDown_OnHide"] = noIndentEffect,
	["WatchFrameDropDown_OnLoad"] = noIndentEffect,
	["WatchFrameHeaderDropDown_Initialize"] = noIndentEffect,
	["WatchFrameHeaderDropDown_OnLoad"] = noIndentEffect,
	["WatchFrameHeader_OnClick"] = noIndentEffect,
	["WatchFrameItem_OnClick"] = noIndentEffect,
	["WatchFrameItem_OnEnter"] = noIndentEffect,
	["WatchFrameItem_OnEvent"] = noIndentEffect,
	["WatchFrameItem_OnHide"] = noIndentEffect,
	["WatchFrameItem_OnLoad"] = noIndentEffect,
	["WatchFrameItem_OnShow"] = noIndentEffect,
	["WatchFrameItem_OnUpdate"] = noIndentEffect,
	["WatchFrameItem_UpdateCooldown"] = noIndentEffect,
	["WatchFrameLineTemplate_OnLoad"] = noIndentEffect,
	["WatchFrameLines_AddUpdateFunction"] = noIndentEffect,
	["WatchFrameLines_OnUpdate"] = noIndentEffect,
	["WatchFrameLines_RemoveUpdateFunction"] = noIndentEffect,
	["WatchFrameLinkButtonTemplate_Highlight"] = noIndentEffect,
	["WatchFrameLinkButtonTemplate_OnClick"] = noIndentEffect,
	["WatchFrameLinkButtonTemplate_OnLeftClick"] = noIndentEffect,
	["WatchFrameQuestPOI_OnClick"] = noIndentEffect,
	["WatchFrame_AbandonQuest"] = noIndentEffect,
	["WatchFrame_AddObjectiveHandler"] = noIndentEffect,
	["WatchFrame_ClearDisplay"] = noIndentEffect,
	["WatchFrame_Collapse"] = noIndentEffect,
	["WatchFrame_CollapseExpandButton_OnClick"] = noIndentEffect,
	["WatchFrame_DisplayQuestTimers"] = noIndentEffect,
	["WatchFrame_DisplayTrackedAchievements"] = noIndentEffect,
	["WatchFrame_DisplayTrackedQuests"] = noIndentEffect,
	["WatchFrame_Expand"] = noIndentEffect,
	["WatchFrame_GetCurrentMapQuests"] = noIndentEffect,
	["WatchFrame_GetVisibleIndex"] = noIndentEffect,
	["WatchFrame_HandleDisplayQuestTimers"] = noIndentEffect,
	["WatchFrame_HandleDisplayTrackedAchievements"] = noIndentEffect,
	["WatchFrame_HandleQuestTimerUpdate"] = noIndentEffect,
	["WatchFrame_MoveQuest"] = noIndentEffect,
	["WatchFrame_OnEvent"] = noIndentEffect,
	["WatchFrame_OnLoad"] = noIndentEffect,
	["WatchFrame_OnSizeChanged"] = noIndentEffect,
	["WatchFrame_OnUpdate"] = noIndentEffect,
	["WatchFrame_OpenAchievementFrame"] = noIndentEffect,
	["WatchFrame_OpenMapToQuest"] = noIndentEffect,
	["WatchFrame_OpenQuestLog"] = noIndentEffect,
	["WatchFrame_QuestTimerUpdateFunction"] = noIndentEffect,
	["WatchFrame_RemoveObjectiveHandler"] = noIndentEffect,
	["WatchFrame_ReverseQuestObjective"] = noIndentEffect,
	["WatchFrame_SetFilter"] = noIndentEffect,
	["WatchFrame_SetLine"] = noIndentEffect,
	["WatchFrame_SetSorting"] = noIndentEffect,
	["WatchFrame_SetWidth"] = noIndentEffect,
	["WatchFrame_ShareQuest"] = noIndentEffect,
	["WatchFrame_StopTrackingAchievement"] = noIndentEffect,
	["WatchFrame_StopTrackingQuest"] = noIndentEffect,
	["WatchFrame_Update"] = noIndentEffect,
	["WatchFrame_UpdateTimedAchievements"] = noIndentEffect,
	["WhoFrameColumn_SetWidth"] = noIndentEffect,
	["WhoFrameDropDownButton_OnClick"] = noIndentEffect,
	["WhoFrameDropDown_Initialize"] = noIndentEffect,
	["WhoFrameDropDown_OnLoad"] = noIndentEffect,
	["WhoFrameEditBox_OnEnterPressed"] = noIndentEffect,
	["WhoFrame_GetDefaultWhoCommand"] = noIndentEffect,
	["WhoList_Update"] = noIndentEffect,
	["WintergraspTimer_OnLoad"] = noIndentEffect,
	["WintergraspTimer_OnUpdate"] = noIndentEffect,
	["WithdrawGoldEditBox_Update"] = noIndentEffect,
	["WithdrawGuildBankMoney"] = noIndentEffect,
	["WorldFrame_OnLoad"] = noIndentEffect,
	["WorldFrame_OnUpdate"] = noIndentEffect,
	["WorldMapBlobFrame_CalculateHitTranslations"] = noIndentEffect,
	["WorldMapBlobFrame_OnLoad"] = noIndentEffect,
	["WorldMapBlobFrame_OnUpdate"] = noIndentEffect,
	["WorldMapButton_OnClick"] = noIndentEffect,
	["WorldMapButton_OnUpdate"] = noIndentEffect,
	["WorldMapContinentButton_OnClick"] = noIndentEffect,
	["WorldMapContinentsDropDown_Initialize"] = noIndentEffect,
	["WorldMapContinentsDropDown_Update"] = noIndentEffect,
	["WorldMapFrame_ChangeOpacity"] = noIndentEffect,
	["WorldMapFrame_ClearQuestPOIs"] = noIndentEffect,
	["WorldMapFrame_DisplayQuestPOI"] = noIndentEffect,
	["WorldMapFrame_DisplayQuests"] = noIndentEffect,
	["WorldMapFrame_GetQuestFrame"] = noIndentEffect,
	["WorldMapFrame_LoadContinents"] = noIndentEffect,
	["WorldMapFrame_LoadZones"] = noIndentEffect,
	["WorldMapFrame_OnEvent"] = noIndentEffect,
	["WorldMapFrame_OnHide"] = noIndentEffect,
	["WorldMapFrame_OnKeyDown"] = noIndentEffect,
	["WorldMapFrame_OnLoad"] = noIndentEffect,
	["WorldMapFrame_OnShow"] = noIndentEffect,
	["WorldMapFrame_OnUpdate"] = noIndentEffect,
	["WorldMapFrame_PingPlayerPosition"] = noIndentEffect,
	["WorldMapFrame_ResetFrameLevels"] = noIndentEffect,
	["WorldMapFrame_ResetQuestColors"] = noIndentEffect,
	["WorldMapFrame_ReverseQuestObjective"] = noIndentEffect,
	["WorldMapFrame_SaveOpacity"] = noIndentEffect,
	["WorldMapFrame_SelectQuestById"] = noIndentEffect,
	["WorldMapFrame_SelectQuestFrame"] = noIndentEffect,
	["WorldMapFrame_SetFullMapView"] = noIndentEffect,
	["WorldMapFrame_SetMapName"] = noIndentEffect,
	["WorldMapFrame_SetMiniMode"] = noIndentEffect,
	["WorldMapFrame_SetOpacity"] = noIndentEffect,
	["WorldMapFrame_SetPOIMaxBounds"] = noIndentEffect,
	["WorldMapFrame_SetQuestMapView"] = noIndentEffect,
	["WorldMapFrame_ToggleAdvanced"] = noIndentEffect,
	["WorldMapFrame_ToggleWindowSize"] = noIndentEffect,
	["WorldMapFrame_Update"] = noIndentEffect,
	["WorldMapFrame_UpdateMap"] = noIndentEffect,
	["WorldMapFrame_UpdateQuests"] = noIndentEffect,
	["WorldMapFrame_UpdateUnits"] = noIndentEffect,
	["WorldMapLevelButton_OnClick"] = noIndentEffect,
	["WorldMapLevelDown_OnClick"] = noIndentEffect,
	["WorldMapLevelDropDown_Initialize"] = noIndentEffect,
	["WorldMapLevelDropDown_Update"] = noIndentEffect,
	["WorldMapLevelUp_OnClick"] = noIndentEffect,
	["WorldMapPOI_OnClick"] = noIndentEffect,
	["WorldMapPOI_OnEnter"] = noIndentEffect,
	["WorldMapPOI_OnLeave"] = noIndentEffect,
	["WorldMapQuestFrame_OnEnter"] = noIndentEffect,
	["WorldMapQuestFrame_OnLeave"] = noIndentEffect,
	["WorldMapQuestFrame_OnMouseDown"] = noIndentEffect,
	["WorldMapQuestFrame_OnMouseUp"] = noIndentEffect,
	["WorldMapQuestFrame_UpdateMouseOver"] = noIndentEffect,
	["WorldMapQuestPOI_OnClick"] = noIndentEffect,
	["WorldMapQuestPOI_OnEnter"] = noIndentEffect,
	["WorldMapQuestPOI_OnLeave"] = noIndentEffect,
	["WorldMapQuestPOI_SetTooltip"] = noIndentEffect,
	["WorldMapQuestShowObjectives_AdjustPosition"] = noIndentEffect,
	["WorldMapQuestShowObjectives_Toggle"] = noIndentEffect,
	["WorldMapTitleButton_OnClick"] = noIndentEffect,
	["WorldMapTitleButton_OnDragStart"] = noIndentEffect,
	["WorldMapTitleButton_OnDragStop"] = noIndentEffect,
	["WorldMapTitleButton_OnLoad"] = noIndentEffect,
	["WorldMapTitleDropDown_Initialize"] = noIndentEffect,
	["WorldMapTitleDropDown_ToggleLock"] = noIndentEffect,
	["WorldMapTitleDropDown_ToggleOpacity"] = noIndentEffect,
	["WorldMapTrackQuest_Toggle"] = noIndentEffect,
	["WorldMapUnitDropDown_Initialize"] = noIndentEffect,
	["WorldMapUnitDropDown_OnClick"] = noIndentEffect,
	["WorldMapUnitDropDown_ReportAll_OnClick"] = noIndentEffect,
	["WorldMapUnit_OnEnter"] = noIndentEffect,
	["WorldMapUnit_OnEvent"] = noIndentEffect,
	["WorldMapUnit_OnHide"] = noIndentEffect,
	["WorldMapUnit_OnLeave"] = noIndentEffect,
	["WorldMapUnit_OnLoad"] = noIndentEffect,
	["WorldMapUnit_OnMouseUp"] = noIndentEffect,
	["WorldMapUnit_OnShow"] = noIndentEffect,
	["WorldMapUnit_Update"] = noIndentEffect,
	["WorldMapZoneButton_OnClick"] = noIndentEffect,
	["WorldMapZoneDropDown_Initialize"] = noIndentEffect,
	["WorldMapZoneDropDown_Update"] = noIndentEffect,
	["WorldMapZoneMinimapDropDown_GetText"] = noIndentEffect,
	["WorldMapZoneMinimapDropDown_Initialize"] = noIndentEffect,
	["WorldMapZoneMinimapDropDown_OnClick"] = noIndentEffect,
	["WorldMapZoneMinimapDropDown_Update"] = noIndentEffect,
	["WorldMapZoomOutButton_OnClick"] = noIndentEffect,
	["WorldMap_ClearTextures"] = noIndentEffect,
	["WorldMap_CreatePOI"] = noIndentEffect,
	["WorldMap_GetPOITextureCoords"] = noIndentEffect,
	["WorldMap_GetVehicleTexture"] = noIndentEffect,
	["WorldMap_LoadTextures"] = noIndentEffect,
	["WorldMap_OpenToQuest"] = noIndentEffect,
	["WorldMap_ToggleSizeDown"] = noIndentEffect,
	["WorldMap_ToggleSizeUp"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_FilterChatMsgLoot"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_FilterChatMsgSystem"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_OnEvent"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_OnLoad"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_OnUpdate"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_StartBGChatFilter"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_StopBGChatFilter"] = noIndentEffect,
	["WorldStateAlwaysUpFrame_Update"] = noIndentEffect,
	["WorldStateFrame_CanShowBattlefieldMinimap"] = noIndentEffect,
	["WorldStateFrame_ToggleBattlefieldMinimap"] = noIndentEffect,
	["WorldStateScoreFrameTab_OnClick"] = noIndentEffect,
	["WorldStateScoreFrame_OnLoad"] = noIndentEffect,
	["WorldStateScoreFrame_Resize"] = noIndentEffect,
	["WorldStateScoreFrame_Update"] = noIndentEffect,
	["ZoneText_OnEvent"] = noIndentEffect,
	["ZoneText_OnLoad"] = noIndentEffect,
	["ZoomOut"] = noIndentEffect,
	["_GetPlayerDifficultyMenuOptions"] = noIndentEffect,
	["debugbreak"] = noIndentEffect,
	["debugdump"] = noIndentEffect,
	["debughook"] = noIndentEffect,
	["debuginfo"] = noIndentEffect,
	["debugload"] = noIndentEffect,
	["debuglocals"] = noIndentEffect,
	["debugprint"] = noIndentEffect,
	["debugprofilestart"] = noIndentEffect,
	["debugprofilestop"] = noIndentEffect,
	["debugstack"] = noIndentEffect,
	["debugtimestamp"] = noIndentEffect,
	["forceinsecure"] = noIndentEffect,
	["geterrorhandler"] = noIndentEffect,
	["getglobal"] = noIndentEffect,
	["getprinthandler"] = noIndentEffect,
	["hooksecurefunc"] = noIndentEffect,
	["issecure"] = noIndentEffect,
	["issecurevariable"] = noIndentEffect,
	["message"] = noIndentEffect,
	["newproxy"] = noIndentEffect,
	["scrub"] = noIndentEffect,
	["securecall"] = noIndentEffect,
	["seterrorhandler"] = noIndentEffect,
	["setglobal"] = noIndentEffect,
	["setprinthandler"] = noIndentEffect,
	["strjoin"] = noIndentEffect,
	["strlenutf8"] = noIndentEffect,
	["strreplace"] = noIndentEffect,
	["strrev"] = noIndentEffect,
	["strsplit"] = noIndentEffect,
	["strtrim"] = noIndentEffect,
	["tContains"] = noIndentEffect,
	["tDeleteItem"] = noIndentEffect,
	["updateContainerFrameAnchors"] = noIndentEffect,
	["wipe"] = noIndentEffect,
	-- Methods and what not
	["AddDoubleLine"] = noIndentEffect,
	["AddFontStrings"] = noIndentEffect,
	["AddHistoryLine"] = noIndentEffect,
	["AddLine"] = noIndentEffect,
	["AddMessage"] = noIndentEffect,
	["AddTexture"] = noIndentEffect,
	["AdvanceTime"] = noIndentEffect,
	["AllowAttributeChanges"] = noIndentEffect,
	["AppendText"] = noIndentEffect,
	["AtBottom"] = noIndentEffect,
	["AtTop"] = noIndentEffect,
	["CanChangeAttribute"] = noIndentEffect,
	["CanChangeProtectedState"] = noIndentEffect,
	["CanNonSpaceWrap"] = noIndentEffect,
	["CanSaveTabardNow"] = noIndentEffect,
	["CanWordWrap"] = noIndentEffect,
	["Clear"] = noIndentEffect,
	["ClearAllPoints"] = noIndentEffect,
	["ClearFocus"] = noIndentEffect,
	["ClearFog"] = noIndentEffect,
	["ClearHistory"] = noIndentEffect,
	["ClearLines"] = noIndentEffect,
	["ClearModel"] = noIndentEffect,
	["Click"] = noIndentEffect,
	["CopyFontObject"] = noIndentEffect,
	["CreateAnimation"] = noIndentEffect,
	["CreateAnimationGroup"] = noIndentEffect,
	["CreateControlPoint"] = noIndentEffect,
	["CreateFontString"] = noIndentEffect,
	["CreateTexture"] = noIndentEffect,
	["CreateTitleRegion"] = noIndentEffect,
	["CycleVariation"] = noIndentEffect,
	["Disable"] = noIndentEffect,
	["DisableDrawLayer"] = noIndentEffect,
	["DrawQuestBlob"] = noIndentEffect,
	["Dress"] = noIndentEffect,
	["Enable"] = noIndentEffect,
	["EnableDrawLayer"] = noIndentEffect,
	["EnableJoystick"] = noIndentEffect,
	["EnableKeyboard"] = noIndentEffect,
	["EnableMerging"] = noIndentEffect,
	["EnableMouse"] = noIndentEffect,
	["EnableMouseWheel"] = noIndentEffect,
	["EnableSmoothing"] = noIndentEffect,
	["EnableSubtitles"] = noIndentEffect,
	["FadeOut"] = noIndentEffect,
	["Finish"] = noIndentEffect,
	["GetAlpha"] = noIndentEffect,
	["GetAltArrowKeyMode"] = noIndentEffect,
	["GetAnchorType"] = noIndentEffect,
	["GetAnimationGroups"] = noIndentEffect,
	["GetAnimations"] = noIndentEffect,
	["GetAttribute"] = noIndentEffect,
	["GetBackdrop"] = noIndentEffect,
	["GetBackdropBorderColor"] = noIndentEffect,
	["GetBackdropColor"] = noIndentEffect,
	["GetBlendMode"] = noIndentEffect,
	["GetBlinkSpeed"] = noIndentEffect,
	["GetBottom"] = noIndentEffect,
	["GetBoundsRect"] = noIndentEffect,
	["GetButtonState"] = noIndentEffect,
	["GetCenter"] = noIndentEffect,
	["GetChange"] = noIndentEffect,
	["GetChecked"] = noIndentEffect,
	["GetCheckedTexture"] = noIndentEffect,
	["GetChildren"] = noIndentEffect,
	["GetClampRectInsets"] = noIndentEffect,
	["GetColorHSV"] = noIndentEffect,
	["GetColorRGB"] = noIndentEffect,
	["GetColorValueTexture"] = noIndentEffect,
	["GetColorValueThumbTexture"] = noIndentEffect,
	["GetColorWheelTexture"] = noIndentEffect,
	["GetColorWheelThumbTexture"] = noIndentEffect,
	["GetControlPoints"] = noIndentEffect,
	["GetCurrentLine"] = noIndentEffect,
	["GetCurrentScroll"] = noIndentEffect,
	["GetCursorPosition"] = noIndentEffect,
	["GetCurve"] = noIndentEffect,
	["GetDegrees"] = noIndentEffect,
	["GetDepth"] = noIndentEffect,
	["GetDisabledCheckedTexture"] = noIndentEffect,
	["GetDisabledFontObject"] = noIndentEffect,
	["GetDisabledTexture"] = noIndentEffect,
	["GetDontSavePosition"] = noIndentEffect,
	["GetDrawEdge"] = noIndentEffect,
	["GetDrawLayer"] = noIndentEffect,
	["GetDuration"] = noIndentEffect,
	["GetEffectiveAlpha"] = noIndentEffect,
	["GetEffectiveDepth"] = noIndentEffect,
	["GetEffectiveScale"] = noIndentEffect,
	["GetElapsed"] = noIndentEffect,
	["GetEndDelay"] = noIndentEffect,
	["GetFacing"] = noIndentEffect,
	["GetFadeDuration"] = noIndentEffect,
	["GetFading"] = noIndentEffect,
	["GetFieldSize"] = noIndentEffect,
	["GetFogColor"] = noIndentEffect,
	["GetFogFar"] = noIndentEffect,
	["GetFogNear"] = noIndentEffect,
	["GetFont"] = noIndentEffect,
	["GetFontObject"] = noIndentEffect,
	["GetFontString"] = noIndentEffect,
	["GetFrameLevel"] = noIndentEffect,
	["GetFrameStrata"] = noIndentEffect,
	["GetHeight"] = noIndentEffect,
	["GetHighlightFontObject"] = noIndentEffect,
	["GetHighlightTexture"] = noIndentEffect,
	["GetHistoryLines"] = noIndentEffect,
	["GetHitRectInsets"] = noIndentEffect,
	["GetHorizTile"] = noIndentEffect,
	["GetHorizontalScroll"] = noIndentEffect,
	["GetHorizontalScrollRange"] = noIndentEffect,
	["GetHyperlinkFormat"] = noIndentEffect,
	["GetHyperlinksEnabled"] = noIndentEffect,
	["GetID"] = noIndentEffect,
	["GetIndentedWordWrap"] = noIndentEffect,
	["GetInitialOffset"] = noIndentEffect,
	["GetInputLanguage"] = noIndentEffect,
	["GetInsertMode"] = noIndentEffect,
	["GetItem"] = noIndentEffect,
	["GetJustifyH"] = noIndentEffect,
	["GetJustifyV"] = noIndentEffect,
	["GetLeft"] = noIndentEffect,
	["GetLight"] = noIndentEffect,
	["GetLoopState"] = noIndentEffect,
	["GetLooping"] = noIndentEffect,
	["GetLowerBackgroundFileName"] = noIndentEffect,
	["GetLowerEmblemFileName"] = noIndentEffect,
	["GetLowerEmblemTexture"] = noIndentEffect,
	["GetMaxBytes"] = noIndentEffect,
	["GetMaxFramerate"] = noIndentEffect,
	["GetMaxLetters"] = noIndentEffect,
	["GetMaxLines"] = noIndentEffect,
	["GetMaxOrder"] = noIndentEffect,
	["GetMaxResize"] = noIndentEffect,
	["GetMessageInfo"] = noIndentEffect,
	["GetMinMaxValues"] = noIndentEffect,
	["GetMinResize"] = noIndentEffect,
	["GetMinimumWidth"] = noIndentEffect,
	["GetModel"] = noIndentEffect,
	["GetModelScale"] = noIndentEffect,
	["GetMotionScriptsWhileDisabled"] = noIndentEffect,
	["GetName"] = noIndentEffect,
	["GetNonBlocking"] = noIndentEffect,
	["GetNormalFontObject"] = noIndentEffect,
	["GetNormalTexture"] = noIndentEffect,
	["GetNumChildren"] = noIndentEffect,
	["GetNumLetters"] = noIndentEffect,
	["GetNumLinesDisplayed"] = noIndentEffect,
	["GetNumMessages"] = noIndentEffect,
	["GetNumPoints"] = noIndentEffect,
	["GetNumRegions"] = noIndentEffect,
	["GetNumTooltips"] = noIndentEffect,
	["GetNumber"] = noIndentEffect,
	["GetObjectType"] = noIndentEffect,
	["GetOffset"] = noIndentEffect,
	["GetOrder"] = noIndentEffect,
	["GetOrientation"] = noIndentEffect,
	["GetOrigin"] = noIndentEffect,
	["GetOwner"] = noIndentEffect,
	["GetPadding"] = noIndentEffect,
	["GetParent"] = noIndentEffect,
	["GetPingPosition"] = noIndentEffect,
	["GetPoint"] = noIndentEffect,
	["GetPosition"] = noIndentEffect,
	["GetProgress"] = noIndentEffect,
	["GetProgressWithDelay"] = noIndentEffect,
	["GetPushedTextOffset"] = noIndentEffect,
	["GetPushedTexture"] = noIndentEffect,
	["GetRadians"] = noIndentEffect,
	["GetRect"] = noIndentEffect,
	["GetRegionParent"] = noIndentEffect,
	["GetRegions"] = noIndentEffect,
	["GetReverse"] = noIndentEffect,
	["GetRight"] = noIndentEffect,
	["GetRotatesTexture"] = noIndentEffect,
	["GetScale"] = noIndentEffect,
	["GetScript"] = noIndentEffect,
	["GetScrollChild"] = noIndentEffect,
	["GetShadowColor"] = noIndentEffect,
	["GetShadowOffset"] = noIndentEffect,
	["GetSize"] = noIndentEffect,
	["GetSmoothProgress"] = noIndentEffect,
	["GetSmoothing"] = noIndentEffect,
	["GetSpacing"] = noIndentEffect,
	["GetSpell"] = noIndentEffect,
	["GetStartDelay"] = noIndentEffect,
	["GetStatusBarColor"] = noIndentEffect,
	["GetStatusBarTexture"] = noIndentEffect,
	["GetStringHeight"] = noIndentEffect,
	["GetStringWidth"] = noIndentEffect,
	["GetTexCoord"] = noIndentEffect,
	["GetText"] = noIndentEffect,
	["GetTextColor"] = noIndentEffect,
	["GetTextHeight"] = noIndentEffect,
	["GetTextInsets"] = noIndentEffect,
	["GetTextWidth"] = noIndentEffect,
	["GetTexture"] = noIndentEffect,
	["GetThumbTexture"] = noIndentEffect,
	["GetTimeVisible"] = noIndentEffect,
	["GetTitleRegion"] = noIndentEffect,
	["GetTooltipIndex"] = noIndentEffect,
	["GetTop"] = noIndentEffect,
	["GetUTF8CursorPosition"] = noIndentEffect,
	["GetUnit"] = noIndentEffect,
	["GetUpperBackgroundFileName"] = noIndentEffect,
	["GetUpperEmblemFileName"] = noIndentEffect,
	["GetUpperEmblemTexture"] = noIndentEffect,
	["GetValue"] = noIndentEffect,
	["GetValueStep"] = noIndentEffect,
	["GetVertTile"] = noIndentEffect,
	["GetVertexColor"] = noIndentEffect,
	["GetVerticalScroll"] = noIndentEffect,
	["GetVerticalScrollRange"] = noIndentEffect,
	["GetWidth"] = noIndentEffect,
	["GetZoom"] = noIndentEffect,
	["GetZoomLevels"] = noIndentEffect,
	["HasFocus"] = noIndentEffect,
	["HasScript"] = noIndentEffect,
	["Hide"] = noIndentEffect,
	["HighlightText"] = noIndentEffect,
	["HookScript"] = noIndentEffect,
	["IgnoreDepth"] = noIndentEffect,
	["InitializeTabardColors"] = noIndentEffect,
	["Insert"] = noIndentEffect,
	["IsAutoFocus"] = noIndentEffect,
	["IsClampedToScreen"] = noIndentEffect,
	["IsCountInvisibleLetters"] = noIndentEffect,
	["IsDelaying"] = noIndentEffect,
	["IsDesaturated"] = noIndentEffect,
	["IsDone"] = noIndentEffect,
	["IsDragging"] = noIndentEffect,
	["IsEnabled"] = noIndentEffect,
	["IsEquippedItem"] = noIndentEffect,
	["IsEventRegistered"] = noIndentEffect,
	["IsIgnoringDepth"] = noIndentEffect,
	["IsInIMECompositionMode"] = noIndentEffect,
	["IsJoystickEnabled"] = noIndentEffect,
	["IsKeyboardEnabled"] = noIndentEffect,
	["IsMouseEnabled"] = noIndentEffect,
	["IsMouseOver"] = noIndentEffect,
	["IsMouseWheelEnabled"] = noIndentEffect,
	["IsMovable"] = noIndentEffect,
	["IsMultiLine"] = noIndentEffect,
	["IsNumeric"] = noIndentEffect,
	["IsObjectType"] = noIndentEffect,
	["IsOwned"] = noIndentEffect,
	["IsPassword"] = noIndentEffect,
	["IsPaused"] = noIndentEffect,
	["IsPendingFinish"] = noIndentEffect,
	["IsPlaying"] = noIndentEffect,
	["IsProtected"] = noIndentEffect,
	["IsResizable"] = noIndentEffect,
	["IsShown"] = noIndentEffect,
	["IsStopped"] = noIndentEffect,
	["IsToplevel"] = noIndentEffect,
	["IsUnit"] = noIndentEffect,
	["IsUserPlaced"] = noIndentEffect,
	["IsVisible"] = noIndentEffect,
	["LockHighlight"] = noIndentEffect,
	["Lower"] = noIndentEffect,
	["NumLines"] = noIndentEffect,
	["PageDown"] = noIndentEffect,
	["PageUp"] = noIndentEffect,
	["Pause"] = noIndentEffect,
	["PingLocation"] = noIndentEffect,
	["Play"] = noIndentEffect,
	["Raise"] = noIndentEffect,
	["RefreshUnit"] = noIndentEffect,
	["RegisterAllEvents"] = noIndentEffect,
	["RegisterEvent"] = noIndentEffect,
	["RegisterForClicks"] = noIndentEffect,
	["RegisterForDrag"] = noIndentEffect,
	["RemoveMessagesByAccessID"] = noIndentEffect,
	["ReplaceIconTexture"] = noIndentEffect,
	["Save"] = noIndentEffect,
	["ScrollDown"] = noIndentEffect,
	["ScrollToBottom"] = noIndentEffect,
	["ScrollToTop"] = noIndentEffect,
	["ScrollUp"] = noIndentEffect,
	["SetAction"] = noIndentEffect,
	["SetAllPoints"] = noIndentEffect,
	["SetAlpha"] = noIndentEffect,
	["SetAlphaGradient"] = noIndentEffect,
	["SetAltArrowKeyMode"] = noIndentEffect,
	["SetAnchorType"] = noIndentEffect,
	["SetAttribute"] = noIndentEffect,
	["SetAuctionItem"] = noIndentEffect,
	["SetAuctionSellItem"] = noIndentEffect,
	["SetAutoFocus"] = noIndentEffect,
	["SetBackdrop"] = noIndentEffect,
	["SetBackdropBorderColor"] = noIndentEffect,
	["SetBackdropColor"] = noIndentEffect,
	["SetBackpackToken"] = noIndentEffect,
	["SetBagItem"] = noIndentEffect,
	["SetBlendMode"] = noIndentEffect,
	["SetBlinkSpeed"] = noIndentEffect,
	["SetBlipTexture"] = noIndentEffect,
	["SetBorderAlpha"] = noIndentEffect,
	["SetBorderScalar"] = noIndentEffect,
	["SetBorderTexture"] = noIndentEffect,
	["SetButtonState"] = noIndentEffect,
	["SetBuybackItem"] = noIndentEffect,
	["SetCamera"] = noIndentEffect,
	["SetChange"] = noIndentEffect,
	["SetChecked"] = noIndentEffect,
	["SetCheckedTexture"] = noIndentEffect,
	["SetClampRectInsets"] = noIndentEffect,
	["SetClampedToScreen"] = noIndentEffect,
	["SetClassBlipTexture"] = noIndentEffect,
	["SetColorHSV"] = noIndentEffect,
	["SetColorRGB"] = noIndentEffect,
	["SetColorValueTexture"] = noIndentEffect,
	["SetColorValueThumbTexture"] = noIndentEffect,
	["SetColorWheelTexture"] = noIndentEffect,
	["SetColorWheelThumbTexture"] = noIndentEffect,
	["SetCooldown"] = noIndentEffect,
	["SetCorpsePOIArrowTexture"] = noIndentEffect,
	["SetCountInvisibleLetters"] = noIndentEffect,
	["SetCreature"] = noIndentEffect,
	["SetCurrencyToken"] = noIndentEffect,
	["SetCursorPosition"] = noIndentEffect,
	["SetCurve"] = noIndentEffect,
	["SetDegrees"] = noIndentEffect,
	["SetDepth"] = noIndentEffect,
	["SetDesaturated"] = noIndentEffect,
	["SetDisabledCheckedTexture"] = noIndentEffect,
	["SetDisabledFontObject"] = noIndentEffect,
	["SetDisabledTexture"] = noIndentEffect,
	["SetDontSavePosition"] = noIndentEffect,
	["SetDrawEdge"] = noIndentEffect,
	["SetDrawLayer"] = noIndentEffect,
	["SetDuration"] = noIndentEffect,
	["SetEndDelay"] = noIndentEffect,
	["SetEquipmentSet"] = noIndentEffect,
	["SetExistingSocketGem"] = noIndentEffect,
	["SetFacing"] = noIndentEffect,
	["SetFadeDuration"] = noIndentEffect,
	["SetFading"] = noIndentEffect,
	["SetFillAlpha"] = noIndentEffect,
	["SetFillTexture"] = noIndentEffect,
	["SetFocus"] = noIndentEffect,
	["SetFogColor"] = noIndentEffect,
	["SetFogFar"] = noIndentEffect,
	["SetFogNear"] = noIndentEffect,
	["SetFont"] = noIndentEffect,
	["SetFontObject"] = noIndentEffect,
	["SetFontString"] = noIndentEffect,
	["SetFormattedText"] = noIndentEffect,
	["SetFrameLevel"] = noIndentEffect,
	["SetFrameStack"] = noIndentEffect,
	["SetFrameStrata"] = noIndentEffect,
	["SetGlow"] = noIndentEffect,
	["SetGlyph"] = noIndentEffect,
	["SetGradient"] = noIndentEffect,
	["SetGradientAlpha"] = noIndentEffect,
	["SetGuildBankItem"] = noIndentEffect,
	["SetHeight"] = noIndentEffect,
	["SetHighlightFontObject"] = noIndentEffect,
	["SetHighlightTexture"] = noIndentEffect,
	["SetHistoryLines"] = noIndentEffect,
	["SetHitRectInsets"] = noIndentEffect,
	["SetHorizTile"] = noIndentEffect,
	["SetHorizontalScroll"] = noIndentEffect,
	["SetHyperlink"] = noIndentEffect,
	["SetHyperlinkCompareItem"] = noIndentEffect,
	["SetHyperlinkFormat"] = noIndentEffect,
	["SetHyperlinksEnabled"] = noIndentEffect,
	["SetID"] = noIndentEffect,
	["SetIconTexture"] = noIndentEffect,
	["SetInboxItem"] = noIndentEffect,
	["SetIndentedWordWrap"] = noIndentEffect,
	["SetInitialOffset"] = noIndentEffect,
	["SetInsertMode"] = noIndentEffect,
	["SetInventoryItem"] = noIndentEffect,
	["SetJustifyH"] = noIndentEffect,
	["SetJustifyV"] = noIndentEffect,
	["SetLFGCompletionReward"] = noIndentEffect,
	["SetLFGDungeonReward"] = noIndentEffect,
	["SetLight"] = noIndentEffect,
	["SetLooping"] = noIndentEffect,
	["SetLootItem"] = noIndentEffect,
	["SetLootRollItem"] = noIndentEffect,
	["SetMaskTexture"] = noIndentEffect,
	["SetMaxBytes"] = noIndentEffect,
	["SetMaxFramerate"] = noIndentEffect,
	["SetMaxLetters"] = noIndentEffect,
	["SetMaxLines"] = noIndentEffect,
	["SetMaxResize"] = noIndentEffect,
	["SetMerchantCostItem"] = noIndentEffect,
	["SetMerchantItem"] = noIndentEffect,
	["SetMergeThreshold"] = noIndentEffect,
	["SetMinMaxValues"] = noIndentEffect,
	["SetMinResize"] = noIndentEffect,
	["SetMinimumWidth"] = noIndentEffect,
	["SetModel"] = noIndentEffect,
	["SetModelScale"] = noIndentEffect,
	["SetMotionScriptsWhileDisabled"] = noIndentEffect,
	["SetMovable"] = noIndentEffect,
	["SetMultiLine"] = noIndentEffect,
	["SetNonBlocking"] = noIndentEffect,
	["SetNonSpaceWrap"] = noIndentEffect,
	["SetNormalFontObject"] = noIndentEffect,
	["SetNormalTexture"] = noIndentEffect,
	["SetNumSplinePoints"] = noIndentEffect,
	["SetNumber"] = noIndentEffect,
	["SetNumeric"] = noIndentEffect,
	["SetOffset"] = noIndentEffect,
	["SetOrder"] = noIndentEffect,
	["SetOrientation"] = noIndentEffect,
	["SetOrigin"] = noIndentEffect,
	["SetOwner"] = noIndentEffect,
	["SetPOIArrowTexture"] = noIndentEffect,
	["SetPadding"] = noIndentEffect,
	["SetParent"] = noIndentEffect,
	["SetPassword"] = noIndentEffect,
	["SetPetAction"] = noIndentEffect,
	["SetPlayerTexture"] = noIndentEffect,
	["SetPlayerTextureHeight"] = noIndentEffect,
	["SetPlayerTextureWidth"] = noIndentEffect,
	["SetPoint"] = noIndentEffect,
	["SetPosition"] = noIndentEffect,
	["SetPossession"] = noIndentEffect,
	["SetPushedTextOffset"] = noIndentEffect,
	["SetPushedTexture"] = noIndentEffect,
	["SetQuestItem"] = noIndentEffect,
	["SetQuestLogItem"] = noIndentEffect,
	["SetQuestLogRewardSpell"] = noIndentEffect,
	["SetQuestLogSpecialItem"] = noIndentEffect,
	["SetQuestRewardSpell"] = noIndentEffect,
	["SetRadians"] = noIndentEffect,
	["SetResizable"] = noIndentEffect,
	["SetReverse"] = noIndentEffect,
	["SetRotatesTexture"] = noIndentEffect,
	["SetRotation"] = noIndentEffect,
	["SetScale"] = noIndentEffect,
	["SetScript"] = noIndentEffect,
	["SetScrollChild"] = noIndentEffect,
	["SetScrollOffset"] = noIndentEffect,
	["SetSendMailItem"] = noIndentEffect,
	["SetSequence"] = noIndentEffect,
	["SetSequenceTime"] = noIndentEffect,
	["SetShadowColor"] = noIndentEffect,
	["SetShadowOffset"] = noIndentEffect,
	["SetShapeshift"] = noIndentEffect,
	["SetSize"] = noIndentEffect,
	["SetSmoothProgress"] = noIndentEffect,
	["SetSmoothing"] = noIndentEffect,
	["SetSocketGem"] = noIndentEffect,
	["SetSocketedItem"] = noIndentEffect,
	["SetSpacing"] = noIndentEffect,
	["SetSpell"] = noIndentEffect,
	["SetSpellByID"] = noIndentEffect,
	["SetStartDelay"] = noIndentEffect,
	["SetStaticPOIArrowTexture"] = noIndentEffect,
	["SetStatusBarColor"] = noIndentEffect,
	["SetStatusBarTexture"] = noIndentEffect,
	["SetTalent"] = noIndentEffect,
	["SetTexCoord"] = noIndentEffect,
	["SetText"] = noIndentEffect,
	["SetTextColor"] = noIndentEffect,
	["SetTextHeight"] = noIndentEffect,
	["SetTextInsets"] = noIndentEffect,
	["SetTexture"] = noIndentEffect,
	["SetThumbTexture"] = noIndentEffect,
	["SetTimeVisible"] = noIndentEffect,
	["SetToplevel"] = noIndentEffect,
	["SetTotem"] = noIndentEffect,
	["SetTracking"] = noIndentEffect,
	["SetTradePlayerItem"] = noIndentEffect,
	["SetTradeSkillItem"] = noIndentEffect,
	["SetTradeTargetItem"] = noIndentEffect,
	["SetTrainerService"] = noIndentEffect,
	["SetUnit"] = noIndentEffect,
	["SetUnitAura"] = noIndentEffect,
	["SetUnitBuff"] = noIndentEffect,
	["SetUnitDebuff"] = noIndentEffect,
	["SetUserPlaced"] = noIndentEffect,
	["SetValue"] = noIndentEffect,
	["SetValueStep"] = noIndentEffect,
	["SetVertTile"] = noIndentEffect,
	["SetVertexColor"] = noIndentEffect,
	["SetVerticalScroll"] = noIndentEffect,
	["SetWidth"] = noIndentEffect,
	["SetWordWrap"] = noIndentEffect,
	["SetZoom"] = noIndentEffect,
	["Show"] = noIndentEffect,
	["StartMovie"] = noIndentEffect,
	["StartMoving"] = noIndentEffect,
	["StartSizing"] = noIndentEffect,
	["Stop"] = noIndentEffect,
	["StopAnimating"] = noIndentEffect,
	["StopMovie"] = noIndentEffect,
	["StopMovingOrSizing"] = noIndentEffect,
	["ToggleInputLanguage"] = noIndentEffect,
	["TryOn"] = noIndentEffect,
	["Undress"] = noIndentEffect,
	["UnlockHighlight"] = noIndentEffect,
	["UnregisterAllEvents"] = noIndentEffect,
	["UnregisterEvent"] = noIndentEffect,
	["UpdateColorByID"] = noIndentEffect,
	["UpdateMouseOverTooltip"] = noIndentEffect,
	["UpdateQuestPOI"] = noIndentEffect,
	["UpdateScrollChildRect"] = noIndentEffect,
	-- Events and stuff
	["ADDON_LOADED"] = noIndentEffect,
	["Ace2_AddonDisabled"] = noIndentEffect,
	["Ace2_AddonEnabled"] = noIndentEffect,
	["AceEvent20EditBox"] = noIndentEffect,
	["AceEvent20Frame"] = noIndentEffect,
	["AceEvent_FullyInitialized"] = noIndentEffect,
	["AceLibrary"] = noIndentEffect,
	["AcquireDBNamespace"] = noIndentEffect,
	["CHAT_MSG_ADDON"] = noIndentEffect,
	["CHAT_MSG_CHANNEL"] = noIndentEffect,
	["CHAT_MSG_CHANNEL_JOIN"] = noIndentEffect,
	["CHAT_MSG_CHANNEL_LEAVE"] = noIndentEffect,
	["CHAT_MSG_CHANNEL_LIST"] = noIndentEffect,
	["CHAT_MSG_CHANNEL_NOTICE"] = noIndentEffect,
	["CHAT_MSG_SYSTEM"] = noIndentEffect,
	["CallMethodOnAllModules"] = noIndentEffect,
	["CancelAllCombatSchedules"] = noIndentEffect,
	["CancelAllScheduledEvents"] = noIndentEffect,
	["CancelScheduledEvent"] = noIndentEffect,
	["ChatThrottleLib"] = noIndentEffect,
	["Classpool"] = noIndentEffect,
	["CopyProfileFrom"] = noIndentEffect,
	["CustomDebug"] = noIndentEffect,
	["CustomLevelDebug"] = noIndentEffect,
	["CustomPrint"] = noIndentEffect,
	["Debug"] = noIndentEffect,
	["DeleteProfile"] = noIndentEffect,
	["Despool"] = noIndentEffect,
	["Enqueue"] = noIndentEffect,
	["Execute"] = noIndentEffect,
	["Factory"] = noIndentEffect,
	["GetAceOptionsDataTable"] = noIndentEffect,
	["GetDebugLevel"] = noIndentEffect,
	["GetDebugPrefix"] = noIndentEffect,
	["GetInstance"] = noIndentEffect,
	["GetLibrary"] = noIndentEffect,
	["GetLibraryVersion"] = noIndentEffect,
	["GetLocalizedCategory"] = noIndentEffect,
	["GetModule"] = noIndentEffect,
	["GetProfile"] = noIndentEffect,
	["HasInstance"] = noIndentEffect,
	["HasModule"] = noIndentEffect,
	["Hook"] = noIndentEffect,
	["HookReport"] = noIndentEffect,
	["HookScript"] = noIndentEffect,
	["Hook_SendAddonMessage"] = noIndentEffect,
	["Hook_SendChatMessage"] = noIndentEffect,
	["Init"] = noIndentEffect,
	["InitializeAddon"] = noIndentEffect,
	["InitializeDB"] = noIndentEffect,
	["InjectAceOptionsTable"] = noIndentEffect,
	["IsActive"] = noIndentEffect,
	["IsBucketEventRegistered"] = noIndentEffect,
	["IsCommRegistered"] = noIndentEffect,
	["IsDebugging"] = noIndentEffect,
	["IsEventRegistered"] = noIndentEffect,
	["IsEventScheduled"] = noIndentEffect,
	["IsFullyInitialized"] = noIndentEffect,
	["IsHooked"] = noIndentEffect,
	["IsModule"] = noIndentEffect,
	["IsModuleActive"] = noIndentEffect,
	["IsNewVersion"] = noIndentEffect,
	["IsTabCompletionRegistered"] = noIndentEffect,
	["IsUserInChannel"] = noIndentEffect,
	["IterateLibraries"] = noIndentEffect,
	["IterateModules"] = noIndentEffect,
	["IterateModulesWithMethod"] = noIndentEffect,
	["LevelDebug"] = noIndentEffect,
	["LibStub"] = noIndentEffect,
	["ManualDisable"] = noIndentEffect,
	["ManualEnable"] = noIndentEffect,
	["NewLibrary"] = noIndentEffect,
	["NewModule"] = noIndentEffect,
	["ORIG_SendAddonMessage"] = noIndentEffect,
	["ORIG_SendChatMessage"] = noIndentEffect,
	["OnEmbedDisable"] = noIndentEffect,
	["OnEmbedInitialize"] = noIndentEffect,
	["OnEmbedProfileDisable"] = noIndentEffect,
	["OnEvent"] = noIndentEffect,
	["OnInstanceInit"] = noIndentEffect,
	["OnManualEmbed"] = noIndentEffect,
	["OnTabPressed"] = noIndentEffect,
	["OnUpdate"] = noIndentEffect,
	["PLAYER_GUILD_UPDATE"] = noIndentEffect,
	["PLAYER_LOGIN"] = noIndentEffect,
	["PLAYER_LOGOUT"] = noIndentEffect,
	["PLAYER_REGEN_DISABLED"] = noIndentEffect,
	["PLAYER_REGEN_ENABLED"] = noIndentEffect,
	["Print"] = noIndentEffect,
	["PrintComma"] = noIndentEffect,
	["PrintLiteral"] = noIndentEffect,
	["QueryAddonVersion"] = noIndentEffect,
	["Register"] = noIndentEffect,
	["RegisterAddonVersionReceptor"] = noIndentEffect,
	["RegisterAllEvents"] = noIndentEffect,
	["RegisterBucketEvent"] = noIndentEffect,
	["RegisterChatCommand"] = noIndentEffect,
	["RegisterComm"] = noIndentEffect,
	["RegisterDB"] = noIndentEffect,
	["RegisterDefaults"] = noIndentEffect,
	["RegisterEvent"] = noIndentEffect,
	["RegisterMemoizations"] = noIndentEffect,
	["RegisterTabCompletion"] = noIndentEffect,
	["ResetDB"] = noIndentEffect,
	["ScheduleEvent"] = noIndentEffect,
	["ScheduleLeaveCombatAction"] = noIndentEffect,
	["ScheduleRepeatingEvent"] = noIndentEffect,
	["SecureHook"] = noIndentEffect,
	["SecureHookScript"] = noIndentEffect,
	["SendAddonMessage"] = noIndentEffect,
	["SendChatMessage"] = noIndentEffect,
	["SendCommMessage"] = noIndentEffect,
	["SendPrioritizedCommMessage"] = noIndentEffect,
	["SetCommPrefix"] = noIndentEffect,
	["SetDebugLevel"] = noIndentEffect,
	["SetDebugging"] = noIndentEffect,
	["SetDefaultCommPriority"] = noIndentEffect,
	["SetModuleClass"] = noIndentEffect,
	["SetModuleDefaultState"] = noIndentEffect,
	["SetModuleMixins"] = noIndentEffect,
	["SetProfile"] = noIndentEffect,
	["TabCompleteInfo"] = noIndentEffect,
	["ToString"] = noIndentEffect,
	["ToggleActive"] = noIndentEffect,
	["ToggleModuleActive"] = noIndentEffect,
	["TriggerEvent"] = noIndentEffect,
	["Unhook"] = noIndentEffect,
	["UnhookAll"] = noIndentEffect,
	["UnregisterAllBucketEvents"] = noIndentEffect,
	["UnregisterAllComms"] = noIndentEffect,
	["UnregisterAllEvents"] = noIndentEffect,
	["UnregisterBucketEvent"] = noIndentEffect,
	["UnregisterComm"] = noIndentEffect,
	["UnregisterEvent"] = noIndentEffect,
	["UnregisterTabCompletion"] = noIndentEffect,
	["UpdateAvail"] = noIndentEffect,
	["ZONE_CHANGED_NEW_AREA"] = noIndentEffect,
	["argCheck"] = noIndentEffect,
	["embed"] = noIndentEffect,
	["error"] = noIndentEffect,
	["inherits"] = noIndentEffect,
	["keybindingValidateFunc"] = noIndentEffect,
	["new"] = noIndentEffect,
	["pcall"] = noIndentEffect,
	-- Ace Stuff
	["Ace3"] = noIndentEffect,
	["AceAddon30Frame"] = noIndentEffect,
	["AceComm30Frame"] = noIndentEffect,
	["AceEvent30Frame"] = noIndentEffect,
	["AceTimer30Frame"] = noIndentEffect,
	["AddToBlizOptions"] = noIndentEffect,
	["CancelAllTimers"] = noIndentEffect,
	["CancelTimer"] = noIndentEffect,
	["ChatThrottleLib"] = noIndentEffect,
	["ClearFocus"] = noIndentEffect,
	["Close"] = noIndentEffect,
	["CloseAll"] = noIndentEffect,
	["ConfigTableChanged"] = noIndentEffect,
	["Create"] = noIndentEffect,
	["CreateChatCommand"] = noIndentEffect,
	["Deserialize"] = noIndentEffect,
	["Despool"] = noIndentEffect,
	["Disable"] = noIndentEffect,
	["DisableAddon"] = noIndentEffect,
	["DisableModule"] = noIndentEffect,
	["Embed"] = noIndentEffect,
	["EmbedLibraries"] = noIndentEffect,
	["EmbedLibrary"] = noIndentEffect,
	["Enable"] = noIndentEffect,
	["EnableAddon"] = noIndentEffect,
	["EnableModule"] = noIndentEffect,
	["Enqueue"] = noIndentEffect,
	["FeedGroup"] = noIndentEffect,
	["GetAddon"] = noIndentEffect,
	["GetArgs"] = noIndentEffect,
	["GetChatCommandOptions"] = noIndentEffect,
	["GetLayout"] = noIndentEffect,
	["GetLibrary"] = noIndentEffect,
	["GetLocale"] = noIndentEffect,
	["GetModule"] = noIndentEffect,
	["GetName"] = noIndentEffect,
	["GetNextWidgetNum"] = noIndentEffect,
	["GetOptionsTable"] = noIndentEffect,
	["GetStatusTable"] = noIndentEffect,
	["GetWidgetCount"] = noIndentEffect,
	["GetWidgetVersion"] = noIndentEffect,
	["HandleCommand"] = noIndentEffect,
	["Hook"] = noIndentEffect,
	["HookScript"] = noIndentEffect,
	["Hook_SendAddonMessage"] = noIndentEffect,
	["Hook_SendChatMessage"] = noIndentEffect,
	["Init"] = noIndentEffect,
	["InitializeAddon"] = noIndentEffect,
	["IsEnabled"] = noIndentEffect,
	["IsHooked"] = noIndentEffect,
	["IsModule"] = noIndentEffect,
	["IsTabCompletionRegistered"] = noIndentEffect,
	["IterateAddonStatus"] = noIndentEffect,
	["IterateAddons"] = noIndentEffect,
	["IterateChatCommands"] = noIndentEffect,
	["IterateEmbeds"] = noIndentEffect,
	["IterateEmbedsOnAddon"] = noIndentEffect,
	["IterateLibraries"] = noIndentEffect,
	["IterateModules"] = noIndentEffect,
	["IterateModulesOfAddon"] = noIndentEffect,
	["IterateOptionsTables"] = noIndentEffect,
	["LibStub"] = noIndentEffect,
	["New"] = noIndentEffect,
	["NewAddon"] = noIndentEffect,
	["NewLibrary"] = noIndentEffect,
	["NewLocale"] = noIndentEffect,
	["NewModule"] = noIndentEffect,
	["NotifyChange"] = noIndentEffect,
	["OnEmbedDisable"] = noIndentEffect,
	["OnEmbedEnable"] = noIndentEffect,
	["OnEvent"] = noIndentEffect,
	["OnInitialize"] = noIndentEffect,
	["OnReceiveMultipartFirst"] = noIndentEffect,
	["OnReceiveMultipartLast"] = noIndentEffect,
	["OnReceiveMultipartNext"] = noIndentEffect,
	["OnTabPressed"] = noIndentEffect,
	["OnUpdate"] = noIndentEffect,
	["Open"] = noIndentEffect,
	["Print"] = noIndentEffect,
	["PrintCmd"] = noIndentEffect,
	["Printf"] = noIndentEffect,
	["RawHook"] = noIndentEffect,
	["RawHookScript"] = noIndentEffect,
	["RegisterAsContainer"] = noIndentEffect,
	["RegisterAsWidget"] = noIndentEffect,
	["RegisterBucketEvent"] = noIndentEffect,
	["RegisterBucketMessage"] = noIndentEffect,
	["RegisterCallback"] = noIndentEffect,
	["RegisterChatCommand"] = noIndentEffect,
	["RegisterComm"] = noIndentEffect,
	["RegisterEvent"] = noIndentEffect,
	["RegisterLayout"] = noIndentEffect,
	["RegisterMessage"] = noIndentEffect,
	["RegisterOptionsTable"] = noIndentEffect,
	["RegisterTabCompletion"] = noIndentEffect,
	["RegisterWidgetType"] = noIndentEffect,
	["Release"] = noIndentEffect,
	["ScheduleRepeatingTimer"] = noIndentEffect,
	["ScheduleTimer"] = noIndentEffect,
	["SecureHook"] = noIndentEffect,
	["SecureHookScript"] = noIndentEffect,
	["SelectGroup"] = noIndentEffect,
	["SendAddonMessage"] = noIndentEffect,
	["SendChatMessage"] = noIndentEffect,
	["SendCommMessage"] = noIndentEffect,
	["SendMessage"] = noIndentEffect,
	["Serialize"] = noIndentEffect,
	["SetDefaultModuleLibraries"] = noIndentEffect,
	["SetDefaultModulePrototype"] = noIndentEffect,
	["SetDefaultModuleState"] = noIndentEffect,
	["SetDefaultSize"] = noIndentEffect,
	["SetEnabledState"] = noIndentEffect,
	["SetFocus"] = noIndentEffect,
	["TimeLeft"] = noIndentEffect,
	["Unhook"] = noIndentEffect,
	["UnhookAll"] = noIndentEffect,
	["UnregisterAllBuckets"] = noIndentEffect,
	["UnregisterAllCallbacks"] = noIndentEffect,
	["UnregisterAllComm"] = noIndentEffect,
	["UnregisterAllEvents"] = noIndentEffect,
	["UnregisterAllMessages"] = noIndentEffect,
	["UnregisterBucket"] = noIndentEffect,
	["UnregisterCallback"] = noIndentEffect,
	["UnregisterChatCommand"] = noIndentEffect,
	["UnregisterComm"] = noIndentEffect,
	["UnregisterEvent"] = noIndentEffect,
	["UnregisterMessage"] = noIndentEffect,
	["UnregisterTabCompletion"] = noIndentEffect,
	["UpdateAvail"] = noIndentEffect,
	["ValidateOptionsTable"] = noIndentEffects,
	["_RegisterComm"] = noIndentEffects,
	
	}
lib.keywords = keywords

local tokenIndentation = {}
lib.tokenIndentation = tokenIndentation
tokenIndentation[tokens.TOKEN_LEFTPAREN] = indentRight
tokenIndentation[tokens.TOKEN_LEFTBRACKET] = indentRight
tokenIndentation[tokens.TOKEN_LEFTWING] = indentRight

tokenIndentation[tokens.TOKEN_RIGHTPAREN] = indentLeft
tokenIndentation[tokens.TOKEN_RIGHTBRACKET] = indentLeft
tokenIndentation[tokens.TOKEN_RIGHTWING] = indentLeft

local function fillWithTabs(n)
	return stringrep("\t", n)
end

local function fillWithSpaces(a, b)
	return stringrep(" ", a*b)
end

function lib.colorCodeCode(code, colorTable, caretPosition)
	local stopColor = colorTable and colorTable[0]
	if not stopColor then
		return code, caretPosition
	end

	local stopColorLen = stringlen(stopColor)

	tableclear(workingTable)
	local tsize = 0
	local totalLen = 0

	local numLines = 0
	local newCaretPosition
	local prevTokenWasColored = false
	local prevTokenWidth = 0
	
	local pos = 1
	local level = 0

	while true do
		if caretPosition and not newCaretPosition and pos >= caretPosition then
			if pos == caretPosition then
				newCaretPosition = totalLen
			else
				newCaretPosition = totalLen
				local diff = pos - caretPosition
				if diff > prevTokenWidth then
					diff = prevTokenWidth
				end
				if prevTokenWasColored then
					diff = diff + stopColorLen
				end
				newCaretPosition = newCaretPosition - diff
			end
		end
		
		prevTokenWasColored = false
		prevTokenWidth = 0
		
		local tokenType, nextPos = lib.nextToken(code, pos)
		
		if not tokenType then
			break
		end
		
		if tokenType == tokens.TOKEN_COLORCODE_START or tokenType == tokens.TOKEN_COLORCODE_STOP or tokenType == tokens.TOKEN_UNKNOWN then
			-- ignore color codes
			
		elseif tokenType == tokens.TOKEN_LINEBREAK or tokenType == tokens.TOKEN_WHITESPACE then
			if tokenType == tokens.TOKEN_LINEBREAK then
				numLines = numLines + 1
			end
			local str = stringsub(code, pos, nextPos - 1)
			prevTokenWidth = nextPos - pos

			tsize = tsize + 1
			workingTable[tsize] = str
			totalLen = totalLen + stringlen(str)
		else
			local str = stringsub(code, pos, nextPos - 1)
			
			prevTokenWidth = nextPos - pos
			
			-- Add coloring
			if keywords[str] then
				tokenType = tokens.TOKEN_KEYWORD
			end
			
			local color
			if stopColor then
				color = colorTable[str]
				if not color then
					color = colorTable[tokenType]
					if not color then
						if tokenType == tokens.TOKEN_IDENTIFIER then
							color = colorTable[tokens.TOKEN_IDENTIFIER]
						else
							color = colorTable[tokens.TOKEN_SPECIAL]
						end
					end
				end
			end
			
			if color then
				tsize = tsize + 1
				workingTable[tsize] = color
				tsize = tsize + 1
				workingTable[tsize] = str
				tsize = tsize + 1
				workingTable[tsize] = stopColor

				totalLen = totalLen + stringlen(color) + (nextPos - pos) + stopColorLen
				prevTokenWasColored = true
			else
				tsize = tsize + 1
				workingTable[tsize] = str

				totalLen = totalLen + stringlen(str)
			end
		end
		
		pos = nextPos
	end
	return table.concat(workingTable), newCaretPosition, numLines
end

function lib.indentCode(code, tabWidth, colorTable, caretPosition)
	local fillFunction
	if tabWidth == nil then
		tabWidth = defaultTabWidth
	end
	if tabWidth then
		fillFunction = fillWithSpaces
	else
		fillFunction = fillWithTabs
	end
	
	tableclear(workingTable)
	local tsize = 0
	local totalLen = 0

	tableclear(workingTable2)
	local tsize2 = 0
	local totalLen2 = 0


	local stopColor = colorTable and colorTable[0]
	local stopColorLen = not stopColor or stringlen(stopColor)

	local newCaretPosition
	local newCaretPositionFinalized = false
	local prevTokenWasColored = false
	local prevTokenWidth = 0
	
	local pos = 1
	local level = 0
	
	local hitNonWhitespace = false
	local hitIndentRight = false
	local preIndent = 0
	local postIndent = 0
	while true do
		if caretPosition and not newCaretPosition and pos >= caretPosition then
			if pos == caretPosition then
				newCaretPosition = totalLen + totalLen2
			else
				newCaretPosition = totalLen + totalLen2
				local diff = pos - caretPosition
				if diff > prevTokenWidth then
					diff = prevTokenWidth
				end
				if prevTokenWasColored then
					diff = diff + stopColorLen
				end
				newCaretPosition = newCaretPosition - diff
			end
		end
		
		prevTokenWasColored = false
		prevTokenWidth = 0
		
		local tokenType, nextPos = lib.nextToken(code, pos)
		
		if not tokenType or tokenType == tokens.TOKEN_LINEBREAK then
			level = level + preIndent
			if level < 0 then level = 0 end
			
			local s = fillFunction(level, tabWidth)

			tsize = tsize + 1
			workingTable[tsize] = s
			totalLen = totalLen + stringlen(s)
			
			if newCaretPosition and not newCaretPositionFinalized then
				newCaretPosition = newCaretPosition + stringlen(s)
				newCaretPositionFinalized = true
			end
			

			for k, v in next,workingTable2 do
				tsize = tsize + 1
				workingTable[tsize] = v
				totalLen = totalLen + stringlen(v)
			end

			if not tokenType then
				break
			end
			
			tsize = tsize + 1
			workingTable[tsize] = stringsub(code, pos, nextPos - 1)
			totalLen = totalLen + nextPos - pos

			level = level + postIndent
			if level < 0 then level = 0 end
			
			tableclear(workingTable2)
			tsize2 = 0
			totalLen2 = 0

			hitNonWhitespace = false
			hitIndentRight = false
			preIndent = 0
			postIndent = 0
		elseif tokenType == tokens.TOKEN_WHITESPACE then
			if hitNonWhitespace then
				prevTokenWidth = nextPos - pos
				
				tsize2 = tsize2 + 1
				local s = stringsub(code, pos, nextPos - 1)
				workingTable2[tsize2] = s
				totalLen2 = totalLen2 + stringlen(s)
			end
		elseif tokenType == tokens.TOKEN_COLORCODE_START or tokenType == tokens.TOKEN_COLORCODE_STOP or tokenType == tokens.TOKEN_UNKNOWN then
			-- skip these, though they shouldn't be encountered here anyway
		else
			hitNonWhitespace = true
			
			local str = stringsub(code, pos, nextPos - 1)
			
			prevTokenWidth = nextPos - pos
			
			-- See if this is an indent-modifier
			local indentTable
			if tokenType == tokens.TOKEN_IDENTIFIER then
				indentTable = keywords[str]
			else
				indentTable = tokenIndentation[tokenType]
			end
			
			if indentTable then
				if hitIndentRight then
					postIndent = postIndent + indentTable[1] + indentTable[2]
				else
					local pre = indentTable[1]
					local post = indentTable[2]
					if post > 0 then
						hitIndentRight = true
					end
					preIndent = preIndent + pre
					postIndent = postIndent + post
				end
			end
			
			-- Add coloring
			if keywords[str] then
				tokenType = tokens.TOKEN_KEYWORD
			end
			
			local color
			if stopColor then
				color = colorTable[str]
				if not color then
					color = colorTable[tokenType]
					if not color then
						if tokenType == tokens.TOKEN_IDENTIFIER then
							color = colorTable[tokens.TOKEN_IDENTIFIER]
						else
							color = colorTable[tokens.TOKEN_SPECIAL]
						end
					end
				end
			end
			
			if color then
				tsize2 = tsize2 + 1
				workingTable2[tsize2] = color
				totalLen2 = totalLen2 + stringlen(color)

				tsize2 = tsize2 + 1
				workingTable2[tsize2] = str
				totalLen2 = totalLen2 + nextPos - pos

				tsize2 = tsize2 + 1
				workingTable2[tsize2] = stopColor
				totalLen2 = totalLen2 + stopColorLen

				prevTokenWasColored = true
			else
				tsize2 = tsize2 + 1
				workingTable2[tsize2] = str
				totalLen2 = totalLen2 + nextPos - pos

			end
		end
		pos = nextPos
	end
	return table.concat(workingTable), newCaretPosition
end



-- WoW specific code:
local GetTime = GetTime

local editboxSetText
local editboxGetText

function lib.stripWowColors(code)

	-- HACK!
	-- This is a fix for a bug, where an unfinished string causes a lot of newlines to be created.
	-- The reason for the bug, is that a |r\n\n gets converted to \n\n|r after the next indent-run
	-- The fix is to remove those last two linebreaks when stripping
	code = stringgsub(code, "|r\n\n$", "|r")
	
	tableclear(workingTable)
	local tsize = 0

	local pos = 1

	local prevVertical = false
	local even = true
	local selectionStart = 1

	while true do
		local byte = stringbyte(code, pos)
		if not byte then
			break
		end
		if byte == bytes.BYTE_VERTICAL then
			even = not even
			prevVertical = true
		else
			if prevVertical and not even then
				if byte == bytes.BYTE_c then
					
					if pos - 2 >= selectionStart then
						tsize = tsize + 1
						workingTable[tsize] = stringsub(code, selectionStart, pos - 2)
					end
					
					pos = pos + 8
					selectionStart = pos + 1
				elseif byte == bytes.BYTE_r then

					if pos - 2 >= selectionStart then
						tsize = tsize + 1
						workingTable[tsize] = stringsub(code, selectionStart, pos - 2)
					end
					selectionStart = pos + 1
				end
			end
			prevVertical = false
			even = true
		end
		pos = pos + 1
	end
	if pos >= selectionStart then
		tsize = tsize + 1
		workingTable[tsize] = stringsub(code, selectionStart, pos - 1)
	end
	return table.concat(workingTable)
end

function lib.decode(code)
	if code then
		code = lib.stripWowColors(code)
		code = stringgsub(code, "||", "|")
	end
	return code or ""
end

function lib.encode(code)
	if code then
		code = stringgsub(code, "|", "||")
	end
	return code or ""
end

function lib.stripWowColorsWithPos(code, pos)
	code = stringinsert(code, pos, "\2")
	code = lib.stripWowColors(code)
	pos = stringfind(code, "\2", 1, 1)
	code = stringdelete(code, pos, pos)
	return code, pos
end

-- returns the padded code, and true if modified, false if unmodified
local linebreak = stringbyte("\n")
function lib.padWithLinebreaks(code)
	do
		return code, false
	end

	local len = stringlen(code)
	if stringbyte(code, len) == linebreak then
		if stringbyte(code, len - 1) == linebreak then
            return code, false
		end
		return code .. "\n", true
	end
	return code .. "\n\n", true

end

local defaultTabWidth = 2
local defaultColorTable

-- Data tables
-- No weak table magic, since editboxes can never be removed in WoW
local enabled = {}
local dirty = {}

local editboxIndentCache = {}
local decodeCache = {}
local editboxStringCache = {}
local editboxNumLinesCache = {}

function lib.coloredGetText(editbox)
	return editboxGetText(editbox)
end

function lib.colorCodeEditbox(editbox)
	dirty[editbox] = nil

	local colorTable = editbox.faiap_colorTable or defaultColorTable
	local tabWidth = editbox.faiap_tabWidth

	local orgCode = editboxGetText(editbox)
	local prevCode = editboxStringCache[editbox]
	if prevCode == orgCode then
		return
	end
	
	local pos = editbox:GetCursorPosition()
	
	local code
	code, pos = lib.stripWowColorsWithPos(orgCode, pos)

	colorTable[0] = "|r"
	
	local newCode, newPos, numLines = lib.colorCodeCode(code, colorTable, pos)
	if editbox:IsMultiLine() then
		newCode = lib.padWithLinebreaks(newCode)
	end

	editboxStringCache[editbox] = newCode
	if orgCode ~= newCode then
		decodeCache[editbox] = nil
		local stringlenNewCode = stringlen(newCode)

		editboxSetText(editbox, newCode)
		if newPos then
			if newPos < 0 then newPos = 0 end
			if newPos > stringlenNewCode then newPos = stringlenNewCode end
			
			editbox:SetCursorPosition(newPos)
		end
	end
	
	if editboxNumLinesCache[editbox] ~= numLines then
		lib.indentEditbox(editbox)
	end
	editboxNumLinesCache[editbox] = numLines
end

function lib.indentEditbox(editbox)
	dirty[editbox] = nil

	local colorTable = editbox.faiap_colorTable or defaultColorTable
	local tabWidth = editbox.faiap_tabWidth

	local orgCode = editboxGetText(editbox)
	local prevCode = editboxIndentCache[editbox]
	if prevCode == orgCode then
		return
	end

	local pos = editbox:GetCursorPosition()
	
	local code
	code, pos = lib.stripWowColorsWithPos(orgCode, pos)

	colorTable[0] = "|r"
	local newCode, newPos = lib.indentCode(code, tabWidth, colorTable, pos)
	if editbox:IsMultiLine() then 
		newCode = lib.padWithLinebreaks(newCode)
	end

	editboxIndentCache[editbox] = newCode
	if code ~= newCode then
		decodeCache[editbox] = nil

		local stringlenNewCode = stringlen(newCode)

		editboxSetText(editbox, newCode)

		if newPos then
			if newPos < 0 then newPos = 0 end
			if newPos > stringlenNewCode then newPos = stringlenNewCode end
			
			editbox:SetCursorPosition(newPos)
		end
	end
end

local function hookHandler(editbox, handler, newFun)
	local oldFun = editbox:GetScript(handler)
	if oldFun == newFun then
		-- already hooked, ignore it
		return
	end
	editbox["faiap_old_" .. handler] = oldFun
	editbox:SetScript(handler, newFun)
end

local function textChangedHook(editbox, ...)
	local oldFun = editbox["faiap_old_OnTextChanged"]
	if oldFun then
		oldFun(editbox, ...)
	end
	if enabled[editbox] then
		dirty[editbox] = GetTime()
	end
end

local function tabPressedHook(editbox, ...)
	local oldFun = editbox["faiap_old_OnTabPressed"]
	if oldFun then
		oldFun(editbox, ...)
	end
	if enabled[editbox] then
		return lib.indentEditbox(editbox)
	end
end

local function onUpdateHook(editbox, ...)
	local oldFun = editbox["faiap_old_OnUpdate"]
	if oldFun then
		oldFun(editbox, ...)
	end
	if enabled[editbox] then
		local now = GetTime()
		local lastUpdate = dirty[editbox] or now
		if now - lastUpdate > 0.2 then
			decodeCache[editbox] = nil
			return lib.colorCodeEditbox(editbox)
		end
	end
end

local function newGetText(editbox, raw)
	if raw then
		return lib.decode(editboxGetText(editbox))
	end

	local decoded = decodeCache[editbox]
	if not decoded then
		decoded = lib.decode(editboxGetText(editbox))
		decodeCache[editbox] = decoded
	end
	return decoded or ""
end

local function newSetText(editbox, text)
	decodeCache[editbox] = nil
	if text then
		local encoded = lib.encode(text)

		return editboxSetText(editbox, encoded)
	end
end

function lib.enable(editbox, colorTable, tabWidth)
	if not editboxSetText then
		editboxSetText = editbox.SetText
		editboxGetText = editbox.GetText
	end

	local modified
	if editbox.faiap_colorTable ~= colorTable then
		editbox.faiap_colorTable = colorTable
		modified = true
	end
	if editbox.faiap_tabWidth ~= tabWidth then
		editbox.faiap_tabWidth = tabWidth
		modified = true
	end

	if enabled[editbox] then
		if modified then
			lib.indentEditbox(editbox)
		end
		return
	end

	-- Editbox is possibly hooked, but disabled
	enabled[editbox] = true

	editbox.oldMaxBytes = editbox:GetMaxBytes()
	editbox.oldMaxLetters = editbox:GetMaxLetters()
	editbox:SetMaxBytes(0)
	editbox:SetMaxLetters(0)

	editbox.GetText = newGetText
	editbox.SetText = newSetText

	hookHandler(editbox, "OnTextChanged", textChangedHook)
	hookHandler(editbox, "OnTabPressed", tabPressedHook)      
	hookHandler(editbox, "OnUpdate", onUpdateHook)      

	lib.indentEditbox(editbox)
end

-- Deprecated function
lib.addSmartCode = lib.enable

function lib.disable(editbox)
	if not enabled[editbox] then
		return
	end
	enabled[editbox] = nil

	-- revert settings for max bytes / letters
	editbox:SetMaxBytes(editbox.oldMaxBytes)
	editbox:SetMaxLetters(editbox.oldMaxLetters)

	-- try a real unhooking, if possible
	if editbox:GetScript("OnTextChanged") == textChangedHook then
		editbox:SetScript("OnTextChanged", editbox.faiap_old_OnTextChanged)
		editbox.faiap_old_OnTextChanged = nil
	end

	if editbox:GetScript("OnTabPressed") == tabPressedHook then
		editbox:SetScript("OnTabPressed", editbox.faiap_old_OnTabPressed)
		editbox.faiap_old_OnTabPressed = nil
	end

	if editbox:GetScript("OnUpdate") == onUpdateHook then
		editbox:SetScript("OnUpdate", editbox.faiap_old_OnUpdate)
		editbox.faiap_old_OnUpdate = nil
	end

	editbox.GetText = nil
	editbox.SetText = nil

	-- change the text back to unformatted
	editbox:SetText(newGetText(editbox))

	-- clear caches
	editboxIndentCache[editbox] = nil
	decodeCache[editbox] = nil
	editboxStringCache[editbox] = nil
	editboxNumLinesCache[editbox] = nil
end


local stringColor = "|c00ffff77"
local tableColor = "|c00ff9900"
local arithmeticColor = "|c0033ff55"
local logicColor1 = "|c0055ff88"
local logicColor2 = "|c0088ffbb"
local LuaColor = "|c00ff0033"
local WoWColor = "|c000099ff"
local methodColor = "|c0000ffff"
local eventColor = "|c00cc66ff"
local AceColor = "|c00ff00ff"

defaultColorTable = {
	[tokens.TOKEN_SPECIAL] = "|c00ff99ff",
	[tokens.TOKEN_KEYWORD] = "|c006666ff",
	[tokens.TOKEN_COMMENT_SHORT] = "|c00999999",
	[tokens.TOKEN_COMMENT_LONG] = "|c00999999",
	
	[tokens.TOKEN_STRING] = stringColor,
	[".."] = stringColor,

	["..."] = tableColor,
	["{"] = tableColor,
	["}"] = tableColor,
	["["] = tableColor,
	["]"] = tableColor,

	[tokens.TOKEN_NUMBER] = arithmeticColor,
	["+"] = arithmeticColor,
	["-"] = arithmeticColor,
	["/"] = arithmeticColor,
	["*"] = arithmeticColor,

	["=="] = logicColor1,
	["<"] = logicColor1,
	["<="] = logicColor1,
	[">"] = logicColor1,
	[">="] = logicColor1,
	["~="] = logicColor1,

	["and"] = logicColor2,
	["or"] = logicColor2,
	["not"] = logicColor2,

	[0] = "|r",

	["_ALERT"] = LuaColor,
	["_ERRORMESSAGE"] = LuaColor,
	["_G"] = LuaColor,
	["_INPUT"] = LuaColor,
	["_OUTPUT"] = LuaColor,
	["_PROMPT"] = LuaColor,
	["_STDERR"] = LuaColor,
	["_STDIN"] = LuaColor,
	["_STDOUT"] = LuaColor,
	["_VERSION"] = LuaColor,
	["abs"] = LuaColor,
	["acos"] = LuaColor,
	["asin"] = LuaColor,
	["assert"] = LuaColor,
	["atan"] = LuaColor,
	["atan2"] = LuaColor,
	["band"] = LuaColor,
	["bit"] = LuaColor,
	["bit.band"] = LuaColor,
	["bit.bor"] = LuaColor,
	["bnot"] = LuaColor,
	["bor"] = LuaColor,
	["bxor"] = LuaColor,
	["byte"] = LuaColor,
	["call"] = LuaColor,
	["ceil"] = LuaColor,
	["char"] = LuaColor,
	["clock"] = LuaColor,
	["close"] = LuaColor,
	["collectgarbage"] = LuaColor,
	["concat"] = LuaColor,
	["coroutine"] = LuaColor,
	["coroutine.create"] = LuaColor,
	["coroutine.resume"] = LuaColor,
	["coroutine.running"] = LuaColor,
	["coroutine.status"] = LuaColor,
	["coroutine.wrap"] = LuaColor,
	["coroutine.yield"] = LuaColor,
	["cos"] = LuaColor,
	["cosh"] = LuaColor,
	["cpath"] = LuaColor,
	["create"] = LuaColor,
	["date"] = LuaColor,
	["debug"] = LuaColor,
	["debug.debug"] = LuaColor,
	["debug.getfenv"] = LuaColor,
	["debug.gethook"] = LuaColor,
	["debug.getinfo"] = LuaColor,
	["debug.getlocal"] = LuaColor,
	["debug.getmetatable"] = LuaColor,
	["debug.getregistry"] = LuaColor,
	["debug.getupvalue"] = LuaColor,
	["debug.setfenv"] = LuaColor,
	["debug.sethook"] = LuaColor,
	["debug.setlocal"] = LuaColor,
	["debug.setmetatable"] = LuaColor,
	["debug.setupvalue"] = LuaColor,
	["debug.traceback"] = LuaColor,
	["deg"] = LuaColor,
	["difftime"] = LuaColor,
	["dofile"] = LuaColor,
	["dostring"] = LuaColor,
	["dump"] = LuaColor,
	["error"] = LuaColor,
	["execute"] = LuaColor,
	["exit"] = LuaColor,
	["exp"] = LuaColor,
	["file"] = LuaColor,
	["file.close"] = LuaColor,
	["file.flush"] = LuaColor,
	["file.lines"] = LuaColor,
	["file.read"] = LuaColor,
	["file.seek"] = LuaColor,
	["file.setvbuf"] = LuaColor,
	["file.write"] = LuaColor,
	["find"] = LuaColor,
	["floor"] = LuaColor,
	["flush"] = LuaColor,
	["fmod"] = LuaColor,
	["foreach"] = LuaColor,
	["foreachi"] = LuaColor,
	["format"] = LuaColor,
	["frexp"] = LuaColor,
	["gcinfo"] = LuaColor,
	["getenv"] = LuaColor,
	["getfenv"] = LuaColor,
	["gethook"] = LuaColor,
	["getinfo"] = LuaColor,
	["getlocal"] = LuaColor,
	["getmetatable"] = LuaColor,
	["getn"] = LuaColor,
	["getregistry"] = LuaColor,
	["getupvalue"] = LuaColor,
	["gfind"] = LuaColor,
	["globals"] = LuaColor,
	["gmatch"] = LuaColor,
	["gsub"] = LuaColor,
	["huge"] = LuaColor,
	["input"] = LuaColor,
	["insert"] = LuaColor,
	["io"] = LuaColor,
	["io.close"] = LuaColor,
	["io.flush"] = LuaColor,
	["io.input"] = LuaColor,
	["io.lines"] = LuaColor,
	["io.open"] = LuaColor,
	["io.output"] = LuaColor,
	["io.popen"] = LuaColor,
	["io.read"] = LuaColor,
	["io.stderr"] = LuaColor,
	["io.stdin"] = LuaColor,
	["io.stdout"] = LuaColor,
	["io.tmpfile"] = LuaColor,
	["io.type"] = LuaColor,
	["io.write"] = LuaColor,
	["ipairs"] = LuaColor,
	["join"] = LuaColor,
	["ldexp"] = LuaColor,
	["len"] = LuaColor,
	["lines"] = LuaColor,
	["load"] = LuaColor,
	["loaded"] = LuaColor,
	["loaders"] = LuaColor,
	["loadfile"] = LuaColor,
	["loadlib"] = LuaColor,
	["loadstring"] = LuaColor,
	["log"] = LuaColor,
	["log10"] = LuaColor,
	["lower"] = LuaColor,
	["lshift"] = LuaColor,
	["match"] = LuaColor,
	["math"] = LuaColor,
	["math.abs"] = LuaColor,
	["math.acos"] = LuaColor,
	["math.asin"] = LuaColor,
	["math.atan"] = LuaColor,
	["math.atan2"] = LuaColor,
	["math.ceil"] = LuaColor,
	["math.cos"] = LuaColor,
	["math.cosh"] = LuaColor,
	["math.deg"] = LuaColor,
	["math.exp"] = LuaColor,
	["math.floor"] = LuaColor,
	["math.fmod"] = LuaColor,
	["math.frexp"] = LuaColor,
	["math.huge"] = LuaColor,
	["math.ldexp"] = LuaColor,
	["math.log"] = LuaColor,
	["math.log10"] = LuaColor,
	["math.max"] = LuaColor,
	["math.min"] = LuaColor,
	["math.modf"] = LuaColor,
	["math.pi"] = LuaColor,
	["math.pow"] = LuaColor,
	["math.rad"] = LuaColor,
	["math.random"] = LuaColor,
	["math.randomseed"] = LuaColor,
	["math.sin"] = LuaColor,
	["math.sinh"] = LuaColor,
	["math.sqrt"] = LuaColor,
	["math.tan"] = LuaColor,
	["math.tanh"] = LuaColor,
	["max"] = LuaColor,
	["maxn"] = LuaColor,
	["min"] = LuaColor,
	["mod"] = LuaColor,
	["modf"] = LuaColor,
	["module"] = LuaColor,
	["new"] = LuaColor,
	["newtable"] = LuaColor,
	["newtype"] = LuaColor,
	["next"] = LuaColor,
	["open"] = LuaColor,
	["os"] = LuaColor,
	["os_clock"] = LuaColor,
	["os.date"] = LuaColor,
	["os.difftime"] = LuaColor,
	["os.execute"] = LuaColor,
	["os.exit"] = LuaColor,
	["os.getenv"] = LuaColor,
	["os.remove"] = LuaColor,
	["os.rename"] = LuaColor,
	["os.setlocale"] = LuaColor,
	["os.time"] = LuaColor,
	["os.tmpname"] = LuaColor,
	["output"] = LuaColor,
	["package"] = LuaColor,
	["package.cpath"] = LuaColor,
	["package.loaded"] = LuaColor,
	["package.loaders"] = LuaColor,
	["package.loadlib"] = LuaColor,
	["package.path"] = LuaColor,
	["package.preload"] = LuaColor,
	["package.seeall"] = LuaColor,
	["pairs"] = LuaColor,
	["path"] = LuaColor,
	["pcall"] = LuaColor,
	["pi"] = LuaColor,
	["popen"] = LuaColor,
	["pow"] = LuaColor,
	["preload"] = LuaColor,
	["print"] = LuaColor,
	["rad"] = LuaColor,
	["random"] = LuaColor,
	["randomseed"] = LuaColor,
	["rawegal"] = LuaColor,
	["rawequal"] = LuaColor,
	["rawget"] = LuaColor,
	["rawset"] = LuaColor,
	["read"] = LuaColor,
	["remove"] = LuaColor,
	["rename"] = LuaColor,
	["rep"] = LuaColor,
	["require"] = LuaColor,
	["resume"] = LuaColor,
	["reverse"] = LuaColor,
	["rshift"] = LuaColor,
	["rtgsub"] = LuaColor,
	["running"] = LuaColor,
	["seeall"] = LuaColor,
	["seek"] = LuaColor,
	["select"] = LuaColor,
	["setfenv"] = LuaColor,
	["sethook"] = LuaColor,
	["setlocal"] = LuaColor,
	["setlocale"] = LuaColor,
	["setmetatable"] = LuaColor,
	["setupvalue"] = LuaColor,
	["setvbuf"] = LuaColor,
	["sin"] = LuaColor,
	["sinh"] = LuaColor,
	["sort"] = LuaColor,
	["split"] = LuaColor,
	["sqrt"] = LuaColor,
	["status"] = LuaColor,
	["stderr"] = LuaColor,
	["stdin"] = LuaColor,
	["stdout"] = LuaColor,
	["strbyte"] = LuaColor,
	["strchar"] = LuaColor,
	["strconcat"] = LuaColor,
	["strdump"] = LuaColor,
	["strfind"] = LuaColor,
	["strformat"] = LuaColor,
	["strgmatch"] = LuaColor,
	["strgsub"] = LuaColor,
	["string"] = LuaColor,
	["string_byte"] = LuaColor,
	["string_char"] = LuaColor,
	["string_dump"] = LuaColor,
	["string_find"] = LuaColor,
	["string_format"] = LuaColor,
	["string_gmatch"] = LuaColor,
	["string_gsub"] = LuaColor,
	["string_len"] = LuaColor,
	["string_lower"] = LuaColor,
	["string_match"] = LuaColor,
	["string_rep"] = LuaColor,
	["string_reverse"] = LuaColor,
	["string_sub"] = LuaColor,
	["string_upper"] = LuaColor,
	["strlen"] = LuaColor,
	["strlower"] = LuaColor,
	["strmatch"] = LuaColor,
	["strrep"] = LuaColor,
	["strreverse"] = LuaColor,
	["strsub"] = LuaColor,
	["strupper"] = LuaColor,
	["sub"] = LuaColor,
	["table"] = LuaColor,
	["table.concat"] = LuaColor,
	["table.insert"] = LuaColor,
	["table.maxn"] = LuaColor,
	["table.remove"] = LuaColor,
	["table.sort"] = LuaColor,
	["tan"] = LuaColor,
	["tanh"] = LuaColor,
	["time"] = LuaColor,
	["tinsert"] = LuaColor,
	["tmpfile"] = LuaColor,
	["tmpname"] = LuaColor,
	["tonumber"] = LuaColor,
	["tostring"] = LuaColor,
	["tostringall"] = LuaColor,
	["traceback"] = LuaColor,
	["tremove"] = LuaColor,
	["trim"] = LuaColor,
	["type"] = LuaColor,
	["unpack"] = LuaColor,
	["upper"] = LuaColor,
	["wrap"] = LuaColor,
	["write"] = LuaColor,
	["xpcall"] = LuaColor,
	["yield"] = LuaColor,
	
	["AbandonQuest"] = WoWColor,
	["AbandonSkill"] = WoWColor,
	["AcceptAreaSpiritHeal"] = WoWColor,
	["AcceptArenaTeam"] = WoWColor,
	["AcceptBattlefieldPort"] = WoWColor,
	["AcceptDuel"] = WoWColor,
	["AcceptGroup"] = WoWColor,
	["AcceptGuild"] = WoWColor,
	["AcceptLevelGrant"] = WoWColor,
	["AcceptProposal"] = WoWColor,
	["AcceptQuest"] = WoWColor,
	["AcceptResurrect"] = WoWColor,
	["AcceptSkillUps"] = WoWColor,
	["AcceptSockets"] = WoWColor,
	["AcceptTrade"] = WoWColor,
	["AcceptXPLoss"] = WoWColor,
	["AchievementAlertFrame_FixAnchors"] = WoWColor,
	["AchievementAlertFrame_GetAlertFrame"] = WoWColor,
	["AchievementAlertFrame_OnClick"] = WoWColor,
	["AchievementAlertFrame_OnHide"] = WoWColor,
	["AchievementAlertFrame_OnLoad"] = WoWColor,
	["AchievementAlertFrame_ShowAlert"] = WoWColor,
	["AchievementFrame_LoadUI"] = WoWColor,
	["AchievementMicroButton_OnEvent"] = WoWColor,
	["ActionBar_PageDown"] = WoWColor,
	["ActionBar_PageUp"] = WoWColor,
	["ActionButtonDown"] = WoWColor,
	["ActionButtonUp"] = WoWColor,
	["ActionButton_CalculateAction"] = WoWColor,
	["ActionButton_GetPagedID"] = WoWColor,
	["ActionButton_HideGrid"] = WoWColor,
	["ActionButton_IsFlashing"] = WoWColor,
	["ActionButton_OnEvent"] = WoWColor,
	["ActionButton_OnLoad"] = WoWColor,
	["ActionButton_OnUpdate"] = WoWColor,
	["ActionButton_SetTooltip"] = WoWColor,
	["ActionButton_ShowGrid"] = WoWColor,
	["ActionButton_StartFlash"] = WoWColor,
	["ActionButton_StopFlash"] = WoWColor,
	["ActionButton_Update"] = WoWColor,
	["ActionButton_UpdateAction"] = WoWColor,
	["ActionButton_UpdateCooldown"] = WoWColor,
	["ActionButton_UpdateCount"] = WoWColor,
	["ActionButton_UpdateFlash"] = WoWColor,
	["ActionButton_UpdateHotkeys"] = WoWColor,
	["ActionButton_UpdateState"] = WoWColor,
	["ActionButton_UpdateUsable"] = WoWColor,
	["ActionHasRange"] = WoWColor,
	["ActionStatus_DisplayMessage"] = WoWColor,
	["ActionStatus_OnEvent"] = WoWColor,
	["ActionStatus_OnLoad"] = WoWColor,
	["ActionStatus_OnUpdate"] = WoWColor,
	["AddChatWindowChannel"] = WoWColor,
	["AddChatWindowMessages"] = WoWColor,
	["AddFriend"] = WoWColor,
	["AddFriendEntryFrame_Collapse"] = WoWColor,
	["AddFriendEntryFrame_Expand"] = WoWColor,
	["AddFriendFrame_Accept"] = WoWColor,
	["AddFriendFrame_OnShow"] = WoWColor,
	["AddFriendFrame_ShowEntry"] = WoWColor,
	["AddFriendFrame_ShowInfo"] = WoWColor,
	["AddFriendNameEditBox_OnTextChanged"] = WoWColor,
	["AddIgnore"] = WoWColor,
	["AddMute"] = WoWColor,
	["AddOrDelIgnore"] = WoWColor,
	["AddOrDelMute"] = WoWColor,
	["AddOrRemoveFriend"] = WoWColor,
	["AddPreviewTalentPoints"] = WoWColor,
	["AddQuestWatch"] = WoWColor,
	["AddSkillUp"] = WoWColor,
	["AddToAutoHide"] = WoWColor,
	["AddTrackedAchievement"] = WoWColor,
	["AddTradeMoney"] = WoWColor,
	["AlertFrame_AnimateIn"] = WoWColor,
	["AlertFrame_FixAnchors"] = WoWColor,
	["AlertFrame_OnEvent"] = WoWColor,
	["AlertFrame_OnLoad"] = WoWColor,
	["AlertFrame_ResumeOutAnimation"] = WoWColor,
	["AlertFrame_StopOutAnimation"] = WoWColor,
	["AltCurrencyFrame_PointsUpdate"] = WoWColor,
	["AltCurrencyFrame_Update"] = WoWColor,
	["AlternatePowerBar_Initialize"] = WoWColor,
	["AlternatePowerBar_OnEvent"] = WoWColor,
	["AlternatePowerBar_OnLoad"] = WoWColor,
	["AlternatePowerBar_OnUpdate"] = WoWColor,
	["AlternatePowerBar_UpdateMaxValues"] = WoWColor,
	["AlternatePowerBar_UpdatePowerType"] = WoWColor,
	["AlternatePowerBar_UpdateValue"] = WoWColor,
	["AnimateTexCoords"] = WoWColor,
	["AnimatedShine_OnUpdate"] = WoWColor,
	["AnimatedShine_Start"] = WoWColor,
	["AnimatedShine_Stop"] = WoWColor,
	["AppendToFile"] = WoWColor,
	["ApplyBarberShopStyle"] = WoWColor,
	["ApplyUnitButtonConfiguration"] = WoWColor,
	["ArenaButton_OnClick"] = WoWColor,
	["ArenaFrameJoinButton_OnClick"] = WoWColor,
	["ArenaFrame_OnEvent"] = WoWColor,
	["ArenaFrame_OnLoad"] = WoWColor,
	["ArenaFrame_Update"] = WoWColor,
	["ArenaRegistrar_OnEvent"] = WoWColor,
	["ArenaRegistrar_OnLoad"] = WoWColor,
	["ArenaRegistrar_OnShow"] = WoWColor,
	["ArenaRegistrar_ShowPurchaseFrame"] = WoWColor,
	["ArenaRegistrar_TurnInPetition"] = WoWColor,
	["ArenaRegistrar_UpdatePrice"] = WoWColor,
	["ArenaTeamDisband"] = WoWColor,
	["ArenaTeamInviteByName"] = WoWColor,
	["ArenaTeamLeave"] = WoWColor,
	["ArenaTeamRoster"] = WoWColor,
	["ArenaTeamSetLeaderByName"] = WoWColor,
	["ArenaTeamUninviteByName"] = WoWColor,
	["ArenaTeam_GetTeamSizeID"] = WoWColor,
	["Arena_LoadUI"] = WoWColor,
	["AscendStop"] = WoWColor,
	["AssistUnit"] = WoWColor,
	["AttackTarget"] = WoWColor,
	["AuctionFrame_LoadUI"] = WoWColor,
	["AudioOptionsFrameCancel_OnClick"] = WoWColor,
	["AudioOptionsFrameDefault_OnClick"] = WoWColor,
	["AudioOptionsFrameOkay_OnClick"] = WoWColor,
	["AudioOptionsFrame_AudioRestart"] = WoWColor,
	["AudioOptionsFrame_OnEvent"] = WoWColor,
	["AudioOptionsFrame_OnHide"] = WoWColor,
	["AudioOptionsFrame_OnLoad"] = WoWColor,
	["AudioOptionsFrame_SetAllToDefaults"] = WoWColor,
	["AudioOptionsFrame_SetCurrentToDefaults"] = WoWColor,
	["AudioOptionsFrame_Toggle"] = WoWColor,
	["AudioOptionsPanel_CheckButton_OnClick"] = WoWColor,
	["AudioOptionsSoundPanelHardwareDropDown_Initialize"] = WoWColor,
	["AudioOptionsSoundPanelHardwareDropDown_OnClick"] = WoWColor,
	["AudioOptionsSoundPanelHardwareDropDown_OnLoad"] = WoWColor,
	["AudioOptionsSoundPanel_OnLoad"] = WoWColor,
	["AudioOptionsVoicePanelBindingOutput_OnUpdate"] = WoWColor,
	["AudioOptionsVoicePanelBindingType_Update"] = WoWColor,
	["AudioOptionsVoicePanelChatModeDropDown_Initialize"] = WoWColor,
	["AudioOptionsVoicePanelChatModeDropDown_OnClick"] = WoWColor,
	["AudioOptionsVoicePanelChatModeDropDown_OnLoad"] = WoWColor,
	["AudioOptionsVoicePanelEnableMicrophone_UpdateControls"] = WoWColor,
	["AudioOptionsVoicePanelEnableVoice_UpdateControls"] = WoWColor,
	["AudioOptionsVoicePanelInputDeviceDropDown_Initialize"] = WoWColor,
	["AudioOptionsVoicePanelInputDeviceDropDown_OnClick"] = WoWColor,
	["AudioOptionsVoicePanelInputDeviceDropDown_OnLoad"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_BindButton"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_CancelBinding"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnClick"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnEnter"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnKeyDown"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_OnKeyUp"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_Refresh"] = WoWColor,
	["AudioOptionsVoicePanelKeyBindingButton_SetTooltip"] = WoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_Initialize"] = WoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnClick"] = WoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnEvent"] = WoWColor,
	["AudioOptionsVoicePanelOutputDeviceDropDown_OnLoad"] = WoWColor,
	["AudioOptionsVoicePanel_DisableMicrophoneControls"] = WoWColor,
	["AudioOptionsVoicePanel_EnableMicrophoneControls"] = WoWColor,
	["AudioOptionsVoicePanel_OnEvent"] = WoWColor,
	["AudioOptionsVoicePanel_OnHide"] = WoWColor,
	["AudioOptionsVoicePanel_OnLoad"] = WoWColor,
	["AudioOptionsVoicePanel_OnShow"] = WoWColor,
	["AudioOptionsVoicePanel_Refresh"] = WoWColor,
	["AudioOptionsVoicePanel_SetInputDevice"] = WoWColor,
	["AudioOptionsVoicePanel_SetOutputDevice"] = WoWColor,
	["AuraButton_OnUpdate"] = WoWColor,
	["AuraButton_Update"] = WoWColor,
	["AuraButton_UpdateDuration"] = WoWColor,
	["AutoCastShine_AutoCastStart"] = WoWColor,
	["AutoCastShine_AutoCastStop"] = WoWColor,
	["AutoCastShine_OnLoad"] = WoWColor,
	["AutoCastShine_OnUpdate"] = WoWColor,
	["AutoCompleteButton_OnClick"] = WoWColor,
	["AutoCompleteEditBox_AddHighlightedText"] = WoWColor,
	["AutoCompleteEditBox_OnChar"] = WoWColor,
	["AutoCompleteEditBox_OnEditFocusLost"] = WoWColor,
	["AutoCompleteEditBox_OnEnterPressed"] = WoWColor,
	["AutoCompleteEditBox_OnEscapePressed"] = WoWColor,
	["AutoCompleteEditBox_OnTabPressed"] = WoWColor,
	["AutoCompleteEditBox_OnTextChanged"] = WoWColor,
	["AutoComplete_GetNumResults"] = WoWColor,
	["AutoComplete_GetSelectedIndex"] = WoWColor,
	["AutoComplete_HideIfAttachedTo"] = WoWColor,
	["AutoComplete_OnLoad"] = WoWColor,
	["AutoComplete_SetSelectedIndex"] = WoWColor,
	["AutoComplete_Update"] = WoWColor,
	["AutoComplete_UpdateResults"] = WoWColor,
	["AutoEquipCursorItem"] = WoWColor,
	["AutoFollowStatus_OnEvent"] = WoWColor,
	["AutoFollowStatus_OnLoad"] = WoWColor,
	["AutoFollowStatus_OnUpdate"] = WoWColor,
	["AutoLootMailItem"] = WoWColor,
	["AutoStoreGuildBankItem"] = WoWColor,
	["BNAcceptFriendInvite"] = WoWColor,
	["BNConnected"] = WoWColor,
	["BNConversationButton_OnClick"] = WoWColor,
	["BNConversationButton_OnEnter"] = WoWColor,
	["BNConversationButton_OnEvent"] = WoWColor,
	["BNConversationButton_OnLeave"] = WoWColor,
	["BNConversationButton_OnLoad"] = WoWColor,
	["BNConversationButton_UpdateAttachmentPoint"] = WoWColor,
	["BNConversationButton_UpdateEnabledState"] = WoWColor,
	["BNConversationButton_UpdateTarget"] = WoWColor,
	["BNConversationInviteDialogInviteButton_OnClick"] = WoWColor,
	["BNConversationInviteDialog_OnEvent"] = WoWColor,
	["BNConversationInviteDialog_OnLoad"] = WoWColor,
	["BNConversationInviteListCheckButton_OnClick"] = WoWColor,
	["BNConversationInvite_Deselect"] = WoWColor,
	["BNConversationInvite_Lock"] = WoWColor,
	["BNConversationInvite_LockActions"] = WoWColor,
	["BNConversationInvite_NewConversation"] = WoWColor,
	["BNConversationInvite_Reset"] = WoWColor,
	["BNConversationInvite_Select"] = WoWColor,
	["BNConversationInvite_SelectPlayers"] = WoWColor,
	["BNConversationInvite_SetMinMaxInvites"] = WoWColor,
	["BNConversationInvite_SetMode"] = WoWColor,
	["BNConversationInvite_Unlock"] = WoWColor,
	["BNConversationInvite_UnlockActions"] = WoWColor,
	["BNConversationInvite_Update"] = WoWColor,
	["BNConversationInvite_UpdateInviteButtonState"] = WoWColor,
	["BNConversation_DisplayConversationTooltip"] = WoWColor,
	["BNCreateConversation"] = WoWColor,
	["BNDeclineFriendInvite"] = WoWColor,
	["BNFeaturesEnabled"] = WoWColor,
	["BNFeaturesEnabledAndConnected"] = WoWColor,
	["BNGetBlockedInfo"] = WoWColor,
	["BNGetBlockedToonInfo"] = WoWColor,
	["BNGetConversationInfo"] = WoWColor,
	["BNGetConversationMemberInfo"] = WoWColor,
	["BNGetCustomMessageTable"] = WoWColor,
	["BNGetFOFInfo"] = WoWColor,
	["BNGetFriendInfo"] = WoWColor,
	["BNGetFriendInfoByID"] = WoWColor,
	["BNGetFriendInviteInfo"] = WoWColor,
	["BNGetFriendToonInfo"] = WoWColor,
	["BNGetInfo"] = WoWColor,
	["BNGetMatureLanguageFilter"] = WoWColor,
	["BNGetMaxPlayersInConversation"] = WoWColor,
	["BNGetNumBlocked"] = WoWColor,
	["BNGetNumBlockedToons"] = WoWColor,
	["BNGetNumConversationMembers"] = WoWColor,
	["BNGetNumFOF"] = WoWColor,
	["BNGetNumFriendInvites"] = WoWColor,
	["BNGetNumFriendToons"] = WoWColor,
	["BNGetNumFriends"] = WoWColor,
	["BNGetSelectedBlock"] = WoWColor,
	["BNGetSelectedFriend"] = WoWColor,
	["BNGetSelectedToonBlock"] = WoWColor,
	["BNGetToonInfo"] = WoWColor,
	["BNInviteToConversation"] = WoWColor,
	["BNIsBlocked"] = WoWColor,
	["BNIsFriend"] = WoWColor,
	["BNIsSelf"] = WoWColor,
	["BNIsToonBlocked"] = WoWColor,
	["BNLeaveConversation"] = WoWColor,
	["BNListConversation"] = WoWColor,
	["BNRemoveFriend"] = WoWColor,
	["BNReportFriendInvite"] = WoWColor,
	["BNReportPlayer"] = WoWColor,
	["BNRequestFOFInfo"] = WoWColor,
	["BNSendConversationMessage"] = WoWColor,
	["BNSendFriendInvite"] = WoWColor,
	["BNSendFriendInviteByID"] = WoWColor,
	["BNSendWhisper"] = WoWColor,
	["BNSetAFK"] = WoWColor,
	["BNSetBlocked"] = WoWColor,
	["BNSetCustomMessage"] = WoWColor,
	["BNSetDND"] = WoWColor,
	["BNSetFocus"] = WoWColor,
	["BNSetFriendNote"] = WoWColor,
	["BNSetMatureLanguageFilter"] = WoWColor,
	["BNSetSelectedBlock"] = WoWColor,
	["BNSetSelectedFriend"] = WoWColor,
	["BNSetSelectedToonBlock"] = WoWColor,
	["BNSetToonBlocked"] = WoWColor,
	["BNToastFrame_AddToast"] = WoWColor,
	["BNToastFrame_Close"] = WoWColor,
	["BNToastFrame_OnClick"] = WoWColor,
	["BNToastFrame_OnEvent"] = WoWColor,
	["BNToastFrame_OnUpdate"] = WoWColor,
	["BNToastFrame_RemoveToast"] = WoWColor,
	["BNToastFrame_Show"] = WoWColor,
	["BNToastFrame_UpdateAnchor"] = WoWColor,
	["BNet_ConfirmReport"] = WoWColor,
	["BNet_DisableToasts"] = WoWColor,
	["BNet_EnableToasts"] = WoWColor,
	["BNet_GetPresenceID"] = WoWColor,
	["BNet_InitiateReport"] = WoWColor,
	["BNet_OnEvent"] = WoWColor,
	["BNet_OnLoad"] = WoWColor,
	["BNet_SendReport"] = WoWColor,
	["BNet_SetToastDuration"] = WoWColor,
	["BNet_UpdateToastEvent"] = WoWColor,
	["BackpackButton_OnClick"] = WoWColor,
	["BackpackButton_OnModifiedClick"] = WoWColor,
	["BackpackButton_UpdateChecked"] = WoWColor,
	["BackpackTokenButton_OnClick"] = WoWColor,
	["BackpackTokenFrame_IsShown"] = WoWColor,
	["BackpackTokenFrame_Update"] = WoWColor,
	["BagSlotButton_OnClick"] = WoWColor,
	["BagSlotButton_OnDrag"] = WoWColor,
	["BagSlotButton_OnEnter"] = WoWColor,
	["BagSlotButton_OnModifiedClick"] = WoWColor,
	["BagSlotButton_UpdateChecked"] = WoWColor,
	["BankButtonIDToInvSlotID"] = WoWColor,
	["BankFrameBagButton_OnLoad"] = WoWColor,
	["BankFrameBaseButton_OnLoad"] = WoWColor,
	["BankFrameItemButtonBag_OnClick"] = WoWColor,
	["BankFrameItemButtonBag_Pickup"] = WoWColor,
	["BankFrameItemButtonGeneric_OnClick"] = WoWColor,
	["BankFrameItemButtonGeneric_OnModifiedClick"] = WoWColor,
	["BankFrameItemButton_OnEnter"] = WoWColor,
	["BankFrameItemButton_OnLoad"] = WoWColor,
	["BankFrameItemButton_Update"] = WoWColor,
	["BankFrameItemButton_UpdateLocked"] = WoWColor,
	["BankFrame_OnEvent"] = WoWColor,
	["BankFrame_OnHide"] = WoWColor,
	["BankFrame_OnLoad"] = WoWColor,
	["BankFrame_OnShow"] = WoWColor,
	["BankFrame_UpdateCooldown"] = WoWColor,
	["BarberShopFrame_LoadUI"] = WoWColor,
	["BarberShopReset"] = WoWColor,
	["BattlefieldButton_OnClick"] = WoWColor,
	["BattlefieldFrameJoinButton_OnClick"] = WoWColor,
	["BattlefieldFrame_GetSelectedBattlegroundInfo"] = WoWColor,
	["BattlefieldFrame_OnEvent"] = WoWColor,
	["BattlefieldFrame_OnLoad"] = WoWColor,
	["BattlefieldFrame_Update"] = WoWColor,
	["BattlefieldFrame_UpdateRandomInfo"] = WoWColor,
	["BattlefieldFrame_UpdateStatus"] = WoWColor,
	["BattlefieldMgrEntryInviteResponse"] = WoWColor,
	["BattlefieldMgrExitRequest"] = WoWColor,
	["BattlefieldMgrQueueInviteResponse"] = WoWColor,
	["BattlefieldMgrQueueRequest"] = WoWColor,
	["BattlefieldMinimap_LoadUI"] = WoWColor,
	["BattlefieldTimerFrame_OnUpdate"] = WoWColor,
	["BattlegroundShineFadeIn"] = WoWColor,
	["BattlegroundShineFadeOut"] = WoWColor,
	["BeginTrade"] = WoWColor,
	["BetterDate"] = WoWColor,
	["BindEnchant"] = WoWColor,
	["BlizzardOptionsPanel_Cancel"] = WoWColor,
	["BlizzardOptionsPanel_CancelControl"] = WoWColor,
	["BlizzardOptionsPanel_CheckButton_Disable"] = WoWColor,
	["BlizzardOptionsPanel_CheckButton_Enable"] = WoWColor,
	["BlizzardOptionsPanel_CheckButton_OnClick"] = WoWColor,
	["BlizzardOptionsPanel_CheckButton_Refresh"] = WoWColor,
	["BlizzardOptionsPanel_CheckButton_SetNewValue"] = WoWColor,
	["BlizzardOptionsPanel_Default"] = WoWColor,
	["BlizzardOptionsPanel_DefaultControl"] = WoWColor,
	["BlizzardOptionsPanel_DropDown_Refresh"] = WoWColor,
	["BlizzardOptionsPanel_GetCVarDefaultSafe"] = WoWColor,
	["BlizzardOptionsPanel_GetCVarMaxSafe"] = WoWColor,
	["BlizzardOptionsPanel_GetCVarMinSafe"] = WoWColor,
	["BlizzardOptionsPanel_GetCVarSafe"] = WoWColor,
	["BlizzardOptionsPanel_Okay"] = WoWColor,
	["BlizzardOptionsPanel_OkayControl"] = WoWColor,
	["BlizzardOptionsPanel_OnEvent"] = WoWColor,
	["BlizzardOptionsPanel_OnLoad"] = WoWColor,
	["BlizzardOptionsPanel_Refresh"] = WoWColor,
	["BlizzardOptionsPanel_RefreshControl"] = WoWColor,
	["BlizzardOptionsPanel_RegisterControl"] = WoWColor,
	["BlizzardOptionsPanel_SetCVarSafe"] = WoWColor,
	["BlizzardOptionsPanel_SetupControl"] = WoWColor,
	["BlizzardOptionsPanel_SetupDependentControl"] = WoWColor,
	["BlizzardOptionsPanel_Slider_Disable"] = WoWColor,
	["BlizzardOptionsPanel_Slider_Enable"] = WoWColor,
	["BlizzardOptionsPanel_Slider_OnValueChanged"] = WoWColor,
	["BlizzardOptionsPanel_Slider_Refresh"] = WoWColor,
	["BlizzardOptionsPanel_UpdateCombatText"] = WoWColor,
	["BlizzardOptionsPanel_UpdateRaidPullouts"] = WoWColor,
	["Blizzard_CombatLog_ApplyFilters"] = WoWColor,
	["Blizzard_CombatLog_CreateActionMenu"] = WoWColor,
	["Blizzard_CombatLog_CreateFilterMenu"] = WoWColor,
	["Blizzard_CombatLog_CreateSpellMenu"] = WoWColor,
	["Blizzard_CombatLog_CreateTabMenu"] = WoWColor,
	["Blizzard_CombatLog_CreateUnitMenu"] = WoWColor,
	["Blizzard_CombatLog_DisableEvent"] = WoWColor,
	["Blizzard_CombatLog_EnableEvent"] = WoWColor,
	["Blizzard_CombatLog_FormattingMenu"] = WoWColor,
	["Blizzard_CombatLog_GenerateFullEventList"] = WoWColor,
	["Blizzard_CombatLog_GenerateFullFlagList"] = WoWColor,
	["Blizzard_CombatLog_HasEvent"] = WoWColor,
	["Blizzard_CombatLog_InitializeFilters"] = WoWColor,
	["Blizzard_CombatLog_MenuHelper"] = WoWColor,
	["Blizzard_CombatLog_MessageTypesMenu"] = WoWColor,
	["Blizzard_CombatLog_QuickButtonFrame_OnEvent"] = WoWColor,
	["Blizzard_CombatLog_QuickButtonFrame_OnLoad"] = WoWColor,
	["Blizzard_CombatLog_QuickButtonRightClick"] = WoWColor,
	["Blizzard_CombatLog_QuickButton_OnClick"] = WoWColor,
	["Blizzard_CombatLog_Refilter"] = WoWColor,
	["Blizzard_CombatLog_RefilterUpdate"] = WoWColor,
	["Blizzard_CombatLog_RefreshGlobalLinks"] = WoWColor,
	["Blizzard_CombatLog_SpellMenuClick"] = WoWColor,
	["Blizzard_CombatLog_UnitMenuClick"] = WoWColor,
	["Blizzard_CombatLog_Update_QuickButtons"] = WoWColor,
	["BonusActionBar_OnEvent"] = WoWColor,
	["BonusActionBar_OnLoad"] = WoWColor,
	["BonusActionBar_OnUpdate"] = WoWColor,
	["BonusActionButtonDown"] = WoWColor,
	["BonusActionButtonUp"] = WoWColor,
	["BossTargetFrameDropDown_Initialize"] = WoWColor,
	["BossTargetFrame_OnLoad"] = WoWColor,
	["BuffButton_OnClick"] = WoWColor,
	["BuffButton_OnLoad"] = WoWColor,
	["BuffFrame_OnEvent"] = WoWColor,
	["BuffFrame_OnLoad"] = WoWColor,
	["BuffFrame_OnUpdate"] = WoWColor,
	["BuffFrame_Update"] = WoWColor,
	["BuffFrame_UpdateAllBuffAnchors"] = WoWColor,
	["BuffFrame_UpdatePositions"] = WoWColor,
	["BuildColoredListString"] = WoWColor,
	["BuildListString"] = WoWColor,
	["BuildMultilineTooltip"] = WoWColor,
	["BuildNewLineListString"] = WoWColor,
	["ButtonInventorySlot"] = WoWColor,
	["ButtonPulse_OnUpdate"] = WoWColor,
	["ButtonPulse_StopPulse"] = WoWColor,
	["BuyGuildBankTab"] = WoWColor,
	["BuyGuildCharter"] = WoWColor,
	["BuyMerchantItem"] = WoWColor,
	["BuyPetition"] = WoWColor,
	["BuySkillTier"] = WoWColor,
	["BuyStableSlot"] = WoWColor,
	["BuyTrainerService"] = WoWColor,
	["BuybackItem"] = WoWColor,
	["COMBAT_TEXT_SCROLL_FUNCTION"] = WoWColor,
	["CalculateAuctionDeposit"] = WoWColor,
	["CalendarAddEvent"] = WoWColor,
	["CalendarCanAddEvent"] = WoWColor,
	["CalendarCanSendInvite"] = WoWColor,
	["CalendarCloseEvent"] = WoWColor,
	["CalendarContextDeselectEvent"] = WoWColor,
	["CalendarContextEventCanComplain"] = WoWColor,
	["CalendarContextEventCanEdit"] = WoWColor,
	["CalendarContextEventClipboard"] = WoWColor,
	["CalendarContextEventComplain"] = WoWColor,
	["CalendarContextEventCopy"] = WoWColor,
	["CalendarContextEventGetCalendarType"] = WoWColor,
	["CalendarContextEventPaste"] = WoWColor,
	["CalendarContextEventRemove"] = WoWColor,
	["CalendarContextEventSignUp"] = WoWColor,
	["CalendarContextGetEventIndex"] = WoWColor,
	["CalendarContextInviteAvailable"] = WoWColor,
	["CalendarContextInviteDecline"] = WoWColor,
	["CalendarContextInviteIsPending"] = WoWColor,
	["CalendarContextInviteModeratorStatus"] = WoWColor,
	["CalendarContextInviteRemove"] = WoWColor,
	["CalendarContextInviteStatus"] = WoWColor,
	["CalendarContextInviteTentative"] = WoWColor,
	["CalendarContextInviteType"] = WoWColor,
	["CalendarContextSelectEvent"] = WoWColor,
	["CalendarDefaultGuildFilter"] = WoWColor,
	["CalendarEventAvailable"] = WoWColor,
	["CalendarEventCanEdit"] = WoWColor,
	["CalendarEventCanModerate"] = WoWColor,
	["CalendarEventClearAutoApprove"] = WoWColor,
	["CalendarEventClearLocked"] = WoWColor,
	["CalendarEventClearModerator"] = WoWColor,
	["CalendarEventDecline"] = WoWColor,
	["CalendarEventGetCalendarType"] = WoWColor,
	["CalendarEventGetInvite"] = WoWColor,
	["CalendarEventGetInviteResponseTime"] = WoWColor,
	["CalendarEventGetInviteSortCriterion"] = WoWColor,
	["CalendarEventGetNumInvites"] = WoWColor,
	["CalendarEventGetRepeatOptions"] = WoWColor,
	["CalendarEventGetSelectedInvite"] = WoWColor,
	["CalendarEventGetStatusOptions"] = WoWColor,
	["CalendarEventGetTextures"] = WoWColor,
	["CalendarEventGetTypes"] = WoWColor,
	["CalendarEventHasPendingInvite"] = WoWColor,
	["CalendarEventHaveSettingsChanged"] = WoWColor,
	["CalendarEventInvite"] = WoWColor,
	["CalendarEventIsModerator"] = WoWColor,
	["CalendarEventRemoveInvite"] = WoWColor,
	["CalendarEventSelectInvite"] = WoWColor,
	["CalendarEventSetAutoApprove"] = WoWColor,
	["CalendarEventSetDate"] = WoWColor,
	["CalendarEventSetDescription"] = WoWColor,
	["CalendarEventSetLocked"] = WoWColor,
	["CalendarEventSetLockoutDate"] = WoWColor,
	["CalendarEventSetLockoutTime"] = WoWColor,
	["CalendarEventSetModerator"] = WoWColor,
	["CalendarEventSetRepeatOption"] = WoWColor,
	["CalendarEventSetSize"] = WoWColor,
	["CalendarEventSetStatus"] = WoWColor,
	["CalendarEventSetTextureID"] = WoWColor,
	["CalendarEventSetTime"] = WoWColor,
	["CalendarEventSetTitle"] = WoWColor,
	["CalendarEventSetType"] = WoWColor,
	["CalendarEventSignUp"] = WoWColor,
	["CalendarEventSortInvites"] = WoWColor,
	["CalendarEventTentative"] = WoWColor,
	["CalendarGetAbsMonth"] = WoWColor,
	["CalendarGetDate"] = WoWColor,
	["CalendarGetDayEvent"] = WoWColor,
	["CalendarGetDayEventSequenceInfo"] = WoWColor,
	["CalendarGetEventIndex"] = WoWColor,
	["CalendarGetEventInfo"] = WoWColor,
	["CalendarGetFirstPendingInvite"] = WoWColor,
	["CalendarGetHolidayInfo"] = WoWColor,
	["CalendarGetMaxCreateDate"] = WoWColor,
	["CalendarGetMaxDate"] = WoWColor,
	["CalendarGetMinDate"] = WoWColor,
	["CalendarGetMinHistoryDate"] = WoWColor,
	["CalendarGetMonth"] = WoWColor,
	["CalendarGetMonthNames"] = WoWColor,
	["CalendarGetNumDayEvents"] = WoWColor,
	["CalendarGetNumPendingInvites"] = WoWColor,
	["CalendarGetRaidInfo"] = WoWColor,
	["CalendarGetWeekdayNames"] = WoWColor,
	["CalendarIsActionPending"] = WoWColor,
	["CalendarMassInviteArenaTeam"] = WoWColor,
	["CalendarMassInviteGuild"] = WoWColor,
	["CalendarNewEvent"] = WoWColor,
	["CalendarNewGuildAnnouncement"] = WoWColor,
	["CalendarNewGuildEvent"] = WoWColor,
	["CalendarOpenEvent"] = WoWColor,
	["CalendarRemoveEvent"] = WoWColor,
	["CalendarSetAbsMonth"] = WoWColor,
	["CalendarSetMonth"] = WoWColor,
	["CalendarUpdateEvent"] = WoWColor,
	["Calendar_LoadUI"] = WoWColor,
	["CallCompanion"] = WoWColor,
	["CallRestrictedClosure"] = WoWColor,
	["CameraOrSelectOrMoveStart"] = WoWColor,
	["CameraOrSelectOrMoveStop"] = WoWColor,
	["CameraZoomIn"] = WoWColor,
	["CameraZoomOut"] = WoWColor,
	["CanAlterSkin"] = WoWColor,
	["CanCancelAuction"] = WoWColor,
	["CanChangePlayerDifficulty"] = WoWColor,
	["CanComplainChat"] = WoWColor,
	["CanComplainInboxItem"] = WoWColor,
	["CanCooperateWithToon"] = WoWColor,
	["CanCreateFilters"] = WoWColor,
	["CanEditGuildEvent"] = WoWColor,
	["CanEditGuildInfo"] = WoWColor,
	["CanEditGuildTabInfo"] = WoWColor,
	["CanEditMOTD"] = WoWColor,
	["CanEditOfficerNote"] = WoWColor,
	["CanEditPublicNote"] = WoWColor,
	["CanEjectPassengerFromSeat"] = WoWColor,
	["CanExitVehicle"] = WoWColor,
	["CanGrantLevel"] = WoWColor,
	["CanGroupInvite"] = WoWColor,
	["CanGuildBankRepair"] = WoWColor,
	["CanGuildDemote"] = WoWColor,
	["CanGuildInvite"] = WoWColor,
	["CanGuildPromote"] = WoWColor,
	["CanGuildRemove"] = WoWColor,
	["CanHearthAndResurrectFromArea"] = WoWColor,
	["CanInspect"] = WoWColor,
	["CanJoinBattlefieldAsGroup"] = WoWColor,
	["CanMapChangeDifficulty"] = WoWColor,
	["CanMerchantRepair"] = WoWColor,
	["CanOpenPanels"] = WoWColor,
	["CanPartyLFGBackfill"] = WoWColor,
	["CanQueueForWintergrasp"] = WoWColor,
	["CanResetTutorials"] = WoWColor,
	["CanSendAuctionQuery"] = WoWColor,
	["CanShowAchievementUI"] = WoWColor,
	["CanShowCenterUIPanel"] = WoWColor,
	["CanShowResetInstances"] = WoWColor,
	["CanShowRightUIPanel"] = WoWColor,
	["CanShowUIPanels"] = WoWColor,
	["CanSignPetition"] = WoWColor,
	["CanSummonFriend"] = WoWColor,
	["CanSwitchVehicleSeat"] = WoWColor,
	["CanSwitchVehicleSeats"] = WoWColor,
	["CanUseEquipmentSets"] = WoWColor,
	["CanViewOfficerNote"] = WoWColor,
	["CanWithdrawGuildBankMoney"] = WoWColor,
	["CancelAreaSpiritHeal"] = WoWColor,
	["CancelAuction"] = WoWColor,
	["CancelBarberShop"] = WoWColor,
	["CancelDuel"] = WoWColor,
	["CancelItemTempEnchantment"] = WoWColor,
	["CancelLogout"] = WoWColor,
	["CancelPendingEquip"] = WoWColor,
	["CancelSell"] = WoWColor,
	["CancelShapeshiftForm"] = WoWColor,
	["CancelSkillUps"] = WoWColor,
	["CancelSummon"] = WoWColor,
	["CancelTrade"] = WoWColor,
	["CancelTradeAccept"] = WoWColor,
	["CancelUnitBuff"] = WoWColor,
	["CannotBeResurrected"] = WoWColor,
	["CaptureBar_Create"] = WoWColor,
	["CaptureBar_Update"] = WoWColor,
	["CastPetAction"] = WoWColor,
	["CastShapeshiftForm"] = WoWColor,
	["CastSpell"] = WoWColor,
	["CastSpellByID"] = WoWColor,
	["CastSpellByName"] = WoWColor,
	["CastingBarFrame_FinishSpell"] = WoWColor,
	["CastingBarFrame_OnEvent"] = WoWColor,
	["CastingBarFrame_OnLoad"] = WoWColor,
	["CastingBarFrame_OnShow"] = WoWColor,
	["CastingBarFrame_OnUpdate"] = WoWColor,
	["CastingBarFrame_UpdateIsShown"] = WoWColor,
	["ChangeActionBarPage"] = WoWColor,
	["ChangeChatColor"] = WoWColor,
	["ChangeMultiCastActionPage"] = WoWColor,
	["ChangePlayerDifficulty"] = WoWColor,
	["ChannelBan"] = WoWColor,
	["ChannelFrameDaughterFrame_Cancel"] = WoWColor,
	["ChannelFrameDaughterFrame_Okay"] = WoWColor,
	["ChannelFrameDaughterFrame_OnHide"] = WoWColor,
	["ChannelFrame_Desaturate"] = WoWColor,
	["ChannelFrame_Join_OnClick"] = WoWColor,
	["ChannelFrame_New_OnClick"] = WoWColor,
	["ChannelFrame_OnEvent"] = WoWColor,
	["ChannelFrame_OnLoad"] = WoWColor,
	["ChannelFrame_OnUpdate"] = WoWColor,
	["ChannelFrame_Update"] = WoWColor,
	["ChannelFrame_UpdateJoin"] = WoWColor,
	["ChannelInvite"] = WoWColor,
	["ChannelKick"] = WoWColor,
	["ChannelListButton_OnDragStart"] = WoWColor,
	["ChannelListButton_OnDragStop"] = WoWColor,
	["ChannelListDropDown_HideDropDown"] = WoWColor,
	["ChannelListDropDown_Initialize"] = WoWColor,
	["ChannelListDropDown_Invite"] = WoWColor,
	["ChannelListDropDown_SetPassword"] = WoWColor,
	["ChannelList_CountUpdate"] = WoWColor,
	["ChannelList_OnClick"] = WoWColor,
	["ChannelList_SetScroll"] = WoWColor,
	["ChannelList_ShowDropdown"] = WoWColor,
	["ChannelList_Update"] = WoWColor,
	["ChannelList_UpdateHighlight"] = WoWColor,
	["ChannelList_UpdateVoice"] = WoWColor,
	["ChannelModerator"] = WoWColor,
	["ChannelMute"] = WoWColor,
	["ChannelPulloutRosterButton_OnEvent"] = WoWColor,
	["ChannelPulloutRoster_DrawButton"] = WoWColor,
	["ChannelPulloutRoster_GetActiveSession"] = WoWColor,
	["ChannelPulloutRoster_GetSessionIDByName"] = WoWColor,
	["ChannelPulloutRoster_GetSessionInfo"] = WoWColor,
	["ChannelPulloutRoster_OnEvent"] = WoWColor,
	["ChannelPulloutRoster_OnLoad"] = WoWColor,
	["ChannelPulloutRoster_Populate"] = WoWColor,
	["ChannelPulloutRoster_Scroll"] = WoWColor,
	["ChannelPulloutRoster_ScrollToBottom"] = WoWColor,
	["ChannelPulloutRoster_ScrollToTop"] = WoWColor,
	["ChannelPulloutRoster_Sort"] = WoWColor,
	["ChannelPulloutRoster_Update"] = WoWColor,
	["ChannelPulloutRoster_UpdateScrollControls"] = WoWColor,
	["ChannelPulloutTabDropDown_Initialize"] = WoWColor,
	["ChannelPulloutTab_OnClick"] = WoWColor,
	["ChannelPulloutTab_ReanchorLeft"] = WoWColor,
	["ChannelPulloutTab_UpdateText"] = WoWColor,
	["ChannelPullout_OnEvent"] = WoWColor,
	["ChannelPullout_OnLoad"] = WoWColor,
	["ChannelPullout_OnUpdate"] = WoWColor,
	["ChannelPullout_SaveOpacity"] = WoWColor,
	["ChannelPullout_SetOpacity"] = WoWColor,
	["ChannelPullout_ShowOpacity"] = WoWColor,
	["ChannelPullout_ToggleDisplay"] = WoWColor,
	["ChannelRosterDropDown_Initialize"] = WoWColor,
	["ChannelRosterFrame_ShowDropdown"] = WoWColor,
	["ChannelRoster_OnClick"] = WoWColor,
	["ChannelRoster_SetScroll"] = WoWColor,
	["ChannelRoster_Update"] = WoWColor,
	["ChannelRoster_UpdateVoice"] = WoWColor,
	["ChannelSilenceAll"] = WoWColor,
	["ChannelSilenceVoice"] = WoWColor,
	["ChannelToggleAnnouncements"] = WoWColor,
	["ChannelUnSilenceAll"] = WoWColor,
	["ChannelUnSilenceVoice"] = WoWColor,
	["ChannelUnban"] = WoWColor,
	["ChannelUnmoderator"] = WoWColor,
	["ChannelUnmute"] = WoWColor,
	["ChannelVoiceOff"] = WoWColor,
	["ChannelVoiceOn"] = WoWColor,
	["CharacterAttackFrame_OnEnter"] = WoWColor,
	["CharacterDamageFrame_OnEnter"] = WoWColor,
	["CharacterFrameTab_OnClick"] = WoWColor,
	["CharacterFrame_OnEvent"] = WoWColor,
	["CharacterFrame_OnHide"] = WoWColor,
	["CharacterFrame_OnLoad"] = WoWColor,
	["CharacterFrame_OnShow"] = WoWColor,
	["CharacterFrame_ShowSubFrame"] = WoWColor,
	["CharacterFrame_TabBoundsCheck"] = WoWColor,
	["CharacterMicroButton_OnEvent"] = WoWColor,
	["CharacterMicroButton_OnLoad"] = WoWColor,
	["CharacterMicroButton_SetNormal"] = WoWColor,
	["CharacterMicroButton_SetPushed"] = WoWColor,
	["CharacterModelFrame_OnMouseUp"] = WoWColor,
	["CharacterRangedDamageFrame_OnEnter"] = WoWColor,
	["CharacterSpellBonusDamage_OnEnter"] = WoWColor,
	["CharacterSpellCritChance_OnEnter"] = WoWColor,
	["ChatChannelDropDown_Initialize"] = WoWColor,
	["ChatChannelDropDown_InviteToConversation"] = WoWColor,
	["ChatChannelDropDown_LeaveConversation"] = WoWColor,
	["ChatChannelDropDown_PopInChat"] = WoWColor,
	["ChatChannelDropDown_PopOutChat"] = WoWColor,
	["ChatChannelDropDown_Show"] = WoWColor,
	["ChatChannelPasswordHandler"] = WoWColor,
	["ChatConfigCancel_OnClick"] = WoWColor,
	["ChatConfigCategory_OnClick"] = WoWColor,
	["ChatConfigCombat_OnLoad"] = WoWColor,
	["ChatConfigFilter_OnClick"] = WoWColor,
	["ChatConfigFrame_OnEvent"] = WoWColor,
	["ChatConfigFrame_OnLoad"] = WoWColor,
	["ChatConfigFrame_PlayCheckboxSound"] = WoWColor,
	["ChatConfig_CreateCheckboxes"] = WoWColor,
	["ChatConfig_CreateColorSwatches"] = WoWColor,
	["ChatConfig_CreateTieredCheckboxes"] = WoWColor,
	["ChatConfig_HideCombatTabs"] = WoWColor,
	["ChatConfig_MoveFilterDown"] = WoWColor,
	["ChatConfig_MoveFilterUp"] = WoWColor,
	["ChatConfig_ShowCombatTabs"] = WoWColor,
	["ChatConfig_UpdateChatSettings"] = WoWColor,
	["ChatConfig_UpdateCheckboxes"] = WoWColor,
	["ChatConfig_UpdateCombatSettings"] = WoWColor,
	["ChatConfig_UpdateCombatTabs"] = WoWColor,
	["ChatConfig_UpdateFilterList"] = WoWColor,
	["ChatConfig_UpdateSwatches"] = WoWColor,
	["ChatConfig_UpdateTieredCheckboxFrame"] = WoWColor,
	["ChatConfig_UpdateTieredCheckboxes"] = WoWColor,
	["ChatEdit_ActivateChat"] = WoWColor,
	["ChatEdit_AddHistory"] = WoWColor,
	["ChatEdit_ChooseBoxForSend"] = WoWColor,
	["ChatEdit_CustomTabPressed"] = WoWColor,
	["ChatEdit_DeactivateChat"] = WoWColor,
	["ChatEdit_ExtractBNConversation"] = WoWColor,
	["ChatEdit_ExtractChannel"] = WoWColor,
	["ChatEdit_ExtractTellTarget"] = WoWColor,
	["ChatEdit_FocusActiveWindow"] = WoWColor,
	["ChatEdit_GetActiveWindow"] = WoWColor,
	["ChatEdit_GetLastActiveWindow"] = WoWColor,
	["ChatEdit_GetLastTellTarget"] = WoWColor,
	["ChatEdit_GetLastToldTarget"] = WoWColor,
	["ChatEdit_GetNextTellTarget"] = WoWColor,
	["ChatEdit_HandleChatType"] = WoWColor,
	["ChatEdit_InsertLink"] = WoWColor,
	["ChatEdit_LanguageShow"] = WoWColor,
	["ChatEdit_OnEditFocusGained"] = WoWColor,
	["ChatEdit_OnEditFocusLost"] = WoWColor,
	["ChatEdit_OnEnterPressed"] = WoWColor,
	["ChatEdit_OnEscapePressed"] = WoWColor,
	["ChatEdit_OnEvent"] = WoWColor,
	["ChatEdit_OnHide"] = WoWColor,
	["ChatEdit_OnInputLanguageChanged"] = WoWColor,
	["ChatEdit_OnLoad"] = WoWColor,
	["ChatEdit_OnShow"] = WoWColor,
	["ChatEdit_OnSpacePressed"] = WoWColor,
	["ChatEdit_OnTabPressed"] = WoWColor,
	["ChatEdit_OnTextChanged"] = WoWColor,
	["ChatEdit_OnTextSet"] = WoWColor,
	["ChatEdit_OnUpdate"] = WoWColor,
	["ChatEdit_ParseText"] = WoWColor,
	["ChatEdit_ResetChatType"] = WoWColor,
	["ChatEdit_ResetChatTypeToSticky"] = WoWColor,
	["ChatEdit_SecureTabPressed"] = WoWColor,
	["ChatEdit_SendText"] = WoWColor,
	["ChatEdit_SetLastActiveWindow"] = WoWColor,
	["ChatEdit_SetLastTellTarget"] = WoWColor,
	["ChatEdit_SetLastToldTarget"] = WoWColor,
	["ChatEdit_UpdateHeader"] = WoWColor,
	["ChatFrameMenu_UpdateAnchorPoint"] = WoWColor,
	["ChatFrame_ActivateCombatMessages"] = WoWColor,
	["ChatFrame_AddBNConversationTarget"] = WoWColor,
	["ChatFrame_AddChannel"] = WoWColor,
	["ChatFrame_AddMessageEventFilter"] = WoWColor,
	["ChatFrame_AddMessageGroup"] = WoWColor,
	["ChatFrame_AddPrivateMessageTarget"] = WoWColor,
	["ChatFrame_ChatPageDown"] = WoWColor,
	["ChatFrame_ChatPageUp"] = WoWColor,
	["ChatFrame_ConfigEventHandler"] = WoWColor,
	["ChatFrame_DisplayChatHelp"] = WoWColor,
	["ChatFrame_DisplayGameTime"] = WoWColor,
	["ChatFrame_DisplayGuildHelp"] = WoWColor,
	["ChatFrame_DisplayHelpText"] = WoWColor,
	["ChatFrame_DisplayMacroHelpText"] = WoWColor,
	["ChatFrame_DisplayStartupText"] = WoWColor,
	["ChatFrame_DisplayTimePlayed"] = WoWColor,
	["ChatFrame_DisplayUsageError"] = WoWColor,
	["ChatFrame_ExcludeBNConversationTarget"] = WoWColor,
	["ChatFrame_ExcludePrivateMessageTarget"] = WoWColor,
	["ChatFrame_GetMessageEventFilters"] = WoWColor,
	["ChatFrame_MessageEventHandler"] = WoWColor,
	["ChatFrame_OnEvent"] = WoWColor,
	["ChatFrame_OnHyperlinkShow"] = WoWColor,
	["ChatFrame_OnLoad"] = WoWColor,
	["ChatFrame_OnMouseWheel"] = WoWColor,
	["ChatFrame_OnUpdate"] = WoWColor,
	["ChatFrame_OpenChat"] = WoWColor,
	["ChatFrame_OpenMenu"] = WoWColor,
	["ChatFrame_ReceiveAllBNConversations"] = WoWColor,
	["ChatFrame_ReceiveAllPrivateMessages"] = WoWColor,
	["ChatFrame_RegisterForChannels"] = WoWColor,
	["ChatFrame_RegisterForMessages"] = WoWColor,
	["ChatFrame_RemoveAllChannels"] = WoWColor,
	["ChatFrame_RemoveAllMessageGroups"] = WoWColor,
	["ChatFrame_RemoveBNConversationTarget"] = WoWColor,
	["ChatFrame_RemoveChannel"] = WoWColor,
	["ChatFrame_RemoveExcludeBNConversationTarget"] = WoWColor,
	["ChatFrame_RemoveExcludePrivateMessageTarget"] = WoWColor,
	["ChatFrame_RemoveMessageEventFilter"] = WoWColor,
	["ChatFrame_RemoveMessageGroup"] = WoWColor,
	["ChatFrame_RemovePrivateMessageTarget"] = WoWColor,
	["ChatFrame_ReplyTell"] = WoWColor,
	["ChatFrame_ReplyTell2"] = WoWColor,
	["ChatFrame_ScrollDown"] = WoWColor,
	["ChatFrame_ScrollToBottom"] = WoWColor,
	["ChatFrame_ScrollUp"] = WoWColor,
	["ChatFrame_SendTell"] = WoWColor,
	["ChatFrame_SystemEventHandler"] = WoWColor,
	["ChatFrame_TimeBreakDown"] = WoWColor,
	["ChatHistory_GetAccessID"] = WoWColor,
	["ChatHistory_GetChatType"] = WoWColor,
	["ChatHistory_GetToken"] = WoWColor,
	["ChatMenu_Battleground"] = WoWColor,
	["ChatMenu_Emote"] = WoWColor,
	["ChatMenu_Guild"] = WoWColor,
	["ChatMenu_OnLoad"] = WoWColor,
	["ChatMenu_OnShow"] = WoWColor,
	["ChatMenu_Party"] = WoWColor,
	["ChatMenu_Raid"] = WoWColor,
	["ChatMenu_Reply"] = WoWColor,
	["ChatMenu_Say"] = WoWColor,
	["ChatMenu_SetChatType"] = WoWColor,
	["ChatMenu_VoiceMacro"] = WoWColor,
	["ChatMenu_Whisper"] = WoWColor,
	["ChatMenu_Yell"] = WoWColor,
	["ChatUnitColor_OpenColorPicker"] = WoWColor,
	["Chat_GetChannelShortcutName"] = WoWColor,
	["Chat_GetChatCategory"] = WoWColor,
	["Chat_GetColoredChatName"] = WoWColor,
	["CheckBinderDist"] = WoWColor,
	["CheckInbox"] = WoWColor,
	["CheckInteractDistance"] = WoWColor,
	["CheckSpiritHealerDist"] = WoWColor,
	["CheckTalentMasterDist"] = WoWColor,
	["CinematicFrame_OnEvent"] = WoWColor,
	["CinematicFrame_OnLoad"] = WoWColor,
	["ClassTrainerFrame_LoadUI"] = WoWColor,
	["ClearAchievementComparisonUnit"] = WoWColor,
	["ClearAllLFGDungeons"] = WoWColor,
	["ClearChannelWatch"] = WoWColor,
	["ClearCursor"] = WoWColor,
	["ClearFocus"] = WoWColor,
	["ClearInspectPlayer"] = WoWColor,
	["ClearLFGDungeon"] = WoWColor,
	["ClearOverrideBindings"] = WoWColor,
	["ClearPartyAssignment"] = WoWColor,
	["ClearPendingGuildBankPermissions"] = WoWColor,
	["ClearRaidMarker"] = WoWColor,
	["ClearSendMail"] = WoWColor,
	["ClearTarget"] = WoWColor,
	["ClearTutorials"] = WoWColor,
	["ClickAuctionSellItemButton"] = WoWColor,
	["ClickLandmark"] = WoWColor,
	["ClickPetitionButton"] = WoWColor,
	["ClickSendMailItemButton"] = WoWColor,
	["ClickSocketButton"] = WoWColor,
	["ClickStablePet"] = WoWColor,
	["ClickTargetTradeButton"] = WoWColor,
	["ClickTradeButton"] = WoWColor,
	["CloseAllBags"] = WoWColor,
	["CloseAllWindows"] = WoWColor,
	["CloseAllWindows_WithExceptions"] = WoWColor,
	["CloseArenaTeamRoster"] = WoWColor,
	["CloseAuctionHouse"] = WoWColor,
	["CloseBackpack"] = WoWColor,
	["CloseBag"] = WoWColor,
	["CloseBankBagFrames"] = WoWColor,
	["CloseBankFrame"] = WoWColor,
	["CloseBattlefield"] = WoWColor,
	["CloseChildWindows"] = WoWColor,
	["CloseDropDownMenus"] = WoWColor,
	["CloseGossip"] = WoWColor,
	["CloseGuildBankFrame"] = WoWColor,
	["CloseGuildRegistrar"] = WoWColor,
	["CloseGuildRoster"] = WoWColor,
	["CloseItemText"] = WoWColor,
	["CloseLoot"] = WoWColor,
	["CloseMail"] = WoWColor,
	["CloseMenus"] = WoWColor,
	["CloseMerchant"] = WoWColor,
	["ClosePetStables"] = WoWColor,
	["ClosePetition"] = WoWColor,
	["ClosePetitionVendor"] = WoWColor,
	["CloseQuest"] = WoWColor,
	["CloseSocketInfo"] = WoWColor,
	["CloseSpecialWindows"] = WoWColor,
	["CloseTabardCreation"] = WoWColor,
	["CloseTaxiMap"] = WoWColor,
	["CloseTrade"] = WoWColor,
	["CloseTradeSkill"] = WoWColor,
	["CloseTrainer"] = WoWColor,
	["CloseWindows"] = WoWColor,
	["CoinPickupFrameCancel_Click"] = WoWColor,
	["CoinPickupFrameLeft_Click"] = WoWColor,
	["CoinPickupFrameOkay_Click"] = WoWColor,
	["CoinPickupFrameRight_Click"] = WoWColor,
	["CoinPickupFrame_OnChar"] = WoWColor,
	["CoinPickupFrame_OnHide"] = WoWColor,
	["CoinPickupFrame_OnKeyDown"] = WoWColor,
	["CoinPickupFrame_OnKeyUp"] = WoWColor,
	["CollapseAllFactionHeaders"] = WoWColor,
	["CollapseChannelHeader"] = WoWColor,
	["CollapseFactionHeader"] = WoWColor,
	["CollapseQuestHeader"] = WoWColor,
	["CollapseSkillHeader"] = WoWColor,
	["CollapseTradeSkillSubClass"] = WoWColor,
	["CollapseTrainerSkillLine"] = WoWColor,
	["ColorClassesCheckBox_OnClick"] = WoWColor,
	["ColorPaperDollStat"] = WoWColor,
	["ColorPicker_GetPreviousValues"] = WoWColor,
	["CombatConfig_Colorize_Update"] = WoWColor,
	["CombatConfig_CreateCombatFilter"] = WoWColor,
	["CombatConfig_DeleteCurrentCombatFilter"] = WoWColor,
	["CombatConfig_Formatting_Update"] = WoWColor,
	["CombatConfig_SetCombatFiltersToDefault"] = WoWColor,
	["CombatConfig_SetFilterName"] = WoWColor,
	["CombatConfig_Settings_Update"] = WoWColor,
	["CombatFeedback_Initialize"] = WoWColor,
	["CombatFeedback_OnCombatEvent"] = WoWColor,
	["CombatFeedback_OnUpdate"] = WoWColor,
	["CombatFeedback_StartFullscreenStatus"] = WoWColor,
	["CombatFeedback_StopFullscreenStatus"] = WoWColor,
	["CombatLogAddFilter"] = WoWColor,
	["CombatLogAdvanceEntry"] = WoWColor,
	["CombatLogClearEntries"] = WoWColor,
	["CombatLogGetCurrentEntry"] = WoWColor,
	["CombatLogGetNumEntries"] = WoWColor,
	["CombatLogGetRetentionTime"] = WoWColor,
	["CombatLogResetFilter"] = WoWColor,
	["CombatLogSetCurrentEntry"] = WoWColor,
	["CombatLogSetRetentionTime"] = WoWColor,
	["CombatLog_AddEvent"] = WoWColor,
	["CombatLog_Color_ColorArrayByEventType"] = WoWColor,
	["CombatLog_Color_ColorArrayBySchool"] = WoWColor,
	["CombatLog_Color_ColorArrayByUnitType"] = WoWColor,
	["CombatLog_Color_ColorStringByEventType"] = WoWColor,
	["CombatLog_Color_ColorStringBySchool"] = WoWColor,
	["CombatLog_Color_ColorStringByUnitType"] = WoWColor,
	["CombatLog_Color_FloatToText"] = WoWColor,
	["CombatLog_Color_HighlightColorArray"] = WoWColor,
	["CombatLog_LoadUI"] = WoWColor,
	["CombatLog_Object_IsA"] = WoWColor,
	["CombatLog_OnEvent"] = WoWColor,
	["CombatLog_String_DamageResultString"] = WoWColor,
	["CombatLog_String_GetIcon"] = WoWColor,
	["CombatLog_String_GetToken"] = WoWColor,
	["CombatLog_String_PowerType"] = WoWColor,
	["CombatLog_String_SchoolString"] = WoWColor,
	["CombatTextSetActiveUnit"] = WoWColor,
	["CombatText_AddMessage"] = WoWColor,
	["CombatText_ClearAnimationList"] = WoWColor,
	["CombatText_FountainScroll"] = WoWColor,
	["CombatText_GetAvailableString"] = WoWColor,
	["CombatText_GetOldestString"] = WoWColor,
	["CombatText_OnEvent"] = WoWColor,
	["CombatText_OnLoad"] = WoWColor,
	["CombatText_OnUpdate"] = WoWColor,
	["CombatText_RemoveMessage"] = WoWColor,
	["CombatText_StandardScroll"] = WoWColor,
	["CombatText_UpdateDisplayedMessages"] = WoWColor,
	["ComboFrame_OnEvent"] = WoWColor,
	["ComboFrame_Update"] = WoWColor,
	["ComboPointShineFadeIn"] = WoWColor,
	["ComboPointShineFadeOut"] = WoWColor,
	["CommentatorAddPlayer"] = WoWColor,
	["CommentatorEnterInstance"] = WoWColor,
	["CommentatorExitInstance"] = WoWColor,
	["CommentatorFollowPlayer"] = WoWColor,
	["CommentatorGetCamera"] = WoWColor,
	["CommentatorGetCurrentMapID"] = WoWColor,
	["CommentatorGetInstanceInfo"] = WoWColor,
	["CommentatorGetMapInfo"] = WoWColor,
	["CommentatorGetMode"] = WoWColor,
	["CommentatorGetNumMaps"] = WoWColor,
	["CommentatorGetNumPlayers"] = WoWColor,
	["CommentatorGetPlayerInfo"] = WoWColor,
	["CommentatorGetSkirmishMode"] = WoWColor,
	["CommentatorGetSkirmishQueueCount"] = WoWColor,
	["CommentatorGetSkirmishQueuePlayerInfo"] = WoWColor,
	["CommentatorLookatPlayer"] = WoWColor,
	["CommentatorRemovePlayer"] = WoWColor,
	["CommentatorRequestSkirmishMode"] = WoWColor,
	["CommentatorRequestSkirmishQueueData"] = WoWColor,
	["CommentatorSetBattlemaster"] = WoWColor,
	["CommentatorSetCamera"] = WoWColor,
	["CommentatorSetCameraCollision"] = WoWColor,
	["CommentatorSetMapAndInstanceIndex"] = WoWColor,
	["CommentatorSetMode"] = WoWColor,
	["CommentatorSetMoveSpeed"] = WoWColor,
	["CommentatorSetPlayerIndex"] = WoWColor,
	["CommentatorSetSkirmishMatchmakingMode"] = WoWColor,
	["CommentatorSetTargetHeightOffset"] = WoWColor,
	["CommentatorStartInstance"] = WoWColor,
	["CommentatorStartSkirmishMatch"] = WoWColor,
	["CommentatorToggleMode"] = WoWColor,
	["CommentatorUpdateMapInfo"] = WoWColor,
	["CommentatorUpdatePlayerInfo"] = WoWColor,
	["CommentatorZoomIn"] = WoWColor,
	["CommentatorZoomOut"] = WoWColor,
	["CompanionButton_OnClick"] = WoWColor,
	["CompanionButton_OnDrag"] = WoWColor,
	["CompanionButton_OnEnter"] = WoWColor,
	["CompanionButton_OnLoad"] = WoWColor,
	["CompanionButton_OnModifiedClick"] = WoWColor,
	["CompanionSummonButton_OnClick"] = WoWColor,
	["ComplainChat"] = WoWColor,
	["ComplainInboxItem"] = WoWColor,
	["CompleteLFGRoleCheck"] = WoWColor,
	["CompleteQuest"] = WoWColor,
	["ComputePetBonus"] = WoWColor,
	["ConfirmAcceptQuest"] = WoWColor,
	["ConfirmBindOnUse"] = WoWColor,
	["ConfirmBinder"] = WoWColor,
	["ConfirmLootRoll"] = WoWColor,
	["ConfirmLootSlot"] = WoWColor,
	["ConfirmReadyCheck"] = WoWColor,
	["ConfirmSummon"] = WoWColor,
	["ConfirmTalentWipe"] = WoWColor,
	["ConsoleAddMessage"] = WoWColor,
	["ConsoleExec"] = WoWColor,
	["ConsolePrint"] = WoWColor,
	["ConsolidatedBuffs_OnEnter"] = WoWColor,
	["ConsolidatedBuffs_OnHide"] = WoWColor,
	["ConsolidatedBuffs_OnShow"] = WoWColor,
	["ConsolidatedBuffs_OnUpdate"] = WoWColor,
	["ConsolidatedBuffs_UpdateAllAnchors"] = WoWColor,
	["ContainerFrameItemButton_OnClick"] = WoWColor,
	["ContainerFrameItemButton_OnDrag"] = WoWColor,
	["ContainerFrameItemButton_OnEnter"] = WoWColor,
	["ContainerFrameItemButton_OnLoad"] = WoWColor,
	["ContainerFrameItemButton_OnModifiedClick"] = WoWColor,
	["ContainerFrame_GenerateFrame"] = WoWColor,
	["ContainerFrame_GetExtendedPriceString"] = WoWColor,
	["ContainerFrame_GetOpenFrame"] = WoWColor,
	["ContainerFrame_OnEvent"] = WoWColor,
	["ContainerFrame_OnHide"] = WoWColor,
	["ContainerFrame_OnLoad"] = WoWColor,
	["ContainerFrame_OnShow"] = WoWColor,
	["ContainerFrame_Update"] = WoWColor,
	["ContainerFrame_UpdateCooldown"] = WoWColor,
	["ContainerFrame_UpdateCooldowns"] = WoWColor,
	["ContainerFrame_UpdateLocked"] = WoWColor,
	["ContainerFrame_UpdateLockedItem"] = WoWColor,
	["ContainerIDToInventoryID"] = WoWColor,
	["ContainerRefundItemPurchase"] = WoWColor,
	["ConvertToRaid"] = WoWColor,
	["ConvertToParty"] = WoWColor,
	["CooldownFrame_SetTimer"] = WoWColor,
	["CopyTable"] = WoWColor,
	["CreateChatChannelList"] = WoWColor,
	["CreateFont"] = WoWColor,
	["CreateFrame"] = WoWColor,
	["CreateMacro"] = WoWColor,
	["CreateMiniWorldMapArrowFrame"] = WoWColor,
	["CreateWorldMapArrowFrame"] = WoWColor,
	["CursorCanGoInSlot"] = WoWColor,
	["CursorHasItem"] = WoWColor,
	["CursorHasMacro"] = WoWColor,
	["CursorHasMoney"] = WoWColor,
	["CursorHasSpell"] = WoWColor,
	["CursorOnUpdate"] = WoWColor,
	["CursorUpdate"] = WoWColor,
	["DamageColor_OpenColorPicker"] = WoWColor,
	["DeathKnniggetThrobFunction"] = WoWColor,
	["DebuffButton_UpdateAnchors"] = WoWColor,
	["DeclineArenaTeam"] = WoWColor,
	["DeclineGroup"] = WoWColor,
	["DeclineGuild"] = WoWColor,
	["DeclineInvite"] = WoWColor,
	["DeclineLevelGrant"] = WoWColor,
	["DeclineName"] = WoWColor,
	["DeclineQuest"] = WoWColor,
	["DeclineResurrect"] = WoWColor,
	["DelIgnore"] = WoWColor,
	["DelMute"] = WoWColor,
	["DeleteCursorItem"] = WoWColor,
	["DeleteEquipmentSet"] = WoWColor,
	["DeleteFile"] = WoWColor,
	["DeleteGMTicket"] = WoWColor,
	["DeleteInboxItem"] = WoWColor,
	["DeleteMacro"] = WoWColor,
	["DemoteAssistant"] = WoWColor,
	["DepositGuildBankMoney"] = WoWColor,
	["DescendStop"] = WoWColor,
	["DestroyTotem"] = WoWColor,
	["DetectWowMouse"] = WoWColor,
	["DisableAddOn"] = WoWColor,
	["DisableAllAddOns"] = WoWColor,
	["DisablePagingButton"] = WoWColor,
	["DisableSpellAutocast"] = WoWColor,
	["Disable_BagButtons"] = WoWColor,
	["DismissCompanion"] = WoWColor,
	["Dismount"] = WoWColor,
	["DisplayChannelOwner"] = WoWColor,
	["DisplayChannelVoiceOff"] = WoWColor,
	["DisplayChannelVoiceOn"] = WoWColor,
	["DoEmote"] = WoWColor,
	["DoReadyCheck"] = WoWColor,
	["DoTradeSkill"] = WoWColor,
	["DownloadSettings"] = WoWColor,
	["DrawOneHopLines"] = WoWColor,
	["DrawRouteLine"] = WoWColor,
	["DressUpItemLink"] = WoWColor,
	["DressUpTexturePath"] = WoWColor,
	["DropCursorMoney"] = WoWColor,
	["DropItemOnUnit"] = WoWColor,
	["DungeonCompletionAlertFrameReward_OnEnter"] = WoWColor,
	["DungeonCompletionAlertFrameReward_OnLeave"] = WoWColor,
	["DungeonCompletionAlertFrameReward_SetReward"] = WoWColor,
	["DungeonCompletionAlertFrame_FixAnchors"] = WoWColor,
	["DungeonCompletionAlertFrame_OnLoad"] = WoWColor,
	["DungeonCompletionAlertFrame_ShowAlert"] = WoWColor,
	["DungeonUsesTerrainMap"] = WoWColor,
	["DurabilityFrame_SetAlerts"] = WoWColor,
	["DynamicScrollFrame_CreateButtons"] = WoWColor,
	["DynamicScrollFrame_OnVerticalScroll"] = WoWColor,
	["DynamicScrollFrame_UnlockAllHighlights"] = WoWColor,
	["DynamicScrollFrame_Update"] = WoWColor,
	["EasyMenu"] = WoWColor,
	["EasyMenu_Initialize"] = WoWColor,
	["EditBox_ClearFocus"] = WoWColor,
	["EditBox_ClearHighlight"] = WoWColor,
	["EditBox_HandleTabbing"] = WoWColor,
	["EditBox_HighlightText"] = WoWColor,
	["EditBox_SetFocus"] = WoWColor,
	["EditMacro"] = WoWColor,
	["EjectPassengerFromSeat"] = WoWColor,
	["EmoteMenu_Click"] = WoWColor,
	["EmoteMenu_OnLoad"] = WoWColor,
	["EnableAddOn"] = WoWColor,
	["EnableAllAddOns"] = WoWColor,
	["EnablePagingButton"] = WoWColor,
	["EnableSpellAutocast"] = WoWColor,
	["Enable_BagButtons"] = WoWColor,
	["EndBoundTradeable"] = WoWColor,
	["EndRefund"] = WoWColor,
	["EnumerateFrames"] = WoWColor,
	["EnumerateServerChannels"] = WoWColor,
	["EquipCursorItem"] = WoWColor,
	["EquipItemByName"] = WoWColor,
	["EquipPendingItem"] = WoWColor,
	["EquipmentManagerClearIgnoredSlotsForSave"] = WoWColor,
	["EquipmentManagerIgnoreSlotForSave"] = WoWColor,
	["EquipmentManagerIsSlotIgnoredForSave"] = WoWColor,
	["EquipmentManagerUnignoreSlotForSave"] = WoWColor,
	["EquipmentManager_EquipContainerItem"] = WoWColor,
	["EquipmentManager_EquipInventoryItem"] = WoWColor,
	["EquipmentManager_EquipItemByLocation"] = WoWColor,
	["EquipmentManager_EquipSet"] = WoWColor,
	["EquipmentManager_GetItemInfoByLocation"] = WoWColor,
	["EquipmentManager_OnEvent"] = WoWColor,
	["EquipmentManager_PutItemInInventory"] = WoWColor,
	["EquipmentManager_RunAction"] = WoWColor,
	["EquipmentManager_UnequipItemInSlot"] = WoWColor,
	["EquipmentManager_UnpackLocation"] = WoWColor,
	["EquipmentManager_UpdateFreeBagSpace"] = WoWColor,
	["EquipmentSetContainsLockedItems"] = WoWColor,
	["ExhaustionTick_OnEvent"] = WoWColor,
	["ExhaustionTick_OnLoad"] = WoWColor,
	["ExhaustionTick_OnUpdate"] = WoWColor,
	["ExhaustionToolTipText"] = WoWColor,
	["ExpandAllFactionHeaders"] = WoWColor,
	["ExpandChannelHeader"] = WoWColor,
	["ExpandCurrencyList"] = WoWColor,
	["ExpandFactionHeader"] = WoWColor,
	["ExpandQuestHeader"] = WoWColor,
	["ExpandSkillHeader"] = WoWColor,
	["ExpandTradeSkillSubClass"] = WoWColor,
	["ExpandTrainerSkillLine"] = WoWColor,
	["EyeTemplate_OnUpdate"] = WoWColor,
	["EyeTemplate_StartAnimating"] = WoWColor,
	["EyeTemplate_StopAnimating"] = WoWColor,
	["FCFChannelDropDown_OnClick"] = WoWColor,
	["FCFClickAnywhereButton_OnEvent"] = WoWColor,
	["FCFClickAnywhereButton_OnLoad"] = WoWColor,
	["FCFClickAnywhereButton_UpdateState"] = WoWColor,
	["FCFDockOverflowButton_OnClick"] = WoWColor,
	["FCFDockOverflowButton_OnEvent"] = WoWColor,
	["FCFDockOverflowButton_UpdatePulseState"] = WoWColor,
	["FCFDockOverflowListButton_OnClick"] = WoWColor,
	["FCFDockOverflowListButton_SetValue"] = WoWColor,
	["FCFDockOverflowList_Update"] = WoWColor,
	["FCFDockOverflow_CloseLists"] = WoWColor,
	["FCFDockScrollFrame_GetLeftmostTab"] = WoWColor,
	["FCFDockScrollFrame_GetScrollDistanceNeeded"] = WoWColor,
	["FCFDockScrollFrame_JumpToTab"] = WoWColor,
	["FCFDockScrollFrame_OnUpdate"] = WoWColor,
	["FCFDock_AddChatFrame"] = WoWColor,
	["FCFDock_CalculateTabSize"] = WoWColor,
	["FCFDock_ForceReanchoring"] = WoWColor,
	["FCFDock_GetChatFrames"] = WoWColor,
	["FCFDock_GetInsertIndex"] = WoWColor,
	["FCFDock_GetSelectedWindow"] = WoWColor,
	["FCFDock_HasDockedChatFrame"] = WoWColor,
	["FCFDock_HideInsertHighlight"] = WoWColor,
	["FCFDock_OnEvent"] = WoWColor,
	["FCFDock_OnLoad"] = WoWColor,
	["FCFDock_OnPrimarySizeChanged"] = WoWColor,
	["FCFDock_OnUpdate"] = WoWColor,
	["FCFDock_PlaceInsertHighlight"] = WoWColor,
	["FCFDock_RemoveChatFrame"] = WoWColor,
	["FCFDock_ScrollToSelectedTab"] = WoWColor,
	["FCFDock_SelectWindow"] = WoWColor,
	["FCFDock_SetDirty"] = WoWColor,
	["FCFDock_SetPrimary"] = WoWColor,
	["FCFDock_UpdateTabs"] = WoWColor,
	["FCFDropDown_LoadChannels"] = WoWColor,
	["FCFDropDown_LoadChatTypes"] = WoWColor,
	["FCFManager_GetNumDedicatedFrames"] = WoWColor,
	["FCFManager_RegisterDedicatedFrame"] = WoWColor,
	["FCFManager_ShouldSuppressMessage"] = WoWColor,
	["FCFManager_UnregisterDedicatedFrame"] = WoWColor,
	["FCFMessageTypeDropDown_OnClick"] = WoWColor,
	["FCFMin_UpdateColors"] = WoWColor,
	["FCFOptionsDropDown_Initialize"] = WoWColor,
	["FCFOptionsDropDown_OnLoad"] = WoWColor,
	["FCFTab_OnDragStop"] = WoWColor,
	["FCFTab_OnUpdate"] = WoWColor,
	["FCFTab_UpdateAlpha"] = WoWColor,
	["FCFTab_UpdateColors"] = WoWColor,
	["FCF_CancelFontColorSettings"] = WoWColor,
	["FCF_CancelWindowColorSettings"] = WoWColor,
	["FCF_Close"] = WoWColor,
	["FCF_CopyChatSettings"] = WoWColor,
	["FCF_CreateMinimizedFrame"] = WoWColor,
	["FCF_DockFrame"] = WoWColor,
	["FCF_DockUpdate"] = WoWColor,
	["FCF_FadeInChatFrame"] = WoWColor,
	["FCF_FadeOutChatFrame"] = WoWColor,
	["FCF_FlagMinimizedPositionReset"] = WoWColor,
	["FCF_FlashTab"] = WoWColor,
	["FCF_GetButtonSide"] = WoWColor,
	["FCF_GetChatWindowInfo"] = WoWColor,
	["FCF_GetCurrentChatFrame"] = WoWColor,
	["FCF_GetCurrentChatFrameID"] = WoWColor,
	["FCF_GetNumActiveChatFrames"] = WoWColor,
	["FCF_HideOnFadeFinished"] = WoWColor,
	["FCF_IsValidChatFrame"] = WoWColor,
	["FCF_LeaveConversation"] = WoWColor,
	["FCF_LoadChatSubTypes"] = WoWColor,
	["FCF_MaximizeFrame"] = WoWColor,
	["FCF_MinimizeFrame"] = WoWColor,
	["FCF_NewChatWindow"] = WoWColor,
	["FCF_OnUpdate"] = WoWColor,
	["FCF_OpenNewWindow"] = WoWColor,
	["FCF_OpenTemporaryWindow"] = WoWColor,
	["FCF_PopInWindow"] = WoWColor,
	["FCF_RenameChatWindow_Popup"] = WoWColor,
	["FCF_ResetAllWindows"] = WoWColor,
	["FCF_ResetChatWindows"] = WoWColor,
	["FCF_RestoreChatsToFrame"] = WoWColor,
	["FCF_RestorePositionAndDimensions"] = WoWColor,
	["FCF_SaveDock"] = WoWColor,
	["FCF_SavePositionAndDimensions"] = WoWColor,
	["FCF_SelectDockFrame"] = WoWColor,
	["FCF_SetButtonSide"] = WoWColor,
	["FCF_SetChatTypeColor"] = WoWColor,
	["FCF_SetChatWindowBackGroundColor"] = WoWColor,
	["FCF_SetChatWindowFontSize"] = WoWColor,
	["FCF_SetChatWindowOpacity"] = WoWColor,
	["FCF_SetExpandedUninteractable"] = WoWColor,
	["FCF_SetLocked"] = WoWColor,
	["FCF_SetTabPosition"] = WoWColor,
	["FCF_SetTemporaryWindowType"] = WoWColor,
	["FCF_SetUninteractable"] = WoWColor,
	["FCF_SetWindowAlpha"] = WoWColor,
	["FCF_SetWindowColor"] = WoWColor,
	["FCF_SetWindowName"] = WoWColor,
	["FCF_Set_NormalChat"] = WoWColor,
	["FCF_StartAlertFlash"] = WoWColor,
	["FCF_StopAlertFlash"] = WoWColor,
	["FCF_StopDragging"] = WoWColor,
	["FCF_StripChatMsg"] = WoWColor,
	["FCF_TabCompare"] = WoWColor,
	["FCF_Tab_OnClick"] = WoWColor,
	["FCF_ToggleLock"] = WoWColor,
	["FCF_ToggleUninteractable"] = WoWColor,
	["FCF_UnDockFrame"] = WoWColor,
	["FCF_UpdateButtonSide"] = WoWColor,
	["FCF_UpdateDockPosition"] = WoWColor,
	["FactionToggleAtWar"] = WoWColor,
	["FadingFrame_OnLoad"] = WoWColor,
	["FadingFrame_OnUpdate"] = WoWColor,
	["FadingFrame_SetFadeInTime"] = WoWColor,
	["FadingFrame_SetFadeOutTime"] = WoWColor,
	["FadingFrame_SetHoldTime"] = WoWColor,
	["FadingFrame_Show"] = WoWColor,
	["FauxScrollFrame_GetOffset"] = WoWColor,
	["FauxScrollFrame_OnVerticalScroll"] = WoWColor,
	["FauxScrollFrame_SetOffset"] = WoWColor,
	["FauxScrollFrame_Update"] = WoWColor,
	["FillLocalizedClassList"] = WoWColor,
	["FindSpellBookSlotByID"] = WoWColor,
	["FlagTutorial"] = WoWColor,
	["FlipCameraYaw"] = WoWColor,
	["FloatingChatFrameManager_OnEvent"] = WoWColor,
	["FloatingChatFrameManager_OnLoad"] = WoWColor,
	["FloatingChatFrame_OnEvent"] = WoWColor,
	["FloatingChatFrame_OnLoad"] = WoWColor,
	["FloatingChatFrame_OnMouseScroll"] = WoWColor,
	["FloatingChatFrame_Update"] = WoWColor,
	["FocusFrameDropDown_Initialize"] = WoWColor,
	["FocusFrame_IsLocked"] = WoWColor,
	["FocusFrame_OnDragStart"] = WoWColor,
	["FocusFrame_OnDragStop"] = WoWColor,
	["FocusFrame_SetLock"] = WoWColor,
	["FocusFrame_SetSmallSize"] = WoWColor,
	["FocusUnit"] = WoWColor,
	["FollowUnit"] = WoWColor,
	["ForceGossip"] = WoWColor,
	["ForceLogout"] = WoWColor,
	["ForceQuit"] = WoWColor,
	["FormatPaperDollTooltipStat"] = WoWColor,
	["FrameXML_Debug"] = WoWColor,
	["FriendsFrameAddFriendButton_OnClick"] = WoWColor,
	["FriendsFrameBNDropDown_Initialize"] = WoWColor,
	["FriendsFrameBNOfflineDropDown_Initialize"] = WoWColor,
	["FriendsFrameBroadcastInput_OnClearPressed"] = WoWColor,
	["FriendsFrameBroadcastInput_OnEnterPressed"] = WoWColor,
	["FriendsFrameBroadcastInput_OnEscapePressed"] = WoWColor,
	["FriendsFrameBroadcastInput_UpdateDisplay"] = WoWColor,
	["FriendsFrameDropDown_Initialize"] = WoWColor,
	["FriendsFrameFriendButton_OnClick"] = WoWColor,
	["FriendsFrameGuildStatusButton_OnClick"] = WoWColor,
	["FriendsFrameIgnoreButton_OnClick"] = WoWColor,
	["FriendsFrameMuteButton_OnClick"] = WoWColor,
	["FriendsFrameOfflineDropDown_Initialize"] = WoWColor,
	["FriendsFramePendingScrollFrame_AdjustScroll"] = WoWColor,
	["FriendsFrameSendMessageButton_OnClick"] = WoWColor,
	["FriendsFrameStatusDropDown_Initialize"] = WoWColor,
	["FriendsFrameStatusDropDown_OnLoad"] = WoWColor,
	["FriendsFrameStatusDropDown_OnShow"] = WoWColor,
	["FriendsFrameStatusDropDown_ShowTooltip"] = WoWColor,
	["FriendsFrameStatusDropDown_Update"] = WoWColor,
	["FriendsFrameTooltip_SetLine"] = WoWColor,
	["FriendsFrameTooltip_Show"] = WoWColor,
	["FriendsFrameUnsquelchButton_OnClick"] = WoWColor,
	["FriendsFrameWhoButton_OnClick"] = WoWColor,
	["FriendsFrame_CheckBattlenetStatus"] = WoWColor,
	["FriendsFrame_ClickSummonButton"] = WoWColor,
	["FriendsFrame_GetLastOnline"] = WoWColor,
	["FriendsFrame_GetTopButton"] = WoWColor,
	["FriendsFrame_GroupInvite"] = WoWColor,
	["FriendsFrame_OnEvent"] = WoWColor,
	["FriendsFrame_OnHide"] = WoWColor,
	["FriendsFrame_OnLoad"] = WoWColor,
	["FriendsFrame_OnShow"] = WoWColor,
	["FriendsFrame_RemoveFriend"] = WoWColor,
	["FriendsFrame_SelectFriend"] = WoWColor,
	["FriendsFrame_SelectSquelched"] = WoWColor,
	["FriendsFrame_SendMessage"] = WoWColor,
	["FriendsFrame_SetButton"] = WoWColor,
	["FriendsFrame_SetOnlineStatus"] = WoWColor,
	["FriendsFrame_ShowBNDropdown"] = WoWColor,
	["FriendsFrame_ShowDropdown"] = WoWColor,
	["FriendsFrame_ShowSubFrame"] = WoWColor,
	["FriendsFrame_SummonButton_OnEvent"] = WoWColor,
	["FriendsFrame_SummonButton_OnShow"] = WoWColor,
	["FriendsFrame_SummonButton_Update"] = WoWColor,
	["FriendsFrame_UnBlock"] = WoWColor,
	["FriendsFrame_UnIgnore"] = WoWColor,
	["FriendsFrame_UnMute"] = WoWColor,
	["FriendsFrame_Update"] = WoWColor,
	["FriendsFriendsButton_OnClick"] = WoWColor,
	["FriendsFriendsFrameDropDown_Initialize"] = WoWColor,
	["FriendsFriendsFrameDropDown_OnClick"] = WoWColor,
	["FriendsFriendsFrame_Close"] = WoWColor,
	["FriendsFriendsFrame_OnEvent"] = WoWColor,
	["FriendsFriendsFrame_Reset"] = WoWColor,
	["FriendsFriendsFrame_SendRequest"] = WoWColor,
	["FriendsFriendsFrame_Show"] = WoWColor,
	["FriendsFriendsList_Update"] = WoWColor,
	["FriendsList_Update"] = WoWColor,
	["GMChatFrame_LoadUI"] = WoWColor,
	["GMReportLag"] = WoWColor,
	["GMRequestPlayerInfo"] = WoWColor,
	["GMResponseNeedMoreHelp"] = WoWColor,
	["GMResponseResolve"] = WoWColor,
	["GMSurveyAnswer"] = WoWColor,
	["GMSurveyAnswerSubmit"] = WoWColor,
	["GMSurveyCommentSubmit"] = WoWColor,
	["GMSurveyFrame_LoadUI"] = WoWColor,
	["GMSurveyNumAnswers"] = WoWColor,
	["GMSurveyQuestion"] = WoWColor,
	["GMSurveySubmit"] = WoWColor,
	["GameMovieFinished"] = WoWColor,
	["GameTimeFrame_OnClick"] = WoWColor,
	["GameTimeFrame_OnEnter"] = WoWColor,
	["GameTimeFrame_OnEvent"] = WoWColor,
	["GameTimeFrame_OnLoad"] = WoWColor,
	["GameTimeFrame_OnUpdate"] = WoWColor,
	["GameTimeFrame_SetDate"] = WoWColor,
	["GameTime_ComputeMilitaryTime"] = WoWColor,
	["GameTime_ComputeMinutes"] = WoWColor,
	["GameTime_ComputeStandardTime"] = WoWColor,
	["GameTime_GetFormattedTime"] = WoWColor,
	["GameTime_GetGameTime"] = WoWColor,
	["GameTime_GetLocalTime"] = WoWColor,
	["GameTime_GetTime"] = WoWColor,
	["GameTime_UpdateTooltip"] = WoWColor,
	["GameTooltip_AddNewbieTip"] = WoWColor,
	["GameTooltip_ClearMoney"] = WoWColor,
	["GameTooltip_ClearStatusBars"] = WoWColor,
	["GameTooltip_Hide"] = WoWColor,
	["GameTooltip_HideResetCursor"] = WoWColor,
	["GameTooltip_OnHide"] = WoWColor,
	["GameTooltip_OnLoad"] = WoWColor,
	["GameTooltip_OnTooltipAddMoney"] = WoWColor,
	["GameTooltip_OnUpdate"] = WoWColor,
	["GameTooltip_SetDefaultAnchor"] = WoWColor,
	["GameTooltip_ShowCompareItem"] = WoWColor,
	["GameTooltip_ShowStatusBar"] = WoWColor,
	["GameTooltip_UnitColor"] = WoWColor,
	["GearManagerDialogDeleteSet_OnClick"] = WoWColor,
	["GearManagerDialogEquipSet_OnClick"] = WoWColor,
	["GearManagerDialogPopupCancel_OnClick"] = WoWColor,
	["GearManagerDialogPopupOkay_OnClick"] = WoWColor,
	["GearManagerDialogPopupOkay_Update"] = WoWColor,
	["GearManagerDialogPopup_OnHide"] = WoWColor,
	["GearManagerDialogPopup_OnLoad"] = WoWColor,
	["GearManagerDialogPopup_OnShow"] = WoWColor,
	["GearManagerDialogPopup_Update"] = WoWColor,
	["GearManagerDialogSaveSet_OnClick"] = WoWColor,
	["GearManagerDialog_OnEvent"] = WoWColor,
	["GearManagerDialog_OnHide"] = WoWColor,
	["GearManagerDialog_OnLoad"] = WoWColor,
	["GearManagerDialog_OnShow"] = WoWColor,
	["GearManagerDialog_Update"] = WoWColor,
	["GearSetButton_OnClick"] = WoWColor,
	["GearSetButton_OnEnter"] = WoWColor,
	["GearSetPopupButton_OnClick"] = WoWColor,
	["GetAbandonQuestItems"] = WoWColor,
	["GetAbandonQuestName"] = WoWColor,
	["GetAccountExpansionLevel"] = WoWColor,
	["GetAchievementCategory"] = WoWColor,
	["GetAchievementComparisonInfo"] = WoWColor,
	["GetAchievementCriteriaInfo"] = WoWColor,
	["GetAchievementInfo"] = WoWColor,
	["GetAchievementInfoFromCriteria"] = WoWColor,
	["GetAchievementLink"] = WoWColor,
	["GetAchievementNumCriteria"] = WoWColor,
	["GetAchievementNumRewards"] = WoWColor,
	["GetAchievementReward"] = WoWColor,
	["GetActionAutocast"] = WoWColor,
	["GetActionBarPage"] = WoWColor,
	["GetActionBarToggles"] = WoWColor,
	["GetActionCooldown"] = WoWColor,
	["GetActionCount"] = WoWColor,
	["GetActionInfo"] = WoWColor,
	["GetActionText"] = WoWColor,
	["GetActionTexture"] = WoWColor,
	["GetActiveLevel"] = WoWColor,
	["GetActiveTalentGroup"] = WoWColor,
	["GetActiveTitle"] = WoWColor,
	["GetActiveVoiceChannel"] = WoWColor,
	["GetAddOnCPUUsage"] = WoWColor,
	["GetAddOnDependencies"] = WoWColor,
	["GetAddOnInfo"] = WoWColor,
	["GetAddOnMemoryUsage"] = WoWColor,
	["GetAddOnMetadata"] = WoWColor,
	["GetAdjustedSkillPoints"] = WoWColor,
	["GetAllowLowLevelRaid"] = WoWColor,
	["GetAreaSpiritHealerTime"] = WoWColor,
	["GetArenaCurrency"] = WoWColor,
	["GetArenaTeam"] = WoWColor,
	["GetArenaTeamGdfInfo"] = WoWColor,
	["GetArenaTeamRosterInfo"] = WoWColor,
	["GetArenaTeamRosterSelection"] = WoWColor,
	["GetArenaTeamRosterShowOffline"] = WoWColor,
	["GetArmorPenetration"] = WoWColor,
	["GetAttackPowerForStat"] = WoWColor,
	["GetAuctionHouseDepositRate"] = WoWColor,
	["GetAuctionInvTypes"] = WoWColor,
	["GetAuctionItemClasses"] = WoWColor,
	["GetAuctionItemInfo"] = WoWColor,
	["GetAuctionItemLink"] = WoWColor,
	["GetAuctionItemSubClasses"] = WoWColor,
	["GetAuctionItemTimeLeft"] = WoWColor,
	["GetAuctionSellItemInfo"] = WoWColor,
	["GetAuctionSort"] = WoWColor,
	["GetAutoCompletePresenceID"] = WoWColor,
	["GetAutoCompleteResults"] = WoWColor,
	["GetAvailableLevel"] = WoWColor,
	["GetAvailableQuestInfo"] = WoWColor,
	["GetAvailableRoles"] = WoWColor,
	["GetAvailableTitle"] = WoWColor,
	["GetBackgroundTexCoordsForRole"] = WoWColor,
	["GetBackpackCurrencyInfo"] = WoWColor,
	["GetBackpackFrame"] = WoWColor,
	["GetBagName"] = WoWColor,
	["GetBankSlotCost"] = WoWColor,
	["GetBarberShopStyleInfo"] = WoWColor,
	["GetBarberShopTotalCost"] = WoWColor,
	["GetBaseMip"] = WoWColor,
	["GetBattlefieldArenaFaction"] = WoWColor,
	["GetBattlefieldEstimatedWaitTime"] = WoWColor,
	["GetBattlefieldFlagPosition"] = WoWColor,
	["GetBattlefieldInfo"] = WoWColor,
	["GetBattlefieldInstanceExpiration"] = WoWColor,
	["GetBattlefieldInstanceInfo"] = WoWColor,
	["GetBattlefieldInstanceRunTime"] = WoWColor,
	["GetBattlefieldMapIconScale"] = WoWColor,
	["GetBattlefieldPortExpiration"] = WoWColor,
	["GetBattlefieldPosition"] = WoWColor,
	["GetBattlefieldScore"] = WoWColor,
	["GetBattlefieldStatData"] = WoWColor,
	["GetBattlefieldStatInfo"] = WoWColor,
	["GetBattlefieldStatus"] = WoWColor,
	["GetBattlefieldTeamInfo"] = WoWColor,
	["GetBattlefieldTimeWaited"] = WoWColor,
	["GetBattlefieldVehicleInfo"] = WoWColor,
	["GetBattlefieldWinner"] = WoWColor,
	["GetBattlegroundInfo"] = WoWColor,
	["GetBidderAuctionItems"] = WoWColor,
	["GetBillingTimeRested"] = WoWColor,
	["GetBindLocation"] = WoWColor,
	["GetBinding"] = WoWColor,
	["GetBindingAction"] = WoWColor,
	["GetBindingByKey"] = WoWColor,
	["GetBindingFromClick"] = WoWColor,
	["GetBindingKey"] = WoWColor,
	["GetBindingText"] = WoWColor,
	["GetBlockChance"] = WoWColor,
	["GetBonusBarOffset"] = WoWColor,
	["GetBuildInfo"] = WoWColor,
	["GetBuybackItemInfo"] = WoWColor,
	["GetBuybackItemLink"] = WoWColor,
	["GetCVar"] = WoWColor,
	["GetCVarAbsoluteMax"] = WoWColor,
	["GetCVarAbsoluteMin"] = WoWColor,
	["GetCVarBool"] = WoWColor,
	["GetCVarDefault"] = WoWColor,
	["GetCVarInfo"] = WoWColor,
	["GetCVarMax"] = WoWColor,
	["GetCVarMin"] = WoWColor,
	["GetCategoryInfo"] = WoWColor,
	["GetCategoryList"] = WoWColor,
	["GetCategoryNumAchievements"] = WoWColor,
	["GetChannelDisplayInfo"] = WoWColor,
	["GetChannelList"] = WoWColor,
	["GetChannelName"] = WoWColor,
	["GetChannelRosterInfo"] = WoWColor,
	["GetChatTypeIndex"] = WoWColor,
	["GetChatUnitColor"] = WoWColor,
	["GetChatWindowChannels"] = WoWColor,
	["GetChatWindowInfo"] = WoWColor,
	["GetChatWindowMessages"] = WoWColor,
	["GetChatWindowSavedDimensions"] = WoWColor,
	["GetChatWindowSavedPosition"] = WoWColor,
	["GetClickFrame"] = WoWColor,
	["GetCoinIcon"] = WoWColor,
	["GetCoinText"] = WoWColor,
	["GetCoinTextureString"] = WoWColor,
	["GetColoredName"] = WoWColor,
	["GetCombatRating"] = WoWColor,
	["GetCombatRatingBonus"] = WoWColor,
	["GetComboPoints"] = WoWColor,
	["GetCompanionCooldown"] = WoWColor,
	["GetCompanionInfo"] = WoWColor,
	["GetComparisonAchievementPoints"] = WoWColor,
	["GetComparisonCategoryNumAchievements"] = WoWColor,
	["GetComparisonStatistic"] = WoWColor,
	["GetContainerFreeSlots"] = WoWColor,
	["GetContainerItemCooldown"] = WoWColor,
	["GetContainerItemDurability"] = WoWColor,
	["GetContainerItemGems"] = WoWColor,
	["GetContainerItemID"] = WoWColor,
	["GetContainerItemInfo"] = WoWColor,
	["GetContainerItemLink"] = WoWColor,
	["GetContainerItemPurchaseInfo"] = WoWColor,
	["GetContainerItemPurchaseItem"] = WoWColor,
	["GetContainerItemQuestInfo"] = WoWColor,
	["GetContainerNumFreeSlots"] = WoWColor,
	["GetContainerNumSlots"] = WoWColor,
	["GetCorpseMapPosition"] = WoWColor,
	["GetCorpseRecoveryDelay"] = WoWColor,
	["GetCritChance"] = WoWColor,
	["GetCritChanceFromAgility"] = WoWColor,
	["GetCurrencyListInfo"] = WoWColor,
	["GetCurrencyListSize"] = WoWColor,
	["GetCurrentArenaSeason"] = WoWColor,
	["GetCurrentBindingSet"] = WoWColor,
	["GetCurrentGuildBankTab"] = WoWColor,
	["GetCurrentKeyBoardFocus"] = WoWColor,
	["GetCurrentMapAreaID"] = WoWColor,
	["GetCurrentMapContinent"] = WoWColor,
	["GetCurrentMapDungeonLevel"] = WoWColor,
	["GetCurrentMapZone"] = WoWColor,
	["GetCurrentMultisampleFormat"] = WoWColor,
	["GetCurrentResolution"] = WoWColor,
	["GetCurrentTitle"] = WoWColor,
	["GetCursorInfo"] = WoWColor,
	["GetCursorMoney"] = WoWColor,
	["GetCursorPosition"] = WoWColor,
	["GetDailyQuestsCompleted"] = WoWColor,
	["GetDamageBonusStat"] = WoWColor,
	["GetDeathReleasePosition"] = WoWColor,
	["GetDebugStats"] = WoWColor,
	["GetDebugZoneMap"] = WoWColor,
	["GetDefaultLanguage"] = WoWColor,
	["GetDenominationsFromCopper"] = WoWColor,
	["GetDodgeBlockParryChanceFromDefense"] = WoWColor,
	["GetDodgeChance"] = WoWColor,
	["GetDungeonDifficulty"] = WoWColor,
	["GetDungeonNameWithDifficulty"] = WoWColor,
	["GetEquipmentSetIconInfo"] = WoWColor,
	["GetEquipmentSetInfo"] = WoWColor,
	["GetEquipmentSetInfoByName"] = WoWColor,
	["GetEquipmentSetItemIDs"] = WoWColor,
	["GetEquipmentSetLocations"] = WoWColor,
	["GetEventCPUUsage"] = WoWColor,
	["GetExistingLocales"] = WoWColor,
	["GetExistingSocketInfo"] = WoWColor,
	["GetExistingSocketLink"] = WoWColor,
	["GetExpansionLevel"] = WoWColor,
	["GetExpertise"] = WoWColor,
	["GetExpertisePercent"] = WoWColor,
	["GetExtendedItemInfo"] = WoWColor,
	["GetFacialHairCustomization"] = WoWColor,
	["GetFactionInfo"] = WoWColor,
	["GetFactionInfoByID"] = WoWColor,
	["GetFarclip"] = WoWColor,
	["GetFirstTradeSkill"] = WoWColor,
	["GetFixedLink"] = WoWColor,
	["GetFrameCPUUsage"] = WoWColor,
	["GetFrameHandle"] = WoWColor,
	["GetFrameHandleFrame"] = WoWColor,
	["GetFramerate"] = WoWColor,
	["GetFramesRegisteredForEvent"] = WoWColor,
	["GetFriendInfo"] = WoWColor,
	["GetFullRaidList"] = WoWColor,
	["GetFunctionCPUUsage"] = WoWColor,
	["GetGMStatus"] = WoWColor,
	["GetGMTicket"] = WoWColor,
	["GetGMTicketCategories"] = WoWColor,
	["GetGameTime"] = WoWColor,
	["GetGamma"] = WoWColor,
	["GetGlyphLink"] = WoWColor,
	["GetGlyphSocketInfo"] = WoWColor,
	["GetGossipActiveQuests"] = WoWColor,
	["GetGossipAvailableQuests"] = WoWColor,
	["GetGossipOptions"] = WoWColor,
	["GetGossipText"] = WoWColor,
	["GetGreetingText"] = WoWColor,
	["GetGroupPreviewTalentPointsSpent"] = WoWColor,
	["GetGuildBankItemInfo"] = WoWColor,
	["GetGuildBankItemLink"] = WoWColor,
	["GetGuildBankMoney"] = WoWColor,
	["GetGuildBankMoneyTransaction"] = WoWColor,
	["GetGuildBankTabCost"] = WoWColor,
	["GetGuildBankTabInfo"] = WoWColor,
	["GetGuildBankTabPermissions"] = WoWColor,
	["GetGuildBankText"] = WoWColor,
	["GetGuildBankTransaction"] = WoWColor,
	["GetGuildBankWithdrawLimit"] = WoWColor,
	["GetGuildBankWithdrawMoney"] = WoWColor,
	["GetGuildCharterCost"] = WoWColor,
	["GetGuildEventInfo"] = WoWColor,
	["GetGuildInfo"] = WoWColor,
	["GetGuildInfoText"] = WoWColor,
	["GetGuildRosterInfo"] = WoWColor,
	["GetGuildRosterLastOnline"] = WoWColor,
	["GetGuildRosterMOTD"] = WoWColor,
	["GetGuildRosterSelection"] = WoWColor,
	["GetGuildRosterShowOffline"] = WoWColor,
	["GetGuildTabardFileNames"] = WoWColor,
	["GetHairCustomization"] = WoWColor,
	["GetHolidayBGHonorCurrencyBonuses"] = WoWColor,
	["GetHonorCurrency"] = WoWColor,
	["GetIgnoreName"] = WoWColor,
	["GetInboxHeaderInfo"] = WoWColor,
	["GetInboxInvoiceInfo"] = WoWColor,
	["GetInboxItem"] = WoWColor,
	["GetInboxItemLink"] = WoWColor,
	["GetInboxNumItems"] = WoWColor,
	["GetInboxText"] = WoWColor,
	["GetInspectArenaTeamData"] = WoWColor,
	["GetInspectHonorData"] = WoWColor,
	["GetInstanceBootTimeRemaining"] = WoWColor,
	["GetInstanceDifficulty"] = WoWColor,
	["GetInstanceInfo"] = WoWColor,
	["GetInstanceLockTimeRemaining"] = WoWColor,
	["GetInstanceLockTimeRemainingEncounter"] = WoWColor,
	["GetInventoryAlertStatus"] = WoWColor,
	["GetInventoryItemBroken"] = WoWColor,
	["GetInventoryItemCooldown"] = WoWColor,
	["GetInventoryItemCount"] = WoWColor,
	["GetInventoryItemDurability"] = WoWColor,
	["GetInventoryItemGems"] = WoWColor,
	["GetInventoryItemID"] = WoWColor,
	["GetInventoryItemLink"] = WoWColor,
	["GetInventoryItemQuality"] = WoWColor,
	["GetInventoryItemTexture"] = WoWColor,
	["GetInventoryItemsForSlot"] = WoWColor,
	["GetInventorySlotInfo"] = WoWColor,
	["GetItemCooldown"] = WoWColor,
	["GetItemCount"] = WoWColor,
	["GetItemFamily"] = WoWColor,
	["GetItemGem"] = WoWColor,
	["GetItemIcon"] = WoWColor,
	["GetItemInfo"] = WoWColor,
	["GetItemQualityColor"] = WoWColor,
	["GetItemSpell"] = WoWColor,
	["GetItemStatDelta"] = WoWColor,
	["GetItemStats"] = WoWColor,
	["GetItemUniqueness"] = WoWColor,
	["GetKeyRingSize"] = WoWColor,
	["GetKnownSlotFromHighestRankSlot"] = WoWColor,
	["GetLFDChoiceCollapseState"] = WoWColor,
	["GetLFDChoiceEnabledState"] = WoWColor,
	["GetLFDChoiceInfo"] = WoWColor,
	["GetLFDChoiceLockedState"] = WoWColor,
	["GetLFDChoiceOrder"] = WoWColor,
	["GetLFDLockInfo"] = WoWColor,
	["GetLFDLockPlayerCount"] = WoWColor,
	["GetLFGBootProposal"] = WoWColor,
	["GetLFGCompletionReward"] = WoWColor,
	["GetLFGCompletionRewardItem"] = WoWColor,
	["GetLFGDeserterExpiration"] = WoWColor,
	["GetLFGDungeonInfo"] = WoWColor,
	["GetLFGDungeonRewardInfo"] = WoWColor,
	["GetLFGDungeonRewardLink"] = WoWColor,
	["GetLFGDungeonRewards"] = WoWColor,
	["GetLFGInfoLocal"] = WoWColor,
	["GetLFGInfoServer"] = WoWColor,
	["GetLFGMode"] = WoWColor,
	["GetLFGProposal"] = WoWColor,
	["GetLFGProposalEncounter"] = WoWColor,
	["GetLFGProposalMember"] = WoWColor,
	["GetLFGQueueStats"] = WoWColor,
	["GetLFGQueuedList"] = WoWColor,
	["GetLFGRandomCooldownExpiration"] = WoWColor,
	["GetLFGRandomDungeonInfo"] = WoWColor,
	["GetLFGRoleUpdate"] = WoWColor,
	["GetLFGRoleUpdateMember"] = WoWColor,
	["GetLFGRoleUpdateSlot"] = WoWColor,
	["GetLFGRoles"] = WoWColor,
	["GetLFGTypes"] = WoWColor,
	["GetLFRChoiceOrder"] = WoWColor,
	["GetLanguageByIndex"] = WoWColor,
	["GetLastQueueStatusIndex"] = WoWColor,
	["GetLatestCompletedAchievements"] = WoWColor,
	["GetLatestCompletedComparisonAchievements"] = WoWColor,
	["GetLatestThreeSenders"] = WoWColor,
	["GetLatestUpdatedComparisonStats"] = WoWColor,
	["GetLatestUpdatedStats"] = WoWColor,
	["GetLocale"] = WoWColor,
	["GetLootMethod"] = WoWColor,
	["GetLootRollItemInfo"] = WoWColor,
	["GetLootRollItemLink"] = WoWColor,
	["GetLootRollTimeLeft"] = WoWColor,
	["GetLootSlotInfo"] = WoWColor,
	["GetLootSlotLink"] = WoWColor,
	["GetLootThreshold"] = WoWColor,
	["GetMacroBody"] = WoWColor,
	["GetMacroIconInfo"] = WoWColor,
	["GetMacroIndexByName"] = WoWColor,
	["GetMacroInfo"] = WoWColor,
	["GetMacroItem"] = WoWColor,
	["GetMacroItemIconInfo"] = WoWColor,
	["GetMacroSpell"] = WoWColor,
	["GetManaRegen"] = WoWColor,
	["GetManagedEnvironment"] = WoWColor,
	["GetMapContinents"] = WoWColor,
	["GetMapDebugObjectInfo"] = WoWColor,
	["GetMapInfo"] = WoWColor,
	["GetMapLandmarkInfo"] = WoWColor,
	["GetMapOverlayInfo"] = WoWColor,
	["GetMapZones"] = WoWColor,
	["GetMasterLootCandidate"] = WoWColor,
	["GetMaterialTextColors"] = WoWColor,
	["GetMaxArenaCurrency"] = WoWColor,
	["GetMaxCombatRatingBonus"] = WoWColor,
	["GetMaxDailyQuests"] = WoWColor,
	["GetMaxUIPanelsWidth"] = WoWColor,
	["GetMerchantItemCostInfo"] = WoWColor,
	["GetMerchantItemCostItem"] = WoWColor,
	["GetMerchantItemInfo"] = WoWColor,
	["GetMerchantItemLink"] = WoWColor,
	["GetMerchantItemMaxStack"] = WoWColor,
	["GetMerchantNumItems"] = WoWColor,
	["GetMessageTypeColor"] = WoWColor,
	["GetMessageTypeState"] = WoWColor,
	["GetMinigameState"] = WoWColor,
	["GetMinigameType"] = WoWColor,
	["GetMinimapZoneText"] = WoWColor,
	["GetMirrorTimerInfo"] = WoWColor,
	["GetMirrorTimerProgress"] = WoWColor,
	["GetModifiedClick"] = WoWColor,
	["GetModifiedClickAction"] = WoWColor,
	["GetMoney"] = WoWColor,
	["GetMoneyString"] = WoWColor,
	["GetMouseButtonClicked"] = WoWColor,
	["GetMouseButtonName"] = WoWColor,
	["GetMouseFocus"] = WoWColor,
	["GetMovieResolution"] = WoWColor,
	["GetMultiCastBarOffset"] = WoWColor,
	["GetMultiCastTotemSpells"] = WoWColor,
	["GetMultisampleFormats"] = WoWColor,
	["GetMuteName"] = WoWColor,
	["GetMuteStatus"] = WoWColor,
	["GetNetStats"] = WoWColor,
	["GetNewSocketInfo"] = WoWColor,
	["GetNewSocketLink"] = WoWColor,
	["GetNextAchievement"] = WoWColor,
	["GetNextCompleatedTutorial"] = WoWColor,
	["GetNextStableSlotCost"] = WoWColor,
	["GetNumActiveQuests"] = WoWColor,
	["GetNumAddOns"] = WoWColor,
	["GetNumArenaOpponents"] = WoWColor,
	["GetNumArenaTeamMembers"] = WoWColor,
	["GetNumAuctionItems"] = WoWColor,
	["GetNumAvailableQuests"] = WoWColor,
	["GetNumBankSlots"] = WoWColor,
	["GetNumBattlefieldFlagPositions"] = WoWColor,
	["GetNumBattlefieldPositions"] = WoWColor,
	["GetNumBattlefieldScores"] = WoWColor,
	["GetNumBattlefieldStats"] = WoWColor,
	["GetNumBattlefieldVehicles"] = WoWColor,
	["GetNumBattlefields"] = WoWColor,
	["GetNumBattlegroundTypes"] = WoWColor,
	["GetNumBindings"] = WoWColor,
	["GetNumBuybackItems"] = WoWColor,
	["GetNumChannelMembers"] = WoWColor,
	["GetNumCompanions"] = WoWColor,
	["GetNumComparisonCompletedAchievements"] = WoWColor,
	["GetNumCompletedAchievements"] = WoWColor,
	["GetNumDeclensionSets"] = WoWColor,
	["GetNumDisplayChannels"] = WoWColor,
	["GetNumDungeonMapLevels"] = WoWColor,
	["GetNumEquipmentSets"] = WoWColor,
	["GetNumFactions"] = WoWColor,
	["GetNumFrames"] = WoWColor,
	["GetNumFriends"] = WoWColor,
	["GetNumGlyphSockets"] = WoWColor,
	["GetNumGossipActiveQuests"] = WoWColor,
	["GetNumGossipAvailableQuests"] = WoWColor,
	["GetNumGossipOptions"] = WoWColor,
	["GetNumGuildBankMoneyTransactions"] = WoWColor,
	["GetNumGuildBankTabs"] = WoWColor,
	["GetNumGuildBankTransactions"] = WoWColor,
	["GetNumGuildEvents"] = WoWColor,
	["GetNumGuildMembers"] = WoWColor,
	["GetNumIgnores"] = WoWColor,
	["GetNumLanguages"] = WoWColor,
	["GetNumLootItems"] = WoWColor,
	["GetNumMacroIcons"] = WoWColor,
	["GetNumMacroItemIcons"] = WoWColor,
	["GetNumMacros"] = WoWColor,
	["GetNumMapDebugObjects"] = WoWColor,
	["GetNumMapLandmarks"] = WoWColor,
	["GetNumMapOverlays"] = WoWColor,
	["GetNumModifiedClickActions"] = WoWColor,
	["GetNumMutes"] = WoWColor,
	["GetNumPackages"] = WoWColor,
	["GetNumPartyMembers"] = WoWColor,
	["GetNumPetitionItems"] = WoWColor,
	["GetNumPetitionNames"] = WoWColor,
	["GetNumQuestChoices"] = WoWColor,
	["GetNumQuestItemDrops"] = WoWColor,
	["GetNumQuestItems"] = WoWColor,
	["GetNumQuestLeaderBoards"] = WoWColor,
	["GetNumQuestLogChoices"] = WoWColor,
	["GetNumQuestLogEntries"] = WoWColor,
	["GetNumQuestLogRewardFactions"] = WoWColor,
	["GetNumQuestLogRewards"] = WoWColor,
	["GetNumQuestRewards"] = WoWColor,
	["GetNumQuestWatches"] = WoWColor,
	["GetNumRaidMembers"] = WoWColor,
	["GetNumRandomDungeons"] = WoWColor,
	["GetNumRoutes"] = WoWColor,
	["GetNumSavedInstances"] = WoWColor,
	["GetNumShapeshiftForms"] = WoWColor,
	["GetNumSkillLines"] = WoWColor,
	["GetNumSockets"] = WoWColor,
	["GetNumSpellTabs"] = WoWColor,
	["GetNumStablePets"] = WoWColor,
	["GetNumStableSlots"] = WoWColor,
	["GetNumStationeries"] = WoWColor,
	["GetNumTalentGroups"] = WoWColor,
	["GetNumTalentTabs"] = WoWColor,
	["GetNumTalents"] = WoWColor,
	["GetNumTitles"] = WoWColor,
	["GetNumTrackedAchievements"] = WoWColor,
	["GetNumTrackingTypes"] = WoWColor,
	["GetNumTradeSkills"] = WoWColor,
	["GetNumTrainerServices"] = WoWColor,
	["GetNumVoiceSessionMembersBySessionID"] = WoWColor,
	["GetNumVoiceSessions"] = WoWColor,
	["GetNumWatchedTokens"] = WoWColor,
	["GetNumWhoResults"] = WoWColor,
	["GetNumWorldStateUI"] = WoWColor,
	["GetObjectiveText"] = WoWColor,
	["GetOptOutOfLoot"] = WoWColor,
	["GetOwnerAuctionItems"] = WoWColor,
	["GetPVPDesired"] = WoWColor,
	["GetPVPLifetimeStats"] = WoWColor,
	["GetPVPRankInfo"] = WoWColor,
	["GetPVPRankProgress"] = WoWColor,
	["GetPVPSessionStats"] = WoWColor,
	["GetPVPTimer"] = WoWColor,
	["GetPVPYesterdayStats"] = WoWColor,
	["GetPackageInfo"] = WoWColor,
	["GetParryChance"] = WoWColor,
	["GetPartyAssignment"] = WoWColor,
	["GetPartyLFGBackfillInfo"] = WoWColor,
	["GetPartyLeaderIndex"] = WoWColor,
	["GetPartyMember"] = WoWColor,
	["GetPetActionCooldown"] = WoWColor,
	["GetPetActionInfo"] = WoWColor,
	["GetPetActionSlotUsable"] = WoWColor,
	["GetPetActionsUsable"] = WoWColor,
	["GetPetExperience"] = WoWColor,
	["GetPetFoodTypes"] = WoWColor,
	["GetPetHappiness"] = WoWColor,
	["GetPetIcon"] = WoWColor,
	["GetPetSpellBonusDamage"] = WoWColor,
	["GetPetTalentTree"] = WoWColor,
	["GetPetTimeRemaining"] = WoWColor,
	["GetPetitionInfo"] = WoWColor,
	["GetPetitionItemInfo"] = WoWColor,
	["GetPetitionNameInfo"] = WoWColor,
	["GetPlayerFacing"] = WoWColor,
	["GetPlayerInfoByGUID"] = WoWColor,
	["GetPlayerMapPosition"] = WoWColor,
	["GetPlayerTradeMoney"] = WoWColor,
	["GetPossessInfo"] = WoWColor,
	["GetPowerRegen"] = WoWColor,
	["GetPrevCompleatedTutorial"] = WoWColor,
	["GetPreviewTalentPointsSpent"] = WoWColor,
	["GetPreviousAchievement"] = WoWColor,
	["GetPreviousArenaSeason"] = WoWColor,
	["GetProgressText"] = WoWColor,
	["GetQuestBackgroundMaterial"] = WoWColor,
	["GetQuestDifficultyColor"] = WoWColor,
	["GetQuestGreenRange"] = WoWColor,
	["GetQuestIndexForTimer"] = WoWColor,
	["GetQuestIndexForWatch"] = WoWColor,
	["GetQuestItemInfo"] = WoWColor,
	["GetQuestItemLink"] = WoWColor,
	["GetQuestLink"] = WoWColor,
	["GetQuestLogChoiceInfo"] = WoWColor,
	["GetQuestLogCompletionText"] = WoWColor,
	["GetQuestLogGroupNum"] = WoWColor,
	["GetQuestLogItemDrop"] = WoWColor,
	["GetQuestLogItemLink"] = WoWColor,
	["GetQuestLogLeaderBoard"] = WoWColor,
	["GetQuestLogPushable"] = WoWColor,
	["GetQuestLogQuestText"] = WoWColor,
	["GetQuestLogRequiredMoney"] = WoWColor,
	["GetQuestLogRewardArenaPoints"] = WoWColor,
	["GetQuestLogRewardFactionInfo"] = WoWColor,
	["GetQuestLogRewardHonor"] = WoWColor,
	["GetQuestLogRewardInfo"] = WoWColor,
	["GetQuestLogRewardMoney"] = WoWColor,
	["GetQuestLogRewardSpell"] = WoWColor,
	["GetQuestLogRewardTalents"] = WoWColor,
	["GetQuestLogRewardTitle"] = WoWColor,
	["GetQuestLogRewardXP"] = WoWColor,
	["GetQuestLogSelection"] = WoWColor,
	["GetQuestLogSpecialItemCooldown"] = WoWColor,
	["GetQuestLogSpecialItemInfo"] = WoWColor,
	["GetQuestLogSpellLink"] = WoWColor,
	["GetQuestLogTimeLeft"] = WoWColor,
	["GetQuestLogTitle"] = WoWColor,
	["GetQuestMoneyToGet"] = WoWColor,
	["GetQuestPOILeaderBoard"] = WoWColor,
	["GetQuestResetTime"] = WoWColor,
	["GetQuestReward"] = WoWColor,
	["GetQuestSortIndex"] = WoWColor,
	["GetQuestSpellLink"] = WoWColor,
	["GetQuestText"] = WoWColor,
	["GetQuestTimers"] = WoWColor,
	["GetQuestWatchIndex"] = WoWColor,
	["GetQuestWorldMapAreaID"] = WoWColor,
	["GetQuestsCompleted"] = WoWColor,
	["GetRaidDifficulty"] = WoWColor,
	["GetRaidRosterInfo"] = WoWColor,
	["GetRaidRosterSelection"] = WoWColor,
	["GetRaidTargetIndex"] = WoWColor,
	["GetRandomArgument"] = WoWColor,
	["GetRandomBGHonorCurrencyBonuses"] = WoWColor,
	["GetRandomDungeonBestChoice"] = WoWColor,
	["GetRangedCritChance"] = WoWColor,
	["GetReadonlyRestrictedTable"] = WoWColor,
	["GetReadyCheckStatus"] = WoWColor,
	["GetReadyCheckTimeLeft"] = WoWColor,
	["GetRealNumPartyMembers"] = WoWColor,
	["GetRealNumRaidMembers"] = WoWColor,
	["GetRealZoneText"] = WoWColor,
	["GetRealmName"] = WoWColor,
	["GetRefreshRates"] = WoWColor,
	["GetReleaseTimeRemaining"] = WoWColor,
	["GetRepairAllCost"] = WoWColor,
	["GetResSicknessDuration"] = WoWColor,
	["GetRestState"] = WoWColor,
	["GetRewardArenaPoints"] = WoWColor,
	["GetRewardHonor"] = WoWColor,
	["GetRewardMoney"] = WoWColor,
	["GetRewardSpell"] = WoWColor,
	["GetRewardTalents"] = WoWColor,
	["GetRewardText"] = WoWColor,
	["GetRewardTitle"] = WoWColor,
	["GetRewardXP"] = WoWColor,
	["GetRuneCooldown"] = WoWColor,
	["GetRuneCount"] = WoWColor,
	["GetRuneType"] = WoWColor,
	["GetRunningMacro"] = WoWColor,
	["GetRunningMacroButton"] = WoWColor,
	["GetSavedInstanceInfo"] = WoWColor,
	["GetScreenHeight"] = WoWColor,
	["GetScreenHeightScale"] = WoWColor,
	["GetScreenResolutions"] = WoWColor,
	["GetScreenWidth"] = WoWColor,
	["GetScreenWidthScale"] = WoWColor,
	["GetScriptCPUUsage"] = WoWColor,
	["GetSelectedAuctionItem"] = WoWColor,
	["GetSelectedBattlefield"] = WoWColor,
	["GetSelectedDisplayChannel"] = WoWColor,
	["GetSelectedFaction"] = WoWColor,
	["GetSelectedFriend"] = WoWColor,
	["GetSelectedIgnore"] = WoWColor,
	["GetSelectedMute"] = WoWColor,
	["GetSelectedSkill"] = WoWColor,
	["GetSelectedStablePet"] = WoWColor,
	["GetSelectedStationeryTexture"] = WoWColor,
	["GetSendMailCOD"] = WoWColor,
	["GetSendMailItem"] = WoWColor,
	["GetSendMailItemLink"] = WoWColor,
	["GetSendMailMoney"] = WoWColor,
	["GetSendMailPrice"] = WoWColor,
	["GetShapeshiftForm"] = WoWColor,
	["GetShapeshiftFormCooldown"] = WoWColor,
	["GetShapeshiftFormInfo"] = WoWColor,
	["GetShieldBlock"] = WoWColor,
	["GetSkillLineInfo"] = WoWColor,
	["GetSocketItemBoundTradeable"] = WoWColor,
	["GetSocketItemInfo"] = WoWColor,
	["GetSocketItemRefundable"] = WoWColor,
	["GetSocketTypes"] = WoWColor,
	["GetSpellAutocast"] = WoWColor,
	["GetSpellBonusDamage"] = WoWColor,
	["GetSpellBonusHealing"] = WoWColor,
	["GetSpellCooldown"] = WoWColor,
	["GetSpellCount"] = WoWColor,
	["GetSpellCritChance"] = WoWColor,
	["GetSpellCritChanceFromIntellect"] = WoWColor,
	["GetSpellInfo"] = WoWColor,
	["GetSpellLink"] = WoWColor,
	["GetSpellName"] = WoWColor,
	["GetSpellNameColor"] = WoWColor,
	["GetSpellPenetration"] = WoWColor,
	["GetSpellTabInfo"] = WoWColor,
	["GetSpellTexture"] = WoWColor,
	["GetStablePetFoodTypes"] = WoWColor,
	["GetStablePetInfo"] = WoWColor,
	["GetStationeryInfo"] = WoWColor,
	["GetStatistic"] = WoWColor,
	["GetStatisticsCategoryList"] = WoWColor,
	["GetSubZoneText"] = WoWColor,
	["GetSuggestedGroupNum"] = WoWColor,
	["GetSummonConfirmAreaName"] = WoWColor,
	["GetSummonConfirmSummoner"] = WoWColor,
	["GetSummonConfirmTimeLeft"] = WoWColor,
	["GetSummonFriendCooldown"] = WoWColor,
	["GetTabardCreationCost"] = WoWColor,
	["GetTabardInfo"] = WoWColor,
	["GetTableColor"] = WoWColor,
	["GetTalentInfo"] = WoWColor,
	["GetTalentLink"] = WoWColor,
	["GetTalentPrereqs"] = WoWColor,
	["GetTalentTabInfo"] = WoWColor,
	["GetTargetTradeMoney"] = WoWColor,
	["GetTaxiBenchmarkMode"] = WoWColor,
	["GetTerrainMip"] = WoWColor,
	["GetTexCoordsByGrid"] = WoWColor,
	["GetTexCoordsForRole"] = WoWColor,
	["GetTexLodBias"] = WoWColor,
	["GetText"] = WoWColor,
	["GetThreatStatusColor"] = WoWColor,
	["GetTime"] = WoWColor,
	["GetTimeToWellRested"] = WoWColor,
	["GetTimerTextColor"] = WoWColor,
	["GetTitleName"] = WoWColor,
	["GetTitleText"] = WoWColor,
	["GetTotalAchievementPoints"] = WoWColor,
	["GetTotemInfo"] = WoWColor,
	["GetTotemTimeLeft"] = WoWColor,
	["GetTrackedAchievements"] = WoWColor,
	["GetTrackingInfo"] = WoWColor,
	["GetTrackingTexture"] = WoWColor,
	["GetTradePlayerItemInfo"] = WoWColor,
	["GetTradePlayerItemLink"] = WoWColor,
	["GetTradeSkillCooldown"] = WoWColor,
	["GetTradeSkillDescription"] = WoWColor,
	["GetTradeSkillIcon"] = WoWColor,
	["GetTradeSkillInfo"] = WoWColor,
	["GetTradeSkillInvSlotFilter"] = WoWColor,
	["GetTradeSkillInvSlots"] = WoWColor,
	["GetTradeSkillItemLevelFilter"] = WoWColor,
	["GetTradeSkillItemLink"] = WoWColor,
	["GetTradeSkillItemNameFilter"] = WoWColor,
	["GetTradeSkillLine"] = WoWColor,
	["GetTradeSkillListLink"] = WoWColor,
	["GetTradeSkillNumMade"] = WoWColor,
	["GetTradeSkillNumReagents"] = WoWColor,
	["GetTradeSkillReagentInfo"] = WoWColor,
	["GetTradeSkillReagentItemLink"] = WoWColor,
	["GetTradeSkillRecipeLink"] = WoWColor,
	["GetTradeSkillSelectionIndex"] = WoWColor,
	["GetTradeSkillSubClassFilter"] = WoWColor,
	["GetTradeSkillSubClasses"] = WoWColor,
	["GetTradeSkillTools"] = WoWColor,
	["GetTradeTargetItemInfo"] = WoWColor,
	["GetTradeTargetItemLink"] = WoWColor,
	["GetTradeskillRepeatCount"] = WoWColor,
	["GetTrainerGreetingText"] = WoWColor,
	["GetTrainerSelectionIndex"] = WoWColor,
	["GetTrainerServiceAbilityReq"] = WoWColor,
	["GetTrainerServiceCost"] = WoWColor,
	["GetTrainerServiceDescription"] = WoWColor,
	["GetTrainerServiceIcon"] = WoWColor,
	["GetTrainerServiceInfo"] = WoWColor,
	["GetTrainerServiceItemLink"] = WoWColor,
	["GetTrainerServiceLevelReq"] = WoWColor,
	["GetTrainerServiceNumAbilityReq"] = WoWColor,
	["GetTrainerServiceSkillLine"] = WoWColor,
	["GetTrainerServiceSkillReq"] = WoWColor,
	["GetTrainerServiceStepIncrease"] = WoWColor,
	["GetTrainerServiceStepReq"] = WoWColor,
	["GetTrainerServiceTypeFilter"] = WoWColor,
	["GetTrainerSkillLineFilter"] = WoWColor,
	["GetTrainerSkillLines"] = WoWColor,
	["GetUIPanel"] = WoWColor,
	["GetUIPanelWidth"] = WoWColor,
	["GetUnitHealthModifier"] = WoWColor,
	["GetUnitHealthRegenRateFromSpirit"] = WoWColor,
	["GetUnitManaRegenRateFromSpirit"] = WoWColor,
	["GetUnitMaxHealthModifier"] = WoWColor,
	["GetUnitName"] = WoWColor,
	["GetUnitPitch"] = WoWColor,
	["GetUnitPowerModifier"] = WoWColor,
	["GetUnitSpeed"] = WoWColor,
	["GetUnspentTalentPoints"] = WoWColor,
	["GetVehicleUIIndicator"] = WoWColor,
	["GetVehicleUIIndicatorSeat"] = WoWColor,
	["GetVideoCaps"] = WoWColor,
	["GetVoiceCurrentSessionID"] = WoWColor,
	["GetVoiceSessionInfo"] = WoWColor,
	["GetVoiceSessionMemberInfoBySessionID"] = WoWColor,
	["GetVoiceStatus"] = WoWColor,
	["GetWatchedFactionInfo"] = WoWColor,
	["GetWaterDetail"] = WoWColor,
	["GetWeaponEnchantInfo"] = WoWColor,
	["GetWhoInfo"] = WoWColor,
	["GetWintergraspWaitTime"] = WoWColor,
	["GetWorldPVPQueueStatus"] = WoWColor,
	["GetWorldStateUIInfo"] = WoWColor,
	["GetXPExhaustion"] = WoWColor,
	["GetZonePVPInfo"] = WoWColor,
	["GetZoneText"] = WoWColor,
	["GiveMasterLoot"] = WoWColor,
	["GlyphFrame_LoadUI"] = WoWColor,
	["GlyphMatchesSocket"] = WoWColor,
	["GossipFrameActiveQuestsUpdate"] = WoWColor,
	["GossipFrameAvailableQuestsUpdate"] = WoWColor,
	["GossipFrameOptionsUpdate"] = WoWColor,
	["GossipFrameUpdate"] = WoWColor,
	["GossipFrame_OnEvent"] = WoWColor,
	["GossipFrame_OnLoad"] = WoWColor,
	["GossipResize"] = WoWColor,
	["GossipTitleButton_OnClick"] = WoWColor,
	["GrantLevel"] = WoWColor,
	["GroupLootDropDown_GiveLoot"] = WoWColor,
	["GroupLootDropDown_Initialize"] = WoWColor,
	["GroupLootDropDown_OnLoad"] = WoWColor,
	["GroupLootFrame_DisableLootButton"] = WoWColor,
	["GroupLootFrame_EnableLootButton"] = WoWColor,
	["GroupLootFrame_OnEvent"] = WoWColor,
	["GroupLootFrame_OnHide"] = WoWColor,
	["GroupLootFrame_OnShow"] = WoWColor,
	["GroupLootFrame_OnUpdate"] = WoWColor,
	["GroupLootFrame_OpenNewFrame"] = WoWColor,
	["GuildBankFrame_LoadUI"] = WoWColor,
	["GuildBankTabPermissionsTab_OnClick"] = WoWColor,
	["GuildControlAddRank"] = WoWColor,
	["GuildControlCheckboxUpdate"] = WoWColor,
	["GuildControlDelRank"] = WoWColor,
	["GuildControlGetNumRanks"] = WoWColor,
	["GuildControlGetRankFlags"] = WoWColor,
	["GuildControlGetRankName"] = WoWColor,
	["GuildControlPopupAcceptButton_OnClick"] = WoWColor,
	["GuildControlPopupFrameAddRankButton_OnUpdate"] = WoWColor,
	["GuildControlPopupFrameDropDownButton_OnClick"] = WoWColor,
	["GuildControlPopupFrameDropDown_Initialize"] = WoWColor,
	["GuildControlPopupFrameDropDown_OnLoad"] = WoWColor,
	["GuildControlPopupFrameRemoveRankButton_OnClick"] = WoWColor,
	["GuildControlPopupFrameRemoveRankButton_OnUpdate"] = WoWColor,
	["GuildControlPopupFrame_Initialize"] = WoWColor,
	["GuildControlPopupFrame_OnEvent"] = WoWColor,
	["GuildControlPopupFrame_OnHide"] = WoWColor,
	["GuildControlPopupFrame_OnLoad"] = WoWColor,
	["GuildControlPopupFrame_OnShow"] = WoWColor,
	["GuildControlPopup_UpdateDepositCheckBox"] = WoWColor,
	["GuildControlPopupframe_Update"] = WoWColor,
	["GuildControlSaveRank"] = WoWColor,
	["GuildControlSetRank"] = WoWColor,
	["GuildControlSetRankFlag"] = WoWColor,
	["GuildDemote"] = WoWColor,
	["GuildDisband"] = WoWColor,
	["GuildEventLog_Update"] = WoWColor,
	["GuildFrameControlButton_OnUpdate"] = WoWColor,
	["GuildFrameGuildListToggleButton_OnClick"] = WoWColor,
	["GuildFramePopup_HideAll"] = WoWColor,
	["GuildFramePopup_Show"] = WoWColor,
	["GuildFrame_GetLastOnline"] = WoWColor,
	["GuildInfo"] = WoWColor,
	["GuildInvite"] = WoWColor,
	["GuildLeave"] = WoWColor,
	["GuildPromote"] = WoWColor,
	["GuildRegistrar_OnShow"] = WoWColor,
	["GuildRegistrar_ShowPurchaseFrame"] = WoWColor,
	["GuildRoster"] = WoWColor,
	["GuildRosterSetOfficerNote"] = WoWColor,
	["GuildRosterSetPublicNote"] = WoWColor,
	["GuildSetLeader"] = WoWColor,
	["GuildSetMOTD"] = WoWColor,
	["GuildStatus_Update"] = WoWColor,
	["GuildUninvite"] = WoWColor,
	["HandleModifiedItemClick"] = WoWColor,
	["HasAction"] = WoWColor,
	["HasCompletedAnyAchievement"] = WoWColor,
	["HasDebugZoneMap"] = WoWColor,
	["HasFilledPetition"] = WoWColor,
	["HasFullControl"] = WoWColor,
	["HasInspectHonorData"] = WoWColor,
	["HasKey"] = WoWColor,
	["HasLFGRestrictions"] = WoWColor,
	["HasMessageType"] = WoWColor,
	["HasMessageTypeGroup"] = WoWColor,
	["HasMultiCastActionBar"] = WoWColor,
	["HasMultiCastActionPage"] = WoWColor,
	["HasNewMail"] = WoWColor,
	["HasPetSpells"] = WoWColor,
	["HasPetUI"] = WoWColor,
	["HasSoulstone"] = WoWColor,
	["HasWandEquipped"] = WoWColor,
	["HealthBar_OnValueChanged"] = WoWColor,
	["HearthAndResurrectFromArea"] = WoWColor,
	["HelpFrameGMTalk_OnShow"] = WoWColor,
	["HelpFrameOpenTicketCancel_OnClick"] = WoWColor,
	["HelpFrameOpenTicketSubmit_OnClick"] = WoWColor,
	["HelpFrameReportIssue_OnShow"] = WoWColor,
	["HelpFrameStuck_OnShow"] = WoWColor,
	["HelpFrameViewResponseButton_OnLoad"] = WoWColor,
	["HelpFrameViewResponseIssueResolved_OnClick"] = WoWColor,
	["HelpFrameViewResponseMoreHelp_OnClick"] = WoWColor,
	["HelpFrame_HaveGMResponse"] = WoWColor,
	["HelpFrame_HaveGMTicket"] = WoWColor,
	["HelpFrame_IsGMTicketQueueActive"] = WoWColor,
	["HelpFrame_OnEvent"] = WoWColor,
	["HelpFrame_OnHide"] = WoWColor,
	["HelpFrame_OnLoad"] = WoWColor,
	["HelpFrame_OnShow"] = WoWColor,
	["HelpFrame_PopAllFrames"] = WoWColor,
	["HelpFrame_PopFrame"] = WoWColor,
	["HelpFrame_ShowFrame"] = WoWColor,
	["HelpReportLag"] = WoWColor,
	["HideBonusActionBar"] = WoWColor,
	["HideDropDownMenu"] = WoWColor,
	["HideMultiCastActionBar"] = WoWColor,
	["HideParentPanel"] = WoWColor,
	["HidePartyFrame"] = WoWColor,
	["HidePetActionBar"] = WoWColor,
	["HideRepairCursor"] = WoWColor,
	["HideTextStatusBarText"] = WoWColor,
	["HideUIPanel"] = WoWColor,
	["HideWatchedReputationBarText"] = WoWColor,
	["HonorFrame_OnEvent"] = WoWColor,
	["HonorFrame_OnLoad"] = WoWColor,
	["HonorFrame_Update"] = WoWColor,
	["HybridScrollFrameScrollButton_OnClick"] = WoWColor,
	["HybridScrollFrameScrollButton_OnUpdate"] = WoWColor,
	["HybridScrollFrameScrollChild_OnLoad"] = WoWColor,
	["HybridScrollFrame_CollapseButton"] = WoWColor,
	["HybridScrollFrame_CreateButtons"] = WoWColor,
	["HybridScrollFrame_ExpandButton"] = WoWColor,
	["HybridScrollFrame_GetOffset"] = WoWColor,
	["HybridScrollFrame_OnLoad"] = WoWColor,
	["HybridScrollFrame_OnMouseWheel"] = WoWColor,
	["HybridScrollFrame_OnValueChanged"] = WoWColor,
	["HybridScrollFrame_SetOffset"] = WoWColor,
	["HybridScrollFrame_Update"] = WoWColor,
	["HybridScrollFrame_UpdateButtonStates"] = WoWColor,
	["IgnoreList_SetHeader"] = WoWColor,
	["IgnoreList_Update"] = WoWColor,
	["InCinematic"] = WoWColor,
	["InCombatLockdown"] = WoWColor,
	["InGuildCheck"] = WoWColor,
	["InRepairMode"] = WoWColor,
	["InboxFrameItem_OnEnter"] = WoWColor,
	["InboxFrame_OnClick"] = WoWColor,
	["InboxFrame_OnModifiedClick"] = WoWColor,
	["InboxFrame_Update"] = WoWColor,
	["InboxGetMoreMail"] = WoWColor,
	["InboxItemCanDelete"] = WoWColor,
	["InboxNextPage"] = WoWColor,
	["InboxPrevPage"] = WoWColor,
	["InitWorldMapPing"] = WoWColor,
	["InitiateRolePoll"] = WoWColor,
	["InitiateTrade"] = WoWColor,
	["InspectAchievements"] = WoWColor,
	["InspectFrame_LoadUI"] = WoWColor,
	["InspectUnit"] = WoWColor,
	["InstanceLock_OnEnter"] = WoWColor,
	["InteractUnit"] = WoWColor,
	["InterfaceAddOnsList_Update"] = WoWColor,
	["InterfaceCategoryList_Update"] = WoWColor,
	["InterfaceOptionsActionBarsPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsActionBarsPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsBattlenetPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsBuffsPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsBuffsPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsCameraPanelStyleDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsCameraPanelStyleDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsCameraPanelStyleDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsCameraPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsCameraPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsCombatPanelFocusCastKeyDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsCombatPanelSelfCastKeyDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsCombatPanelTOTDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsCombatPanelTOTDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsCombatPanelTOTDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsCombatTextPanelFCTDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsCombatTextPanelFCTDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsCombatTextPanelFCTDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsCombatTextPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsCombatTextPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsControlsPanelAutoLootKeyDropDown_Update"] = WoWColor,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_Initialize"] = WoWColor,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_OnClick"] = WoWColor,
	["InterfaceOptionsDisplayPanelAggroWarningDisplay_OnEvent"] = WoWColor,
	["InterfaceOptionsDisplayPanelPreviewTalentChanges_SetFunc"] = WoWColor,
	["InterfaceOptionsDisplayPanelShowAggroPercentage_SetFunc"] = WoWColor,
	["InterfaceOptionsDisplayPanelShowClock_SetFunc"] = WoWColor,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_Initialize"] = WoWColor,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_OnClick"] = WoWColor,
	["InterfaceOptionsDisplayPanelWorldPVPObjectiveDisplay_OnEvent"] = WoWColor,
	["InterfaceOptionsDisplayPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsDisplayPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsFrameCancel_OnClick"] = WoWColor,
	["InterfaceOptionsFrameDefaults_OnClick"] = WoWColor,
	["InterfaceOptionsFrameOkay_OnClick"] = WoWColor,
	["InterfaceOptionsFrame_InitializeUVars"] = WoWColor,
	["InterfaceOptionsFrame_LoadUVars"] = WoWColor,
	["InterfaceOptionsFrame_OnEvent"] = WoWColor,
	["InterfaceOptionsFrame_OnHide"] = WoWColor,
	["InterfaceOptionsFrame_OnLoad"] = WoWColor,
	["InterfaceOptionsFrame_OnShow"] = WoWColor,
	["InterfaceOptionsFrame_OpenToCategory"] = WoWColor,
	["InterfaceOptionsFrame_SetAllToDefaults"] = WoWColor,
	["InterfaceOptionsFrame_SetCurrentToDefaults"] = WoWColor,
	["InterfaceOptionsFrame_Show"] = WoWColor,
	["InterfaceOptionsFrame_TabOnClick"] = WoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_InitializeHelper"] = WoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsLanguagesPanelLocaleDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsLanguagesPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsListButton_OnClick"] = WoWColor,
	["InterfaceOptionsListButton_ToggleSubCategories"] = WoWColor,
	["InterfaceOptionsList_DisplayPanel"] = WoWColor,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_Initialize"] = WoWColor,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_OnClick"] = WoWColor,
	["InterfaceOptionsMousePanelClickMoveStyleDropDown_OnEvent"] = WoWColor,
	["InterfaceOptionsObjectivesPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsObjectivesPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsOptionsFrame_RefreshAddOns"] = WoWColor,
	["InterfaceOptionsOptionsFrame_RefreshCategories"] = WoWColor,
	["InterfaceOptionsPanel_CheckButton_OnClick"] = WoWColor,
	["InterfaceOptionsPanel_CheckButton_Update"] = WoWColor,
	["InterfaceOptionsPanel_OnLoad"] = WoWColor,
	["InterfaceOptionsSocialPanelChatMouseScroll_SetScrolling"] = WoWColor,
	["InterfaceOptionsSocialPanelChatStyle_Initialize"] = WoWColor,
	["InterfaceOptionsSocialPanelChatStyle_OnClick"] = WoWColor,
	["InterfaceOptionsSocialPanelChatStyle_OnEvent"] = WoWColor,
	["InterfaceOptionsSocialPanelChatStyle_SetChatStyle"] = WoWColor,
	["InterfaceOptionsSocialPanelConversationMode_Initialize"] = WoWColor,
	["InterfaceOptionsSocialPanelConversationMode_OnClick"] = WoWColor,
	["InterfaceOptionsSocialPanelConversationMode_OnEvent"] = WoWColor,
	["InterfaceOptionsSocialPanelProfanityFilter_SyncWithBattlenet"] = WoWColor,
	["InterfaceOptionsSocialPanelProfanityFilter_UpdateDisplay"] = WoWColor,
	["InterfaceOptionsSocialPanelTimestamps_AddTimestampFormat"] = WoWColor,
	["InterfaceOptionsSocialPanelTimestamps_Initialize"] = WoWColor,
	["InterfaceOptionsSocialPanelTimestamps_OnClick"] = WoWColor,
	["InterfaceOptionsSocialPanelTimestamps_OnEvent"] = WoWColor,
	["InterfaceOptionsSocialPanel_OnEvent"] = WoWColor,
	["InterfaceOptionsSocialPanel_OnLoad"] = WoWColor,
	["InterfaceOptions_AddCategory"] = WoWColor,
	["InterfaceOptions_UpdateMultiActionBars"] = WoWColor,
	["InviteUnit"] = WoWColor,
	["IsActionInRange"] = WoWColor,
	["IsActiveBattlefieldArena"] = WoWColor,
	["IsActiveQuestTrivial"] = WoWColor,
	["IsAddOnLoadOnDemand"] = WoWColor,
	["IsAddOnLoaded"] = WoWColor,
	["IsAlreadyInQueue"] = WoWColor,
	["IsAltKeyDown"] = WoWColor,
	["IsArenaTeamCaptain"] = WoWColor,
	["IsAtStableMaster"] = WoWColor,
	["IsAttackAction"] = WoWColor,
	["IsAttackSpell"] = WoWColor,
	["IsAuctionSortReversed"] = WoWColor,
	["IsAutoRepeatAction"] = WoWColor,
	["IsAutoRepeatSpell"] = WoWColor,
	["IsAvailableQuestTrivial"] = WoWColor,
	["IsBNLogin"] = WoWColor,
	["IsBagOpen"] = WoWColor,
	["IsBattlefieldArena"] = WoWColor,
	["IsClassColoringMessageType"] = WoWColor,
	["IsCombatLog"] = WoWColor,
	["IsConsumableAction"] = WoWColor,
	["IsConsumableItem"] = WoWColor,
	["IsConsumableSpell"] = WoWColor,
	["IsControlKeyDown"] = WoWColor,
	["IsCurrentAction"] = WoWColor,
	["IsCurrentItem"] = WoWColor,
	["IsCurrentQuestFailed"] = WoWColor,
	["IsCurrentSpell"] = WoWColor,
	["IsDebugBuild"] = WoWColor,
	["IsDesaturateSupported"] = WoWColor,
	["IsDisplayChannelModerator"] = WoWColor,
	["IsDisplayChannelOwner"] = WoWColor,
	["IsDressableItem"] = WoWColor,
	["IsEquippableItem"] = WoWColor,
	["IsEquippedAction"] = WoWColor,
	["IsEquippedItem"] = WoWColor,
	["IsEquippedItemType"] = WoWColor,
	["IsFactionInactive"] = WoWColor,
	["IsFalling"] = WoWColor,
	["IsFishingLoot"] = WoWColor,
	["IsFlyableArea"] = WoWColor,
	["IsFlying"] = WoWColor,
	["IsFrameHandle"] = WoWColor,
	["IsGuildLeader"] = WoWColor,
	["IsHarmfulItem"] = WoWColor,
	["IsHarmfulSpell"] = WoWColor,
	["IsHelpfulItem"] = WoWColor,
	["IsHelpfulSpell"] = WoWColor,
	["IsIgnored"] = WoWColor,
	["IsIgnoredOrMuted"] = WoWColor,
	["IsInArenaTeam"] = WoWColor,
	["IsInGuild"] = WoWColor,
	["IsInInstance"] = WoWColor,
	["IsInLFGDungeon"] = WoWColor,
	["IsIndoors"] = WoWColor,
	["IsInventoryItemLocked"] = WoWColor,
	["IsItemInRange"] = WoWColor,
	["IsLFGDungeonJoinable"] = WoWColor,
	["IsLeftAltKeyDown"] = WoWColor,
	["IsLeftControlKeyDown"] = WoWColor,
	["IsLeftShiftKeyDown"] = WoWColor,
	["IsLinuxClient"] = WoWColor,
	["IsListedInLFR"] = WoWColor,
	["IsListeningForMessageType"] = WoWColor,
	["IsLoggedIn"] = WoWColor,
	["IsMacClient"] = WoWColor,
	["IsMessageDoneBy"] = WoWColor,
	["IsMessageDoneTo"] = WoWColor,
	["IsModifiedClick"] = WoWColor,
	["IsModifierKeyDown"] = WoWColor,
	["IsMounted"] = WoWColor,
	["IsMouseButtonDown"] = WoWColor,
	["IsMouselooking"] = WoWColor,
	["IsMuted"] = WoWColor,
	["IsOptionFrameOpen"] = WoWColor,
	["IsOutOfBounds"] = WoWColor,
	["IsOutdoors"] = WoWColor,
	["IsPVPTimerRunning"] = WoWColor,
	["IsPartyLFG"] = WoWColor,
	["IsPartyLeader"] = WoWColor,
	["IsPassiveSpell"] = WoWColor,
	["IsPetAttackAction"] = WoWColor,
	["IsPetAttackActive"] = WoWColor,
	["IsPlayerResolutionAvailable"] = WoWColor,
	["IsPossessBarVisible"] = WoWColor,
	["IsQuestCompletable"] = WoWColor,
	["IsQuestFlaggedCompleted"] = WoWColor,
	["IsQuestLogSpecialItemInRange"] = WoWColor,
	["IsQuestWatched"] = WoWColor,
	["IsRaidLeader"] = WoWColor,
	["IsRaidOfficer"] = WoWColor,
	["IsRealPartyLeader"] = WoWColor,
	["IsRealRaidLeader"] = WoWColor,
	["IsReferAFriendLinked"] = WoWColor,
	["IsResting"] = WoWColor,
	["IsRightAltKeyDown"] = WoWColor,
	["IsRightControlKeyDown"] = WoWColor,
	["IsRightShiftKeyDown"] = WoWColor,
	["IsSecureCmd"] = WoWColor,
	["IsSelectedSpell"] = WoWColor,
	["IsShiftKeyDown"] = WoWColor,
	["IsSilenced"] = WoWColor,
	["IsSpellInRange"] = WoWColor,
	["IsSpellKnown"] = WoWColor,
	["IsStackableAction"] = WoWColor,
	["IsStealthed"] = WoWColor,
	["IsStereoVideoAvailable"] = WoWColor,
	["IsSubZonePVPPOI"] = WoWColor,
	["IsSwimming"] = WoWColor,
	["IsThreatWarningEnabled"] = WoWColor,
	["IsTitleKnown"] = WoWColor,
	["IsTrackedAchievement"] = WoWColor,
	["IsTradeSkillLinked"] = WoWColor,
	["IsTradeskillTrainer"] = WoWColor,
	["IsTrainerServiceSkillStep"] = WoWColor,
	["IsTutorialFlagged"] = WoWColor,
	["IsUnitOnQuest"] = WoWColor,
	["IsUsableAction"] = WoWColor,
	["IsUsableItem"] = WoWColor,
	["IsUsableSpell"] = WoWColor,
	["IsUsingVehicleControls"] = WoWColor,
	["IsVehicleAimAngleAdjustable"] = WoWColor,
	["IsVehicleAimPowerAdjustable"] = WoWColor,
	["IsVoiceChatAllowed"] = WoWColor,
	["IsVoiceChatAllowedByServer"] = WoWColor,
	["IsVoiceChatEnabled"] = WoWColor,
	["IsWindowsClient"] = WoWColor,
	["IsXPUserDisabled"] = WoWColor,
	["IsZoomOutAvailable"] = WoWColor,
	["ItemAnim_OnAnimFinished"] = WoWColor,
	["ItemAnim_OnEvent"] = WoWColor,
	["ItemAnim_OnLoad"] = WoWColor,
	["ItemHasRange"] = WoWColor,
	["ItemSocketingFrame_LoadUI"] = WoWColor,
	["ItemTextFrame_OnEvent"] = WoWColor,
	["ItemTextFrame_OnLoad"] = WoWColor,
	["ItemTextFrame_OnUpdate"] = WoWColor,
	["ItemTextGetCreator"] = WoWColor,
	["ItemTextGetItem"] = WoWColor,
	["ItemTextGetMaterial"] = WoWColor,
	["ItemTextGetPage"] = WoWColor,
	["ItemTextGetText"] = WoWColor,
	["ItemTextHasNextPage"] = WoWColor,
	["ItemTextNextPage"] = WoWColor,
	["ItemTextPrevPage"] = WoWColor,
	["JoinBattlefield"] = WoWColor,
	["JoinChannelByName"] = WoWColor,
	["JoinLFG"] = WoWColor,
	["JoinPermanentChannel"] = WoWColor,
	["JoinTemporaryChannel"] = WoWColor,
	["JumpOrAscendStart"] = WoWColor,
	["KBArticle_BeginLoading"] = WoWColor,
	["KBArticle_GetData"] = WoWColor,
	["KBArticle_IsLoaded"] = WoWColor,
	["KBQuery_BeginLoading"] = WoWColor,
	["KBQuery_GetArticleHeaderCount"] = WoWColor,
	["KBQuery_GetArticleHeaderData"] = WoWColor,
	["KBQuery_GetTotalArticleCount"] = WoWColor,
	["KBQuery_IsLoaded"] = WoWColor,
	["KBSetup_BeginLoading"] = WoWColor,
	["KBSetup_GetArticleHeaderCount"] = WoWColor,
	["KBSetup_GetArticleHeaderData"] = WoWColor,
	["KBSetup_GetCategoryCount"] = WoWColor,
	["KBSetup_GetCategoryData"] = WoWColor,
	["KBSetup_GetLanguageCount"] = WoWColor,
	["KBSetup_GetLanguageData"] = WoWColor,
	["KBSetup_GetSubCategoryCount"] = WoWColor,
	["KBSetup_GetSubCategoryData"] = WoWColor,
	["KBSetup_GetTotalArticleCount"] = WoWColor,
	["KBSetup_IsLoaded"] = WoWColor,
	["KBSystem_GetMOTD"] = WoWColor,
	["KBSystem_GetServerNotice"] = WoWColor,
	["KBSystem_GetServerStatus"] = WoWColor,
	["KeyBindingFrame_LoadUI"] = WoWColor,
	["KeyRingButtonIDToInvSlotID"] = WoWColor,
	["KnowledgeBaseArticleListFrame_HideArticleList"] = WoWColor,
	["KnowledgeBaseArticleListFrame_NextPage"] = WoWColor,
	["KnowledgeBaseArticleListFrame_PopulateArticleList"] = WoWColor,
	["KnowledgeBaseArticleListFrame_PreviousPage"] = WoWColor,
	["KnowledgeBaseArticleListItem_OnClick"] = WoWColor,
	["KnowledgeBaseArticleListItem_OnEnter"] = WoWColor,
	["KnowledgeBaseArticleListItem_OnLeave"] = WoWColor,
	["KnowledgeBaseArticleListItem_OnUpdate"] = WoWColor,
	["KnowledgeBaseArticleListItem_Update"] = WoWColor,
	["KnowledgeBaseErrorFrame_SetErrorMessage"] = WoWColor,
	["KnowledgeBaseFrameCategoryButton_OnClick"] = WoWColor,
	["KnowledgeBaseFrameCategoryDropDown_AddInfo"] = WoWColor,
	["KnowledgeBaseFrameCategoryDropDown_Initialize"] = WoWColor,
	["KnowledgeBaseFrameCategoryDropDown_OnLoad"] = WoWColor,
	["KnowledgeBaseFrameSubCategoryButton_OnClick"] = WoWColor,
	["KnowledgeBaseFrameSubCategoryDropDown_AddInfo"] = WoWColor,
	["KnowledgeBaseFrameSubCategoryDropDown_Initialize"] = WoWColor,
	["KnowledgeBaseFrameSubCategoryDropDown_OnLoad"] = WoWColor,
	["KnowledgeBaseFrame_DisableButtons"] = WoWColor,
	["KnowledgeBaseFrame_EnableButtons"] = WoWColor,
	["KnowledgeBaseFrame_LoadTopIssues"] = WoWColor,
	["KnowledgeBaseFrame_OnEvent"] = WoWColor,
	["KnowledgeBaseFrame_OnLoad"] = WoWColor,
	["KnowledgeBaseFrame_OnShow"] = WoWColor,
	["KnowledgeBaseFrame_Search"] = WoWColor,
	["KnowledgeBaseFrame_ShowArticleFrame"] = WoWColor,
	["KnowledgeBaseFrame_ShowErrorFrame"] = WoWColor,
	["KnowledgeBaseFrame_ShowSearchFrame"] = WoWColor,
	["KnowledgeBaseFrame_UpdateMotd"] = WoWColor,
	["KnowledgeBaseFrame_UpdateServerMessage"] = WoWColor,
	["KnowledgeBaseMotdTextFrame_OnEnter"] = WoWColor,
	["KnowledgeBaseMotdTextFrame_OnLeave"] = WoWColor,
	["KnowledgeBaseMotdTextFrame_OnUpdate"] = WoWColor,
	["KnowledgeBaseServerMessageTextFrame_OnEnter"] = WoWColor,
	["KnowledgeBaseServerMessageTextFrame_OnLeave"] = WoWColor,
	["KnowledgeBaseServerMessageTextFrame_OnUpdate"] = WoWColor,
	["KnowledgeBaseUpdateTopPanelPositions"] = WoWColor,
	["LFDConstructDeclinedMessage"] = WoWColor,
	["LFDDungeonReadyDialogInstanceInfo_OnEnter"] = WoWColor,
	["LFDDungeonReadyDialogReward_OnEnter"] = WoWColor,
	["LFDDungeonReadyDialogReward_SetMisc"] = WoWColor,
	["LFDDungeonReadyDialogReward_SetReward"] = WoWColor,
	["LFDDungeonReadyDialog_UpdateInstanceInfo"] = WoWColor,
	["LFDDungeonReadyDialog_UpdateRewards"] = WoWColor,
	["LFDDungeonReadyPopup_OnFail"] = WoWColor,
	["LFDDungeonReadyPopup_OnUpdate"] = WoWColor,
	["LFDDungeonReadyPopup_Update"] = WoWColor,
	["LFDDungeonReadyStatus_ResetReadyStates"] = WoWColor,
	["LFDDungeonReadyStatus_UpdateIcon"] = WoWColor,
	["LFDFrameRoleCheckButton_OnClick"] = WoWColor,
	["LFDFrameRoleCheckButton_OnEnter"] = WoWColor,
	["LFDFrame_OnEvent"] = WoWColor,
	["LFDFrame_OnHide"] = WoWColor,
	["LFDFrame_OnLoad"] = WoWColor,
	["LFDFrame_OnShow"] = WoWColor,
	["LFDFrame_UpdateBackfill"] = WoWColor,
	["LFDGetNumDungeons"] = WoWColor,
	["LFDList_DefaultFilterFunction"] = WoWColor,
	["LFDList_SetDungeonEnabled"] = WoWColor,
	["LFDList_SetHeaderCollapsed"] = WoWColor,
	["LFDList_SetHeaderEnabled"] = WoWColor,
	["LFDQueueFrameDungeonChoiceEnableButton_OnClick"] = WoWColor,
	["LFDQueueFrameDungeonListButton_OnEnter"] = WoWColor,
	["LFDQueueFrameExpandOrCollapseButton_OnClick"] = WoWColor,
	["LFDQueueFrameFindGroupButton_Update"] = WoWColor,
	["LFDQueueFrameRandomCooldownFrame_OnEvent"] = WoWColor,
	["LFDQueueFrameRandomCooldownFrame_OnLoad"] = WoWColor,
	["LFDQueueFrameRandomCooldownFrame_OnUpdate"] = WoWColor,
	["LFDQueueFrameRandomCooldownFrame_Update"] = WoWColor,
	["LFDQueueFrameRandom_UpdateFrame"] = WoWColor,
	["LFDQueueFrameSpecificListButton_SetDungeon"] = WoWColor,
	["LFDQueueFrameSpecificList_Update"] = WoWColor,
	["LFDQueueFrameTypeDropDownButton_OnClick"] = WoWColor,
	["LFDQueueFrameTypeDropDown_Initialize"] = WoWColor,
	["LFDQueueFrameTypeDropDown_SetUp"] = WoWColor,
	["LFDQueueFrame_Join"] = WoWColor,
	["LFDQueueFrame_QueueForInstanceIfEnabled"] = WoWColor,
	["LFDQueueFrame_SetRoles"] = WoWColor,
	["LFDQueueFrame_SetType"] = WoWColor,
	["LFDQueueFrame_SetTypeRandomDungeon"] = WoWColor,
	["LFDQueueFrame_SetTypeSpecificDungeon"] = WoWColor,
	["LFDQueueFrame_Update"] = WoWColor,
	["LFDQueueFrame_UpdatePortrait"] = WoWColor,
	["LFDRoleCheckPopupAccept_OnClick"] = WoWColor,
	["LFDRoleCheckPopupDecline_OnClick"] = WoWColor,
	["LFDRoleCheckPopupDescription_OnEnter"] = WoWColor,
	["LFDRoleCheckPopup_Update"] = WoWColor,
	["LFDSearchStatusPlayer_SetFound"] = WoWColor,
	["LFDSearchStatus_OnEvent"] = WoWColor,
	["LFDSearchStatus_OnUpdate"] = WoWColor,
	["LFDSearchStatus_Update"] = WoWColor,
	["LFDSearchStatus_UpdateRoles"] = WoWColor,
	["LFD_CURRENT_FILTER"] = WoWColor,
	["LFD_IsEmpowered"] = WoWColor,
	["LFGDebug"] = WoWColor,
	["LFGDungeonList_Setup"] = WoWColor,
	["LFGEventFrame_OnEvent"] = WoWColor,
	["LFGEventFrame_OnLoad"] = WoWColor,
	["LFGGetDungeonInfoByID"] = WoWColor,
	["LFGIsIDHeader"] = WoWColor,
	["LFGListFilterChoices"] = WoWColor,
	["LFGListRemoveCollapsedChildren"] = WoWColor,
	["LFGListRemoveHeadersWithoutChildren"] = WoWColor,
	["LFGListUpdateHeaderEnabledAndLockedStates"] = WoWColor,
	["LFGQueueFrame_UpdateLFGDungeonList"] = WoWColor,
	["LFGSpecificChoiceEnableButton_SetIsRadio"] = WoWColor,
	["LFGTeleport"] = WoWColor,
	["LFG_DisableRoleButton"] = WoWColor,
	["LFG_EnableRoleButton"] = WoWColor,
	["LFG_PermanentlyDisableRoleButton"] = WoWColor,
	["LFG_UpdateAvailableRoles"] = WoWColor,
	["LFG_UpdateFindGroupButtons"] = WoWColor,
	["LFG_UpdateFramesIfShown"] = WoWColor,
	["LFG_UpdateLockedOutPanels"] = WoWColor,
	["LFG_UpdateQueuedList"] = WoWColor,
	["LFG_UpdateRoleCheckboxes"] = WoWColor,
	["LFG_UpdateRolesChangeable"] = WoWColor,
	["LFRBrowseButton_OnClick"] = WoWColor,
	["LFRBrowseButton_OnEnter"] = WoWColor,
	["LFRBrowseFrameListButton_SetData"] = WoWColor,
	["LFRBrowseFrameList_Update"] = WoWColor,
	["LFRBrowseFrameRaidDropDownButton_OnClick"] = WoWColor,
	["LFRBrowseFrameRaidDropDown_Initialize"] = WoWColor,
	["LFRBrowseFrameRaidDropDown_SetUp"] = WoWColor,
	["LFRBrowseFrameRefreshButton_OnUpdate"] = WoWColor,
	["LFRBrowseFrame_OnLoad"] = WoWColor,
	["LFRBrowseFrame_OnUpdateAlways"] = WoWColor,
	["LFRBrowse_UpdateButtonStates"] = WoWColor,
	["LFRFrameRoleCheckButton_OnClick"] = WoWColor,
	["LFRFrame_OnEvent"] = WoWColor,
	["LFRFrame_OnLoad"] = WoWColor,
	["LFRFrame_SetActiveTab"] = WoWColor,
	["LFRGetNumDungeons"] = WoWColor,
	["LFRList_DefaultFilterFunction"] = WoWColor,
	["LFRList_SetHeaderCollapsed"] = WoWColor,
	["LFRList_SetHeaderEnabled"] = WoWColor,
	["LFRList_SetRaidEnabled"] = WoWColor,
	["LFRQueueFrameDungeonChoiceEnableButton_OnClick"] = WoWColor,
	["LFRQueueFrameExpandOrCollapseButton_OnClick"] = WoWColor,
	["LFRQueueFrameFindGroupButton_Update"] = WoWColor,
	["LFRQueueFrameSpecificListButton_SetDungeon"] = WoWColor,
	["LFRQueueFrameSpecificList_Update"] = WoWColor,
	["LFRQueueFrame_Join"] = WoWColor,
	["LFRQueueFrame_QueueForInstanceIfEnabled"] = WoWColor,
	["LFRQueueFrame_SetRoles"] = WoWColor,
	["LFRQueueFrame_Update"] = WoWColor,
	["LFR_CURRENT_FILTER"] = WoWColor,
	["LFR_CanQueueForLockedInstances"] = WoWColor,
	["LFR_CanQueueForMultiple"] = WoWColor,
	["LFR_IsEmpowered"] = WoWColor,
	["LanguageMenu_Click"] = WoWColor,
	["LanguageMenu_LoadLanguages"] = WoWColor,
	["LanguageMenu_OnEvent"] = WoWColor,
	["LanguageMenu_OnLoad"] = WoWColor,
	["LearnPreviewTalents"] = WoWColor,
	["LearnTalent"] = WoWColor,
	["LeaveBattlefield"] = WoWColor,
	["LeaveChannelByName"] = WoWColor,
	["LeaveLFG"] = WoWColor,
	["LeaveParty"] = WoWColor,
	["ListChannelByName"] = WoWColor,
	["ListChannels"] = WoWColor,
	["LoadAddOn"] = WoWColor,
	["LoadBindings"] = WoWColor,
	["LoadMicroButtonTextures"] = WoWColor,
	["Localize"] = WoWColor,
	["LocalizeFrames"] = WoWColor,
	["LocalizePost"] = WoWColor,
	["LockMultiCastActionBar"] = WoWColor,
	["LockPetActionBar"] = WoWColor,
	["LoggingChat"] = WoWColor,
	["LoggingCombat"] = WoWColor,
	["Logout"] = WoWColor,
	["LoopbackVUMeter_OnLoad"] = WoWColor,
	["LoopbackVUMeter_OnUpdate"] = WoWColor,
	["LootButton_OnClick"] = WoWColor,
	["LootFrame_OnEvent"] = WoWColor,
	["LootFrame_OnHide"] = WoWColor,
	["LootFrame_OnLoad"] = WoWColor,
	["LootFrame_OnShow"] = WoWColor,
	["LootFrame_PageDown"] = WoWColor,
	["LootFrame_PageUp"] = WoWColor,
	["LootFrame_Show"] = WoWColor,
	["LootFrame_Update"] = WoWColor,
	["LootFrame_UpdateButton"] = WoWColor,
	["LootItem_OnEnter"] = WoWColor,
	["LootSlot"] = WoWColor,
	["LootSlotIsCoin"] = WoWColor,
	["LootSlotIsItem"] = WoWColor,
	["LowHealthFrame_OnUpdate"] = WoWColor,
	["LowHealthFrame_StartFlashing"] = WoWColor,
	["LowHealthFrame_StopFlashing"] = WoWColor,
	["LowerFrameLevel"] = WoWColor,
	["MacOptionsCancelFrame_OnShow"] = WoWColor,
	["MacOptionsCompressFrame_OnShow"] = WoWColor,
	["MacOptionsFrameCodecDropDown_Initialize"] = WoWColor,
	["MacOptionsFrameCodecDropDown_OnClick"] = WoWColor,
	["MacOptionsFrameCodecDropDown_OnLoad"] = WoWColor,
	["MacOptionsFrameFramerateDropDown_Initialize"] = WoWColor,
	["MacOptionsFrameFramerateDropDown_OnClick"] = WoWColor,
	["MacOptionsFrameFramerateDropDown_OnLoad"] = WoWColor,
	["MacOptionsFrameResolutionButton_OnClick"] = WoWColor,
	["MacOptionsFrameResolutionDropDown_Initialize"] = WoWColor,
	["MacOptionsFrameResolutionDropDown_OnLoad"] = WoWColor,
	["MacOptionsFrame_Cancel"] = WoWColor,
	["MacOptionsFrame_DisableCheckBox"] = WoWColor,
	["MacOptionsFrame_DisableSlider"] = WoWColor,
	["MacOptionsFrame_DisableText"] = WoWColor,
	["MacOptionsFrame_EnableCheckBox"] = WoWColor,
	["MacOptionsFrame_Load"] = WoWColor,
	["MacOptionsFrame_OnEvent"] = WoWColor,
	["MacOptionsFrame_OnLoad"] = WoWColor,
	["MacOptionsFrame_Save"] = WoWColor,
	["MacOptionsFrame_SetDefaults"] = WoWColor,
	["MacOptionsFrame_UpdateTime"] = WoWColor,
	["MacroFrame_LoadUI"] = WoWColor,
	["MacroFrame_SaveMacro"] = WoWColor,
	["MailFrameTab_OnClick"] = WoWColor,
	["MailFrame_OnEvent"] = WoWColor,
	["MailFrame_OnLoad"] = WoWColor,
	["MainMenuBarBackpackButton_OnEvent"] = WoWColor,
	["MainMenuBarBackpackButton_UpdateFreeSlots"] = WoWColor,
	["MainMenuBarPerformanceBarFrame_OnEnter"] = WoWColor,
	["MainMenuBarVehicleLeaveButton_OnEvent"] = WoWColor,
	["MainMenuBarVehicleLeaveButton_OnLoad"] = WoWColor,
	["MainMenuBarVehicleLeaveButton_Update"] = WoWColor,
	["MainMenuBar_AnimFinished"] = WoWColor,
	["MainMenuBar_OnEvent"] = WoWColor,
	["MainMenuBar_OnLoad"] = WoWColor,
	["MainMenuBar_ToPlayerArt"] = WoWColor,
	["MainMenuBar_ToVehicleArt"] = WoWColor,
	["MainMenuBar_UnlockAB"] = WoWColor,
	["MainMenuBar_UpdateArt"] = WoWColor,
	["MainMenuBar_UpdateKeyRing"] = WoWColor,
	["MainMenuExpBar_Update"] = WoWColor,
	["MainMenuMicroButton_SetNormal"] = WoWColor,
	["MainMenuMicroButton_SetPushed"] = WoWColor,
	["MakeMinigameMove"] = WoWColor,
	["ManageBackpackTokenFrame"] = WoWColor,
	["MerchantFrame_ConfirmExtendedItemCost"] = WoWColor,
	["MerchantFrame_ConfirmHighCostItem"] = WoWColor,
	["MerchantFrame_OnEvent"] = WoWColor,
	["MerchantFrame_OnHide"] = WoWColor,
	["MerchantFrame_OnLoad"] = WoWColor,
	["MerchantFrame_OnShow"] = WoWColor,
	["MerchantFrame_ResetRefundItem"] = WoWColor,
	["MerchantFrame_SetRefundItem"] = WoWColor,
	["MerchantFrame_Update"] = WoWColor,
	["MerchantFrame_UpdateAltCurrency"] = WoWColor,
	["MerchantFrame_UpdateBuybackInfo"] = WoWColor,
	["MerchantFrame_UpdateCanRepairAll"] = WoWColor,
	["MerchantFrame_UpdateGuildBankRepair"] = WoWColor,
	["MerchantFrame_UpdateMerchantInfo"] = WoWColor,
	["MerchantFrame_UpdateRepairButtons"] = WoWColor,
	["MerchantItemButton_OnClick"] = WoWColor,
	["MerchantItemButton_OnEnter"] = WoWColor,
	["MerchantItemButton_OnLoad"] = WoWColor,
	["MerchantItemButton_OnModifiedClick"] = WoWColor,
	["MerchantItemBuybackButton_OnLoad"] = WoWColor,
	["MerchantNextPageButton_OnClick"] = WoWColor,
	["MerchantPrevPageButton_OnClick"] = WoWColor,
	["MessageFrameScrollButton_OnLoad"] = WoWColor,
	["MessageFrameScrollButton_OnUpdate"] = WoWColor,
	["MessageTypeColor_OpenColorPicker"] = WoWColor,
	["MicroButtonTooltipText"] = WoWColor,
	["MiniMapBattlefieldDropDown_Initialize"] = WoWColor,
	["MiniMapBattlefieldDropDown_OnLoad"] = WoWColor,
	["MiniMapBattlefieldFrame_OnUpdate"] = WoWColor,
	["MiniMapBattlefieldFrame_isArena"] = WoWColor,
	["MiniMapInstanceDifficulty_OnEvent"] = WoWColor,
	["MiniMapLFGFrameDropDown_Update"] = WoWColor,
	["MiniMapLFGFrame_OnClick"] = WoWColor,
	["MiniMapLFGFrame_OnEnter"] = WoWColor,
	["MiniMapLFGFrame_OnLeave"] = WoWColor,
	["MiniMapLFGFrame_TeleportIn"] = WoWColor,
	["MiniMapLFGFrame_TeleportOut"] = WoWColor,
	["MiniMapLFG_UpdateIsShown"] = WoWColor,
	["MiniMapTrackingDropDown_Initialize"] = WoWColor,
	["MiniMapTrackingDropDown_OnLoad"] = WoWColor,
	["MiniMapTrackingShineFadeIn"] = WoWColor,
	["MiniMapTrackingShineFadeOut"] = WoWColor,
	["MiniMapTracking_SetTracking"] = WoWColor,
	["MiniMapTracking_Update"] = WoWColor,
	["MiniMapVoiceChatDropDown_Initialize"] = WoWColor,
	["MiniMapVoiceChatDropDown_OnLoad"] = WoWColor,
	["MiniMapVoiceChat_Update"] = WoWColor,
	["MinimapButton_OnMouseDown"] = WoWColor,
	["MinimapButton_OnMouseUp"] = WoWColor,
	["MinimapMailFrameUpdate"] = WoWColor,
	["MinimapPing_FadeOut"] = WoWColor,
	["MinimapPing_OnEvent"] = WoWColor,
	["MinimapPing_OnLoad"] = WoWColor,
	["MinimapPing_OnUpdate"] = WoWColor,
	["Minimap_OnClick"] = WoWColor,
	["Minimap_SetPing"] = WoWColor,
	["Minimap_SetTooltip"] = WoWColor,
	["Minimap_Update"] = WoWColor,
	["Minimap_UpdateRotationSetting"] = WoWColor,
	["Minimap_ZoomIn"] = WoWColor,
	["Minimap_ZoomInClick"] = WoWColor,
	["Minimap_ZoomOut"] = WoWColor,
	["Minimap_ZoomOutClick"] = WoWColor,
	["MirrorTimerFrame_OnEvent"] = WoWColor,
	["MirrorTimerFrame_OnLoad"] = WoWColor,
	["MirrorTimerFrame_OnUpdate"] = WoWColor,
	["MirrorTimer_Show"] = WoWColor,
	["Model_OnLoad"] = WoWColor,
	["Model_OnUpdate"] = WoWColor,
	["Model_RotateLeft"] = WoWColor,
	["Model_RotateRight"] = WoWColor,
	["MoneyFrame_OnEvent"] = WoWColor,
	["MoneyFrame_OnLoad"] = WoWColor,
	["MoneyFrame_SetType"] = WoWColor,
	["MoneyFrame_Update"] = WoWColor,
	["MoneyFrame_UpdateMoney"] = WoWColor,
	["MoneyInputFrame_ClearFocus"] = WoWColor,
	["MoneyInputFrame_GetCopper"] = WoWColor,
	["MoneyInputFrame_OnShow"] = WoWColor,
	["MoneyInputFrame_OnTextChanged"] = WoWColor,
	["MoneyInputFrame_ResetMoney"] = WoWColor,
	["MoneyInputFrame_SetCopper"] = WoWColor,
	["MoneyInputFrame_SetMode"] = WoWColor,
	["MoneyInputFrame_SetNextFocus"] = WoWColor,
	["MoneyInputFrame_SetOnValueChangedFunc"] = WoWColor,
	["MoneyInputFrame_SetPreviousFocus"] = WoWColor,
	["MoneyInputFrame_SetTextColor"] = WoWColor,
	["MouseIsOver"] = WoWColor,
	["MouselookStart"] = WoWColor,
	["MouselookStop"] = WoWColor,
	["MoveAndSteerStart"] = WoWColor,
	["MoveAndSteerStop"] = WoWColor,
	["MoveBackwardStart"] = WoWColor,
	["MoveBackwardStop"] = WoWColor,
	["MoveForwardStart"] = WoWColor,
	["MoveForwardStop"] = WoWColor,
	["MoveViewDownStart"] = WoWColor,
	["MoveViewDownStop"] = WoWColor,
	["MoveViewInStart"] = WoWColor,
	["MoveViewInStop"] = WoWColor,
	["MoveViewLeftStart"] = WoWColor,
	["MoveViewLeftStop"] = WoWColor,
	["MoveViewOutStart"] = WoWColor,
	["MoveViewOutStop"] = WoWColor,
	["MoveViewRightStart"] = WoWColor,
	["MoveViewRightStop"] = WoWColor,
	["MoveViewUpStart"] = WoWColor,
	["MoveViewUpStop"] = WoWColor,
	["MovieFrame_OnEvent"] = WoWColor,
	["MovieFrame_OnHide"] = WoWColor,
	["MovieFrame_OnKeyUp"] = WoWColor,
	["MovieFrame_OnLoad"] = WoWColor,
	["MovieFrame_OnMovieFinished"] = WoWColor,
	["MovieFrame_OnMovieHideSubtitle"] = WoWColor,
	["MovieFrame_OnMovieShowSubtitle"] = WoWColor,
	["MovieFrame_OnShow"] = WoWColor,
	["MovieFrame_OnUpdate"] = WoWColor,
	["MovieFrame_PlayMovie"] = WoWColor,
	["MovieRecordingProgress_OnUpdate"] = WoWColor,
	["MultiActionBarFrame_OnLoad"] = WoWColor,
	["MultiActionBar_HideAllGrids"] = WoWColor,
	["MultiActionBar_ShowAllGrids"] = WoWColor,
	["MultiActionBar_Update"] = WoWColor,
	["MultiActionBar_UpdateGrid"] = WoWColor,
	["MultiActionBar_UpdateGridVisibility"] = WoWColor,
	["MultiActionButtonDown"] = WoWColor,
	["MultiActionButtonUp"] = WoWColor,
	["MultiBar1_IsVisible"] = WoWColor,
	["MultiBar2_IsVisible"] = WoWColor,
	["MultiBar3_IsVisible"] = WoWColor,
	["MultiBar4_IsVisible"] = WoWColor,
	["MultiCastActionBarFrame_OnEvent"] = WoWColor,
	["MultiCastActionBarFrame_OnLoad"] = WoWColor,
	["MultiCastActionBarFrame_OnUpdate"] = WoWColor,
	["MultiCastActionBarFrame_Update"] = WoWColor,
	["MultiCastActionButtonDown"] = WoWColor,
	["MultiCastActionButtonUp"] = WoWColor,
	["MultiCastActionButton_OnEnter"] = WoWColor,
	["MultiCastActionButton_OnEvent"] = WoWColor,
	["MultiCastActionButton_OnLeave"] = WoWColor,
	["MultiCastActionButton_OnLoad"] = WoWColor,
	["MultiCastActionButton_OnPostClick"] = WoWColor,
	["MultiCastActionButton_OnShow"] = WoWColor,
	["MultiCastActionButton_Update"] = WoWColor,
	["MultiCastFlyoutButton_OnClick"] = WoWColor,
	["MultiCastFlyoutButton_OnEnter"] = WoWColor,
	["MultiCastFlyoutButton_OnLeave"] = WoWColor,
	["MultiCastFlyoutButton_OnLoad"] = WoWColor,
	["MultiCastFlyoutButton_SetTooltip"] = WoWColor,
	["MultiCastFlyoutFrameCloseButton_OnClick"] = WoWColor,
	["MultiCastFlyoutFrameOpenButton_Hide"] = WoWColor,
	["MultiCastFlyoutFrameOpenButton_OnClick"] = WoWColor,
	["MultiCastFlyoutFrameOpenButton_OnLeave"] = WoWColor,
	["MultiCastFlyoutFrameOpenButton_Show"] = WoWColor,
	["MultiCastFlyoutFrame_Hide"] = WoWColor,
	["MultiCastFlyoutFrame_LoadPageSpells"] = WoWColor,
	["MultiCastFlyoutFrame_LoadSlotSpells"] = WoWColor,
	["MultiCastFlyoutFrame_OnEnter"] = WoWColor,
	["MultiCastFlyoutFrame_OnHide"] = WoWColor,
	["MultiCastFlyoutFrame_OnLeave"] = WoWColor,
	["MultiCastFlyoutFrame_OnShow"] = WoWColor,
	["MultiCastFlyoutFrame_OnUpdate"] = WoWColor,
	["MultiCastFlyoutFrame_ToggleFlyout"] = WoWColor,
	["MultiCastRecallSpellButtonUp"] = WoWColor,
	["MultiCastRecallSpellButton_OnClick"] = WoWColor,
	["MultiCastRecallSpellButton_OnLoad"] = WoWColor,
	["MultiCastRecallSpellButton_Update"] = WoWColor,
	["MultiCastSlotButton_OnEnter"] = WoWColor,
	["MultiCastSlotButton_OnEvent"] = WoWColor,
	["MultiCastSlotButton_OnLeave"] = WoWColor,
	["MultiCastSlotButton_Update"] = WoWColor,
	["MultiCastSpellButton_OnEnter"] = WoWColor,
	["MultiCastSpellButton_OnEvent"] = WoWColor,
	["MultiCastSpellButton_OnLeave"] = WoWColor,
	["MultiCastSpellButton_OnLoad"] = WoWColor,
	["MultiCastSpellButton_SetTooltip"] = WoWColor,
	["MultiCastSpellButton_UpdateCooldown"] = WoWColor,
	["MultiCastSpellButton_UpdateState"] = WoWColor,
	["MultiCastSummonSpellButtonUp"] = WoWColor,
	["MultiCastSummonSpellButton_OnClick"] = WoWColor,
	["MultiCastSummonSpellButton_OnEnter"] = WoWColor,
	["MultiCastSummonSpellButton_OnEvent"] = WoWColor,
	["MultiCastSummonSpellButton_OnLeave"] = WoWColor,
	["MultiCastSummonSpellButton_OnLoad"] = WoWColor,
	["MultiCastSummonSpellButton_Update"] = WoWColor,
	["MultibarGrid_IsVisible"] = WoWColor,
	["Multibar_EmptyFunc"] = WoWColor,
	["NewGMTicket"] = WoWColor,
	["NextView"] = WoWColor,
	["NoPlayTime"] = WoWColor,
	["NotWhileDeadError"] = WoWColor,
	["NotifyInspect"] = WoWColor,
	["NumTaxiNodes"] = WoWColor,
	["OfferPetition"] = WoWColor,
	["OffhandHasWeapon"] = WoWColor,
	["OnMenuLoad"] = WoWColor,
	["OpenAllBags"] = WoWColor,
	["OpenBackpack"] = WoWColor,
	["OpenBag"] = WoWColor,
	["OpenCalendar"] = WoWColor,
	["OpenCoinPickupFrame"] = WoWColor,
	["OpenColorPicker"] = WoWColor,
	["OpenGlyphFrame"] = WoWColor,
	["OpenMailAttachment_OnClick"] = WoWColor,
	["OpenMailAttachment_OnEnter"] = WoWColor,
	["OpenMailFrame_OnHide"] = WoWColor,
	["OpenMailFrame_UpdateButtonPositions"] = WoWColor,
	["OpenMail_Delete"] = WoWColor,
	["OpenMail_GetItemCounts"] = WoWColor,
	["OpenMail_Reply"] = WoWColor,
	["OpenMail_ReportSpam"] = WoWColor,
	["OpenMail_Update"] = WoWColor,
	["OpenStackSplitFrame"] = WoWColor,
	["OpenTrainer"] = WoWColor,
	["OpeningCinematic"] = WoWColor,
	["OptionsCategoryFrame_Update"] = WoWColor,
	["OptionsFrameCancel_OnClick"] = WoWColor,
	["OptionsFrameDefault_OnClick"] = WoWColor,
	["OptionsFrameOkay_OnClick"] = WoWColor,
	["OptionsFrame_AddCategory"] = WoWColor,
	["OptionsFrame_OnHide"] = WoWColor,
	["OptionsFrame_OnLoad"] = WoWColor,
	["OptionsFrame_OnShow"] = WoWColor,
	["OptionsFrame_OpenToCategory"] = WoWColor,
	["OptionsFrame_RefreshCategories"] = WoWColor,
	["OptionsFrame_SetAllToDefaults"] = WoWColor,
	["OptionsFrame_SetCurrentToDefaults"] = WoWColor,
	["OptionsListButtonToggle_OnClick"] = WoWColor,
	["OptionsListButton_OnClick"] = WoWColor,
	["OptionsListButton_OnLoad"] = WoWColor,
	["OptionsListButton_ToggleSubCategories"] = WoWColor,
	["OptionsListScroll_Update"] = WoWColor,
	["OptionsList_ClearSelection"] = WoWColor,
	["OptionsList_DisplayButton"] = WoWColor,
	["OptionsList_DisplayPanel"] = WoWColor,
	["OptionsList_DisplayScrollBar"] = WoWColor,
	["OptionsList_HideButton"] = WoWColor,
	["OptionsList_HideScrollBar"] = WoWColor,
	["OptionsList_OnLoad"] = WoWColor,
	["OptionsList_SelectButton"] = WoWColor,
	["PVPBannerCustomization_Left"] = WoWColor,
	["PVPBannerCustomization_Right"] = WoWColor,
	["PVPBannerFrame_OnShow"] = WoWColor,
	["PVPBannerFrame_OpenColorPicker"] = WoWColor,
	["PVPBannerFrame_SaveBanner"] = WoWColor,
	["PVPBannerFrame_SetBannerColor"] = WoWColor,
	["PVPBannerFrame_SetBorderColor"] = WoWColor,
	["PVPBannerFrame_SetEmblemColor"] = WoWColor,
	["PVPBattlegroundButton_OnClick"] = WoWColor,
	["PVPBattlegroundFrameJoinButton_OnClick"] = WoWColor,
	["PVPBattlegroundFrame_OnEvent"] = WoWColor,
	["PVPBattlegroundFrame_OnHide"] = WoWColor,
	["PVPBattlegroundFrame_OnLoad"] = WoWColor,
	["PVPBattlegroundFrame_OnShow"] = WoWColor,
	["PVPBattlegroundFrame_UpdateGroupAvailable"] = WoWColor,
	["PVPBattlegroundFrame_UpdateVisible"] = WoWColor,
	["PVPBattleground_GetSelectedBattlegroundInfo"] = WoWColor,
	["PVPBattleground_ResetInfo"] = WoWColor,
	["PVPBattleground_UpdateBattlegrounds"] = WoWColor,
	["PVPBattleground_UpdateInfo"] = WoWColor,
	["PVPBattleground_UpdateJoinButton"] = WoWColor,
	["PVPBattleground_UpdateQueueStatus"] = WoWColor,
	["PVPBattleground_UpdateRandomInfo"] = WoWColor,
	["PVPDropDown_Initialize"] = WoWColor,
	["PVPFrameToggleButton_OnClick"] = WoWColor,
	["PVPFrame_IsJustBG"] = WoWColor,
	["PVPFrame_OnEvent"] = WoWColor,
	["PVPFrame_OnHide"] = WoWColor,
	["PVPFrame_OnLoad"] = WoWColor,
	["PVPFrame_OnShow"] = WoWColor,
	["PVPFrame_SetFaction"] = WoWColor,
	["PVPFrame_SetJustBG"] = WoWColor,
	["PVPFrame_SetToInSeason"] = WoWColor,
	["PVPFrame_SetToOffSeason"] = WoWColor,
	["PVPFrame_ShowDropdown"] = WoWColor,
	["PVPFrame_Update"] = WoWColor,
	["PVPHonor_Update"] = WoWColor,
	["PVPMicroButton_SetNormal"] = WoWColor,
	["PVPMicroButton_SetPushed"] = WoWColor,
	["PVPQueue_UpdateRandomInfo"] = WoWColor,
	["PVPStandard_OnLoad"] = WoWColor,
	["PVPTeamDetailsButton_OnClick"] = WoWColor,
	["PVPTeamDetailsToggleButton_OnClick"] = WoWColor,
	["PVPTeamDetails_OnHide"] = WoWColor,
	["PVPTeamDetails_OnShow"] = WoWColor,
	["PVPTeamDetails_Update"] = WoWColor,
	["PVPTeam_OnClick"] = WoWColor,
	["PVPTeam_OnEnter"] = WoWColor,
	["PVPTeam_OnLeave"] = WoWColor,
	["PVPTeam_OnMouseDown"] = WoWColor,
	["PVPTeam_OnMouseUp"] = WoWColor,
	["PVPTeam_Update"] = WoWColor,
	["PanelTemplates_DeselectTab"] = WoWColor,
	["PanelTemplates_DisableTab"] = WoWColor,
	["PanelTemplates_EnableTab"] = WoWColor,
	["PanelTemplates_GetSelectedTab"] = WoWColor,
	["PanelTemplates_GetTabWidth"] = WoWColor,
	["PanelTemplates_SelectTab"] = WoWColor,
	["PanelTemplates_SetDisabledTabState"] = WoWColor,
	["PanelTemplates_SetNumTabs"] = WoWColor,
	["PanelTemplates_SetTab"] = WoWColor,
	["PanelTemplates_TabResize"] = WoWColor,
	["PanelTemplates_Tab_OnClick"] = WoWColor,
	["PanelTemplates_UpdateTabs"] = WoWColor,
	["PaperDollFormatStat"] = WoWColor,
	["PaperDollFrameItemFlyoutButton_OnClick"] = WoWColor,
	["PaperDollFrameItemFlyoutButton_OnEnter"] = WoWColor,
	["PaperDollFrameItemFlyout_CreateButton"] = WoWColor,
	["PaperDollFrameItemFlyout_DisplayButton"] = WoWColor,
	["PaperDollFrameItemFlyout_DisplaySpecialButton"] = WoWColor,
	["PaperDollFrameItemFlyout_Hide"] = WoWColor,
	["PaperDollFrameItemFlyout_OnEvent"] = WoWColor,
	["PaperDollFrameItemFlyout_OnHide"] = WoWColor,
	["PaperDollFrameItemFlyout_OnShow"] = WoWColor,
	["PaperDollFrameItemFlyout_OnUpdate"] = WoWColor,
	["PaperDollFrameItemFlyout_Show"] = WoWColor,
	["PaperDollFrameItemPopoutButton_HideAll"] = WoWColor,
	["PaperDollFrameItemPopoutButton_OnClick"] = WoWColor,
	["PaperDollFrameItemPopoutButton_OnLoad"] = WoWColor,
	["PaperDollFrameItemPopoutButton_SetReversed"] = WoWColor,
	["PaperDollFrameItemPopoutButton_ShowAll"] = WoWColor,
	["PaperDollFrame_ClearIgnoredSlots"] = WoWColor,
	["PaperDollFrame_GetArmorReduction"] = WoWColor,
	["PaperDollFrame_IgnoreSlotsForSet"] = WoWColor,
	["PaperDollFrame_OnEvent"] = WoWColor,
	["PaperDollFrame_OnHide"] = WoWColor,
	["PaperDollFrame_OnLoad"] = WoWColor,
	["PaperDollFrame_OnShow"] = WoWColor,
	["PaperDollFrame_SetArmor"] = WoWColor,
	["PaperDollFrame_SetAttackBothHands"] = WoWColor,
	["PaperDollFrame_SetAttackPower"] = WoWColor,
	["PaperDollFrame_SetAttackSpeed"] = WoWColor,
	["PaperDollFrame_SetBlock"] = WoWColor,
	["PaperDollFrame_SetDamage"] = WoWColor,
	["PaperDollFrame_SetDefense"] = WoWColor,
	["PaperDollFrame_SetDodge"] = WoWColor,
	["PaperDollFrame_SetExpertise"] = WoWColor,
	["PaperDollFrame_SetGuild"] = WoWColor,
	["PaperDollFrame_SetLabelAndText"] = WoWColor,
	["PaperDollFrame_SetLevel"] = WoWColor,
	["PaperDollFrame_SetManaRegen"] = WoWColor,
	["PaperDollFrame_SetMeleeCritChance"] = WoWColor,
	["PaperDollFrame_SetParry"] = WoWColor,
	["PaperDollFrame_SetRangedAttack"] = WoWColor,
	["PaperDollFrame_SetRangedAttackPower"] = WoWColor,
	["PaperDollFrame_SetRangedAttackSpeed"] = WoWColor,
	["PaperDollFrame_SetRangedCritChance"] = WoWColor,
	["PaperDollFrame_SetRangedDamage"] = WoWColor,
	["PaperDollFrame_SetRating"] = WoWColor,
	["PaperDollFrame_SetResilience"] = WoWColor,
	["PaperDollFrame_SetResistances"] = WoWColor,
	["PaperDollFrame_SetSpellBonusDamage"] = WoWColor,
	["PaperDollFrame_SetSpellBonusHealing"] = WoWColor,
	["PaperDollFrame_SetSpellCritChance"] = WoWColor,
	["PaperDollFrame_SetSpellHaste"] = WoWColor,
	["PaperDollFrame_SetSpellPenetration"] = WoWColor,
	["PaperDollFrame_SetStat"] = WoWColor,
	["PaperDollFrame_UpdateStats"] = WoWColor,
	["PaperDollItemSlotButton_OnClick"] = WoWColor,
	["PaperDollItemSlotButton_OnEnter"] = WoWColor,
	["PaperDollItemSlotButton_OnEvent"] = WoWColor,
	["PaperDollItemSlotButton_OnHide"] = WoWColor,
	["PaperDollItemSlotButton_OnLeave"] = WoWColor,
	["PaperDollItemSlotButton_OnLoad"] = WoWColor,
	["PaperDollItemSlotButton_OnModifiedClick"] = WoWColor,
	["PaperDollItemSlotButton_OnShow"] = WoWColor,
	["PaperDollItemSlotButton_Update"] = WoWColor,
	["PaperDollItemSlotButton_UpdateFlyout"] = WoWColor,
	["PaperDollItemSlotButton_UpdateLock"] = WoWColor,
	["PaperDollStatTooltip"] = WoWColor,
	["PaperDoll_IsEquippedSlot"] = WoWColor,
	["PartialPlayTime"] = WoWColor,
	["PartyFrameDropDown_Initialize"] = WoWColor,
	["PartyFrameDropDown_OnLoad"] = WoWColor,
	["PartyLFGStartBackfill"] = WoWColor,
	["PartyMemberBackground_SaveOpacity"] = WoWColor,
	["PartyMemberBackground_SetOpacity"] = WoWColor,
	["PartyMemberBackground_ToggleOpacity"] = WoWColor,
	["PartyMemberBuffTooltip_Update"] = WoWColor,
	["PartyMemberFrame_OnEvent"] = WoWColor,
	["PartyMemberFrame_OnLoad"] = WoWColor,
	["PartyMemberFrame_OnUpdate"] = WoWColor,
	["PartyMemberFrame_RefreshPetDebuffs"] = WoWColor,
	["PartyMemberFrame_ToPlayerArt"] = WoWColor,
	["PartyMemberFrame_ToVehicleArt"] = WoWColor,
	["PartyMemberFrame_UpdateArt"] = WoWColor,
	["PartyMemberFrame_UpdateAssignedRoles"] = WoWColor,
	["PartyMemberFrame_UpdateLeader"] = WoWColor,
	["PartyMemberFrame_UpdateMember"] = WoWColor,
	["PartyMemberFrame_UpdateMemberHealth"] = WoWColor,
	["PartyMemberFrame_UpdateOnlineStatus"] = WoWColor,
	["PartyMemberFrame_UpdatePet"] = WoWColor,
	["PartyMemberFrame_UpdatePvPStatus"] = WoWColor,
	["PartyMemberFrame_UpdateReadyCheck"] = WoWColor,
	["PartyMemberFrame_UpdateStatusBarText"] = WoWColor,
	["PartyMemberFrame_UpdateVoiceStatus"] = WoWColor,
	["PartyMemberHealthCheck"] = WoWColor,
	["PendingListFrameDropDown_Initialize"] = WoWColor,
	["PendingListFrameDropDown_OnLoad"] = WoWColor,
	["PendingListFrame_BlockCommunication"] = WoWColor,
	["PendingListFrame_OnHide"] = WoWColor,
	["PendingListFrame_OnShow"] = WoWColor,
	["PendingListFrame_ReportPlayer"] = WoWColor,
	["PendingListFrame_ReportSpam"] = WoWColor,
	["PendingList_Scroll"] = WoWColor,
	["PendingList_Update"] = WoWColor,
	["PendingList_UpdateTab"] = WoWColor,
	["PetAbandon"] = WoWColor,
	["PetActionBarFrame_IsAboveShapeshift"] = WoWColor,
	["PetActionBarFrame_OnUpdate"] = WoWColor,
	["PetActionBar_HideGrid"] = WoWColor,
	["PetActionBar_OnEvent"] = WoWColor,
	["PetActionBar_OnLoad"] = WoWColor,
	["PetActionBar_ShowGrid"] = WoWColor,
	["PetActionBar_Update"] = WoWColor,
	["PetActionBar_UpdateCooldowns"] = WoWColor,
	["PetActionBar_UpdatePositionValues"] = WoWColor,
	["PetActionButtonDown"] = WoWColor,
	["PetActionButtonUp"] = WoWColor,
	["PetActionButton_IsFlashing"] = WoWColor,
	["PetActionButton_OnClick"] = WoWColor,
	["PetActionButton_OnDragStart"] = WoWColor,
	["PetActionButton_OnEnter"] = WoWColor,
	["PetActionButton_OnEvent"] = WoWColor,
	["PetActionButton_OnLeave"] = WoWColor,
	["PetActionButton_OnLoad"] = WoWColor,
	["PetActionButton_OnModifiedClick"] = WoWColor,
	["PetActionButton_OnReceiveDrag"] = WoWColor,
	["PetActionButton_OnUpdate"] = WoWColor,
	["PetActionButton_SetHotkeys"] = WoWColor,
	["PetActionButton_StartFlash"] = WoWColor,
	["PetActionButton_StopFlash"] = WoWColor,
	["PetAggressiveMode"] = WoWColor,
	["PetAttack"] = WoWColor,
	["PetCanBeAbandoned"] = WoWColor,
	["PetCanBeDismissed"] = WoWColor,
	["PetCanBeRenamed"] = WoWColor,
	["PetCastingBarFrame_OnEvent"] = WoWColor,
	["PetCastingBarFrame_OnLoad"] = WoWColor,
	["PetDefensiveMode"] = WoWColor,
	["PetDismiss"] = WoWColor,
	["PetExpBar_Update"] = WoWColor,
	["PetFollow"] = WoWColor,
	["PetFrameDropDown_Initialize"] = WoWColor,
	["PetFrameDropDown_OnLoad"] = WoWColor,
	["PetFrame_OnEvent"] = WoWColor,
	["PetFrame_OnLoad"] = WoWColor,
	["PetFrame_OnUpdate"] = WoWColor,
	["PetFrame_SetHappiness"] = WoWColor,
	["PetFrame_Update"] = WoWColor,
	["PetHasActionBar"] = WoWColor,
	["PetPaperDollFrame_FindCompanionIndex"] = WoWColor,
	["PetPaperDollFrame_OnEvent"] = WoWColor,
	["PetPaperDollFrame_OnHide"] = WoWColor,
	["PetPaperDollFrame_OnLoad"] = WoWColor,
	["PetPaperDollFrame_OnShow"] = WoWColor,
	["PetPaperDollFrame_SetCompanionPage"] = WoWColor,
	["PetPaperDollFrame_SetResistances"] = WoWColor,
	["PetPaperDollFrame_SetSpellBonusDamage"] = WoWColor,
	["PetPaperDollFrame_SetStats"] = WoWColor,
	["PetPaperDollFrame_SetTab"] = WoWColor,
	["PetPaperDollFrame_Update"] = WoWColor,
	["PetPaperDollFrame_UpdateCompanionCooldowns"] = WoWColor,
	["PetPaperDollFrame_UpdateCompanionPreview"] = WoWColor,
	["PetPaperDollFrame_UpdateCompanions"] = WoWColor,
	["PetPaperDollFrame_UpdateIsAvailable"] = WoWColor,
	["PetPaperDollFrame_UpdateTabs"] = WoWColor,
	["PetPassiveMode"] = WoWColor,
	["PetRename"] = WoWColor,
	["PetStable_NoPetsAllowed"] = WoWColor,
	["PetStable_OnEvent"] = WoWColor,
	["PetStable_OnLoad"] = WoWColor,
	["PetStable_Update"] = WoWColor,
	["PetStopAttack"] = WoWColor,
	["PetWait"] = WoWColor,
	["PetitionFrame_Update"] = WoWColor,
	["PickupAction"] = WoWColor,
	["PickupBagFromSlot"] = WoWColor,
	["PickupCompanion"] = WoWColor,
	["PickupContainerItem"] = WoWColor,
	["PickupEquipmentSet"] = WoWColor,
	["PickupEquipmentSetByName"] = WoWColor,
	["PickupGuildBankItem"] = WoWColor,
	["PickupGuildBankMoney"] = WoWColor,
	["PickupInventoryItem"] = WoWColor,
	["PickupItem"] = WoWColor,
	["PickupMacro"] = WoWColor,
	["PickupMerchantItem"] = WoWColor,
	["PickupPetAction"] = WoWColor,
	["PickupPlayerMoney"] = WoWColor,
	["PickupSpell"] = WoWColor,
	["PickupStablePet"] = WoWColor,
	["PickupTradeMoney"] = WoWColor,
	["PitchDownStart"] = WoWColor,
	["PitchDownStop"] = WoWColor,
	["PitchUpStart"] = WoWColor,
	["PitchUpStop"] = WoWColor,
	["PlaceAction"] = WoWColor,
	["PlaceAuctionBid"] = WoWColor,
	["PlaceGlyphInSocket"] = WoWColor,
	["PlayDance"] = WoWColor,
	["PlayMusic"] = WoWColor,
	["PlaySound"] = WoWColor,
	["PlaySoundFile"] = WoWColor,
	["PlayerCanTeleport"] = WoWColor,
	["PlayerFrameDropDown_Initialize"] = WoWColor,
	["PlayerFrameDropDown_OnLoad"] = WoWColor,
	["PlayerFrame_AnimFinished"] = WoWColor,
	["PlayerFrame_AnimateOut"] = WoWColor,
	["PlayerFrame_OnEvent"] = WoWColor,
	["PlayerFrame_OnLoad"] = WoWColor,
	["PlayerFrame_OnReceiveDrag"] = WoWColor,
	["PlayerFrame_OnUpdate"] = WoWColor,
	["PlayerFrame_SequenceFinished"] = WoWColor,
	["PlayerFrame_SetRunicPower"] = WoWColor,
	["PlayerFrame_SetupDeathKnniggetLayout"] = WoWColor,
	["PlayerFrame_ToPlayerArt"] = WoWColor,
	["PlayerFrame_ToVehicleArt"] = WoWColor,
	["PlayerFrame_Update"] = WoWColor,
	["PlayerFrame_UpdateArt"] = WoWColor,
	["PlayerFrame_UpdateGroupIndicator"] = WoWColor,
	["PlayerFrame_UpdateLayout"] = WoWColor,
	["PlayerFrame_UpdatePartyLeader"] = WoWColor,
	["PlayerFrame_UpdatePlaytime"] = WoWColor,
	["PlayerFrame_UpdatePvPStatus"] = WoWColor,
	["PlayerFrame_UpdateReadyCheck"] = WoWColor,
	["PlayerFrame_UpdateRolesAssigned"] = WoWColor,
	["PlayerFrame_UpdateStatus"] = WoWColor,
	["PlayerFrame_UpdateVoiceStatus"] = WoWColor,
	["PlayerIsPVPInactive"] = WoWColor,
	["PlayerStatFrameLeftDropDown_Initialize"] = WoWColor,
	["PlayerStatFrameLeftDropDown_OnClick"] = WoWColor,
	["PlayerStatFrameLeftDropDown_OnLoad"] = WoWColor,
	["PlayerStatFrameLeftDropDown_OnShow"] = WoWColor,
	["PlayerStatFrameRightDropDown_Initialize"] = WoWColor,
	["PlayerStatFrameRightDropDown_OnClick"] = WoWColor,
	["PlayerStatFrameRightDropDown_OnLoad"] = WoWColor,
	["PlayerStatFrameRightDropDown_OnShow"] = WoWColor,
	["PlayerTitleButton_OnClick"] = WoWColor,
	["PlayerTitleFrame_UpdateTitles"] = WoWColor,
	["PlayerTitlePickerFrame_Toggle"] = WoWColor,
	["PlayerTitlePickerScrollFrame_OnLoad"] = WoWColor,
	["PlayerTitlePickerScrollFrame_Update"] = WoWColor,
	["PositionMiniWorldMapArrowFrame"] = WoWColor,
	["PositionWorldMapArrowFrame"] = WoWColor,
	["PossessBar_OnEvent"] = WoWColor,
	["PossessBar_OnLoad"] = WoWColor,
	["PossessBar_Update"] = WoWColor,
	["PossessBar_UpdateState"] = WoWColor,
	["PossessButton_OnClick"] = WoWColor,
	["PossessButton_OnEnter"] = WoWColor,
	["PrevView"] = WoWColor,
	["ProcessMapClick"] = WoWColor,
	["ProcessQuestLogRewardFactions"] = WoWColor,
	["PromoteToAssistant"] = WoWColor,
	["PromoteToLeader"] = WoWColor,
	["PurchaseSlot"] = WoWColor,
	["PutItemInBackpack"] = WoWColor,
	["PutItemInBag"] = WoWColor,
	["PutKeyInKeyRing"] = WoWColor,
	["QueryAuctionItems"] = WoWColor,
	["QueryCastSequence"] = WoWColor,
	["QueryGuildBankLog"] = WoWColor,
	["QueryGuildBankTab"] = WoWColor,
	["QueryGuildBankText"] = WoWColor,
	["QueryGuildEventLog"] = WoWColor,
	["QueryQuestsCompleted"] = WoWColor,
	["QuestChooseRewardError"] = WoWColor,
	["QuestDetailAcceptButton_OnClick"] = WoWColor,
	["QuestDetailDeclineButton_OnClick"] = WoWColor,
	["QuestFlagsPVP"] = WoWColor,
	["QuestFrameDetailPanel_OnShow"] = WoWColor,
	["QuestFrameGreetingPanel_OnShow"] = WoWColor,
	["QuestFrameProgressItems_Update"] = WoWColor,
	["QuestFrameProgressPanel_OnShow"] = WoWColor,
	["QuestFrameRewardPanel_OnShow"] = WoWColor,
	["QuestFrame_GetMaterial"] = WoWColor,
	["QuestFrame_OnEvent"] = WoWColor,
	["QuestFrame_OnHide"] = WoWColor,
	["QuestFrame_OnLoad"] = WoWColor,
	["QuestFrame_OnShow"] = WoWColor,
	["QuestFrame_SetMaterial"] = WoWColor,
	["QuestFrame_SetPortrait"] = WoWColor,
	["QuestFrame_SetTextColor"] = WoWColor,
	["QuestFrame_SetTitleTextColor"] = WoWColor,
	["QuestGetAutoAccept"] = WoWColor,
	["QuestGoodbyeButton_OnClick"] = WoWColor,
	["QuestInfoFadingFrame_OnUpdate"] = WoWColor,
	["QuestInfoItem_OnClick"] = WoWColor,
	["QuestInfoTimerFrame_OnUpdate"] = WoWColor,
	["QuestInfo_Display"] = WoWColor,
	["QuestInfo_DoReputations"] = WoWColor,
	["QuestInfo_ShowAnchor"] = WoWColor,
	["QuestInfo_ShowDescriptionHeader"] = WoWColor,
	["QuestInfo_ShowDescriptionText"] = WoWColor,
	["QuestInfo_ShowFadingFrame"] = WoWColor,
	["QuestInfo_ShowGroupSize"] = WoWColor,
	["QuestInfo_ShowObjectives"] = WoWColor,
	["QuestInfo_ShowObjectivesHeader"] = WoWColor,
	["QuestInfo_ShowObjectivesText"] = WoWColor,
	["QuestInfo_ShowRequiredMoney"] = WoWColor,
	["QuestInfo_ShowRewardText"] = WoWColor,
	["QuestInfo_ShowRewards"] = WoWColor,
	["QuestInfo_ShowSpacer"] = WoWColor,
	["QuestInfo_ShowTimer"] = WoWColor,
	["QuestInfo_ShowTitle"] = WoWColor,
	["QuestInfo_ToggleRewardElement"] = WoWColor,
	["QuestIsDaily"] = WoWColor,
	["QuestIsWeekly"] = WoWColor,
	["QuestLogControlPanel_UpdatePosition"] = WoWColor,
	["QuestLogControlPanel_UpdateState"] = WoWColor,
	["QuestLogDetailFrame_AttachToQuestLog"] = WoWColor,
	["QuestLogDetailFrame_DetachFromQuestLog"] = WoWColor,
	["QuestLogDetailFrame_OnHide"] = WoWColor,
	["QuestLogDetailFrame_OnLoad"] = WoWColor,
	["QuestLogDetailFrame_OnShow"] = WoWColor,
	["QuestLogFrameTrackButton_OnClick"] = WoWColor,
	["QuestLogPushQuest"] = WoWColor,
	["QuestLogScrollFrame_OnLoad"] = WoWColor,
	["QuestLogShowMapPOI_UpdatePosition"] = WoWColor,
	["QuestLogTitleButton_OnClick"] = WoWColor,
	["QuestLogTitleButton_OnEnter"] = WoWColor,
	["QuestLogTitleButton_OnEvent"] = WoWColor,
	["QuestLogTitleButton_OnLeave"] = WoWColor,
	["QuestLogTitleButton_OnLoad"] = WoWColor,
	["QuestLogTitleButton_Resize"] = WoWColor,
	["QuestLog_GetFirstSelectableQuest"] = WoWColor,
	["QuestLog_OnEvent"] = WoWColor,
	["QuestLog_OnHide"] = WoWColor,
	["QuestLog_OnLoad"] = WoWColor,
	["QuestLog_OnShow"] = WoWColor,
	["QuestLog_OnUpdate"] = WoWColor,
	["QuestLog_OpenToQuest"] = WoWColor,
	["QuestLog_SetFirstValidSelection"] = WoWColor,
	["QuestLog_SetNearestValidSelection"] = WoWColor,
	["QuestLog_SetSelection"] = WoWColor,
	["QuestLog_UnsetSelection"] = WoWColor,
	["QuestLog_Update"] = WoWColor,
	["QuestLog_UpdateMap"] = WoWColor,
	["QuestLog_UpdateMapButton"] = WoWColor,
	["QuestLog_UpdatePartyInfoTooltip"] = WoWColor,
	["QuestLog_UpdateQuestCount"] = WoWColor,
	["QuestLog_UpdateQuestDetails"] = WoWColor,
	["QuestMapUpdateAllQuests"] = WoWColor,
	["QuestPOIButton_OnMouseDown"] = WoWColor,
	["QuestPOIButton_OnMouseUp"] = WoWColor,
	["QuestPOIGetIconInfo"] = WoWColor,
	["QuestPOIGetQuestIDByIndex"] = WoWColor,
	["QuestPOIGetQuestIDByVisibleIndex"] = WoWColor,
	["QuestPOIUpdateIcons"] = WoWColor,
	["QuestPOIUpdateTexture"] = WoWColor,
	["QuestPOI_DeselectButton"] = WoWColor,
	["QuestPOI_DeselectButtonByParent"] = WoWColor,
	["QuestPOI_DisplayButton"] = WoWColor,
	["QuestPOI_HideAllButtons"] = WoWColor,
	["QuestPOI_HideButtons"] = WoWColor,
	["QuestPOI_SelectButton"] = WoWColor,
	["QuestPOI_SelectButtonByIndex"] = WoWColor,
	["QuestPOI_SelectButtonByQuestId"] = WoWColor,
	["QuestPOI_SetTextColor"] = WoWColor,
	["QuestProgressCompleteButton_OnClick"] = WoWColor,
	["QuestRewardCancelButton_OnClick"] = WoWColor,
	["QuestRewardCompleteButton_OnClick"] = WoWColor,
	["QuestRewardItem_OnClick"] = WoWColor,
	["QuestTitleButton_OnClick"] = WoWColor,
	["Quit"] = WoWColor,
	["RaidBossEmoteFrame_OnEvent"] = WoWColor,
	["RaidBossEmoteFrame_OnLoad"] = WoWColor,
	["RaidFrame_LoadUI"] = WoWColor,
	["RaidFrame_OnEvent"] = WoWColor,
	["RaidFrame_OnLoad"] = WoWColor,
	["RaidFrame_Update"] = WoWColor,
	["RaidInfoExtendButton_OnClick"] = WoWColor,
	["RaidInfoFrame_Update"] = WoWColor,
	["RaidInfoFrame_UpdateSelectedIndex"] = WoWColor,
	["RaidInfoInstance_OnClick"] = WoWColor,
	["RaidInfoInstance_OnEnter"] = WoWColor,
	["RaidInfoInstance_OnMouseDown"] = WoWColor,
	["RaidInfoInstance_OnMouseUp"] = WoWColor,
	["RaidInfoScrollFrame_OnLoad"] = WoWColor,
	["RaidNotice_AddMessage"] = WoWColor,
	["RaidNotice_FadeInit"] = WoWColor,
	["RaidNotice_OnUpdate"] = WoWColor,
	["RaidNotice_SetSlot"] = WoWColor,
	["RaidNotice_UpdateSlot"] = WoWColor,
	["RaidOptionsFrame_UpdatePartyFrames"] = WoWColor,
	["RaidWarningFrame_OnEvent"] = WoWColor,
	["RaidWarningFrame_OnLoad"] = WoWColor,
	["RaiseFrameLevel"] = WoWColor,
	["RaiseFrameLevelByTwo"] = WoWColor,
	["RandomRoll"] = WoWColor,
	["ReadFile"] = WoWColor,
	["ReadyCheckFrame_OnEvent"] = WoWColor,
	["ReadyCheckFrame_OnHide"] = WoWColor,
	["ReadyCheckFrame_OnLoad"] = WoWColor,
	["ReadyCheck_Confirm"] = WoWColor,
	["ReadyCheck_Finish"] = WoWColor,
	["ReadyCheck_OnUpdate"] = WoWColor,
	["ReadyCheck_Start"] = WoWColor,
	["RealPartyIsFull"] = WoWColor,
	["RecalculateGearManagerDialogPopup"] = WoWColor,
	["RecentTimeDate"] = WoWColor,
	["RecordLoopbackSoundButton_OnUpdate"] = WoWColor,
	["RefreshAuras"] = WoWColor,
	["RefreshBuffs"] = WoWColor,
	["RefreshDebuffs"] = WoWColor,
	["RefreshEquipmentSetIconInfo"] = WoWColor,
	["RefreshLFGList"] = WoWColor,
	["RefreshMoneyFrame"] = WoWColor,
	["RegisterAutoHide"] = WoWColor,
	["RegisterCVar"] = WoWColor,
	["RegisterForSave"] = WoWColor,
	["RegisterForSavePerCharacter"] = WoWColor,
	["RegisterStateDriver"] = WoWColor,
	["RegisterStaticConstants"] = WoWColor,
	["RegisterUnitWatch"] = WoWColor,
	["RejectProposal"] = WoWColor,
	["ReloadUI"] = WoWColor,
	["RemoveChatWindowChannel"] = WoWColor,
	["RemoveChatWindowMessages"] = WoWColor,
	["RemoveFriend"] = WoWColor,
	["RemoveGlyphFromSocket"] = WoWColor,
	["RemoveQuestWatch"] = WoWColor,
	["RemoveSkillUp"] = WoWColor,
	["RemoveTrackedAchievement"] = WoWColor,
	["RenameEquipmentSet"] = WoWColor,
	["RenamePetition"] = WoWColor,
	["RepairAllItems"] = WoWColor,
	["ReplaceEnchant"] = WoWColor,
	["ReplaceTradeEnchant"] = WoWColor,
	["RepopMe"] = WoWColor,
	["ReportBug"] = WoWColor,
	["ReportPlayerIsPVPAFK"] = WoWColor,
	["ReportSuggestion"] = WoWColor,
	["ReputationBar_DrawHorizontalLine"] = WoWColor,
	["ReputationBar_DrawVerticalLine"] = WoWColor,
	["ReputationBar_OnClick"] = WoWColor,
	["ReputationFrame_OnEvent"] = WoWColor,
	["ReputationFrame_OnLoad"] = WoWColor,
	["ReputationFrame_OnShow"] = WoWColor,
	["ReputationFrame_SetRowType"] = WoWColor,
	["ReputationFrame_Update"] = WoWColor,
	["ReputationWatchBar_Update"] = WoWColor,
	["RequestBattlefieldPositions"] = WoWColor,
	["RequestBattlefieldScoreData"] = WoWColor,
	["RequestBattlegroundInstanceInfo"] = WoWColor,
	["RequestInspectHonorData"] = WoWColor,
	["RequestLFDPartyLockInfo"] = WoWColor,
	["RequestLFDPlayerLockInfo"] = WoWColor,
	["RequestRaidInfo"] = WoWColor,
	["RequestTimePlayed"] = WoWColor,
	["ResetCPUUsage"] = WoWColor,
	["ResetChatColors"] = WoWColor,
	["ResetChatWindows"] = WoWColor,
	["ResetCursor"] = WoWColor,
	["ResetDisabledAddOns"] = WoWColor,
	["ResetGroupPreviewTalentPoints"] = WoWColor,
	["ResetInstances"] = WoWColor,
	["ResetPerformanceValues"] = WoWColor,
	["ResetPreviewTalentPoints"] = WoWColor,
	["ResetTutorials"] = WoWColor,
	["ResetView"] = WoWColor,
	["RespondInstanceLock"] = WoWColor,
	["RespondMailLockSendItem"] = WoWColor,
	["RestartGx"] = WoWColor,
	["RestoreVideoEffectsDefaults"] = WoWColor,
	["RestoreVideoResolutionDefaults"] = WoWColor,
	["RestoreVideoStereoDefaults"] = WoWColor,
	["ResurrectGetOfferer"] = WoWColor,
	["ResurrectHasSickness"] = WoWColor,
	["ResurrectHasTimer"] = WoWColor,
	["RetrieveCorpse"] = WoWColor,
	["ReturnInboxItem"] = WoWColor,
	["RollOnLoot"] = WoWColor,
	["RunBinding"] = WoWColor,
	["RunMacro"] = WoWColor,
	["RunMacroText"] = WoWColor,
	["RunScript"] = WoWColor,
	["RuneButton_OnEnter"] = WoWColor,
	["RuneButton_OnLeave"] = WoWColor,
	["RuneButton_OnLoad"] = WoWColor,
	["RuneButton_OnUpdate"] = WoWColor,
	["RuneButton_ShineFadeIn"] = WoWColor,
	["RuneButton_ShineFadeOut"] = WoWColor,
	["RuneButton_Update"] = WoWColor,
	["RuneFrame_AddRune"] = WoWColor,
	["RuneFrame_FixRunes"] = WoWColor,
	["RuneFrame_OnEvent"] = WoWColor,
	["RuneFrame_OnLoad"] = WoWColor,
	["SaveBindings"] = WoWColor,
	["SaveEquipmentSet"] = WoWColor,
	["SavePendingGuildBankTabPermissions"] = WoWColor,
	["SaveView"] = WoWColor,
	["ScorePlayerDropDown_Cancel"] = WoWColor,
	["ScorePlayerDropDown_Initialize"] = WoWColor,
	["ScorePlayerDropDown_OnClick"] = WoWColor,
	["ScorePlayer_OnMouseUp"] = WoWColor,
	["Screenshot"] = WoWColor,
	["ScrollFrameTemplate_OnMouseWheel"] = WoWColor,
	["ScrollFrame_OnLoad"] = WoWColor,
	["ScrollFrame_OnScrollRangeChanged"] = WoWColor,
	["ScrollingEdit_OnCursorChanged"] = WoWColor,
	["ScrollingEdit_OnTextChanged"] = WoWColor,
	["ScrollingEdit_OnUpdate"] = WoWColor,
	["SearchButton_OnUpdate"] = WoWColor,
	["SearchLFGGetEncounterResults"] = WoWColor,
	["SearchLFGGetJoinedID"] = WoWColor,
	["SearchLFGGetNumResults"] = WoWColor,
	["SearchLFGGetPartyResults"] = WoWColor,
	["SearchLFGGetResults"] = WoWColor,
	["SearchLFGJoin"] = WoWColor,
	["SearchLFGLeave"] = WoWColor,
	["SearchLFGSort"] = WoWColor,
	["SeatIndicator_Pulse"] = WoWColor,
	["SecondsToTime"] = WoWColor,
	["SecondsToTimeAbbrev"] = WoWColor,
	["SecureActionButton_OnClick"] = WoWColor,
	["SecureButton_GetAttribute"] = WoWColor,
	["SecureButton_GetButtonSuffix"] = WoWColor,
	["SecureButton_GetEffectiveButton"] = WoWColor,
	["SecureButton_GetModifiedAttribute"] = WoWColor,
	["SecureButton_GetModifiedUnit"] = WoWColor,
	["SecureButton_GetModifierPrefix"] = WoWColor,
	["SecureButton_GetUnit"] = WoWColor,
	["SecureButton_ParseModifierString"] = WoWColor,
	["SecureCmdItemParse"] = WoWColor,
	["SecureCmdOptionParse"] = WoWColor,
	["SecureCmdUseItem"] = WoWColor,
	["SecureGroupHeader_OnAttributeChanged"] = WoWColor,
	["SecureGroupHeader_OnEvent"] = WoWColor,
	["SecureGroupHeader_OnLoad"] = WoWColor,
	["SecureGroupHeader_Update"] = WoWColor,
	["SecureGroupPetHeader_OnAttributeChanged"] = WoWColor,
	["SecureGroupPetHeader_OnEvent"] = WoWColor,
	["SecureGroupPetHeader_OnLoad"] = WoWColor,
	["SecureGroupPetHeader_Update"] = WoWColor,
	["SecureHandlerExecute"] = WoWColor,
	["SecureHandlerSetFrameRef"] = WoWColor,
	["SecureHandlerUnwrapScript"] = WoWColor,
	["SecureHandlerWrapScript"] = WoWColor,
	["SecureHandler_AttributeOnAttributeChanged"] = WoWColor,
	["SecureHandler_OnClick"] = WoWColor,
	["SecureHandler_OnDragEvent"] = WoWColor,
	["SecureHandler_OnLoad"] = WoWColor,
	["SecureHandler_OnMouseUpDown"] = WoWColor,
	["SecureHandler_OnMouseWheel"] = WoWColor,
	["SecureHandler_OnSimpleEvent"] = WoWColor,
	["SecureHandler_StateOnAttributeChanged"] = WoWColor,
	["SecureUnitButton_OnClick"] = WoWColor,
	["SecureUnitButton_OnLoad"] = WoWColor,
	["SelectActiveQuest"] = WoWColor,
	["SelectAvailableQuest"] = WoWColor,
	["SelectGossipActiveQuest"] = WoWColor,
	["SelectGossipAvailableQuest"] = WoWColor,
	["SelectGossipOption"] = WoWColor,
	["SelectPackage"] = WoWColor,
	["SelectQuestLogEntry"] = WoWColor,
	["SelectStationery"] = WoWColor,
	["SelectTradeSkill"] = WoWColor,
	["SelectTrainerService"] = WoWColor,
	["SendAddonMessage"] = WoWColor,
	["SendChatMessage"] = WoWColor,
	["SendMail"] = WoWColor,
	["SendMailAttachmentButton_OnClick"] = WoWColor,
	["SendMailAttachmentButton_OnDropAny"] = WoWColor,
	["SendMailAttachment_OnEnter"] = WoWColor,
	["SendMailFrame_CanSend"] = WoWColor,
	["SendMailFrame_Reset"] = WoWColor,
	["SendMailFrame_SendMail"] = WoWColor,
	["SendMailFrame_Update"] = WoWColor,
	["SendMailMailButton_OnClick"] = WoWColor,
	["SendMailMoneyButton_OnClick"] = WoWColor,
	["SendMailRadioButton_OnClick"] = WoWColor,
	["SendSystemMessage"] = WoWColor,
	["SendWho"] = WoWColor,
	["SetAbandonQuest"] = WoWColor,
	["SetAchievementComparisonUnit"] = WoWColor,
	["SetActionBarToggles"] = WoWColor,
	["SetActiveTalentGroup"] = WoWColor,
	["SetActiveVoiceChannel"] = WoWColor,
	["SetActiveVoiceChannelBySessionID"] = WoWColor,
	["SetAllowLowLevelRaid"] = WoWColor,
	["SetArenaTeamRosterSelection"] = WoWColor,
	["SetArenaTeamRosterShowOffline"] = WoWColor,
	["SetAuctionsTabShowing"] = WoWColor,
	["SetBagPortraitTexture"] = WoWColor,
	["SetBaseMip"] = WoWColor,
	["SetBattlefieldScoreFaction"] = WoWColor,
	["SetBinding"] = WoWColor,
	["SetBindingClick"] = WoWColor,
	["SetBindingItem"] = WoWColor,
	["SetBindingMacro"] = WoWColor,
	["SetBindingSpell"] = WoWColor,
	["SetButtonPulse"] = WoWColor,
	["SetCVar"] = WoWColor,
	["SetChannelOwner"] = WoWColor,
	["SetChannelPassword"] = WoWColor,
	["SetChannelWatch"] = WoWColor,
	["SetChatColorNameByClass"] = WoWColor,
	["SetChatMouseOverDelay"] = WoWColor,
	["SetChatUnitColor"] = WoWColor,
	["SetChatWindowAlpha"] = WoWColor,
	["SetChatWindowColor"] = WoWColor,
	["SetChatWindowDocked"] = WoWColor,
	["SetChatWindowLocked"] = WoWColor,
	["SetChatWindowName"] = WoWColor,
	["SetChatWindowSavedDimensions"] = WoWColor,
	["SetChatWindowSavedPosition"] = WoWColor,
	["SetChatWindowShown"] = WoWColor,
	["SetChatWindowSize"] = WoWColor,
	["SetChatWindowUninteractable"] = WoWColor,
	["SetConsoleKey"] = WoWColor,
	["SetCurrencyBackpack"] = WoWColor,
	["SetCurrencyUnused"] = WoWColor,
	["SetCurrentGuildBankTab"] = WoWColor,
	["SetCurrentTitle"] = WoWColor,
	["SetCursor"] = WoWColor,
	["SetDesaturation"] = WoWColor,
	["SetDressUpBackground"] = WoWColor,
	["SetDungeonDifficulty"] = WoWColor,
	["SetDungeonMapLevel"] = WoWColor,
	["SetEuropeanNumbers"] = WoWColor,
	["SetFactionActive"] = WoWColor,
	["SetFactionInactive"] = WoWColor,
	["SetFarclip"] = WoWColor,
	["SetFriendNotes"] = WoWColor,
	["SetGamma"] = WoWColor,
	["SetGuildBankTabInfo"] = WoWColor,
	["SetGuildBankTabPermissions"] = WoWColor,
	["SetGuildBankTabWithdraw"] = WoWColor,
	["SetGuildBankText"] = WoWColor,
	["SetGuildBankWithdrawLimit"] = WoWColor,
	["SetGuildInfoText"] = WoWColor,
	["SetGuildRosterSelection"] = WoWColor,
	["SetGuildRosterShowOffline"] = WoWColor,
	["SetInventoryPortraitTexture"] = WoWColor,
	["SetItemButtonCount"] = WoWColor,
	["SetItemButtonDesaturated"] = WoWColor,
	["SetItemButtonNameFrameVertexColor"] = WoWColor,
	["SetItemButtonNormalTextureVertexColor"] = WoWColor,
	["SetItemButtonSlotVertexColor"] = WoWColor,
	["SetItemButtonStock"] = WoWColor,
	["SetItemButtonTexture"] = WoWColor,
	["SetItemButtonTextureVertexColor"] = WoWColor,
	["SetItemRef"] = WoWColor,
	["SetLFGBootVote"] = WoWColor,
	["SetLFGComment"] = WoWColor,
	["SetLFGDungeon"] = WoWColor,
	["SetLFGDungeonEnabled"] = WoWColor,
	["SetLFGHeaderCollapsed"] = WoWColor,
	["SetLFGRoles"] = WoWColor,
	["SetLayoutMode"] = WoWColor,
	["SetLootMethod"] = WoWColor,
	["SetLootPortrait"] = WoWColor,
	["SetLootThreshold"] = WoWColor,
	["SetMacroItem"] = WoWColor,
	["SetMacroSpell"] = WoWColor,
	["SetMapByID"] = WoWColor,
	["SetMapToCurrentZone"] = WoWColor,
	["SetMapZoom"] = WoWColor,
	["SetModifiedClick"] = WoWColor,
	["SetMoneyFrameColor"] = WoWColor,
	["SetMouselookOverrideBinding"] = WoWColor,
	["SetMultiCastSpell"] = WoWColor,
	["SetMultisampleFormat"] = WoWColor,
	["SetNextBarberShopStyle"] = WoWColor,
	["SetOptOutOfLoot"] = WoWColor,
	["SetOverrideBinding"] = WoWColor,
	["SetOverrideBindingClick"] = WoWColor,
	["SetOverrideBindingItem"] = WoWColor,
	["SetOverrideBindingMacro"] = WoWColor,
	["SetOverrideBindingSpell"] = WoWColor,
	["SetPOIIconOverlapDistance"] = WoWColor,
	["SetPOIIconOverlapPushDistance"] = WoWColor,
	["SetPVP"] = WoWColor,
	["SetPartyAssignment"] = WoWColor,
	["SetPendingGuildBankTabPermissions"] = WoWColor,
	["SetPendingGuildBankTabWithdraw"] = WoWColor,
	["SetPetStablePaperdoll"] = WoWColor,
	["SetPortraitTexture"] = WoWColor,
	["SetPortraitToTexture"] = WoWColor,
	["SetRaidDifficulty"] = WoWColor,
	["SetRaidRosterSelection"] = WoWColor,
	["SetRaidSubgroup"] = WoWColor,
	["SetRaidTarget"] = WoWColor,
	["SetRaidTargetIcon"] = WoWColor,
	["SetRaidTargetIconTexture"] = WoWColor,
	["SetSavedInstanceExtend"] = WoWColor,
	["SetScreenResolution"] = WoWColor,
	["SetSelectedAuctionItem"] = WoWColor,
	["SetSelectedBattlefield"] = WoWColor,
	["SetSelectedDisplayChannel"] = WoWColor,
	["SetSelectedFaction"] = WoWColor,
	["SetSelectedFriend"] = WoWColor,
	["SetSelectedIgnore"] = WoWColor,
	["SetSelectedMute"] = WoWColor,
	["SetSelectedSkill"] = WoWColor,
	["SetSelfMuteState"] = WoWColor,
	["SetSendMailCOD"] = WoWColor,
	["SetSendMailMoney"] = WoWColor,
	["SetSendMailShowing"] = WoWColor,
	["SetSpellNameColor"] = WoWColor,
	["SetTableColor"] = WoWColor,
	["SetTalentButtonLocation"] = WoWColor,
	["SetTargetSpellbarAspect"] = WoWColor,
	["SetTaxiBenchmarkMode"] = WoWColor,
	["SetTaxiMap"] = WoWColor,
	["SetTerrainMip"] = WoWColor,
	["SetTexLodBias"] = WoWColor,
	["SetTextStatusBarText"] = WoWColor,
	["SetTextStatusBarTextPrefix"] = WoWColor,
	["SetTextStatusBarTextZeroText"] = WoWColor,
	["SetTitleByName"] = WoWColor,
	["SetTooltipMoney"] = WoWColor,
	["SetTracking"] = WoWColor,
	["SetTradeMoney"] = WoWColor,
	["SetTradeSkillInvSlotFilter"] = WoWColor,
	["SetTradeSkillItemLevelFilter"] = WoWColor,
	["SetTradeSkillItemNameFilter"] = WoWColor,
	["SetTradeSkillSubClassFilter"] = WoWColor,
	["SetTrainerServiceTypeFilter"] = WoWColor,
	["SetTrainerSkillLineFilter"] = WoWColor,
	["SetUIVisibility"] = WoWColor,
	["SetUpAnimation"] = WoWColor,
	["SetView"] = WoWColor,
	["SetWatchedFactionIndex"] = WoWColor,
	["SetWaterDetail"] = WoWColor,
	["SetWhoToUI"] = WoWColor,
	["SetZoneText"] = WoWColor,
	["SetupFullscreenScale"] = WoWColor,
	["SetupUnitButtonConfiguration"] = WoWColor,
	["ShapeshiftBar_ChangeForm"] = WoWColor,
	["ShapeshiftBar_OnEvent"] = WoWColor,
	["ShapeshiftBar_OnLoad"] = WoWColor,
	["ShapeshiftBar_Update"] = WoWColor,
	["ShapeshiftBar_UpdateState"] = WoWColor,
	["ShiftQuestWatches"] = WoWColor,
	["ShowBonusActionBar"] = WoWColor,
	["ShowBuybackSellCursor"] = WoWColor,
	["ShowCloak"] = WoWColor,
	["ShowContainerSellCursor"] = WoWColor,
	["ShowFriends"] = WoWColor,
	["ShowHelm"] = WoWColor,
	["ShowInspectCursor"] = WoWColor,
	["ShowInventorySellCursor"] = WoWColor,
	["ShowMacroFrame"] = WoWColor,
	["ShowMerchantSellCursor"] = WoWColor,
	["ShowMiniWorldMapArrowFrame"] = WoWColor,
	["ShowMultiCastActionBar"] = WoWColor,
	["ShowNumericThreat"] = WoWColor,
	["ShowPartyFrame"] = WoWColor,
	["ShowPetActionBar"] = WoWColor,
	["ShowQuickButton"] = WoWColor,
	["ShowReadyCheck"] = WoWColor,
	["ShowRepairCursor"] = WoWColor,
	["ShowResurrectRequest"] = WoWColor,
	["ShowTextStatusBarText"] = WoWColor,
	["ShowUIPanel"] = WoWColor,
	["ShowWatchedReputationBarText"] = WoWColor,
	["ShowWhoPanel"] = WoWColor,
	["ShowWorldMapArrowFrame"] = WoWColor,
	["ShowingCloak"] = WoWColor,
	["ShowingHelm"] = WoWColor,
	["SignPetition"] = WoWColor,
	["SilenceMember"] = WoWColor,
	["SitStandOrDescendStart"] = WoWColor,
	["SkillBar_OnClick"] = WoWColor,
	["SkillDetailFrame_SetStatusBar"] = WoWColor,
	["SkillFrame_OnEvent"] = WoWColor,
	["SkillFrame_OnLoad"] = WoWColor,
	["SkillFrame_OnShow"] = WoWColor,
	["SkillFrame_SetStatusBar"] = WoWColor,
	["SkillFrame_UpdateSkills"] = WoWColor,
	["SmallMoneyFrame_OnLoad"] = WoWColor,
	["SocketContainerItem"] = WoWColor,
	["SocketInventoryItem"] = WoWColor,
	["SortArenaTeamRoster"] = WoWColor,
	["SortAuctionApplySort"] = WoWColor,
	["SortAuctionClearSort"] = WoWColor,
	["SortAuctionItems"] = WoWColor,
	["SortAuctionSetSort"] = WoWColor,
	["SortBGList"] = WoWColor,
	["SortBattlefieldScoreData"] = WoWColor,
	["SortGuildRoster"] = WoWColor,
	["SortQuestWatches"] = WoWColor,
	["SortWho"] = WoWColor,
	["Sound_ChatSystem_GetInputDriverNameByIndex"] = WoWColor,
	["Sound_ChatSystem_GetNumInputDrivers"] = WoWColor,
	["Sound_ChatSystem_GetNumOutputDrivers"] = WoWColor,
	["Sound_ChatSystem_GetOutputDriverNameByIndex"] = WoWColor,
	["Sound_GameSystem_GetInputDriverNameByIndex"] = WoWColor,
	["Sound_GameSystem_GetNumInputDrivers"] = WoWColor,
	["Sound_GameSystem_GetNumOutputDrivers"] = WoWColor,
	["Sound_GameSystem_GetOutputDriverNameByIndex"] = WoWColor,
	["Sound_GameSystem_RestartSoundSystem"] = WoWColor,
	["Sound_MasterVolumeDown"] = WoWColor,
	["Sound_MasterVolumeUp"] = WoWColor,
	["Sound_ToggleMusic"] = WoWColor,
	["Sound_ToggleSound"] = WoWColor,
	["SpellBookFrameTabButton_OnClick"] = WoWColor,
	["SpellBookFrame_HideSpells"] = WoWColor,
	["SpellBookFrame_OnEvent"] = WoWColor,
	["SpellBookFrame_OnHide"] = WoWColor,
	["SpellBookFrame_OnLoad"] = WoWColor,
	["SpellBookFrame_OnShow"] = WoWColor,
	["SpellBookFrame_PlayCloseSound"] = WoWColor,
	["SpellBookFrame_PlayOpenSound"] = WoWColor,
	["SpellBookFrame_SetTabType"] = WoWColor,
	["SpellBookFrame_ShowSpells"] = WoWColor,
	["SpellBookFrame_Update"] = WoWColor,
	["SpellBookFrame_UpdatePages"] = WoWColor,
	["SpellBookNextPageButton_OnClick"] = WoWColor,
	["SpellBookPrevPageButton_OnClick"] = WoWColor,
	["SpellBookSkillLineTab_OnClick"] = WoWColor,
	["SpellBook_GetAutoCastShine"] = WoWColor,
	["SpellBook_GetCurrentPage"] = WoWColor,
	["SpellBook_GetSpellID"] = WoWColor,
	["SpellBook_GetTabInfo"] = WoWColor,
	["SpellBook_ReleaseAutoCastShine"] = WoWColor,
	["SpellBook_UpdatePageArrows"] = WoWColor,
	["SpellButton_OnClick"] = WoWColor,
	["SpellButton_OnDrag"] = WoWColor,
	["SpellButton_OnEnter"] = WoWColor,
	["SpellButton_OnEvent"] = WoWColor,
	["SpellButton_OnHide"] = WoWColor,
	["SpellButton_OnLoad"] = WoWColor,
	["SpellButton_OnModifiedClick"] = WoWColor,
	["SpellButton_OnShow"] = WoWColor,
	["SpellButton_UpdateButton"] = WoWColor,
	["SpellButton_UpdateSelection"] = WoWColor,
	["SpellCanTargetGlyph"] = WoWColor,
	["SpellCanTargetItem"] = WoWColor,
	["SpellCanTargetUnit"] = WoWColor,
	["SpellColor_OpenColorPicker"] = WoWColor,
	["SpellHasRange"] = WoWColor,
	["SpellIsTargeting"] = WoWColor,
	["SpellStopCasting"] = WoWColor,
	["SpellStopTargeting"] = WoWColor,
	["SpellTargetItem"] = WoWColor,
	["SpellTargetUnit"] = WoWColor,
	["SplitContainerItem"] = WoWColor,
	["SplitGuildBankItem"] = WoWColor,
	["StablePet"] = WoWColor,
	["StackSplitFrameCancel_Click"] = WoWColor,
	["StackSplitFrameLeft_Click"] = WoWColor,
	["StackSplitFrameOkay_Click"] = WoWColor,
	["StackSplitFrameRight_Click"] = WoWColor,
	["StackSplitFrame_OnChar"] = WoWColor,
	["StackSplitFrame_OnHide"] = WoWColor,
	["StackSplitFrame_OnKeyDown"] = WoWColor,
	["StackSplitFrame_OnKeyUp"] = WoWColor,
	["StartAttack"] = WoWColor,
	["StartAuction"] = WoWColor,
	["StartDuel"] = WoWColor,
	["StaticPopupSpecial_Hide"] = WoWColor,
	["StaticPopupSpecial_Show"] = WoWColor,
	["StaticPopup_CollapseTable"] = WoWColor,
	["StaticPopup_EditBoxOnEnterPressed"] = WoWColor,
	["StaticPopup_EditBoxOnEscapePressed"] = WoWColor,
	["StaticPopup_EditBoxOnTextChanged"] = WoWColor,
	["StaticPopup_EscapePressed"] = WoWColor,
	["StaticPopup_FindVisible"] = WoWColor,
	["StaticPopup_Hide"] = WoWColor,
	["StaticPopup_HideExclusive"] = WoWColor,
	["StaticPopup_IsLastDisplayedFrame"] = WoWColor,
	["StaticPopup_OnClick"] = WoWColor,
	["StaticPopup_OnEvent"] = WoWColor,
	["StaticPopup_OnHide"] = WoWColor,
	["StaticPopup_OnKeyDown"] = WoWColor,
	["StaticPopup_OnShow"] = WoWColor,
	["StaticPopup_OnUpdate"] = WoWColor,
	["StaticPopup_Resize"] = WoWColor,
	["StaticPopup_SetUpPosition"] = WoWColor,
	["StaticPopup_Show"] = WoWColor,
	["StaticPopup_Visible"] = WoWColor,
	["StationeryPopupButton_OnClick"] = WoWColor,
	["StationeryPopupFrame_Update"] = WoWColor,
	["StatsFrame_OnLoad"] = WoWColor,
	["StatsFrame_OnUpdate"] = WoWColor,
	["StopAttack"] = WoWColor,
	["StopCinematic"] = WoWColor,
	["StopMacro"] = WoWColor,
	["StopMusic"] = WoWColor,
	["StopTradeSkillRepeat"] = WoWColor,
	["StopwatchCloseButton_OnClick"] = WoWColor,
	["StopwatchFrame_OnDragStart"] = WoWColor,
	["StopwatchFrame_OnDragStop"] = WoWColor,
	["StopwatchFrame_OnEvent"] = WoWColor,
	["StopwatchFrame_OnHide"] = WoWColor,
	["StopwatchFrame_OnLoad"] = WoWColor,
	["StopwatchFrame_OnMouseDown"] = WoWColor,
	["StopwatchFrame_OnMouseUp"] = WoWColor,
	["StopwatchFrame_OnShow"] = WoWColor,
	["StopwatchFrame_OnUpdate"] = WoWColor,
	["StopwatchPlayPauseButton_OnClick"] = WoWColor,
	["StopwatchResetButton_OnClick"] = WoWColor,
	["StopwatchTicker_OnUpdate"] = WoWColor,
	["StopwatchTicker_Update"] = WoWColor,
	["Stopwatch_Clear"] = WoWColor,
	["Stopwatch_FinishCountdown"] = WoWColor,
	["Stopwatch_IsPlaying"] = WoWColor,
	["Stopwatch_Pause"] = WoWColor,
	["Stopwatch_Play"] = WoWColor,
	["Stopwatch_StartCountdown"] = WoWColor,
	["Stopwatch_Toggle"] = WoWColor,
	["StrafeLeftStart"] = WoWColor,
	["StrafeLeftStop"] = WoWColor,
	["StrafeRightStart"] = WoWColor,
	["StrafeRightStop"] = WoWColor,
	["Stuck"] = WoWColor,
	["SubZoneText_OnLoad"] = WoWColor,
	["SummonFriend"] = WoWColor,
	["SummonRandomCritter"] = WoWColor,
	["SwapRaidSubgroup"] = WoWColor,
	["SynchronizeBNetStatus"] = WoWColor,
	["TEXT"] = WoWColor,
	["TabardCharacterModelFrame_OnLoad"] = WoWColor,
	["TabardCharacterModelFrame_OnUpdate"] = WoWColor,
	["TabardCharacterModelRotateLeftButton_OnClick"] = WoWColor,
	["TabardCharacterModelRotateRightButton_OnClick"] = WoWColor,
	["TabardCustomization_Left"] = WoWColor,
	["TabardCustomization_Right"] = WoWColor,
	["TabardFrame_OnEvent"] = WoWColor,
	["TabardFrame_OnLoad"] = WoWColor,
	["TabardFrame_UpdateButtons"] = WoWColor,
	["TabardFrame_UpdateTextures"] = WoWColor,
	["TakeInboxItem"] = WoWColor,
	["TakeInboxMoney"] = WoWColor,
	["TakeInboxTextItem"] = WoWColor,
	["TakeScreenshot"] = WoWColor,
	["TakeTaxiNode"] = WoWColor,
	["TalentFrame_DrawLines"] = WoWColor,
	["TalentFrame_GetArrowTexture"] = WoWColor,
	["TalentFrame_GetArrowTextureCount"] = WoWColor,
	["TalentFrame_GetBranchTexture"] = WoWColor,
	["TalentFrame_GetBranchTextureCount"] = WoWColor,
	["TalentFrame_Load"] = WoWColor,
	["TalentFrame_LoadUI"] = WoWColor,
	["TalentFrame_ResetArrowTextureCount"] = WoWColor,
	["TalentFrame_ResetBranchTextureCount"] = WoWColor,
	["TalentFrame_ResetBranches"] = WoWColor,
	["TalentFrame_SetArrowTexture"] = WoWColor,
	["TalentFrame_SetBranchTexture"] = WoWColor,
	["TalentFrame_SetPrereqs"] = WoWColor,
	["TalentFrame_Update"] = WoWColor,
	["TalentFrame_UpdateSpecInfoCache"] = WoWColor,
	["TalentFrame_UpdateTalentPoints"] = WoWColor,
	["TalentMicroButton_OnEvent"] = WoWColor,
	["TargetDirectionEnemy"] = WoWColor,
	["TargetDirectionFinished"] = WoWColor,
	["TargetDirectionFriend"] = WoWColor,
	["TargetFrameDropDown_Initialize"] = WoWColor,
	["TargetFrame_CheckClassification"] = WoWColor,
	["TargetFrame_CheckDead"] = WoWColor,
	["TargetFrame_CheckFaction"] = WoWColor,
	["TargetFrame_CheckLevel"] = WoWColor,
	["TargetFrame_CreateSpellbar"] = WoWColor,
	["TargetFrame_CreateTargetofTarget"] = WoWColor,
	["TargetFrame_HealthUpdate"] = WoWColor,
	["TargetFrame_OnEvent"] = WoWColor,
	["TargetFrame_OnHide"] = WoWColor,
	["TargetFrame_OnLoad"] = WoWColor,
	["TargetFrame_OnUpdate"] = WoWColor,
	["TargetFrame_Update"] = WoWColor,
	["TargetFrame_UpdateAuraPositions"] = WoWColor,
	["TargetFrame_UpdateAuras"] = WoWColor,
	["TargetFrame_UpdateBuffAnchor"] = WoWColor,
	["TargetFrame_UpdateDebuffAnchor"] = WoWColor,
	["TargetFrame_UpdateRaidTargetIcon"] = WoWColor,
	["TargetHealthCheck"] = WoWColor,
	["TargetLastEnemy"] = WoWColor,
	["TargetLastFriend"] = WoWColor,
	["TargetLastTarget"] = WoWColor,
	["TargetNearest"] = WoWColor,
	["TargetNearestEnemy"] = WoWColor,
	["TargetNearestEnemyPlayer"] = WoWColor,
	["TargetNearestFriend"] = WoWColor,
	["TargetNearestFriendPlayer"] = WoWColor,
	["TargetNearestPartyMember"] = WoWColor,
	["TargetNearestRaidMember"] = WoWColor,
	["TargetTotem"] = WoWColor,
	["TargetUnit"] = WoWColor,
	["Target_Spellbar_AdjustPosition"] = WoWColor,
	["Target_Spellbar_OnEvent"] = WoWColor,
	["TargetofTargetHealthCheck"] = WoWColor,
	["TargetofTarget_CheckDead"] = WoWColor,
	["TargetofTarget_OnHide"] = WoWColor,
	["TargetofTarget_Update"] = WoWColor,
	["TaxiFrame_OnEvent"] = WoWColor,
	["TaxiFrame_OnLoad"] = WoWColor,
	["TaxiGetDestX"] = WoWColor,
	["TaxiGetDestY"] = WoWColor,
	["TaxiGetSrcX"] = WoWColor,
	["TaxiGetSrcY"] = WoWColor,
	["TaxiNodeCost"] = WoWColor,
	["TaxiNodeGetType"] = WoWColor,
	["TaxiNodeName"] = WoWColor,
	["TaxiNodeOnButtonEnter"] = WoWColor,
	["TaxiNodePosition"] = WoWColor,
	["TaxiNodeSetCurrent"] = WoWColor,
	["TeleportToDebugObject"] = WoWColor,
	["TempEnchantButton_OnClick"] = WoWColor,
	["TempEnchantButton_OnEnter"] = WoWColor,
	["TempEnchantButton_OnLoad"] = WoWColor,
	["TempEnchantButton_OnUpdate"] = WoWColor,
	["TemporaryEnchantFrame_Hide"] = WoWColor,
	["TemporaryEnchantFrame_OnUpdate"] = WoWColor,
	["TextEmoteSort"] = WoWColor,
	["TextStatusBar_CapDisplayOfNumericValue"] = WoWColor,
	["TextStatusBar_Initialize"] = WoWColor,
	["TextStatusBar_OnEvent"] = WoWColor,
	["TextStatusBar_OnValueChanged"] = WoWColor,
	["TextStatusBar_UpdateTextString"] = WoWColor,
	["TicketStatusFrameButton_OnClick"] = WoWColor,
	["TicketStatusFrameButton_OnLoad"] = WoWColor,
	["TicketStatusFrame_OnEvent"] = WoWColor,
	["TicketStatusFrame_OnHide"] = WoWColor,
	["TicketStatusFrame_OnLoad"] = WoWColor,
	["TicketStatusFrame_OnShow"] = WoWColor,
	["TicketStatusFrame_OnUpdate"] = WoWColor,
	["TimeManagerAlarmAMPMDropDown_Initialize"] = WoWColor,
	["TimeManagerAlarmAMPMDropDown_OnClick"] = WoWColor,
	["TimeManagerAlarmAMPMDropDown_OnHide"] = WoWColor,
	["TimeManagerAlarmAMPMDropDown_OnShow"] = WoWColor,
	["TimeManagerAlarmEnabledButton_OnClick"] = WoWColor,
	["TimeManagerAlarmEnabledButton_Update"] = WoWColor,
	["TimeManagerAlarmHourDropDown_Initialize"] = WoWColor,
	["TimeManagerAlarmHourDropDown_OnClick"] = WoWColor,
	["TimeManagerAlarmMessageEditBox_OnEditFocusLost"] = WoWColor,
	["TimeManagerAlarmMessageEditBox_OnEnterPressed"] = WoWColor,
	["TimeManagerAlarmMessageEditBox_OnEscapePressed"] = WoWColor,
	["TimeManagerAlarmMinuteDropDown_Initialize"] = WoWColor,
	["TimeManagerAlarmMinuteDropDown_OnClick"] = WoWColor,
	["TimeManagerClockButton_Hide"] = WoWColor,
	["TimeManagerClockButton_OnClick"] = WoWColor,
	["TimeManagerClockButton_OnEnter"] = WoWColor,
	["TimeManagerClockButton_OnLeave"] = WoWColor,
	["TimeManagerClockButton_OnLoad"] = WoWColor,
	["TimeManagerClockButton_OnUpdate"] = WoWColor,
	["TimeManagerClockButton_OnUpdateWithTooltip"] = WoWColor,
	["TimeManagerClockButton_Show"] = WoWColor,
	["TimeManagerClockButton_Update"] = WoWColor,
	["TimeManagerClockButton_UpdateTooltip"] = WoWColor,
	["TimeManagerCloseButton_OnClick"] = WoWColor,
	["TimeManagerFrame_OnHide"] = WoWColor,
	["TimeManagerFrame_OnLoad"] = WoWColor,
	["TimeManagerFrame_OnShow"] = WoWColor,
	["TimeManagerFrame_OnUpdate"] = WoWColor,
	["TimeManagerLocalTimeCheck_OnClick"] = WoWColor,
	["TimeManagerMilitaryTimeCheck_OnClick"] = WoWColor,
	["TimeManagerStopwatchCheck_OnClick"] = WoWColor,
	["TimeManager_CheckAlarm"] = WoWColor,
	["TimeManager_FireAlarm"] = WoWColor,
	["TimeManager_FireAlarmWarning"] = WoWColor,
	["TimeManager_IsAlarmFiring"] = WoWColor,
	["TimeManager_LoadUI"] = WoWColor,
	["TimeManager_ShouldCheckAlarm"] = WoWColor,
	["TimeManager_StartCheckingAlarm"] = WoWColor,
	["TimeManager_Toggle"] = WoWColor,
	["TimeManager_ToggleLocalTime"] = WoWColor,
	["TimeManager_ToggleTimeFormat"] = WoWColor,
	["TimeManager_TurnOffAlarm"] = WoWColor,
	["TimeManager_Update"] = WoWColor,
	["TimeManager_UpdateAlarmTime"] = WoWColor,
	["TimeManager_UpdateTimeTicker"] = WoWColor,
	["ToggleAchievementFrame"] = WoWColor,
	["ToggleAutoRun"] = WoWColor,
	["ToggleBackpack"] = WoWColor,
	["ToggleBag"] = WoWColor,
	["ToggleBattlefieldMinimap"] = WoWColor,
	["ToggleCalendar"] = WoWColor,
	["ToggleCharacter"] = WoWColor,
	["ToggleChatChannel"] = WoWColor,
	["ToggleChatColorNamesByClassGroup"] = WoWColor,
	["ToggleChatMessageGroup"] = WoWColor,
	["ToggleCollision"] = WoWColor,
	["ToggleCollisionDisplay"] = WoWColor,
	["ToggleDropDownMenu"] = WoWColor,
	["ToggleFrame"] = WoWColor,
	["ToggleFramerate"] = WoWColor,
	["ToggleFriendsFrame"] = WoWColor,
	["ToggleFriendsPanel"] = WoWColor,
	["ToggleGameMenu"] = WoWColor,
	["ToggleGlyphFrame"] = WoWColor,
	["ToggleGuildEventLog"] = WoWColor,
	["ToggleGuildInfoFrame"] = WoWColor,
	["ToggleHelpFrame"] = WoWColor,
	["ToggleIgnorePanel"] = WoWColor,
	["ToggleKeyRing"] = WoWColor,
	["ToggleLFDParentFrame"] = WoWColor,
	["ToggleLFRParentFrame"] = WoWColor,
	["ToggleMapFramerate"] = WoWColor,
	["ToggleMessageDest"] = WoWColor,
	["ToggleMessageSource"] = WoWColor,
	["ToggleMessageType"] = WoWColor,
	["ToggleMessageTypeGroup"] = WoWColor,
	["ToggleMiniMapRotation"] = WoWColor,
	["ToggleMinimap"] = WoWColor,
	["TogglePVP"] = WoWColor,
	["TogglePVPFrame"] = WoWColor,
	["TogglePerformanceDisplay"] = WoWColor,
	["TogglePerformancePause"] = WoWColor,
	["TogglePerformanceValues"] = WoWColor,
	["TogglePetAutocast"] = WoWColor,
	["TogglePlayerBounds"] = WoWColor,
	["TogglePortals"] = WoWColor,
	["ToggleRun"] = WoWColor,
	["ToggleSheath"] = WoWColor,
	["ToggleSpellAutocast"] = WoWColor,
	["ToggleSpellBook"] = WoWColor,
	["ToggleStats"] = WoWColor,
	["ToggleTalentFrame"] = WoWColor,
	["ToggleTimeManager"] = WoWColor,
	["ToggleTris"] = WoWColor,
	["ToggleWorldStateScoreFrame"] = WoWColor,
	["TokenButtonLinkButton_OnClick"] = WoWColor,
	["TokenButton_OnClick"] = WoWColor,
	["TokenButton_OnLoad"] = WoWColor,
	["TokenFramePopup_CloseIfHidden"] = WoWColor,
	["TokenFrame_LoadUI"] = WoWColor,
	["TokenFrame_OnLoad"] = WoWColor,
	["TokenFrame_OnShow"] = WoWColor,
	["TokenFrame_Update"] = WoWColor,
	["TokenFrame_UpdatePopup"] = WoWColor,
	["TotemButton_OnClick"] = WoWColor,
	["TotemButton_OnLoad"] = WoWColor,
	["TotemButton_OnUpdate"] = WoWColor,
	["TotemButton_Update"] = WoWColor,
	["TotemFrame_OnEvent"] = WoWColor,
	["TotemFrame_OnLoad"] = WoWColor,
	["TotemFrame_Update"] = WoWColor,
	["TradeFrameCancelButton_OnClick"] = WoWColor,
	["TradeFrameTradeButton_Disable"] = WoWColor,
	["TradeFrameTradeButton_Enable"] = WoWColor,
	["TradeFrameTradeButton_SetToEnabledState"] = WoWColor,
	["TradeFrame_GetAvailableSlot"] = WoWColor,
	["TradeFrame_OnEvent"] = WoWColor,
	["TradeFrame_OnHide"] = WoWColor,
	["TradeFrame_OnLoad"] = WoWColor,
	["TradeFrame_OnMouseUp"] = WoWColor,
	["TradeFrame_OnShow"] = WoWColor,
	["TradeFrame_SetAcceptState"] = WoWColor,
	["TradeFrame_Update"] = WoWColor,
	["TradeFrame_UpdateMoney"] = WoWColor,
	["TradeFrame_UpdatePlayerItem"] = WoWColor,
	["TradeFrame_UpdateTargetItem"] = WoWColor,
	["TradeSkillFrame_LoadUI"] = WoWColor,
	["TradeSkillOnlyShowMakeable"] = WoWColor,
	["TradeSkillOnlyShowSkillUps"] = WoWColor,
	["TriggerTutorial"] = WoWColor,
	["TurnInArenaPetition"] = WoWColor,
	["TurnInGuildCharter"] = WoWColor,
	["TurnInPetition"] = WoWColor,
	["TurnLeftStart"] = WoWColor,
	["TurnLeftStop"] = WoWColor,
	["TurnOrActionStart"] = WoWColor,
	["TurnOrActionStop"] = WoWColor,
	["TurnRightStart"] = WoWColor,
	["TurnRightStop"] = WoWColor,
	["TutorialFrameNextButton_OnClick"] = WoWColor,
	["TutorialFramePrevButton_OnClick"] = WoWColor,
	["TutorialFrame_AlertButton_OnClick"] = WoWColor,
	["TutorialFrame_CheckBadge"] = WoWColor,
	["TutorialFrame_CheckNextPrevButtons"] = WoWColor,
	["TutorialFrame_ClearQueue"] = WoWColor,
	["TutorialFrame_ClearTextures"] = WoWColor,
	["TutorialFrame_Hide"] = WoWColor,
	["TutorialFrame_NewTutorial"] = WoWColor,
	["TutorialFrame_OnHide"] = WoWColor,
	["TutorialFrame_OnLoad"] = WoWColor,
	["TutorialFrame_OnShow"] = WoWColor,
	["TutorialFrame_Update"] = WoWColor,
	["UIDoFramesIntersect"] = WoWColor,
	["UIDropDownMenuButton_GetChecked"] = WoWColor,
	["UIDropDownMenuButton_GetName"] = WoWColor,
	["UIDropDownMenuButton_OnClick"] = WoWColor,
	["UIDropDownMenuButton_OpenColorPicker"] = WoWColor,
	["UIDropDownMenuDelegate_OnAttributeChanged"] = WoWColor,
	["UIDropDownMenu_AddButton"] = WoWColor,
	["UIDropDownMenu_ClearAll"] = WoWColor,
	["UIDropDownMenu_CreateFrames"] = WoWColor,
	["UIDropDownMenu_CreateInfo"] = WoWColor,
	["UIDropDownMenu_DisableButton"] = WoWColor,
	["UIDropDownMenu_DisableDropDown"] = WoWColor,
	["UIDropDownMenu_EnableButton"] = WoWColor,
	["UIDropDownMenu_EnableDropDown"] = WoWColor,
	["UIDropDownMenu_GetCurrentDropDown"] = WoWColor,
	["UIDropDownMenu_GetSelectedID"] = WoWColor,
	["UIDropDownMenu_GetSelectedName"] = WoWColor,
	["UIDropDownMenu_GetSelectedValue"] = WoWColor,
	["UIDropDownMenu_GetText"] = WoWColor,
	["UIDropDownMenu_GetValue"] = WoWColor,
	["UIDropDownMenu_Initialize"] = WoWColor,
	["UIDropDownMenu_InitializeHelper"] = WoWColor,
	["UIDropDownMenu_IsEnabled"] = WoWColor,
	["UIDropDownMenu_JustifyText"] = WoWColor,
	["UIDropDownMenu_OnHide"] = WoWColor,
	["UIDropDownMenu_OnUpdate"] = WoWColor,
	["UIDropDownMenu_Refresh"] = WoWColor,
	["UIDropDownMenu_SetAnchor"] = WoWColor,
	["UIDropDownMenu_SetButtonText"] = WoWColor,
	["UIDropDownMenu_SetButtonWidth"] = WoWColor,
	["UIDropDownMenu_SetSelectedID"] = WoWColor,
	["UIDropDownMenu_SetSelectedName"] = WoWColor,
	["UIDropDownMenu_SetSelectedValue"] = WoWColor,
	["UIDropDownMenu_SetText"] = WoWColor,
	["UIDropDownMenu_SetWidth"] = WoWColor,
	["UIDropDownMenu_StartCounting"] = WoWColor,
	["UIDropDownMenu_StopCounting"] = WoWColor,
	["UIErrorsFrame_OnEvent"] = WoWColor,
	["UIErrorsFrame_OnLoad"] = WoWColor,
	["UIFrameFade"] = WoWColor,
	["UIFrameFadeIn"] = WoWColor,
	["UIFrameFadeOut"] = WoWColor,
	["UIFrameFadeRemoveFrame"] = WoWColor,
	["UIFrameFade_OnUpdate"] = WoWColor,
	["UIFrameFlash"] = WoWColor,
	["UIFrameFlashRemoveFrame"] = WoWColor,
	["UIFrameFlashStop"] = WoWColor,
	["UIFrameFlash_OnUpdate"] = WoWColor,
	["UIFrameIsFading"] = WoWColor,
	["UIFrameIsFlashing"] = WoWColor,
	["UIMenuButton_OnClick"] = WoWColor,
	["UIMenuButton_OnEnter"] = WoWColor,
	["UIMenuButton_OnLeave"] = WoWColor,
	["UIMenuButton_OnLoad"] = WoWColor,
	["UIMenu_AddButton"] = WoWColor,
	["UIMenu_AutoSize"] = WoWColor,
	["UIMenu_FinishInitializing"] = WoWColor,
	["UIMenu_GetNumButtons"] = WoWColor,
	["UIMenu_Initialize"] = WoWColor,
	["UIMenu_OnShow"] = WoWColor,
	["UIMenu_OnUpdate"] = WoWColor,
	["UIMenu_StartCounting"] = WoWColor,
	["UIMenu_StopCounting"] = WoWColor,
	["UIParentLoadAddOn"] = WoWColor,
	["UIParent_ManageFramePosition"] = WoWColor,
	["UIParent_ManageFramePositions"] = WoWColor,
	["UIParent_OnEvent"] = WoWColor,
	["UIParent_OnLoad"] = WoWColor,
	["UnSilenceMember"] = WoWColor,
	["UninviteUnit"] = WoWColor,
	["UnitAffectingCombat"] = WoWColor,
	["UnitArmor"] = WoWColor,
	["UnitAttackBothHands"] = WoWColor,
	["UnitAttackPower"] = WoWColor,
	["UnitAttackSpeed"] = WoWColor,
	["UnitAura"] = WoWColor,
	["UnitBuff"] = WoWColor,
	["UnitCanAssist"] = WoWColor,
	["UnitCanAttack"] = WoWColor,
	["UnitCanCooperate"] = WoWColor,
	["UnitCastingInfo"] = WoWColor,
	["UnitChannelInfo"] = WoWColor,
	["UnitCharacterPoints"] = WoWColor,
	["UnitClass"] = WoWColor,
	["UnitClassBase"] = WoWColor,
	["UnitClassification"] = WoWColor,
	["UnitControllingVehicle"] = WoWColor,
	["UnitCreatureFamily"] = WoWColor,
	["UnitCreatureType"] = WoWColor,
	["UnitDamage"] = WoWColor,
	["UnitDebuff"] = WoWColor,
	["UnitDefense"] = WoWColor,
	["UnitDetailedThreatSituation"] = WoWColor,
	["UnitExists"] = WoWColor,
	["UnitFactionGroup"] = WoWColor,
	["UnitFrameHealthBar_Initialize"] = WoWColor,
	["UnitFrameHealthBar_OnEvent"] = WoWColor,
	["UnitFrameHealthBar_OnUpdate"] = WoWColor,
	["UnitFrameHealthBar_OnValueChanged"] = WoWColor,
	["UnitFrameHealthBar_Update"] = WoWColor,
	["UnitFrameManaBar_Initialize"] = WoWColor,
	["UnitFrameManaBar_OnEvent"] = WoWColor,
	["UnitFrameManaBar_OnUpdate"] = WoWColor,
	["UnitFrameManaBar_RegisterDefaultEvents"] = WoWColor,
	["UnitFrameManaBar_UnregisterDefaultEvents"] = WoWColor,
	["UnitFrameManaBar_Update"] = WoWColor,
	["UnitFrameManaBar_UpdateType"] = WoWColor,
	["UnitFramePortrait_Update"] = WoWColor,
	["UnitFrameThreatIndicator_Initialize"] = WoWColor,
	["UnitFrameThreatIndicator_OnEvent"] = WoWColor,
	["UnitFrame_Initialize"] = WoWColor,
	["UnitFrame_OnEnter"] = WoWColor,
	["UnitFrame_OnEvent"] = WoWColor,
	["UnitFrame_OnLeave"] = WoWColor,
	["UnitFrame_SetUnit"] = WoWColor,
	["UnitFrame_Update"] = WoWColor,
	["UnitFrame_UpdateThreatIndicator"] = WoWColor,
	["UnitFrame_UpdateTooltip"] = WoWColor,
	["UnitGUID"] = WoWColor,
	["UnitGroupRolesAssigned"] = WoWColor,
	["UnitHasLFGDeserter"] = WoWColor,
	["UnitHasLFGRandomCooldown"] = WoWColor,
	["UnitHasMana"] = WoWColor,
	["UnitHasRelicSlot"] = WoWColor,
	["UnitHasVehicleUI"] = WoWColor,
	["UnitHealth"] = WoWColor,
	["UnitHealthMax"] = WoWColor,
	["UnitInBattleground"] = WoWColor,
	["UnitInParty"] = WoWColor,
	["UnitInRaid"] = WoWColor,
	["UnitInRange"] = WoWColor,
	["UnitInVehicle"] = WoWColor,
	["UnitInVehicleControlSeat"] = WoWColor,
	["UnitIsAFK"] = WoWColor,
	["UnitIsCharmed"] = WoWColor,
	["UnitIsConnected"] = WoWColor,
	["UnitIsControlling"] = WoWColor,
	["UnitIsCorpse"] = WoWColor,
	["UnitIsDND"] = WoWColor,
	["UnitIsDead"] = WoWColor,
	["UnitIsDeadOrGhost"] = WoWColor,
	["UnitIsEnemy"] = WoWColor,
	["UnitIsFeignDeath"] = WoWColor,
	["UnitIsFriend"] = WoWColor,
	["UnitIsGhost"] = WoWColor,
	["UnitIsInMyGuild"] = WoWColor,
	["UnitIsPVP"] = WoWColor,
	["UnitIsPVPFreeForAll"] = WoWColor,
	["UnitIsPVPSanctuary"] = WoWColor,
	["UnitIsPartyLeader"] = WoWColor,
	["UnitIsPlayer"] = WoWColor,
	["UnitIsPossessed"] = WoWColor,
	["UnitIsRaidOfficer"] = WoWColor,
	["UnitIsSameServer"] = WoWColor,
	["UnitIsSilenced"] = WoWColor,
	["UnitIsTalking"] = WoWColor,
	["UnitIsTapped"] = WoWColor,
	["UnitIsTappedByAllThreatList"] = WoWColor,
	["UnitIsTappedByPlayer"] = WoWColor,
	["UnitIsTrivial"] = WoWColor,
	["UnitIsUnit"] = WoWColor,
	["UnitIsVisible"] = WoWColor,
	["UnitLevel"] = WoWColor,
	["UnitMana"] = WoWColor,
	["UnitManaMax"] = WoWColor,
	["UnitName"] = WoWColor,
	["UnitOnTaxi"] = WoWColor,
	["UnitPVPName"] = WoWColor,
	["UnitPVPRank"] = WoWColor,
	["UnitPlayerControlled"] = WoWColor,
	["UnitPlayerOrPetInParty"] = WoWColor,
	["UnitPlayerOrPetInRaid"] = WoWColor,
	["UnitPopup_HideButtons"] = WoWColor,
	["UnitPopup_OnClick"] = WoWColor,
	["UnitPopup_OnUpdate"] = WoWColor,
	["UnitPopup_ShowMenu"] = WoWColor,
	["UnitPower"] = WoWColor,
	["UnitPowerMax"] = WoWColor,
	["UnitPowerType"] = WoWColor,
	["UnitRace"] = WoWColor,
	["UnitRangedAttack"] = WoWColor,
	["UnitRangedAttackPower"] = WoWColor,
	["UnitRangedDamage"] = WoWColor,
	["UnitReaction"] = WoWColor,
	["UnitResistance"] = WoWColor,
	["UnitSelectionColor"] = WoWColor,
	["UnitSex"] = WoWColor,
	["UnitStat"] = WoWColor,
	["UnitSwitchToVehicleSeat"] = WoWColor,
	["UnitTargetsVehicleInRaidUI"] = WoWColor,
	["UnitThreatSituation"] = WoWColor,
	["UnitUsingVehicle"] = WoWColor,
	["UnitVehicleSeatCount"] = WoWColor,
	["UnitVehicleSeatInfo"] = WoWColor,
	["UnitVehicleSkin"] = WoWColor,
	["UnitWatchRegistered"] = WoWColor,
	["UnitXP"] = WoWColor,
	["UnitXPMax"] = WoWColor,
	["UnlockMultiCastActionBar"] = WoWColor,
	["UnlockPetActionBar"] = WoWColor,
	["UnregisterAutoHide"] = WoWColor,
	["UnregisterStateDriver"] = WoWColor,
	["UnregisterUnitWatch"] = WoWColor,
	["UnstablePet"] = WoWColor,
	["UpdateAddOnCPUUsage"] = WoWColor,
	["UpdateAddOnMemoryUsage"] = WoWColor,
	["UpdateBagButtonHighlight"] = WoWColor,
	["UpdateBagSlotStatus"] = WoWColor,
	["UpdateCoinPickupFrame"] = WoWColor,
	["UpdateGMTicket"] = WoWColor,
	["UpdateInventoryAlertStatus"] = WoWColor,
	["UpdateMapHighlight"] = WoWColor,
	["UpdateMenuBarTop"] = WoWColor,
	["UpdateMicroButtons"] = WoWColor,
	["UpdatePaperdollStats"] = WoWColor,
	["UpdatePartyMemberBackground"] = WoWColor,
	["UpdateSpells"] = WoWColor,
	["UpdateStackSplitFrame"] = WoWColor,
	["UpdateSubCategoryEnabledState"] = WoWColor,
	["UpdateUIPanelPositions"] = WoWColor,
	["UpdateWorldMapArrowFrames"] = WoWColor,
	["UploadSettings"] = WoWColor,
	["UseAction"] = WoWColor,
	["UseContainerItem"] = WoWColor,
	["UseEquipmentSet"] = WoWColor,
	["UseInventoryItem"] = WoWColor,
	["UseItemByName"] = WoWColor,
	["UseQuestLogSpecialItem"] = WoWColor,
	["UseSoulstone"] = WoWColor,
	["UsesGUID"] = WoWColor,
	["ValidateFramePosition"] = WoWColor,
	["VehicleActionButton_OnClick"] = WoWColor,
	["VehicleAimDecrement"] = WoWColor,
	["VehicleAimDownStart"] = WoWColor,
	["VehicleAimDownStop"] = WoWColor,
	["VehicleAimGetAngle"] = WoWColor,
	["VehicleAimGetNormAngle"] = WoWColor,
	["VehicleAimGetNormPower"] = WoWColor,
	["VehicleAimIncrement"] = WoWColor,
	["VehicleAimRequestAngle"] = WoWColor,
	["VehicleAimRequestNormAngle"] = WoWColor,
	["VehicleAimSetNormPower"] = WoWColor,
	["VehicleAimUpStart"] = WoWColor,
	["VehicleAimUpStop"] = WoWColor,
	["VehicleCameraZoomIn"] = WoWColor,
	["VehicleCameraZoomOut"] = WoWColor,
	["VehicleExit"] = WoWColor,
	["VehicleMenuBarPitch_OnClick"] = WoWColor,
	["VehicleMenuBarPitch_OnEvent"] = WoWColor,
	["VehicleMenuBarPitch_OnLoad"] = WoWColor,
	["VehicleMenuBarPitch_SetValue"] = WoWColor,
	["VehicleMenuBarStatusBars_ShowTooltip"] = WoWColor,
	["VehicleMenuBar_MoveMicroButtons"] = WoWColor,
	["VehicleMenuBar_OnEvent"] = WoWColor,
	["VehicleMenuBar_OnLoad"] = WoWColor,
	["VehicleMenuBar_ReleaseSkins"] = WoWColor,
	["VehicleMenuBar_SetSkin"] = WoWColor,
	["VehicleMenuBar_UpdateActionBars"] = WoWColor,
	["VehicleNextSeat"] = WoWColor,
	["VehiclePrevSeat"] = WoWColor,
	["VehicleSeatIndicatorButton_OnClick"] = WoWColor,
	["VehicleSeatIndicatorButton_OnEnter"] = WoWColor,
	["VehicleSeatIndicatorButton_OnLeave"] = WoWColor,
	["VehicleSeatIndicatorDropDown_Initialize"] = WoWColor,
	["VehicleSeatIndicatorDropDown_OnClick"] = WoWColor,
	["VehicleSeatIndicator_OnEvent"] = WoWColor,
	["VehicleSeatIndicator_OnLoad"] = WoWColor,
	["VehicleSeatIndicator_SetUpVehicle"] = WoWColor,
	["VehicleSeatIndicator_UnloadTextures"] = WoWColor,
	["VehicleSeatIndicator_Update"] = WoWColor,
	["VideoOptionsEffectsPanelSlider_OnValueChanged"] = WoWColor,
	["VideoOptionsEffectsPanel_Default"] = WoWColor,
	["VideoOptionsEffectsPanel_FixupQualityLevels"] = WoWColor,
	["VideoOptionsEffectsPanel_GetVideoQuality"] = WoWColor,
	["VideoOptionsEffectsPanel_OnEvent"] = WoWColor,
	["VideoOptionsEffectsPanel_OnLoad"] = WoWColor,
	["VideoOptionsEffectsPanel_Refresh"] = WoWColor,
	["VideoOptionsEffectsPanel_SetCustomQuality"] = WoWColor,
	["VideoOptionsEffectsPanel_SetPresetQuality"] = WoWColor,
	["VideoOptionsEffectsPanel_SetVideoQuality"] = WoWColor,
	["VideoOptionsEffectsPanel_SetVideoQualityLabels"] = WoWColor,
	["VideoOptionsEffectsPanel_UpdateVideoQuality"] = WoWColor,
	["VideoOptionsFrameCancel_OnClick"] = WoWColor,
	["VideoOptionsFrameDefault_OnClick"] = WoWColor,
	["VideoOptionsFrameOkay_OnClick"] = WoWColor,
	["VideoOptionsFrame_OnHide"] = WoWColor,
	["VideoOptionsFrame_OnLoad"] = WoWColor,
	["VideoOptionsFrame_SetAllToDefaults"] = WoWColor,
	["VideoOptionsFrame_SetCurrentToDefaults"] = WoWColor,
	["VideoOptionsFrame_Toggle"] = WoWColor,
	["VideoOptionsPanel_Cancel"] = WoWColor,
	["VideoOptionsPanel_Default"] = WoWColor,
	["VideoOptionsPanel_Okay"] = WoWColor,
	["VideoOptionsPanel_OnLoad"] = WoWColor,
	["VideoOptionsResolutionPanelMultiSampleDropDown_Initialize"] = WoWColor,
	["VideoOptionsResolutionPanelMultiSampleDropDown_OnClick"] = WoWColor,
	["VideoOptionsResolutionPanelMultiSampleDropDown_OnLoad"] = WoWColor,
	["VideoOptionsResolutionPanelRefreshDropDown_Initialize"] = WoWColor,
	["VideoOptionsResolutionPanelRefreshDropDown_OnClick"] = WoWColor,
	["VideoOptionsResolutionPanelRefreshDropDown_OnLoad"] = WoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_Initialize"] = WoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_LoadResolutions"] = WoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_OnClick"] = WoWColor,
	["VideoOptionsResolutionPanelResolutionDropDown_OnLoad"] = WoWColor,
	["VideoOptionsResolutionPanel_Default"] = WoWColor,
	["VideoOptionsResolutionPanel_GetMultisampleFormats"] = WoWColor,
	["VideoOptionsResolutionPanel_GetRefreshRates"] = WoWColor,
	["VideoOptionsResolutionPanel_OnEvent"] = WoWColor,
	["VideoOptionsResolutionPanel_OnLoad"] = WoWColor,
	["VideoOptionsResolutionPanel_Refresh"] = WoWColor,
	["VideoOptionsResolutionPanel_RefreshGammaControls"] = WoWColor,
	["VideoOptionsResolutionPanel_SetGamma"] = WoWColor,
	["VideoOptionsResolutionPanel_SetWindowed"] = WoWColor,
	["VideoOptionsStereoPanel_Default"] = WoWColor,
	["VideoOptionsStereoPanel_OnEvent"] = WoWColor,
	["VideoOptionsStereoPanel_OnLoad"] = WoWColor,
	["VoiceChatShineFadeIn"] = WoWColor,
	["VoiceChatShineFadeOut"] = WoWColor,
	["VoiceChatTalkers_CanHide"] = WoWColor,
	["VoiceChatTalkers_CreateButtons"] = WoWColor,
	["VoiceChatTalkers_FadeOut"] = WoWColor,
	["VoiceChatTalkers_OnEvent"] = WoWColor,
	["VoiceChatTalkers_OnLoad"] = WoWColor,
	["VoiceChatTalkers_OnUpdate"] = WoWColor,
	["VoiceChatTalkers_ResizeFrame"] = WoWColor,
	["VoiceChatTalkers_Update"] = WoWColor,
	["VoiceChat_ActivatePrimaryCaptureCallback"] = WoWColor,
	["VoiceChat_Animate"] = WoWColor,
	["VoiceChat_GetCurrentMicrophoneSignalLevel"] = WoWColor,
	["VoiceChat_IsPlayingLoopbackSound"] = WoWColor,
	["VoiceChat_IsRecordingLoopbackSound"] = WoWColor,
	["VoiceChat_OnUpdate"] = WoWColor,
	["VoiceChat_PlayLoopbackSound"] = WoWColor,
	["VoiceChat_RecordLoopbackSound"] = WoWColor,
	["VoiceChat_StartCapture"] = WoWColor,
	["VoiceChat_StopCapture"] = WoWColor,
	["VoiceChat_StopPlayingLoopbackSound"] = WoWColor,
	["VoiceChat_StopRecordingLoopbackSound"] = WoWColor,
	["VoiceChat_Toggle"] = WoWColor,
	["VoiceEnumerateCaptureDevices"] = WoWColor,
	["VoiceEnumerateOutputDevices"] = WoWColor,
	["VoiceGetCurrentCaptureDevice"] = WoWColor,
	["VoiceGetCurrentOutputDevice"] = WoWColor,
	["VoiceIsDisabledByClient"] = WoWColor,
	["VoiceMacroMenu_Click"] = WoWColor,
	["VoiceMacroMenu_OnLoad"] = WoWColor,
	["VoicePushToTalkStart"] = WoWColor,
	["VoicePushToTalkStop"] = WoWColor,
	["VoiceSelectCaptureDevice"] = WoWColor,
	["VoiceSelectOutputDevice"] = WoWColor,
	["WatchFrameDropDown_Initialize"] = WoWColor,
	["WatchFrameDropDown_OnHide"] = WoWColor,
	["WatchFrameDropDown_OnLoad"] = WoWColor,
	["WatchFrameHeaderDropDown_Initialize"] = WoWColor,
	["WatchFrameHeaderDropDown_OnLoad"] = WoWColor,
	["WatchFrameHeader_OnClick"] = WoWColor,
	["WatchFrameItem_OnClick"] = WoWColor,
	["WatchFrameItem_OnEnter"] = WoWColor,
	["WatchFrameItem_OnEvent"] = WoWColor,
	["WatchFrameItem_OnHide"] = WoWColor,
	["WatchFrameItem_OnLoad"] = WoWColor,
	["WatchFrameItem_OnShow"] = WoWColor,
	["WatchFrameItem_OnUpdate"] = WoWColor,
	["WatchFrameItem_UpdateCooldown"] = WoWColor,
	["WatchFrameLineTemplate_OnLoad"] = WoWColor,
	["WatchFrameLines_AddUpdateFunction"] = WoWColor,
	["WatchFrameLines_OnUpdate"] = WoWColor,
	["WatchFrameLines_RemoveUpdateFunction"] = WoWColor,
	["WatchFrameLinkButtonTemplate_Highlight"] = WoWColor,
	["WatchFrameLinkButtonTemplate_OnClick"] = WoWColor,
	["WatchFrameLinkButtonTemplate_OnLeftClick"] = WoWColor,
	["WatchFrameQuestPOI_OnClick"] = WoWColor,
	["WatchFrame_AbandonQuest"] = WoWColor,
	["WatchFrame_AddObjectiveHandler"] = WoWColor,
	["WatchFrame_ClearDisplay"] = WoWColor,
	["WatchFrame_Collapse"] = WoWColor,
	["WatchFrame_CollapseExpandButton_OnClick"] = WoWColor,
	["WatchFrame_DisplayQuestTimers"] = WoWColor,
	["WatchFrame_DisplayTrackedAchievements"] = WoWColor,
	["WatchFrame_DisplayTrackedQuests"] = WoWColor,
	["WatchFrame_Expand"] = WoWColor,
	["WatchFrame_GetCurrentMapQuests"] = WoWColor,
	["WatchFrame_GetVisibleIndex"] = WoWColor,
	["WatchFrame_HandleDisplayQuestTimers"] = WoWColor,
	["WatchFrame_HandleDisplayTrackedAchievements"] = WoWColor,
	["WatchFrame_HandleQuestTimerUpdate"] = WoWColor,
	["WatchFrame_MoveQuest"] = WoWColor,
	["WatchFrame_OnEvent"] = WoWColor,
	["WatchFrame_OnLoad"] = WoWColor,
	["WatchFrame_OnSizeChanged"] = WoWColor,
	["WatchFrame_OnUpdate"] = WoWColor,
	["WatchFrame_OpenAchievementFrame"] = WoWColor,
	["WatchFrame_OpenMapToQuest"] = WoWColor,
	["WatchFrame_OpenQuestLog"] = WoWColor,
	["WatchFrame_QuestTimerUpdateFunction"] = WoWColor,
	["WatchFrame_RemoveObjectiveHandler"] = WoWColor,
	["WatchFrame_ReverseQuestObjective"] = WoWColor,
	["WatchFrame_SetFilter"] = WoWColor,
	["WatchFrame_SetLine"] = WoWColor,
	["WatchFrame_SetSorting"] = WoWColor,
	["WatchFrame_SetWidth"] = WoWColor,
	["WatchFrame_ShareQuest"] = WoWColor,
	["WatchFrame_StopTrackingAchievement"] = WoWColor,
	["WatchFrame_StopTrackingQuest"] = WoWColor,
	["WatchFrame_Update"] = WoWColor,
	["WatchFrame_UpdateTimedAchievements"] = WoWColor,
	["WhoFrameColumn_SetWidth"] = WoWColor,
	["WhoFrameDropDownButton_OnClick"] = WoWColor,
	["WhoFrameDropDown_Initialize"] = WoWColor,
	["WhoFrameDropDown_OnLoad"] = WoWColor,
	["WhoFrameEditBox_OnEnterPressed"] = WoWColor,
	["WhoFrame_GetDefaultWhoCommand"] = WoWColor,
	["WhoList_Update"] = WoWColor,
	["WintergraspTimer_OnLoad"] = WoWColor,
	["WintergraspTimer_OnUpdate"] = WoWColor,
	["WithdrawGoldEditBox_Update"] = WoWColor,
	["WithdrawGuildBankMoney"] = WoWColor,
	["WorldFrame_OnLoad"] = WoWColor,
	["WorldFrame_OnUpdate"] = WoWColor,
	["WorldMapBlobFrame_CalculateHitTranslations"] = WoWColor,
	["WorldMapBlobFrame_OnLoad"] = WoWColor,
	["WorldMapBlobFrame_OnUpdate"] = WoWColor,
	["WorldMapButton_OnClick"] = WoWColor,
	["WorldMapButton_OnUpdate"] = WoWColor,
	["WorldMapContinentButton_OnClick"] = WoWColor,
	["WorldMapContinentsDropDown_Initialize"] = WoWColor,
	["WorldMapContinentsDropDown_Update"] = WoWColor,
	["WorldMapFrame_ChangeOpacity"] = WoWColor,
	["WorldMapFrame_ClearQuestPOIs"] = WoWColor,
	["WorldMapFrame_DisplayQuestPOI"] = WoWColor,
	["WorldMapFrame_DisplayQuests"] = WoWColor,
	["WorldMapFrame_GetQuestFrame"] = WoWColor,
	["WorldMapFrame_LoadContinents"] = WoWColor,
	["WorldMapFrame_LoadZones"] = WoWColor,
	["WorldMapFrame_OnEvent"] = WoWColor,
	["WorldMapFrame_OnHide"] = WoWColor,
	["WorldMapFrame_OnKeyDown"] = WoWColor,
	["WorldMapFrame_OnLoad"] = WoWColor,
	["WorldMapFrame_OnShow"] = WoWColor,
	["WorldMapFrame_OnUpdate"] = WoWColor,
	["WorldMapFrame_PingPlayerPosition"] = WoWColor,
	["WorldMapFrame_ResetFrameLevels"] = WoWColor,
	["WorldMapFrame_ResetQuestColors"] = WoWColor,
	["WorldMapFrame_ReverseQuestObjective"] = WoWColor,
	["WorldMapFrame_SaveOpacity"] = WoWColor,
	["WorldMapFrame_SelectQuestById"] = WoWColor,
	["WorldMapFrame_SelectQuestFrame"] = WoWColor,
	["WorldMapFrame_SetFullMapView"] = WoWColor,
	["WorldMapFrame_SetMapName"] = WoWColor,
	["WorldMapFrame_SetMiniMode"] = WoWColor,
	["WorldMapFrame_SetOpacity"] = WoWColor,
	["WorldMapFrame_SetPOIMaxBounds"] = WoWColor,
	["WorldMapFrame_SetQuestMapView"] = WoWColor,
	["WorldMapFrame_ToggleAdvanced"] = WoWColor,
	["WorldMapFrame_ToggleWindowSize"] = WoWColor,
	["WorldMapFrame_Update"] = WoWColor,
	["WorldMapFrame_UpdateMap"] = WoWColor,
	["WorldMapFrame_UpdateQuests"] = WoWColor,
	["WorldMapFrame_UpdateUnits"] = WoWColor,
	["WorldMapLevelButton_OnClick"] = WoWColor,
	["WorldMapLevelDown_OnClick"] = WoWColor,
	["WorldMapLevelDropDown_Initialize"] = WoWColor,
	["WorldMapLevelDropDown_Update"] = WoWColor,
	["WorldMapLevelUp_OnClick"] = WoWColor,
	["WorldMapPOI_OnClick"] = WoWColor,
	["WorldMapPOI_OnEnter"] = WoWColor,
	["WorldMapPOI_OnLeave"] = WoWColor,
	["WorldMapQuestFrame_OnEnter"] = WoWColor,
	["WorldMapQuestFrame_OnLeave"] = WoWColor,
	["WorldMapQuestFrame_OnMouseDown"] = WoWColor,
	["WorldMapQuestFrame_OnMouseUp"] = WoWColor,
	["WorldMapQuestFrame_UpdateMouseOver"] = WoWColor,
	["WorldMapQuestPOI_OnClick"] = WoWColor,
	["WorldMapQuestPOI_OnEnter"] = WoWColor,
	["WorldMapQuestPOI_OnLeave"] = WoWColor,
	["WorldMapQuestPOI_SetTooltip"] = WoWColor,
	["WorldMapQuestShowObjectives_AdjustPosition"] = WoWColor,
	["WorldMapQuestShowObjectives_Toggle"] = WoWColor,
	["WorldMapTitleButton_OnClick"] = WoWColor,
	["WorldMapTitleButton_OnDragStart"] = WoWColor,
	["WorldMapTitleButton_OnDragStop"] = WoWColor,
	["WorldMapTitleButton_OnLoad"] = WoWColor,
	["WorldMapTitleDropDown_Initialize"] = WoWColor,
	["WorldMapTitleDropDown_ToggleLock"] = WoWColor,
	["WorldMapTitleDropDown_ToggleOpacity"] = WoWColor,
	["WorldMapTrackQuest_Toggle"] = WoWColor,
	["WorldMapUnitDropDown_Initialize"] = WoWColor,
	["WorldMapUnitDropDown_OnClick"] = WoWColor,
	["WorldMapUnitDropDown_ReportAll_OnClick"] = WoWColor,
	["WorldMapUnit_OnEnter"] = WoWColor,
	["WorldMapUnit_OnEvent"] = WoWColor,
	["WorldMapUnit_OnHide"] = WoWColor,
	["WorldMapUnit_OnLeave"] = WoWColor,
	["WorldMapUnit_OnLoad"] = WoWColor,
	["WorldMapUnit_OnMouseUp"] = WoWColor,
	["WorldMapUnit_OnShow"] = WoWColor,
	["WorldMapUnit_Update"] = WoWColor,
	["WorldMapZoneButton_OnClick"] = WoWColor,
	["WorldMapZoneDropDown_Initialize"] = WoWColor,
	["WorldMapZoneDropDown_Update"] = WoWColor,
	["WorldMapZoneMinimapDropDown_GetText"] = WoWColor,
	["WorldMapZoneMinimapDropDown_Initialize"] = WoWColor,
	["WorldMapZoneMinimapDropDown_OnClick"] = WoWColor,
	["WorldMapZoneMinimapDropDown_Update"] = WoWColor,
	["WorldMapZoomOutButton_OnClick"] = WoWColor,
	["WorldMap_ClearTextures"] = WoWColor,
	["WorldMap_CreatePOI"] = WoWColor,
	["WorldMap_GetPOITextureCoords"] = WoWColor,
	["WorldMap_GetVehicleTexture"] = WoWColor,
	["WorldMap_LoadTextures"] = WoWColor,
	["WorldMap_OpenToQuest"] = WoWColor,
	["WorldMap_ToggleSizeDown"] = WoWColor,
	["WorldMap_ToggleSizeUp"] = WoWColor,
	["WorldStateAlwaysUpFrame_FilterChatMsgLoot"] = WoWColor,
	["WorldStateAlwaysUpFrame_FilterChatMsgSystem"] = WoWColor,
	["WorldStateAlwaysUpFrame_OnEvent"] = WoWColor,
	["WorldStateAlwaysUpFrame_OnLoad"] = WoWColor,
	["WorldStateAlwaysUpFrame_OnUpdate"] = WoWColor,
	["WorldStateAlwaysUpFrame_StartBGChatFilter"] = WoWColor,
	["WorldStateAlwaysUpFrame_StopBGChatFilter"] = WoWColor,
	["WorldStateAlwaysUpFrame_Update"] = WoWColor,
	["WorldStateFrame_CanShowBattlefieldMinimap"] = WoWColor,
	["WorldStateFrame_ToggleBattlefieldMinimap"] = WoWColor,
	["WorldStateScoreFrameTab_OnClick"] = WoWColor,
	["WorldStateScoreFrame_OnLoad"] = WoWColor,
	["WorldStateScoreFrame_Resize"] = WoWColor,
	["WorldStateScoreFrame_Update"] = WoWColor,
	["ZoneText_OnEvent"] = WoWColor,
	["ZoneText_OnLoad"] = WoWColor,
	["ZoomOut"] = WoWColor,
	["_GetPlayerDifficultyMenuOptions"] = WoWColor,
	["debugbreak"] = WoWColor,
	["debugdump"] = WoWColor,
	["debughook"] = WoWColor,
	["debuginfo"] = WoWColor,
	["debugload"] = WoWColor,
	["debuglocals"] = WoWColor,
	["debugprint"] = WoWColor,
	["debugprofilestart"] = WoWColor,
	["debugprofilestop"] = WoWColor,
	["debugstack"] = WoWColor,
	["debugtimestamp"] = WoWColor,
	["forceinsecure"] = WoWColor,
	["geterrorhandler"] = WoWColor,
	["getglobal"] = WoWColor,
	["getprinthandler"] = WoWColor,
	["hooksecurefunc"] = WoWColor,
	["issecure"] = WoWColor,
	["issecurevariable"] = WoWColor,
	["message"] = WoWColor,
	["newproxy"] = WoWColor,
	["scrub"] = WoWColor,
	["securecall"] = WoWColor,
	["seterrorhandler"] = WoWColor,
	["setglobal"] = WoWColor,
	["setprinthandler"] = WoWColor,
	["strjoin"] = WoWColor,
	["strlenutf8"] = WoWColor,
	["strreplace"] = WoWColor,
	["strrev"] = WoWColor,
	["strsplit"] = WoWColor,
	["strtrim"] = WoWColor,
	["tContains"] = WoWColor,
	["tDeleteItem"] = WoWColor,
	["updateContainerFrameAnchors"] = WoWColor,
	["wipe"] = WoWColor,
	
	["AddDoubleLine"] = methodColor,
	["AddFontStrings"] = methodColor,
	["AddHistoryLine"] = methodColor,
	["AddLine"] = methodColor,
	["AddMessage"] = methodColor,
	["AddTexture"] = methodColor,
	["AdvanceTime"] = methodColor,
	["AllowAttributeChanges"] = methodColor,
	["AppendText"] = methodColor,
	["AtBottom"] = methodColor,
	["AtTop"] = methodColor,
	["CanChangeAttribute"] = methodColor,
	["CanChangeProtectedState"] = methodColor,
	["CanNonSpaceWrap"] = methodColor,
	["CanSaveTabardNow"] = methodColor,
	["CanWordWrap"] = methodColor,
	["Clear"] = methodColor,
	["ClearAllPoints"] = methodColor,
	["ClearFocus"] = methodColor,
	["ClearFog"] = methodColor,
	["ClearHistory"] = methodColor,
	["ClearLines"] = methodColor,
	["ClearModel"] = methodColor,
	["Click"] = methodColor,
	["CopyFontObject"] = methodColor,
	["CreateAnimation"] = methodColor,
	["CreateAnimationGroup"] = methodColor,
	["CreateControlPoint"] = methodColor,
	["CreateFontString"] = methodColor,
	["CreateTexture"] = methodColor,
	["CreateTitleRegion"] = methodColor,
	["CycleVariation"] = methodColor,
	["Disable"] = methodColor,
	["DisableDrawLayer"] = methodColor,
	["DrawQuestBlob"] = methodColor,
	["Dress"] = methodColor,
	["Enable"] = methodColor,
	["EnableDrawLayer"] = methodColor,
	["EnableJoystick"] = methodColor,
	["EnableKeyboard"] = methodColor,
	["EnableMerging"] = methodColor,
	["EnableMouse"] = methodColor,
	["EnableMouseWheel"] = methodColor,
	["EnableSmoothing"] = methodColor,
	["EnableSubtitles"] = methodColor,
	["FadeOut"] = methodColor,
	["Finish"] = methodColor,
	["GetAlpha"] = methodColor,
	["GetAltArrowKeyMode"] = methodColor,
	["GetAnchorType"] = methodColor,
	["GetAnimationGroups"] = methodColor,
	["GetAnimations"] = methodColor,
	["GetAttribute"] = methodColor,
	["GetBackdrop"] = methodColor,
	["GetBackdropBorderColor"] = methodColor,
	["GetBackdropColor"] = methodColor,
	["GetBlendMode"] = methodColor,
	["GetBlinkSpeed"] = methodColor,
	["GetBottom"] = methodColor,
	["GetBoundsRect"] = methodColor,
	["GetButtonState"] = methodColor,
	["GetCenter"] = methodColor,
	["GetChange"] = methodColor,
	["GetChecked"] = methodColor,
	["GetCheckedTexture"] = methodColor,
	["GetChildren"] = methodColor,
	["GetClampRectInsets"] = methodColor,
	["GetColorHSV"] = methodColor,
	["GetColorRGB"] = methodColor,
	["GetColorValueTexture"] = methodColor,
	["GetColorValueThumbTexture"] = methodColor,
	["GetColorWheelTexture"] = methodColor,
	["GetColorWheelThumbTexture"] = methodColor,
	["GetControlPoints"] = methodColor,
	["GetCurrentLine"] = methodColor,
	["GetCurrentScroll"] = methodColor,
	["GetCursorPosition"] = methodColor,
	["GetCurve"] = methodColor,
	["GetDegrees"] = methodColor,
	["GetDepth"] = methodColor,
	["GetDisabledCheckedTexture"] = methodColor,
	["GetDisabledFontObject"] = methodColor,
	["GetDisabledTexture"] = methodColor,
	["GetDontSavePosition"] = methodColor,
	["GetDrawEdge"] = methodColor,
	["GetDrawLayer"] = methodColor,
	["GetDuration"] = methodColor,
	["GetEffectiveAlpha"] = methodColor,
	["GetEffectiveDepth"] = methodColor,
	["GetEffectiveScale"] = methodColor,
	["GetElapsed"] = methodColor,
	["GetEndDelay"] = methodColor,
	["GetFacing"] = methodColor,
	["GetFadeDuration"] = methodColor,
	["GetFading"] = methodColor,
	["GetFieldSize"] = methodColor,
	["GetFogColor"] = methodColor,
	["GetFogFar"] = methodColor,
	["GetFogNear"] = methodColor,
	["GetFont"] = methodColor,
	["GetFontObject"] = methodColor,
	["GetFontString"] = methodColor,
	["GetFrameLevel"] = methodColor,
	["GetFrameStrata"] = methodColor,
	["GetHeight"] = methodColor,
	["GetHighlightFontObject"] = methodColor,
	["GetHighlightTexture"] = methodColor,
	["GetHistoryLines"] = methodColor,
	["GetHitRectInsets"] = methodColor,
	["GetHorizTile"] = methodColor,
	["GetHorizontalScroll"] = methodColor,
	["GetHorizontalScrollRange"] = methodColor,
	["GetHyperlinkFormat"] = methodColor,
	["GetHyperlinksEnabled"] = methodColor,
	["GetID"] = methodColor,
	["GetIndentedWordWrap"] = methodColor,
	["GetInitialOffset"] = methodColor,
	["GetInputLanguage"] = methodColor,
	["GetInsertMode"] = methodColor,
	["GetItem"] = methodColor,
	["GetJustifyH"] = methodColor,
	["GetJustifyV"] = methodColor,
	["GetLeft"] = methodColor,
	["GetLight"] = methodColor,
	["GetLoopState"] = methodColor,
	["GetLooping"] = methodColor,
	["GetLowerBackgroundFileName"] = methodColor,
	["GetLowerEmblemFileName"] = methodColor,
	["GetLowerEmblemTexture"] = methodColor,
	["GetMaxBytes"] = methodColor,
	["GetMaxFramerate"] = methodColor,
	["GetMaxLetters"] = methodColor,
	["GetMaxLines"] = methodColor,
	["GetMaxOrder"] = methodColor,
	["GetMaxResize"] = methodColor,
	["GetMessageInfo"] = methodColor,
	["GetMinMaxValues"] = methodColor,
	["GetMinResize"] = methodColor,
	["GetMinimumWidth"] = methodColor,
	["GetModel"] = methodColor,
	["GetModelScale"] = methodColor,
	["GetMotionScriptsWhileDisabled"] = methodColor,
	["GetName"] = methodColor,
	["GetNonBlocking"] = methodColor,
	["GetNormalFontObject"] = methodColor,
	["GetNormalTexture"] = methodColor,
	["GetNumChildren"] = methodColor,
	["GetNumLetters"] = methodColor,
	["GetNumLinesDisplayed"] = methodColor,
	["GetNumMessages"] = methodColor,
	["GetNumPoints"] = methodColor,
	["GetNumRegions"] = methodColor,
	["GetNumTooltips"] = methodColor,
	["GetNumber"] = methodColor,
	["GetObjectType"] = methodColor,
	["GetOffset"] = methodColor,
	["GetOrder"] = methodColor,
	["GetOrientation"] = methodColor,
	["GetOrigin"] = methodColor,
	["GetOwner"] = methodColor,
	["GetPadding"] = methodColor,
	["GetParent"] = methodColor,
	["GetPingPosition"] = methodColor,
	["GetPoint"] = methodColor,
	["GetPosition"] = methodColor,
	["GetProgress"] = methodColor,
	["GetProgressWithDelay"] = methodColor,
	["GetPushedTextOffset"] = methodColor,
	["GetPushedTexture"] = methodColor,
	["GetRadians"] = methodColor,
	["GetRect"] = methodColor,
	["GetRegionParent"] = methodColor,
	["GetRegions"] = methodColor,
	["GetReverse"] = methodColor,
	["GetRight"] = methodColor,
	["GetRotatesTexture"] = methodColor,
	["GetScale"] = methodColor,
	["GetScript"] = methodColor,
	["GetScrollChild"] = methodColor,
	["GetShadowColor"] = methodColor,
	["GetShadowOffset"] = methodColor,
	["GetSize"] = methodColor,
	["GetSmoothProgress"] = methodColor,
	["GetSmoothing"] = methodColor,
	["GetSpacing"] = methodColor,
	["GetSpell"] = methodColor,
	["GetStartDelay"] = methodColor,
	["GetStatusBarColor"] = methodColor,
	["GetStatusBarTexture"] = methodColor,
	["GetStringHeight"] = methodColor,
	["GetStringWidth"] = methodColor,
	["GetTexCoord"] = methodColor,
	["GetText"] = methodColor,
	["GetTextColor"] = methodColor,
	["GetTextHeight"] = methodColor,
	["GetTextInsets"] = methodColor,
	["GetTextWidth"] = methodColor,
	["GetTexture"] = methodColor,
	["GetThumbTexture"] = methodColor,
	["GetTimeVisible"] = methodColor,
	["GetTitleRegion"] = methodColor,
	["GetTooltipIndex"] = methodColor,
	["GetTop"] = methodColor,
	["GetUTF8CursorPosition"] = methodColor,
	["GetUnit"] = methodColor,
	["GetUpperBackgroundFileName"] = methodColor,
	["GetUpperEmblemFileName"] = methodColor,
	["GetUpperEmblemTexture"] = methodColor,
	["GetValue"] = methodColor,
	["GetValueStep"] = methodColor,
	["GetVertTile"] = methodColor,
	["GetVertexColor"] = methodColor,
	["GetVerticalScroll"] = methodColor,
	["GetVerticalScrollRange"] = methodColor,
	["GetWidth"] = methodColor,
	["GetZoom"] = methodColor,
	["GetZoomLevels"] = methodColor,
	["HasFocus"] = methodColor,
	["HasScript"] = methodColor,
	["Hide"] = methodColor,
	["HighlightText"] = methodColor,
	["HookScript"] = methodColor,
	["IgnoreDepth"] = methodColor,
	["InitializeTabardColors"] = methodColor,
	["Insert"] = methodColor,
	["IsAutoFocus"] = methodColor,
	["IsClampedToScreen"] = methodColor,
	["IsCountInvisibleLetters"] = methodColor,
	["IsDelaying"] = methodColor,
	["IsDesaturated"] = methodColor,
	["IsDone"] = methodColor,
	["IsDragging"] = methodColor,
	["IsEnabled"] = methodColor,
	["IsEquippedItem"] = methodColor,
	["IsEventRegistered"] = methodColor,
	["IsIgnoringDepth"] = methodColor,
	["IsInIMECompositionMode"] = methodColor,
	["IsJoystickEnabled"] = methodColor,
	["IsKeyboardEnabled"] = methodColor,
	["IsMouseEnabled"] = methodColor,
	["IsMouseOver"] = methodColor,
	["IsMouseWheelEnabled"] = methodColor,
	["IsMovable"] = methodColor,
	["IsMultiLine"] = methodColor,
	["IsNumeric"] = methodColor,
	["IsObjectType"] = methodColor,
	["IsOwned"] = methodColor,
	["IsPassword"] = methodColor,
	["IsPaused"] = methodColor,
	["IsPendingFinish"] = methodColor,
	["IsPlaying"] = methodColor,
	["IsProtected"] = methodColor,
	["IsResizable"] = methodColor,
	["IsShown"] = methodColor,
	["IsStopped"] = methodColor,
	["IsToplevel"] = methodColor,
	["IsUnit"] = methodColor,
	["IsUserPlaced"] = methodColor,
	["IsVisible"] = methodColor,
	["LockHighlight"] = methodColor,
	["Lower"] = methodColor,
	["NumLines"] = methodColor,
	["PageDown"] = methodColor,
	["PageUp"] = methodColor,
	["Pause"] = methodColor,
	["PingLocation"] = methodColor,
	["Play"] = methodColor,
	["Raise"] = methodColor,
	["RefreshUnit"] = methodColor,
	["RegisterAllEvents"] = methodColor,
	["RegisterEvent"] = methodColor,
	["RegisterForClicks"] = methodColor,
	["RegisterForDrag"] = methodColor,
	["RemoveMessagesByAccessID"] = methodColor,
	["ReplaceIconTexture"] = methodColor,
	["Save"] = methodColor,
	["ScrollDown"] = methodColor,
	["ScrollToBottom"] = methodColor,
	["ScrollToTop"] = methodColor,
	["ScrollUp"] = methodColor,
	["SetAction"] = methodColor,
	["SetAllPoints"] = methodColor,
	["SetAlpha"] = methodColor,
	["SetAlphaGradient"] = methodColor,
	["SetAltArrowKeyMode"] = methodColor,
	["SetAnchorType"] = methodColor,
	["SetAttribute"] = methodColor,
	["SetAuctionItem"] = methodColor,
	["SetAuctionSellItem"] = methodColor,
	["SetAutoFocus"] = methodColor,
	["SetBackdrop"] = methodColor,
	["SetBackdropBorderColor"] = methodColor,
	["SetBackdropColor"] = methodColor,
	["SetBackpackToken"] = methodColor,
	["SetBagItem"] = methodColor,
	["SetBlendMode"] = methodColor,
	["SetBlinkSpeed"] = methodColor,
	["SetBlipTexture"] = methodColor,
	["SetBorderAlpha"] = methodColor,
	["SetBorderScalar"] = methodColor,
	["SetBorderTexture"] = methodColor,
	["SetButtonState"] = methodColor,
	["SetBuybackItem"] = methodColor,
	["SetCamera"] = methodColor,
	["SetChange"] = methodColor,
	["SetChecked"] = methodColor,
	["SetCheckedTexture"] = methodColor,
	["SetClampRectInsets"] = methodColor,
	["SetClampedToScreen"] = methodColor,
	["SetClassBlipTexture"] = methodColor,
	["SetColorHSV"] = methodColor,
	["SetColorRGB"] = methodColor,
	["SetColorValueTexture"] = methodColor,
	["SetColorValueThumbTexture"] = methodColor,
	["SetColorWheelTexture"] = methodColor,
	["SetColorWheelThumbTexture"] = methodColor,
	["SetCooldown"] = methodColor,
	["SetCorpsePOIArrowTexture"] = methodColor,
	["SetCountInvisibleLetters"] = methodColor,
	["SetCreature"] = methodColor,
	["SetCurrencyToken"] = methodColor,
	["SetCursorPosition"] = methodColor,
	["SetCurve"] = methodColor,
	["SetDegrees"] = methodColor,
	["SetDepth"] = methodColor,
	["SetDesaturated"] = methodColor,
	["SetDisabledCheckedTexture"] = methodColor,
	["SetDisabledFontObject"] = methodColor,
	["SetDisabledTexture"] = methodColor,
	["SetDontSavePosition"] = methodColor,
	["SetDrawEdge"] = methodColor,
	["SetDrawLayer"] = methodColor,
	["SetDuration"] = methodColor,
	["SetEndDelay"] = methodColor,
	["SetEquipmentSet"] = methodColor,
	["SetExistingSocketGem"] = methodColor,
	["SetFacing"] = methodColor,
	["SetFadeDuration"] = methodColor,
	["SetFading"] = methodColor,
	["SetFillAlpha"] = methodColor,
	["SetFillTexture"] = methodColor,
	["SetFocus"] = methodColor,
	["SetFogColor"] = methodColor,
	["SetFogFar"] = methodColor,
	["SetFogNear"] = methodColor,
	["SetFont"] = methodColor,
	["SetFontObject"] = methodColor,
	["SetFontString"] = methodColor,
	["SetFormattedText"] = methodColor,
	["SetFrameLevel"] = methodColor,
	["SetFrameStack"] = methodColor,
	["SetFrameStrata"] = methodColor,
	["SetGlow"] = methodColor,
	["SetGlyph"] = methodColor,
	["SetGradient"] = methodColor,
	["SetGradientAlpha"] = methodColor,
	["SetGuildBankItem"] = methodColor,
	["SetHeight"] = methodColor,
	["SetHighlightFontObject"] = methodColor,
	["SetHighlightTexture"] = methodColor,
	["SetHistoryLines"] = methodColor,
	["SetHitRectInsets"] = methodColor,
	["SetHorizTile"] = methodColor,
	["SetHorizontalScroll"] = methodColor,
	["SetHyperlink"] = methodColor,
	["SetHyperlinkCompareItem"] = methodColor,
	["SetHyperlinkFormat"] = methodColor,
	["SetHyperlinksEnabled"] = methodColor,
	["SetID"] = methodColor,
	["SetIconTexture"] = methodColor,
	["SetInboxItem"] = methodColor,
	["SetIndentedWordWrap"] = methodColor,
	["SetInitialOffset"] = methodColor,
	["SetInsertMode"] = methodColor,
	["SetInventoryItem"] = methodColor,
	["SetJustifyH"] = methodColor,
	["SetJustifyV"] = methodColor,
	["SetLFGCompletionReward"] = methodColor,
	["SetLFGDungeonReward"] = methodColor,
	["SetLight"] = methodColor,
	["SetLooping"] = methodColor,
	["SetLootItem"] = methodColor,
	["SetLootRollItem"] = methodColor,
	["SetMaskTexture"] = methodColor,
	["SetMaxBytes"] = methodColor,
	["SetMaxFramerate"] = methodColor,
	["SetMaxLetters"] = methodColor,
	["SetMaxLines"] = methodColor,
	["SetMaxResize"] = methodColor,
	["SetMerchantCostItem"] = methodColor,
	["SetMerchantItem"] = methodColor,
	["SetMergeThreshold"] = methodColor,
	["SetMinMaxValues"] = methodColor,
	["SetMinResize"] = methodColor,
	["SetMinimumWidth"] = methodColor,
	["SetModel"] = methodColor,
	["SetModelScale"] = methodColor,
	["SetMotionScriptsWhileDisabled"] = methodColor,
	["SetMovable"] = methodColor,
	["SetMultiLine"] = methodColor,
	["SetNonBlocking"] = methodColor,
	["SetNonSpaceWrap"] = methodColor,
	["SetNormalFontObject"] = methodColor,
	["SetNormalTexture"] = methodColor,
	["SetNumSplinePoints"] = methodColor,
	["SetNumber"] = methodColor,
	["SetNumeric"] = methodColor,
	["SetOffset"] = methodColor,
	["SetOrder"] = methodColor,
	["SetOrientation"] = methodColor,
	["SetOrigin"] = methodColor,
	["SetOwner"] = methodColor,
	["SetPOIArrowTexture"] = methodColor,
	["SetPadding"] = methodColor,
	["SetParent"] = methodColor,
	["SetPassword"] = methodColor,
	["SetPetAction"] = methodColor,
	["SetPlayerTexture"] = methodColor,
	["SetPlayerTextureHeight"] = methodColor,
	["SetPlayerTextureWidth"] = methodColor,
	["SetPoint"] = methodColor,
	["SetPosition"] = methodColor,
	["SetPossession"] = methodColor,
	["SetPushedTextOffset"] = methodColor,
	["SetPushedTexture"] = methodColor,
	["SetQuestItem"] = methodColor,
	["SetQuestLogItem"] = methodColor,
	["SetQuestLogRewardSpell"] = methodColor,
	["SetQuestLogSpecialItem"] = methodColor,
	["SetQuestRewardSpell"] = methodColor,
	["SetRadians"] = methodColor,
	["SetResizable"] = methodColor,
	["SetReverse"] = methodColor,
	["SetRotatesTexture"] = methodColor,
	["SetRotation"] = methodColor,
	["SetScale"] = methodColor,
	["SetScript"] = methodColor,
	["SetScrollChild"] = methodColor,
	["SetScrollOffset"] = methodColor,
	["SetSendMailItem"] = methodColor,
	["SetSequence"] = methodColor,
	["SetSequenceTime"] = methodColor,
	["SetShadowColor"] = methodColor,
	["SetShadowOffset"] = methodColor,
	["SetShapeshift"] = methodColor,
	["SetSize"] = methodColor,
	["SetSmoothProgress"] = methodColor,
	["SetSmoothing"] = methodColor,
	["SetSocketGem"] = methodColor,
	["SetSocketedItem"] = methodColor,
	["SetSpacing"] = methodColor,
	["SetSpell"] = methodColor,
	["SetSpellByID"] = methodColor,
	["SetStartDelay"] = methodColor,
	["SetStaticPOIArrowTexture"] = methodColor,
	["SetStatusBarColor"] = methodColor,
	["SetStatusBarTexture"] = methodColor,
	["SetTalent"] = methodColor,
	["SetTexCoord"] = methodColor,
	["SetText"] = methodColor,
	["SetTextColor"] = methodColor,
	["SetTextHeight"] = methodColor,
	["SetTextInsets"] = methodColor,
	["SetTexture"] = methodColor,
	["SetThumbTexture"] = methodColor,
	["SetTimeVisible"] = methodColor,
	["SetToplevel"] = methodColor,
	["SetTotem"] = methodColor,
	["SetTracking"] = methodColor,
	["SetTradePlayerItem"] = methodColor,
	["SetTradeSkillItem"] = methodColor,
	["SetTradeTargetItem"] = methodColor,
	["SetTrainerService"] = methodColor,
	["SetUnit"] = methodColor,
	["SetUnitAura"] = methodColor,
	["SetUnitBuff"] = methodColor,
	["SetUnitDebuff"] = methodColor,
	["SetUserPlaced"] = methodColor,
	["SetValue"] = methodColor,
	["SetValueStep"] = methodColor,
	["SetVertTile"] = methodColor,
	["SetVertexColor"] = methodColor,
	["SetVerticalScroll"] = methodColor,
	["SetWidth"] = methodColor,
	["SetWordWrap"] = methodColor,
	["SetZoom"] = methodColor,
	["Show"] = methodColor,
	["StartMovie"] = methodColor,
	["StartMoving"] = methodColor,
	["StartSizing"] = methodColor,
	["Stop"] = methodColor,
	["StopAnimating"] = methodColor,
	["StopMovie"] = methodColor,
	["StopMovingOrSizing"] = methodColor,
	["ToggleInputLanguage"] = methodColor,
	["TryOn"] = methodColor,
	["Undress"] = methodColor,
	["UnlockHighlight"] = methodColor,
	["UnregisterAllEvents"] = methodColor,
	["UnregisterEvent"] = methodColor,
	["UpdateColorByID"] = methodColor,
	["UpdateMouseOverTooltip"] = methodColor,
	["UpdateQuestPOI"] = methodColor,
	["UpdateScrollChildRect"] = methodColor,
	
	["ADDON_LOADED"] = eventColor,
	["Ace2_AddonDisabled"] = eventColor,
	["Ace2_AddonEnabled"] = eventColor,
	["AceEvent20EditBox"] = eventColor,
	["AceEvent20Frame"] = eventColor,
	["AceEvent_FullyInitialized"] = eventColor,
	["AceLibrary"] = eventColor,
	["AcquireDBNamespace"] = eventColor,
	["CHAT_MSG_ADDON"] = eventColor,
	["CHAT_MSG_CHANNEL"] = eventColor,
	["CHAT_MSG_CHANNEL_JOIN"] = eventColor,
	["CHAT_MSG_CHANNEL_LEAVE"] = eventColor,
	["CHAT_MSG_CHANNEL_LIST"] = eventColor,
	["CHAT_MSG_CHANNEL_NOTICE"] = eventColor,
	["CHAT_MSG_SYSTEM"] = eventColor,
	["CallMethodOnAllModules"] = eventColor,
	["CancelAllCombatSchedules"] = eventColor,
	["CancelAllScheduledEvents"] = eventColor,
	["CancelScheduledEvent"] = eventColor,
	["ChatThrottleLib"] = eventColor,
	["Classpool"] = eventColor,
	["CopyProfileFrom"] = eventColor,
	["CustomDebug"] = eventColor,
	["CustomLevelDebug"] = eventColor,
	["CustomPrint"] = eventColor,
	["Debug"] = eventColor,
	["DeleteProfile"] = eventColor,
	["Despool"] = eventColor,
	["Enqueue"] = eventColor,
	["Execute"] = eventColor,
	["Factory"] = eventColor,
	["GetAceOptionsDataTable"] = eventColor,
	["GetDebugLevel"] = eventColor,
	["GetDebugPrefix"] = eventColor,
	["GetInstance"] = eventColor,
	["GetLibrary"] = eventColor,
	["GetLibraryVersion"] = eventColor,
	["GetLocalizedCategory"] = eventColor,
	["GetModule"] = eventColor,
	["GetProfile"] = eventColor,
	["HasInstance"] = eventColor,
	["HasModule"] = eventColor,
	["Hook"] = eventColor,
	["HookReport"] = eventColor,
	["HookScript"] = eventColor,
	["Hook_SendAddonMessage"] = eventColor,
	["Hook_SendChatMessage"] = eventColor,
	["Init"] = eventColor,
	["InitializeAddon"] = eventColor,
	["InitializeDB"] = eventColor,
	["InjectAceOptionsTable"] = eventColor,
	["IsActive"] = eventColor,
	["IsBucketEventRegistered"] = eventColor,
	["IsCommRegistered"] = eventColor,
	["IsDebugging"] = eventColor,
	["IsEventRegistered"] = eventColor,
	["IsEventScheduled"] = eventColor,
	["IsFullyInitialized"] = eventColor,
	["IsHooked"] = eventColor,
	["IsModule"] = eventColor,
	["IsModuleActive"] = eventColor,
	["IsNewVersion"] = eventColor,
	["IsTabCompletionRegistered"] = eventColor,
	["IsUserInChannel"] = eventColor,
	["IterateLibraries"] = eventColor,
	["IterateModules"] = eventColor,
	["IterateModulesWithMethod"] = eventColor,
	["LevelDebug"] = eventColor,
	["LibStub"] = eventColor,
	["ManualDisable"] = eventColor,
	["ManualEnable"] = eventColor,
	["NewLibrary"] = eventColor,
	["NewModule"] = eventColor,
	["ORIG_SendAddonMessage"] = eventColor,
	["ORIG_SendChatMessage"] = eventColor,
	["OnEmbedDisable"] = eventColor,
	["OnEmbedInitialize"] = eventColor,
	["OnEmbedProfileDisable"] = eventColor,
	["OnEvent"] = eventColor,
	["OnInstanceInit"] = eventColor,
	["OnManualEmbed"] = eventColor,
	["OnTabPressed"] = eventColor,
	["OnUpdate"] = eventColor,
	["PLAYER_GUILD_UPDATE"] = eventColor,
	["PLAYER_LOGIN"] = eventColor,
	["PLAYER_LOGOUT"] = eventColor,
	["PLAYER_REGEN_DISABLED"] = eventColor,
	["PLAYER_REGEN_ENABLED"] = eventColor,
	["Print"] = eventColor,
	["PrintComma"] = eventColor,
	["PrintLiteral"] = eventColor,
	["QueryAddonVersion"] = eventColor,
	["Register"] = eventColor,
	["RegisterAddonVersionReceptor"] = eventColor,
	["RegisterAllEvents"] = eventColor,
	["RegisterBucketEvent"] = eventColor,
	["RegisterChatCommand"] = eventColor,
	["RegisterComm"] = eventColor,
	["RegisterDB"] = eventColor,
	["RegisterDefaults"] = eventColor,
	["RegisterEvent"] = eventColor,
	["RegisterMemoizations"] = eventColor,
	["RegisterTabCompletion"] = eventColor,
	["ResetDB"] = eventColor,
	["ScheduleEvent"] = eventColor,
	["ScheduleLeaveCombatAction"] = eventColor,
	["ScheduleRepeatingEvent"] = eventColor,
	["SecureHook"] = eventColor,
	["SecureHookScript"] = eventColor,
	["SendAddonMessage"] = eventColor,
	["SendChatMessage"] = eventColor,
	["SendCommMessage"] = eventColor,
	["SendPrioritizedCommMessage"] = eventColor,
	["SetCommPrefix"] = eventColor,
	["SetDebugLevel"] = eventColor,
	["SetDebugging"] = eventColor,
	["SetDefaultCommPriority"] = eventColor,
	["SetModuleClass"] = eventColor,
	["SetModuleDefaultState"] = eventColor,
	["SetModuleMixins"] = eventColor,
	["SetProfile"] = eventColor,
	["TabCompleteInfo"] = eventColor,
	["ToString"] = eventColor,
	["ToggleActive"] = eventColor,
	["ToggleModuleActive"] = eventColor,
	["TriggerEvent"] = eventColor,
	["Unhook"] = eventColor,
	["UnhookAll"] = eventColor,
	["UnregisterAllBucketEvents"] = eventColor,
	["UnregisterAllComms"] = eventColor,
	["UnregisterAllEvents"] = eventColor,
	["UnregisterBucketEvent"] = eventColor,
	["UnregisterComm"] = eventColor,
	["UnregisterEvent"] = eventColor,
	["UnregisterTabCompletion"] = eventColor,
	["UpdateAvail"] = eventColor,
	["ZONE_CHANGED_NEW_AREA"] = eventColor,
	["argCheck"] = eventColor,
	["embed"] = eventColor,
	["error"] = eventColor,
	["inherits"] = eventColor,
	["keybindingValidateFunc"] = eventColor,
	["new"] = eventColor,
	["pcall"] = eventColor,
	
	["Ace3"] = AceColor,
	["AceAddon30Frame"] = AceColor,
	["AceComm30Frame"] = AceColor,
	["AceEvent30Frame"] = AceColor,
	["AceTimer30Frame"] = AceColor,
	["AddToBlizOptions"] = AceColor,
	["CancelAllTimers"] = AceColor,
	["CancelTimer"] = AceColor,
	["ChatThrottleLib"] = AceColor,
	["ClearFocus"] = AceColor,
	["Close"] = AceColor,
	["CloseAll"] = AceColor,
	["ConfigTableChanged"] = AceColor,
	["Create"] = AceColor,
	["CreateChatCommand"] = AceColor,
	["Deserialize"] = AceColor,
	["Despool"] = AceColor,
	["Disable"] = AceColor,
	["DisableAddon"] = AceColor,
	["DisableModule"] = AceColor,
	["Embed"] = AceColor,
	["EmbedLibraries"] = AceColor,
	["EmbedLibrary"] = AceColor,
	["Enable"] = AceColor,
	["EnableAddon"] = AceColor,
	["EnableModule"] = AceColor,
	["Enqueue"] = AceColor,
	["FeedGroup"] = AceColor,
	["GetAddon"] = AceColor,
	["GetArgs"] = AceColor,
	["GetChatCommandOptions"] = AceColor,
	["GetLayout"] = AceColor,
	["GetLibrary"] = AceColor,
	["GetLocale"] = AceColor,
	["GetModule"] = AceColor,
	["GetName"] = AceColor,
	["GetNextWidgetNum"] = AceColor,
	["GetOptionsTable"] = AceColor,
	["GetStatusTable"] = AceColor,
	["GetWidgetCount"] = AceColor,
	["GetWidgetVersion"] = AceColor,
	["HandleCommand"] = AceColor,
	["Hook"] = AceColor,
	["HookScript"] = AceColor,
	["Hook_SendAddonMessage"] = AceColor,
	["Hook_SendChatMessage"] = AceColor,
	["Init"] = AceColor,
	["InitializeAddon"] = AceColor,
	["IsEnabled"] = AceColor,
	["IsHooked"] = AceColor,
	["IsModule"] = AceColor,
	["IsTabCompletionRegistered"] = AceColor,
	["IterateAddonStatus"] = AceColor,
	["IterateAddons"] = AceColor,
	["IterateChatCommands"] = AceColor,
	["IterateEmbeds"] = AceColor,
	["IterateEmbedsOnAddon"] = AceColor,
	["IterateLibraries"] = AceColor,
	["IterateModules"] = AceColor,
	["IterateModulesOfAddon"] = AceColor,
	["IterateOptionsTables"] = AceColor,
	["LibStub"] = AceColor,
	["New"] = AceColor,
	["NewAddon"] = AceColor,
	["NewLibrary"] = AceColor,
	["NewLocale"] = AceColor,
	["NewModule"] = AceColor,
	["NotifyChange"] = AceColor,
	["OnEmbedDisable"] = AceColor,
	["OnEmbedEnable"] = AceColor,
	["OnEvent"] = AceColor,
	["OnInitialize"] = AceColor,
	["OnReceiveMultipartFirst"] = AceColor,
	["OnReceiveMultipartLast"] = AceColor,
	["OnReceiveMultipartNext"] = AceColor,
	["OnTabPressed"] = AceColor,
	["OnUpdate"] = AceColor,
	["Open"] = AceColor,
	["Print"] = AceColor,
	["PrintCmd"] = AceColor,
	["Printf"] = AceColor,
	["RawHook"] = AceColor,
	["RawHookScript"] = AceColor,
	["RegisterAsContainer"] = AceColor,
	["RegisterAsWidget"] = AceColor,
	["RegisterBucketEvent"] = AceColor,
	["RegisterBucketMessage"] = AceColor,
	["RegisterCallback"] = AceColor,
	["RegisterChatCommand"] = AceColor,
	["RegisterComm"] = AceColor,
	["RegisterEvent"] = AceColor,
	["RegisterLayout"] = AceColor,
	["RegisterMessage"] = AceColor,
	["RegisterOptionsTable"] = AceColor,
	["RegisterTabCompletion"] = AceColor,
	["RegisterWidgetType"] = AceColor,
	["Release"] = AceColor,
	["ScheduleRepeatingTimer"] = AceColor,
	["ScheduleTimer"] = AceColor,
	["SecureHook"] = AceColor,
	["SecureHookScript"] = AceColor,
	["SelectGroup"] = AceColor,
	["SendAddonMessage"] = AceColor,
	["SendChatMessage"] = AceColor,
	["SendCommMessage"] = AceColor,
	["SendMessage"] = AceColor,
	["Serialize"] = AceColor,
	["SetDefaultModuleLibraries"] = AceColor,
	["SetDefaultModulePrototype"] = AceColor,
	["SetDefaultModuleState"] = AceColor,
	["SetDefaultSize"] = AceColor,
	["SetEnabledState"] = AceColor,
	["SetFocus"] = AceColor,
	["TimeLeft"] = AceColor,
	["Unhook"] = AceColor,
	["UnhookAll"] = AceColor,
	["UnregisterAllBuckets"] = AceColor,
	["UnregisterAllCallbacks"] = AceColor,
	["UnregisterAllComm"] = AceColor,
	["UnregisterAllEvents"] = AceColor,
	["UnregisterAllMessages"] = AceColor,
	["UnregisterBucket"] = AceColor,
	["UnregisterCallback"] = AceColor,
	["UnregisterChatCommand"] = AceColor,
	["UnregisterComm"] = AceColor,
	["UnregisterEvent"] = AceColor,
	["UnregisterMessage"] = AceColor,
	["UnregisterTabCompletion"] = AceColor,
	["UpdateAvail"] = AceColor,
	["ValidateOptionsTable"] = AceColor,
	["_RegisterComm"] = AceColor,
	
	}
lib.defaultColorTable = defaultColorTable
